@@ -11,11 +11,11 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // Class_audio
 //-----------------------------------------------------------------------------
-class GURA_DLLDECLARE Class_audio : public Class {
+class GURA_DLLDECLARE Class_audio : public ClassFundamental {
 public:
 	Class_audio(Environment *pEnvOuter);
-	virtual void Prepare(Environment &env);
-	virtual bool CastFrom(Environment &env, Signal sig, Value &value, const Declaration *pDecl);
+	virtual void DoPrepare(Environment &env);
+	virtual bool CastFrom(Environment &env, Value &value, ULong flags);
 };
 
 //-----------------------------------------------------------------------------
@@ -32,11 +32,6 @@ public:
 	inline Audio *GetAudio() { return _pAudio.get(); }
 	inline const Audio *GetAudio() const { return _pAudio.get(); }
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-						const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-						const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 };
 
