@@ -9,15 +9,18 @@
 namespace Gura {
 
 //-----------------------------------------------------------------------------
-// Class_error / Object_error
+// Class_error
 //-----------------------------------------------------------------------------
-class GURA_DLLDECLARE Class_error : public Class {
+class GURA_DLLDECLARE Class_error : public ClassFundamental {
 public:
 	Class_error(Environment *pEnvOuter);
-	virtual void Prepare(Environment &env);
-	virtual Object *CreateDescendant(Environment &env, Signal sig, Class *pClass);
+	virtual void DoPrepare(Environment &env);
+	virtual Object *CreateDescendant(Environment &env, Class *pClass);
 };
 
+//-----------------------------------------------------------------------------
+// Object_error
+//-----------------------------------------------------------------------------
 class GURA_DLLDECLARE Object_error : public Object {
 public:
 	Gura_DeclareObjectAccessor(error)
@@ -31,9 +34,6 @@ public:
 	Object_error(const Object_error &obj);
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline const Gura::Error &GetError() const { return _err; }
 };
 
