@@ -11,12 +11,12 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // Class_expr
 //-----------------------------------------------------------------------------
-class GURA_DLLDECLARE Class_expr : public Class {
+class GURA_DLLDECLARE Class_expr : public ClassFundamental {
 public:
 	Class_expr(Environment *pEnvOuter);
-	virtual void Prepare(Environment &env);
-	virtual bool CastFrom(Environment &env, Signal sig, Value &value, const Declaration *pDecl);
-	virtual Object *CreateDescendant(Environment &env, Signal sig, Class *pClass);
+	virtual void DoPrepare(Environment &env);
+	virtual bool CastFrom(Environment &env, Value &value, ULong flags);
+	virtual Object *CreateDescendant(Environment &env, Class *pClass);
 };
 
 //-----------------------------------------------------------------------------
@@ -34,9 +34,6 @@ public:
 						Object(pClass), _pExpr(pExpr) {}
 	Object_expr(const Object_expr &obj);
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 	inline Expr *GetExpr() { return _pExpr.get(); }
 	inline const Expr *GetExpr() const { return _pExpr.get(); }
