@@ -11,10 +11,10 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // Class_help
 //-----------------------------------------------------------------------------
-class GURA_DLLDECLARE Class_help : public Class {
+class GURA_DLLDECLARE Class_help : public ClassFundamental {
 public:
 	Class_help(Environment *pEnvOuter);
-	virtual void Prepare(Environment &env);
+	virtual void DoPrepare(Environment &env);
 };
 
 //-----------------------------------------------------------------------------
@@ -31,11 +31,6 @@ public:
 	inline Help *GetHelp() { return _pHelp.get(); }
 	inline const Help *GetHelp() const { return _pHelp.get(); }
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-						const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-						const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 };
 
