@@ -11,13 +11,14 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // Class_symbol
 //-----------------------------------------------------------------------------
-class GURA_DLLDECLARE Class_symbol : public Class {
+class GURA_DLLDECLARE Class_symbol : public ClassPrimitive {
 public:
 	Class_symbol(Environment *pEnvOuter);
-	virtual void Prepare(Environment &env);
-	virtual bool CastFrom(Environment &env, Signal sig, Value &value, const Declaration *pDecl);
-	virtual bool Serialize(Environment &env, Signal sig, Stream &stream, const Value &value) const;
-	virtual bool Deserialize(Environment &env, Signal sig, Stream &stream, Value &value) const;
+	virtual void DoPrepare(Environment &env);
+	virtual bool CastFrom(Environment &env, Value &value, ULong flags);
+	virtual SerializeFmtVer GetSerializeFmtVer() const;
+	virtual bool Serialize(Environment &env, Stream &stream, const Value &value) const;
+	virtual bool Deserialize(Environment &env, Stream &stream, Value &value, SerializeFmtVer serializeFmtVer) const;
 };
 
 }
