@@ -12,6 +12,13 @@ namespace Gura {
 class GURA_DLLDECLARE Complex : public std::complex<double> {
 public:
 	static const Complex Zero;
+public:
+	inline static void *operator new(size_t size) {
+		return MemoryPool::Allocate(size, "Complex");
+	}
+	inline static void operator delete(void *pv) {
+		MemoryPool::Deallocate(pv);
+	}
 public:
 	inline Complex() : std::complex<double>(0.) {}
 	inline Complex(const Complex &comp) : std::complex<double>(comp) {}
@@ -22,6 +29,7 @@ public:
 	inline static Complex Polar(double abs, double arg) {
 		return Complex(abs * ::cos(arg), abs * ::sin(arg));
 	}
+	inline explicit operator Boolean() const noexcept { return !IsZero(); }
 };
 
 typedef std::vector<Complex> ComplexList;
