@@ -5,6 +5,9 @@
 
 namespace Gura {
 
+static const char *helpDoc_en = R"**(
+)**";
+
 //-----------------------------------------------------------------------------
 // Object_datetime
 //-----------------------------------------------------------------------------
@@ -22,128 +25,6 @@ Object *Object_datetime::Clone() const
 	return new Object_datetime(*this);
 }
 
-bool Object_datetime::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_Symbol(year));
-	symbols.insert(Gura_Symbol(month));
-	symbols.insert(Gura_Symbol(day));
-	symbols.insert(Gura_Symbol(hour));
-	symbols.insert(Gura_Symbol(min));
-	symbols.insert(Gura_Symbol(sec));
-	symbols.insert(Gura_Symbol(usec));
-	symbols.insert(Gura_Symbol(wday));
-	symbols.insert(Gura_Symbol(week));
-	symbols.insert(Gura_Symbol(yday));
-	symbols.insert(Gura_Symbol(unixtime));
-	return true;
-}
-
-Value Object_datetime::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_Symbol(year))) {
-		return Value(static_cast<Number>(_dateTime.GetYear()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(month))) {
-		return Value(static_cast<Number>(_dateTime.GetMonth()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(day))) {
-		return Value(static_cast<Number>(_dateTime.GetDay()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(hour))) {
-		return Value(static_cast<Number>(_dateTime.GetHour()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(min))) {
-		return Value(static_cast<Number>(_dateTime.GetMin()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(sec))) {
-		return Value(static_cast<Number>(_dateTime.GetSec()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(usec))) {
-		return Value(static_cast<Number>(_dateTime.GetUSec()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(wday))) {
-		return Value(static_cast<Number>(_dateTime.GetDayOfWeek()));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(week))) {
-		int wday = _dateTime.GetDayOfWeek();
-		const Symbol *pSymbol =
-			(wday == 0)? Gura_Symbol(sunday) :
-			(wday == 1)? Gura_Symbol(monday) :
-			(wday == 2)? Gura_Symbol(tuesday) :
-			(wday == 3)? Gura_Symbol(wednesday) :
-			(wday == 4)? Gura_Symbol(thursday) :
-			(wday == 5)? Gura_Symbol(friday) :
-			(wday == 6)? Gura_Symbol(saturday) : NULL;
-		if (pSymbol == NULL) return Value::Null; // this must not happen
-		return Value(pSymbol);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(yday))) {
-		return Value(static_cast<Number>(_dateTime.GetDayOfYear() + 1));
-	} else if (pSymbol->IsIdentical(Gura_Symbol(unixtime))) {
-		return Value(static_cast<Number>(_dateTime.GetUnixTime()));
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_datetime::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_Symbol(year))) {
-		long num = value.GetLong();
-		if (num < 0 || num > 9999) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's year");
-			return Value::Null;
-		}
-		_dateTime.SetYear(static_cast<short>(num));
-		return Value(num);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(month))) {
-		long num = value.GetLong();
-		if (num < 1 || num > 12) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's month");
-			return Value::Null;
-		}
-		_dateTime.SetMonth(static_cast<char>(num));
-		return Value(num);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(day))) {
-		long num = value.GetLong();
-		if (num < 1 || num > 31) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's day");
-			return Value::Null;
-		}
-		_dateTime.SetDay(static_cast<char>(num));
-		return Value(num);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(hour))) {
-		long num = value.GetLong();
-		if (num < 0 || num > 23) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's hour");
-			return Value::Null;
-		}
-		_dateTime.SetHour(static_cast<char>(num));
-		return Value(num);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(min))) {
-		long num = value.GetLong();
-		if (num < 0 || num > 59) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's min");
-			return Value::Null;
-		}
-		_dateTime.SetMin(static_cast<char>(num));
-		return Value(num);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(sec))) {
-		long num = value.GetLong();
-		if (num < 0 || num > 59) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's sec");
-			return Value::Null;
-		}
-		_dateTime.SetSec(static_cast<char>(num));
-		return Value(num);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(usec))) {
-		long num = value.GetLong();
-		if (num < 0 || num > 999999) {
-			sig.SetError(ERR_ValueError, "invalid number for datetime's usec");
-			return Value::Null;
-		}
-		_dateTime.SetUSec(num);
-		return Value(num);
-	}
-	return DoGetProp(env, sig, pSymbol, attrs, evaluatedFlag);
-}
-
 String Object_datetime::ToString(bool exprFlag)
 {
 	String str;
@@ -166,15 +47,15 @@ Gura_DeclareFunction(datetime)
 	DeclareArg(env, "year", VTYPE_number, OCCUR_Once, FLAG_None);
 	DeclareArg(env, "month", VTYPE_number, OCCUR_Once, FLAG_None);
 	DeclareArg(env, "day", VTYPE_number, OCCUR_Once, FLAG_None);
-	DeclareArg(env, "hour", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
-	DeclareArg(env, "min", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
-	DeclareArg(env, "sec", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
-	DeclareArg(env, "usec", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "hour", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
+	DeclareArg(env, "min", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
+	DeclareArg(env, "sec", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
+	DeclareArg(env, "usec", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "minsoff", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(env.LookupClass(VTYPE_datetime));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates an instance of `datetime` class based on the specified arguments.\n"
 		"\n"
 		"Explanations of the arguments are shown below:\n"
@@ -195,22 +76,294 @@ Gura_DeclareFunction(datetime)
 
 Gura_ImplementFunction(datetime)
 {
-	short year = static_cast<short>(args.GetLong(0));
-	char month = static_cast<char>(args.GetLong(1));
-	char day = static_cast<char>(args.GetLong(2));
-	long sec = static_cast<long>(args.GetLong(3) * 3600 +
-								args.GetLong(4) * 60 + args.GetLong(5));
-	long usec = args.GetLong(6);
-	long secsOffset = 0;
-	if (args.Is_number(7)) {
-		secsOffset = args.GetLong(7) * 60;
+	Int16 year = arg.GetInt32(0);
+	Int8 month = arg.GetInt8(1);
+	Int8 day = arg.GetInt8(2);
+	Int32 sec = arg.GetInt32(3) * 3600 + arg.GetInt32(4) * 60 + arg.GetInt32(5);
+	Int32 usec = arg.GetInt32(6);
+	Int32 secsOffset = 0;
+	if (arg.Is_number(7)) {
+		secsOffset = arg.GetInt32(7) * 60;
 	} else {
 		secsOffset = OAL::GetSecsOffsetTZ();
 	}
-	return ReturnValue(env, sig, args,
+	return ReturnValue(env, arg,
 		Value(new Object_datetime(env, DateTime(year, month, day, sec, usec, secsOffset))));
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// datetime#year
+Gura_DeclareProperty_RW(datetime, year)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Year value between 1 and 9999."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, year)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetYear()));
+}
+
+Gura_ImplementPropertySetter(datetime, year)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int32 num = value.GetInt32();
+	if (num < 1 || num > 9999) {
+		env.SetError(ERR_ValueError, "datetime#year must be betwen 1 and 9999 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetYear(static_cast<short>(num));
+	return Value(num);
+}
+
+// datetime#month
+Gura_DeclareProperty_RW(datetime, month)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Month value between 1 and 12."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, month)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetMonth()));
+}
+
+Gura_ImplementPropertySetter(datetime, month)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int32 num = value.GetInt32();
+	if (num < 1 || num > 12) {
+		env.SetError(ERR_ValueError, "datetime#month must be between 1 and 12 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetMonth(static_cast<char>(num));
+	return Value(num);
+}
+
+// datetime#day
+Gura_DeclareProperty_RW(datetime, day)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Day value betwen 1 and 31."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, day)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetDay()));
+}
+
+Gura_ImplementPropertySetter(datetime, day)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int32 num = value.GetInt32();
+	if (num < 1 || num > 31) {
+		env.SetError(ERR_ValueError, "datetime#day must be between 1 and 31 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetDay(static_cast<char>(num));
+	return Value(num);
+}
+
+// datetime#hour
+Gura_DeclareProperty_RW(datetime, hour)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Hour value between 0 and 23."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, hour)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetHour()));
+}
+
+Gura_ImplementPropertySetter(datetime, hour)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int8 num = value.GetInt8();
+	if (num < 0 || num > 23) {
+		env.SetError(ERR_ValueError, "datetime#hour must be between 0 and 23 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetHour(num);
+	return Value(num);
+}
+
+// datetime#min
+Gura_DeclareProperty_RW(datetime, min)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Minute value between 0 and 59."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, min)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetMin()));
+}
+
+Gura_ImplementPropertySetter(datetime, min)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int8 num = value.GetInt8();
+	if (num < 0 || num > 59) {
+		env.SetError(ERR_ValueError, "datetime#min must be betwen 0 and 59 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetMin(num);
+	return Value(num);
+}
+
+// datetime#sec
+Gura_DeclareProperty_RW(datetime, sec)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Second value between 0 and 59."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, sec)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetSec()));
+}
+
+Gura_ImplementPropertySetter(datetime, sec)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int8 num = value.GetInt8();
+	if (num < 0 || num > 59) {
+		env.SetError(ERR_ValueError, "datetime#sec must be between 0 and 59 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetSec(num);
+	return Value(num);
+}
+
+// datetime#usec
+Gura_DeclareProperty_RW(datetime, usec)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Milli second value between 0 and 999999."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, usec)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetUSec()));
+}
+
+Gura_ImplementPropertySetter(datetime, usec)
+{
+	DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	Int32 num = value.GetInt32();
+	if (num < 0 || num > 999999) {
+		env.SetError(ERR_ValueError, "datetime#usec must be between 0 and 999999 inclusive");
+		return Value::Nil;
+	}
+	dateTime.SetUSec(num);
+	return Value(num);
+}
+
+// datetime#wday
+Gura_DeclareProperty_R(datetime, wday)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Week day value between 0 and 6."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, wday)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetDayOfWeek()));
+}
+
+// datetime#week
+Gura_DeclareProperty_R(datetime, week)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, week)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	int wday = dateTime.GetDayOfWeek();
+	const Symbol *pSymbol =
+		(wday == 0)? Gura_Symbol(sunday) :
+		(wday == 1)? Gura_Symbol(monday) :
+		(wday == 2)? Gura_Symbol(tuesday) :
+		(wday == 3)? Gura_Symbol(wednesday) :
+		(wday == 4)? Gura_Symbol(thursday) :
+		(wday == 5)? Gura_Symbol(friday) :
+		(wday == 6)? Gura_Symbol(saturday) : nullptr;
+	if (pSymbol == nullptr) return Value::Nil; // this must not happen
+	return Value(pSymbol);
+}
+
+// datetime#yday
+Gura_DeclareProperty_R(datetime, yday)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Day in a year between 1 and 366."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, yday)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetDayOfYear() + 1));
+}
+
+// datetime#unixtime
+Gura_DeclareProperty_R(datetime, unixtime)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		"Unixtime."
+		);
+}
+
+Gura_ImplementPropertyGetter(datetime, unixtime)
+{
+	const DateTime &dateTime = Object_datetime::GetObject(valueThis)->GetDateTime();
+	return Value(static_cast<Number>(dateTime.GetUnixTime()));
+}
+
 //-----------------------------------------------------------------------------
 // Implementation of methods
 //-----------------------------------------------------------------------------
@@ -219,15 +372,15 @@ Gura_DeclareMethod(datetime, clrtzoff)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Reduce, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Eliminates timezone offset information from the instance.");
 }
 
 Gura_ImplementMethod(datetime, clrtzoff)
 {
-	DateTime &dateTime = Object_datetime::GetThisObj(args)->GetDateTime();
+	DateTime &dateTime = Object_datetime::GetObjectThis(arg)->GetDateTime();
 	dateTime.ClearTZOffset();
-	return args.GetThis();
+	return arg.GetValueThis();
 }
 
 // datetime#format(format => `w3c)
@@ -235,9 +388,9 @@ Gura_DeclareMethod(datetime, format)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "format", VTYPE_any, OCCUR_Once,
-								FLAG_None, new Expr_Value(Gura_Symbol(w3c)));
+			   FLAG_None, 0, new Expr_Value(Gura_Symbol(w3c)));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"Returns a string of the datetime properties based on the specified format.\n"
 		"For the argument `format`, you can specify either a string of user-specific format\n"
 		"or a symbol of predefined style.\n"
@@ -264,6 +417,7 @@ Gura_DeclareMethod(datetime, format)
 
 Gura_ImplementMethod(datetime, format)
 {
+	Signal &sig = env.GetSignal();
 	static const char *weekNames[] = {
 		"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
 	};
@@ -271,11 +425,11 @@ Gura_ImplementMethod(datetime, format)
 		"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 		"Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
 	};
-	const DateTime &dateTime = Object_datetime::GetThisObj(args)->GetDateTime();
-	if (args.Is_string(0)) {
-		return Value(dateTime.ToString(args.GetString(0)));
-	} else if (args.Is_symbol(0)) {
-		const Symbol *pSymbol = args.GetSymbol(0);
+	const DateTime &dateTime = Object_datetime::GetObjectThis(arg)->GetDateTime();
+	if (arg.Is_string(0)) {
+		return Value(dateTime.ToString(arg.GetString(0)));
+	} else if (arg.Is_symbol(0)) {
+		const Symbol *pSymbol = arg.GetSymbol(0);
 		char str[64];
 		if (pSymbol->IsIdentical(Gura_Symbol(w3c))) {
 			::sprintf(str, "%04d-%02d-%02dT%02d:%02d:%02d%s",
@@ -289,8 +443,8 @@ Gura_ImplementMethod(datetime, format)
 				strTZ += dateTime.GetTZOffsetStr(false);
 			}
 			::sprintf(str, "%s, %02d %s %04d %02d:%02d:%02d%s",
-				weekNames[dateTime.GetDayOfWeek()], dateTime.GetDay(),
-				monthNames[dateTime.GetMonth()], dateTime.GetYear(),
+				weekNames[static_cast<int>(dateTime.GetDayOfWeek())], dateTime.GetDay(),
+				monthNames[static_cast<int>(dateTime.GetMonth())], dateTime.GetYear(),
 				dateTime.GetHour(), dateTime.GetMin(), dateTime.GetSec(),
 				strTZ.c_str());
 		} else if (pSymbol->IsIdentical(Gura_Symbol(asctime))) {
@@ -300,18 +454,18 @@ Gura_ImplementMethod(datetime, format)
 				strTZ += dateTime.GetTZOffsetStr(false);
 			}
 			::sprintf(str, "%s %s %2d %02d:%02d:%02d%s %04d",
-				weekNames[dateTime.GetDayOfWeek()],
-				monthNames[dateTime.GetMonth()], dateTime.GetDay(),
+				weekNames[static_cast<int>(dateTime.GetDayOfWeek())],
+				monthNames[static_cast<int>(dateTime.GetMonth())], dateTime.GetDay(),
 				dateTime.GetHour(), dateTime.GetMin(), dateTime.GetSec(),
 				strTZ.c_str(), dateTime.GetYear());
 		} else {
 			sig.SetError(ERR_ValueError, "unknown format symbol `%s", pSymbol->GetName());
-			return Value::Null;
+			return Value::Nil;
 		}
 		return Value(str);
 	}
-	SetError_InvalidValType(sig, args.GetValue(0));
-	return Value::Null;
+	SetError_InvalidValType(sig, arg.GetValue(0));
+	return Value::Nil;
 }
 
 // datetime.isleap(year:number):map
@@ -320,13 +474,13 @@ Gura_DeclareClassMethod(datetime, isleap)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "year", VTYPE_number);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns `true` if the specified year is a leap one.");
 }
 
 Gura_ImplementClassMethod(datetime, isleap)
 {
-	return Value(DateTime::IsLeapYear(args.GetShort(0)));
+	return Value(DateTime::IsLeapYear(arg.GetShort(0)));
 }
 
 // datetime.monthdays(year:number, month:number):map {block?}
@@ -337,7 +491,7 @@ Gura_DeclareClassMethod(datetime, monthdays)
 	DeclareArg(env, "month", VTYPE_number);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns a number of days that exists in the specified month.\n"
 		"\n"
 		GURA_HELPTEXT_BLOCK_en("n", "number"));
@@ -345,9 +499,9 @@ Gura_DeclareClassMethod(datetime, monthdays)
 
 Gura_ImplementClassMethod(datetime, monthdays)
 {
-	int year = args.GetInt(0);
-	int month = args.GetInt(1);
-	return ReturnValue(env, sig, args,
+	int year = arg.GetInt(0);
+	int month = arg.GetInt(1);
+	return ReturnValue(env, arg,
 			Value(static_cast<Number>(DateTime::GetDaysOfMonth(year, month))));
 }
 
@@ -358,7 +512,7 @@ Gura_DeclareClassMethod(datetime, now)
 	DeclareAttr(Gura_Symbol(utc));
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `datetime` instance of the current time.\n"
 		"\n"
 		"In default, the timezone offset is set to one in the system setting.\n"
@@ -369,8 +523,8 @@ Gura_DeclareClassMethod(datetime, now)
 
 Gura_ImplementClassMethod(datetime, now)
 {
-	DateTime dateTime = OAL::GetCurDateTime(args.IsSet(Gura_Symbol(utc)));
-	return ReturnValue(env, sig, args, Value(new Object_datetime(env, dateTime)));
+	DateTime dateTime = OAL::GetCurDateTime(arg.IsSet(Gura_Symbol(utc)));
+	return ReturnValue(env, arg, Value(new Object_datetime(env, dateTime)));
 }
 
 // datetime.parse(str:string):map {block?}
@@ -380,7 +534,7 @@ Gura_DeclareClassMethod(datetime, parse)
 	DeclareArg(env, "str", VTYPE_string);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Parses a string that describs date and time information\n"
 		"and returns the `datetime` instance.\n"
 		"\n"
@@ -397,12 +551,13 @@ Gura_DeclareClassMethod(datetime, parse)
 
 Gura_ImplementClassMethod(datetime, parse)
 {
+	Signal &sig = env.GetSignal();
 	DateTime dateTime;
-	if (!dateTime.Parse(args.GetString(0))) {
+	if (!dateTime.Parse(arg.GetString(0))) {
 		sig.SetError(ERR_FormatError, "invalid time format");
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_datetime(env, dateTime)));
+	return ReturnValue(env, arg, Value(new Object_datetime(env, dateTime)));
 }
 
 // datetime#settzoff(mins:number):reduce
@@ -411,28 +566,28 @@ Gura_DeclareMethod(datetime, settzoff)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Reduce, FLAG_None);
 	DeclareArg(env, "mins", VTYPE_number);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Sets timezone offset in minutes.");
 }
 
 Gura_ImplementMethod(datetime, settzoff)
 {
-	DateTime &dateTime = Object_datetime::GetThisObj(args)->GetDateTime();
-	dateTime.SetTZOffset(args.GetLong(0) * 60);
-	return args.GetThis();
+	DateTime &dateTime = Object_datetime::GetObjectThis(arg)->GetDateTime();
+	dateTime.SetTZOffset(arg.GetInt32(0) * 60);
+	return arg.GetValueThis();
 }
 
 // datetime.time(hour:number => 0, minute:number => 0, sec:number => 0, usec:number => 0):map {block?}
 Gura_DeclareClassMethod(datetime, time)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
-	DeclareArg(env, "hour", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
-	DeclareArg(env, "minute", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
-	DeclareArg(env, "sec", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
-	DeclareArg(env, "usec", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "hour", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
+	DeclareArg(env, "minute", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
+	DeclareArg(env, "sec", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
+	DeclareArg(env, "usec", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `datetime` instance from time information.\n"
 		"The date inforomation is set as 1st of January in the Christian year of 0.\n"
 		"\n"
@@ -444,11 +599,10 @@ Gura_ImplementClassMethod(datetime, time)
 	short year = 0;
 	char month = 1;
 	char day = 1;
-	long sec = static_cast<long>(args.GetNumber(0) * 3600 +
-						args.GetNumber(1) * 60 + args.GetNumber(2));
-	long usec = args.GetLong(3);
-	long secsOffset = OAL::GetSecsOffsetTZ();
-	return ReturnValue(env, sig, args,
+	Int32 sec = arg.GetInt32(0) * 3600 + arg.GetInt32(1) * 60 + arg.GetInt32(2);
+	Int32 usec = arg.GetInt32(3);
+	Int32 secsOffset = OAL::GetSecsOffsetTZ();
+	return ReturnValue(env, arg,
 		Value(new Object_datetime(env, DateTime(year, month, day, sec, usec, secsOffset))));
 }
 
@@ -459,7 +613,7 @@ Gura_DeclareClassMethod(datetime, today)
 	DeclareAttr(Gura_Symbol(utc));
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `datetime` instance of today. All the time information are cleared to 0.\n"
 		"\n"
 		"In default, the timezone offset is set to one in the system setting.\n"
@@ -470,9 +624,9 @@ Gura_DeclareClassMethod(datetime, today)
 
 Gura_ImplementClassMethod(datetime, today)
 {
-	DateTime dateTime = OAL::GetCurDateTime(args.IsSet(Gura_Symbol(utc)));
+	DateTime dateTime = OAL::GetCurDateTime(arg.IsSet(Gura_Symbol(utc)));
 	dateTime.ClearTime();
-	return ReturnValue(env, sig, args, Value(new Object_datetime(env, dateTime)));
+	return ReturnValue(env, arg, Value(new Object_datetime(env, dateTime)));
 }
 
 // datetime#utc()
@@ -480,17 +634,18 @@ Gura_DeclareMethod(datetime, utc)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Calculates UTC time of the target `datetime` instance.\n"
 		"An error occurs if the instance has no timezone offset\n");
 }
 
 Gura_ImplementMethod(datetime, utc)
 {
-	const DateTime &dateTime = Object_datetime::GetThisObj(args)->GetDateTime();
+	Signal &sig = env.GetSignal();
+	const DateTime &dateTime = Object_datetime::GetObjectThis(arg)->GetDateTime();
 	if (!dateTime.HasTZOffset()) {
 		sig.SetError(ERR_ValueError, "datetime has no timezone offset");
-		return Value::Null;
+		return Value::Nil;
 	}
 	return Value(new Object_datetime(env, dateTime.ToUTC()));
 }
@@ -503,37 +658,42 @@ Gura_DeclareClassMethod(datetime, weekday)
 	DeclareArg(env, "month", VTYPE_number);
 	DeclareArg(env, "day", VTYPE_number);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns a week number for the specified date, which starts from 0 for Sunday.\n");
 }
 
 Gura_ImplementClassMethod(datetime, weekday)
 {
-	int year = args.GetInt(0);
-	int month = args.GetInt(1);
-	int day = args.GetInt(2);
+	int year = arg.GetInt(0);
+	int month = arg.GetInt(1);
+	int day = arg.GetInt(2);
 	return Value(static_cast<Number>(DateTime::GetDayOfWeek(year, month, day)));
 }
 
 //-----------------------------------------------------------------------------
 // Implementation of class
 //-----------------------------------------------------------------------------
-Class_datetime::Class_datetime(Environment *pEnvOuter) : Class(pEnvOuter, VTYPE_datetime)
+Class_datetime::Class_datetime(Environment *pEnvOuter) : ClassFundamental(pEnvOuter, VTYPE_datetime)
 {
 }
 
-void Class_datetime::Prepare(Environment &env)
+void Class_datetime::DoPrepare(Environment &env)
 {
-	// function assignment
+	// Assignment of function
 	Gura_AssignFunction(datetime);
-	// value assignment
-	Gura_AssignClassValue(Sunday,		Value(0));
-	Gura_AssignClassValue(Monday,		Value(1));
-	Gura_AssignClassValue(Tuesday,		Value(2));
-	Gura_AssignClassValue(Wednesday,	Value(3));
-	Gura_AssignClassValue(Thursday,		Value(4));
-	Gura_AssignClassValue(Friday,		Value(5));
-	Gura_AssignClassValue(Saturday,		Value(6));
+	// Assignment of properties
+	Gura_AssignProperty(datetime, year);
+	Gura_AssignProperty(datetime, month);
+	Gura_AssignProperty(datetime, day);
+	Gura_AssignProperty(datetime, hour);
+	Gura_AssignProperty(datetime, min);
+	Gura_AssignProperty(datetime, sec);
+	Gura_AssignProperty(datetime, usec);
+	Gura_AssignProperty(datetime, wday);
+	Gura_AssignProperty(datetime, week);
+	Gura_AssignProperty(datetime, yday);
+	Gura_AssignProperty(datetime, unixtime);
+	// Assignment of methods
 	Gura_AssignMethod(datetime, clrtzoff);
 	Gura_AssignMethod(datetime, format);
 	Gura_AssignMethod(datetime, isleap);
@@ -545,12 +705,22 @@ void Class_datetime::Prepare(Environment &env)
 	Gura_AssignMethod(datetime, today);
 	Gura_AssignMethod(datetime, utc);
 	Gura_AssignMethod(datetime, weekday);
+	// Assignment of values
+	Gura_AssignClassValue(Sunday,		Value(0));
+	Gura_AssignClassValue(Monday,		Value(1));
+	Gura_AssignClassValue(Tuesday,		Value(2));
+	Gura_AssignClassValue(Wednesday,	Value(3));
+	Gura_AssignClassValue(Thursday,		Value(4));
+	Gura_AssignClassValue(Friday,		Value(5));
+	Gura_AssignClassValue(Saturday,		Value(6));
+	// help document
+	AddHelpTemplate(env, Gura_Symbol(en), helpDoc_en);
 }
 
-Object *Class_datetime::CreateDescendant(Environment &env, Signal sig, Class *pClass)
+Object *Class_datetime::CreateDescendant(Environment &env, Class *pClass)
 {
 	GURA_ERROREND(env, "this function must not be called");
-	return NULL;
+	return nullptr;
 }
 
 }
