@@ -5,6 +5,9 @@
 
 namespace Gura {
 
+static const char *helpDoc_en = R"**(
+)**";
+
 //-----------------------------------------------------------------------------
 // Object_dict
 //-----------------------------------------------------------------------------
@@ -13,32 +16,46 @@ Object *Object_dict::Clone() const
 	return new Object_dict(*this);
 }
 
-Value Object_dict::IndexGet(Environment &env, Signal sig, const Value &valueIdx)
+Value Object_dict::IndexGet(Environment &env, const Value &valueIdx)
 {
+	Signal &sig = GetSignal();
 	const Value *pValue = GetDict().Find(sig, valueIdx);
 	if (sig.IsSignalled()) {
-		return Value::Null;
-	} else if (pValue == NULL) {
-		SetError_KeyNotFound(sig, valueIdx);
-		return Value::Null;
+		return Value::Nil;
+	} else if (pValue == nullptr) {
+		ValueDict::SetError_KeyNotFound(sig, valueIdx);
+		return Value::Nil;
 	}
 	return *pValue;
 }
 
-void Object_dict::IndexSet(Environment &env, Signal sig, const Value &valueIdx, const Value &value)
+void Object_dict::IndexSet(Environment &env, const Value &valueIdx, const Value &value)
 {
-	if (!valueIdx.IsValidKey()) {
-		sig.SetError(ERR_KeyError, "invalid value type for key");
+	Signal &sig = GetSignal();
+	if (!IsWritable()) {
+		ValueDict::SetError_NotWritable(sig);
 		return;
 	}
+	if (!valueIdx.IsValidKey()) {
+		ValueDict::SetError_InvalidKey(sig, valueIdx);
+		return;
+	}
+	InvalidateIterators();
 	GetDict()[valueIdx] = value;
 }
 
-Iterator *Object_dict::CreateIterator(Signal sig)
+Iterator *Object_dict::CreateIterator(Signal &sig)
 {
 	return new IteratorItems(Object_dict::Reference(this));
 }
 
+void Object_dict::InvalidateIterators()
+{
+	foreach (IteratorExList, ppIterator, _iterList) {
+		(*ppIterator)->Invalidate();
+	}
+}
+
 String Object_dict::ToString(bool exprFlag)
 {
 	bool limitLenFlag = true;
@@ -63,27 +80,32 @@ String Object_dict::ToString(bool exprFlag)
 	return str;
 }
 
-void Object_dict::SetError_KeyNotFound(Signal sig, const Value &valueIdx)
-{
-	sig.SetError(ERR_KeyError, "dictionary doesn't have a key '%s'",
-										valueIdx.ToString().c_str());
-}
-
 //-----------------------------------------------------------------------------
 // Object_dict::IteratorKeys
 //-----------------------------------------------------------------------------
 Object_dict::IteratorKeys::IteratorKeys(Object_dict *pObj) :
-				Iterator(false), _pObj(pObj), _pCur(pObj->GetDict().begin())
+	IteratorEx(Finite, pObj), _pCur(pObj->GetDict().begin())
 {
+	_pObj->AddIterator(this);
+}
+
+Object_dict::IteratorKeys::~IteratorKeys()
+{
+	_pObj->RemoveIterator(this);
 }
 
 Iterator *Object_dict::IteratorKeys::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_dict::IteratorKeys::DoNext(Environment &env, Signal sig, Value &value)
+bool Object_dict::IteratorKeys::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
+	if (!_validFlag) {
+		ValueDict::SetError_InvalidIterator(sig);
+		return false;
+	}
 	if (_pCur == _pObj->GetDict().end()) return false;
 	value = _pCur->first;
 	_pCur++;
@@ -103,17 +125,28 @@ void Object_dict::IteratorKeys::GatherFollower(Environment::Frame *pFrame, Envir
 // Object_dict::IteratorValues
 //-----------------------------------------------------------------------------
 Object_dict::IteratorValues::IteratorValues(Object_dict *pObj) :
-				Iterator(false), _pObj(pObj), _pCur(pObj->GetDict().begin())
+	IteratorEx(Finite, pObj), _pCur(pObj->GetDict().begin())
 {
+	_pObj->AddIterator(this);
+}
+
+Object_dict::IteratorValues::~IteratorValues()
+{
+	_pObj->RemoveIterator(this);
 }
 
 Iterator *Object_dict::IteratorValues::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_dict::IteratorValues::DoNext(Environment &env, Signal sig, Value &value)
+bool Object_dict::IteratorValues::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
+	if (!_validFlag) {
+		ValueDict::SetError_InvalidIterator(sig);
+		return false;
+	}
 	if (_pCur == _pObj->GetDict().end()) return false;
 	value = _pCur->second;
 	_pCur++;
@@ -133,21 +166,33 @@ void Object_dict::IteratorValues::GatherFollower(Environment::Frame *pFrame, Env
 // Object_dict::IteratorItems
 //-----------------------------------------------------------------------------
 Object_dict::IteratorItems::IteratorItems(Object_dict *pObj) :
-				Iterator(false), _pObj(pObj), _pCur(pObj->GetDict().begin())
+	IteratorEx(Finite, pObj), _pCur(pObj->GetDict().begin())
 {
+	_pObj->AddIterator(this);
+}
+
+Object_dict::IteratorItems::~IteratorItems()
+{
+	_pObj->RemoveIterator(this);
 }
 
 Iterator *Object_dict::IteratorItems::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_dict::IteratorItems::DoNext(Environment &env, Signal sig, Value &value)
+bool Object_dict::IteratorItems::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
+	if (!_validFlag) {
+		ValueDict::SetError_InvalidIterator(sig);
+		return false;
+	}
 	if (_pCur == _pObj->GetDict().end()) return false;
-	ValueList &valList = value.InitAsList(*_pObj);
-	valList.push_back(_pCur->first);
-	valList.push_back(_pCur->second);
+	Object_list *pObjList = value.InitAsList(*_pObj);
+	pObjList->Reserve(2);
+	pObjList->Add(_pCur->first);
+	pObjList->Add(_pCur->second);
 	_pCur++;
 	return true;
 }
@@ -161,48 +206,6 @@ void Object_dict::IteratorItems::GatherFollower(Environment::Frame *pFrame, Envi
 {
 }
 
-//-----------------------------------------------------------------------------
-// Object_dict::IteratorGet
-//-----------------------------------------------------------------------------
-Object_dict::IteratorGet::IteratorGet(Object_dict *pObj, Iterator *pIteratorKey,
-					const Value &valDefault, bool raiseFlag, bool setDefaultFlag) :
-	Iterator(pIteratorKey->IsInfinite()), _pObj(pObj), _pIteratorKey(pIteratorKey),
-	_valDefault(valDefault), _raiseFlag(raiseFlag), _setDefaultFlag(setDefaultFlag)
-{
-}
-
-Iterator *Object_dict::IteratorGet::GetSource()
-{
-	return NULL;
-}
-
-bool Object_dict::IteratorGet::DoNext(Environment &env, Signal sig, Value &value)
-{
-	Value valueIdx;
-	if (!_pIteratorKey->Next(env, sig, valueIdx)) return false;
-	const Value *pValue = _pObj->GetDict().Find(sig, valueIdx);
-	if (pValue != NULL) {
-		value = *pValue;
-	} else if (_raiseFlag) {
-		Object_dict::SetError_KeyNotFound(sig, valueIdx);
-		return false;
-	} else {
-		value = _valDefault;
-		if (_setDefaultFlag) _pObj->IndexSet(env, sig, valueIdx, value);
-		if (sig.IsSignalled()) return false;
-	}
-	return true;
-}
-
-String Object_dict::IteratorGet::ToString() const
-{
-	return String("dict#get");
-}
-
-void Object_dict::IteratorGet::GatherFollower(Environment::Frame *pFrame, EnvironmentSet &envSet)
-{
-}
-
 //-----------------------------------------------------------------------------
 // Implementation of functions
 //-----------------------------------------------------------------------------
@@ -213,9 +216,11 @@ Gura_DeclareFunction(dict)
 	DeclareArg(env, "elems", VTYPE_any, OCCUR_ZeroOrOnce);
 	DeclareAttr(Gura_Symbol(icase));
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	SetClassToConstruct(env.LookupClass(VTYPE_dict));
+	if (::strcmp(GetName(), "dict") == 0) {
+		SetClassToConstruct(env.LookupClass(VTYPE_dict));
+	}
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `dict` instance.\n"
 		"\n"
 		"It takes a list of key-value pairs in an argument as shown below:\n"
@@ -252,36 +257,36 @@ Gura_DeclareFunction(dict)
 
 Gura_ImplementFunction(dict)
 {
-	Object_dict *pObj = new Object_dict(env, new ValueDict(args.IsSet(Gura_Symbol(icase))));
+	Signal &sig = env.GetSignal();
+	Object_dict *pObj = new Object_dict(env, new ValueDict(arg.IsSet(Gura_Symbol(icase))), true);
 	ValueDict &valDict = pObj->GetDict();
 	ValueDict::StoreMode storeMode = ValueDict::STORE_Strict;
-	if (args.GetValue(0).Is_list()) {
-		if (!valDict.Store(sig, args.GetList(0), storeMode)) {
-			return Value::Null;
+	if (arg.GetValue(0).Is_list()) {
+		if (!valDict.Store(sig, arg.GetList(0), storeMode)) {
+			return Value::Nil;
 		}
-	} else if (args.GetValue(0).Is_dict()) {
-		if (!valDict.Store(sig, args.GetDict(0), storeMode)) {
-			return Value::Null;
+	} else if (arg.GetValue(0).Is_dict()) {
+		if (!valDict.Store(sig, arg.GetDict(0), storeMode)) {
+			return Value::Nil;
 		}
-	} else if (args.IsValid(0)) {
+	} else if (arg.IsValid(0)) {
 		sig.SetError(ERR_ValueError, "invalid argument type");
-		return Value::Null;
+		return Value::Nil;
 	}
-	if (args.IsBlockSpecified()) {
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
-		AutoPtr<Environment> pEnvLister(new Environment(&env, ENVTYPE_lister));
+	if (arg.IsBlockSpecified()) {
+		const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+		if (sig.IsSignalled()) return Value::Nil;
+		AutoPtr<Environment> pEnvLister(env.Derive(ENVTYPE_lister));
 		ValueList valList;
 		foreach_const (ExprOwner, ppExpr, pExprBlock->GetExprOwner()) {
-			SeqPostHandler *pSeqPostHandler = NULL;
-			Value value = (*ppExpr)->Exec2(*pEnvLister, sig, pSeqPostHandler);
+			Value value = (*ppExpr)->Exec(*pEnvLister);
 			if (sig.IsSignalled()) {
 				sig.AddExprCause(*ppExpr);
-				return Value::Null;
+				return Value::Nil;
 			}
 			valList.push_back(value);
 		}
-		if (!valDict.Store(sig, valList, storeMode)) return Value::Null;
+		if (!valDict.Store(sig, valList, storeMode)) return Value::Nil;
 	}
 	return Value(pObj);
 }
@@ -299,7 +304,7 @@ Gura_DeclareMethod(dict, append)
 	DeclareAttr(Gura_Symbol(timid));
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Adds multiple key-value pairs.\n"
 		"It takes a list of key-value pairs in an argument or in a block\n"
 		"that has the same format with one for the function `dict()`.\n"
@@ -314,40 +319,46 @@ Gura_DeclareMethod(dict, append)
 
 Gura_ImplementMethod(dict, append)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
-	ValueDict::StoreMode storeMode =
-		args.IsSet(Gura_Symbol(strict))? ValueDict::STORE_Strict :
-		args.IsSet(Gura_Symbol(timid))? ValueDict::STORE_Timid :
-		ValueDict::STORE_Overwrite;
-	if (args.GetValue(0).Is_list()) {
-		if (!valDict.Store(sig, args.GetList(0), storeMode)) {
-			return Value::Null;
-		}
-	} else if (args.GetValue(0).Is_dict()) {
-		if (!valDict.Store(sig, args.GetDict(0), storeMode)) {
-			return Value::Null;
-		}
-	} else if (args.IsValid(0)) {
-		sig.SetError(ERR_ValueError, "invalid argument type");
-		return Value::Null;
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
+	ValueDict &valDict = pThis->GetDict();
+	Signal &sig = env.GetSignal();
+	if (!pThis->IsWritable()) {
+		ValueDict::SetError_NotWritable(sig);
+		return Value::Nil;
 	}
-	if (args.IsBlockSpecified()) {
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
-		AutoPtr<Environment> pEnvLister(new Environment(&env, ENVTYPE_lister));
+	pThis->InvalidateIterators();
+	ValueDict::StoreMode storeMode =
+		arg.IsSet(Gura_Symbol(strict))? ValueDict::STORE_Strict :
+		arg.IsSet(Gura_Symbol(timid))? ValueDict::STORE_Timid :
+		ValueDict::STORE_Overwrite;
+	if (arg.GetValue(0).Is_list()) {
+		if (!valDict.Store(sig, arg.GetList(0), storeMode)) {
+			return Value::Nil;
+		}
+	} else if (arg.GetValue(0).Is_dict()) {
+		if (!valDict.Store(sig, arg.GetDict(0), storeMode)) {
+			return Value::Nil;
+		}
+	} else if (arg.IsValid(0)) {
+		sig.SetError(ERR_ValueError, "invalid argument type");
+		return Value::Nil;
+	}
+	if (arg.IsBlockSpecified()) {
+		const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+		if (sig.IsSignalled()) return Value::Nil;
+		AutoPtr<Environment> pEnvLister(env.Derive(ENVTYPE_lister));
 		ValueList valList;
 		foreach_const (ExprOwner, ppExpr, pExprBlock->GetExprOwner()) {
-			SeqPostHandler *pSeqPostHandler = NULL;
-			Value value = (*ppExpr)->Exec2(*pEnvLister, sig, pSeqPostHandler);
+			Value value = (*ppExpr)->Exec(*pEnvLister);
 			if (sig.IsSignalled()) {
 				sig.AddExprCause(*ppExpr);
-				return Value::Null;
+				return Value::Nil;
 			}
 			valList.push_back(value);
 		}
-		if (!valDict.Store(sig, valList, storeMode)) return Value::Null;
+		if (!valDict.Store(sig, valList, storeMode)) return Value::Nil;
 	}
-	return args.GetThis();
+	return arg.GetValueThis();
 }
 
 // dict#clear()
@@ -355,15 +366,22 @@ Gura_DeclareMethod(dict, clear)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Clears all the key-value pairs in the dictionary.");
 }
 
 Gura_ImplementMethod(dict, clear)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
+	ValueDict &valDict = pThis->GetDict();
+	Signal &sig = env.GetSignal();
+	if (!pThis->IsWritable()) {
+		ValueDict::SetError_NotWritable(sig);
+		return Value::Nil;
+	}
+	pThis->InvalidateIterators();
 	valDict.clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 // dict#erase(key):map
@@ -372,7 +390,7 @@ Gura_DeclareMethod(dict, erase)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "key", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Erases a key-value pair that mathces the provided `key`.\n"
 		"\n"
 		"The `key` is either `number`, `string` or `symbol`.\n");
@@ -380,9 +398,16 @@ Gura_DeclareMethod(dict, erase)
 
 Gura_ImplementMethod(dict, erase)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
-	valDict.erase(args.GetValue(0));
-	return Value::Null;
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
+	ValueDict &valDict = pThis->GetDict();
+	Signal &sig = env.GetSignal();
+	if (!pThis->IsWritable()) {
+		ValueDict::SetError_NotWritable(sig);
+		return Value::Nil;
+	}
+	pThis->InvalidateIterators();
+	valDict.erase(arg.GetValue(0));
+	return Value::Nil;
 }
 
 // dict#get(key, default?):map:[raise]
@@ -393,7 +418,7 @@ Gura_DeclareMethod(dict, get)
 	DeclareArg(env, "default", VTYPE_any, OCCUR_ZeroOrOnce);
 	DeclareAttr(Gura_Symbol(raise));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Seeks a value that is associated with the specified `key`.\n"
 		"\n"
 		"The method would return `nil` as its default value\n"
@@ -416,17 +441,18 @@ Gura_DeclareMethod(dict, get)
 
 Gura_ImplementMethod(dict, get)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
-	const Value &valueIdx = args.GetValue(0);
-	bool raiseFlag = args.IsSet(Gura_Symbol(raise));
+	Signal &sig = env.GetSignal();
+	ValueDict &valDict = Object_dict::GetObjectThis(arg)->GetDict();
+	const Value &valueIdx = arg.GetValue(0);
+	bool raiseFlag = arg.IsSet(Gura_Symbol(raise));
 	const Value *pValue = valDict.Find(sig, valueIdx);
-	if (pValue != NULL) {
+	if (pValue != nullptr) {
 		return *pValue;
 	} else if (raiseFlag) {
-		Object_dict::SetError_KeyNotFound(sig, valueIdx);
-		return Value::Null;
+		ValueDict::SetError_KeyNotFound(sig, valueIdx);
+		return Value::Nil;
 	} else {
-		const Value &value = args.GetValue(1);
+		const Value &value = arg.GetValue(1);
 		return value;
 	}
 }
@@ -437,16 +463,17 @@ Gura_DeclareMethod(dict, haskey)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "key", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns `true` if the specified `key` exists in the dictionary.\n");
 }
 
 Gura_ImplementMethod(dict, haskey)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
-	const Value &valueIdx = args.GetValue(0);
+	Signal &sig = env.GetSignal();
+	ValueDict &valDict = Object_dict::GetObjectThis(arg)->GetDict();
+	const Value &valueIdx = arg.GetValue(0);
 	const Value *pValue = valDict.Find(sig, valueIdx);
-	return Value(pValue != NULL);
+	return Value(pValue != nullptr);
 }
 
 // dict#items() {block?}
@@ -455,7 +482,7 @@ Gura_DeclareMethod(dict, items)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns an iterator of key-value pairs in the dictionary.\n"
 		"\n"
 		GURA_HELPTEXT_ITERATOR_en());
@@ -463,19 +490,35 @@ Gura_DeclareMethod(dict, items)
 
 Gura_ImplementMethod(dict, items)
 {
-	Object_dict *pThis = Object_dict::GetThisObj(args);
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
 	Object_dict *pObj = Object_dict::Reference(pThis);
-	return ReturnIterator(env, sig, args,
+	return ReturnIterator(env, arg,
 							new Object_dict::IteratorItems(pObj));
 }
 
+// dict#isempty()
+Gura_DeclareMethod(dict, isempty)
+{
+	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
+	DeclareBlock(OCCUR_ZeroOrOnce);
+	AddHelp(
+		Gura_Symbol(en),
+		"Returns `true` is the dictionary contains no entries.\n");
+}
+
+Gura_ImplementMethod(dict, isempty)
+{
+	ValueDict &valDict = Object_dict::GetObjectThis(arg)->GetDict();
+	return Value(valDict.empty());
+}
+
 // dict#keys() {block?}
 Gura_DeclareMethod(dict, keys)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns an iterator of keys in the dictionary.\n"
 		"\n"
 		GURA_HELPTEXT_ITERATOR_en());
@@ -483,9 +526,9 @@ Gura_DeclareMethod(dict, keys)
 
 Gura_ImplementMethod(dict, keys)
 {
-	Object_dict *pThis = Object_dict::GetThisObj(args);
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
 	Object_dict *pObj = Object_dict::Reference(pThis);
-	return ReturnIterator(env, sig, args,
+	return ReturnIterator(env, arg,
 							new Object_dict::IteratorKeys(pObj));
 }
 
@@ -494,13 +537,13 @@ Gura_DeclareMethod(dict, len)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns the number of key-value pairs in the dictionary.");
 }
 
 Gura_ImplementMethod(dict, len)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
+	ValueDict &valDict = Object_dict::GetObjectThis(arg)->GetDict();
 	return Value(static_cast<Number>(valDict.size()));
 }
 
@@ -514,7 +557,7 @@ Gura_DeclareMethod(dict, put)
 	DeclareAttr(Gura_Symbol(strict));
 	DeclareAttr(Gura_Symbol(timid));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Adds a new key-value pair.\n"
 		"\n"
 		"If the specified key already exists in the dictionary, it would be overwritten.\n"
@@ -533,15 +576,22 @@ Gura_DeclareMethod(dict, put)
 
 Gura_ImplementMethod(dict, put)
 {
-	ValueDict &valDict = Object_dict::GetThisObj(args)->GetDict();
-	const Value &valueIdx = args.GetValue(0);
-	const Value &value = args.GetValue(1);
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
+	ValueDict &valDict = pThis->GetDict();
+	Signal &sig = env.GetSignal();
+	if (!pThis->IsWritable()) {
+		ValueDict::SetError_NotWritable(sig);
+		return Value::Nil;
+	}
+	pThis->InvalidateIterators();
+	const Value &valueIdx = arg.GetValue(0);
+	const Value &value = arg.GetValue(1);
 	ValueDict::StoreMode storeMode =
-		args.IsSet(Gura_Symbol(strict))? ValueDict::STORE_Strict :
-		args.IsSet(Gura_Symbol(timid))? ValueDict::STORE_Timid :
+		arg.IsSet(Gura_Symbol(strict))? ValueDict::STORE_Strict :
+		arg.IsSet(Gura_Symbol(timid))? ValueDict::STORE_Timid :
 		ValueDict::STORE_Overwrite;
-	if (!valDict.Store(sig, valueIdx, value, storeMode)) return Value::Null;
-	return args.GetThis();
+	if (!valDict.Store(sig, valueIdx, value, storeMode)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // dict#values() {block?}
@@ -550,7 +600,7 @@ Gura_DeclareMethod(dict, values)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns an iterator of values in the dictionary.\n"
 		"\n"
 		GURA_HELPTEXT_ITERATOR_en());
@@ -558,53 +608,89 @@ Gura_DeclareMethod(dict, values)
 
 Gura_ImplementMethod(dict, values)
 {
-	Object_dict *pThis = Object_dict::GetThisObj(args);
+	Object_dict *pThis = Object_dict::GetObjectThis(arg);
 	Object_dict *pObj = Object_dict::Reference(pThis);
-	return ReturnIterator(env, sig, args,
+	return ReturnIterator(env, arg,
 							new Object_dict::IteratorValues(pObj));
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// dict#writable
+Gura_DeclareProperty_R(dict, writable)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(dict, writable)
+{
+	Object_dict *pThis = Object_dict::GetObject(valueThis);
+	return Value(pThis->IsWritable());
+}
+
 //-----------------------------------------------------------------------------
 // Implementation of class
 //-----------------------------------------------------------------------------
-Class_dict::Class_dict(Environment *pEnvOuter) : Class(pEnvOuter, VTYPE_dict)
+Class_dict::Class_dict(Environment *pEnvOuter) : ClassFundamental(pEnvOuter, VTYPE_dict)
 {
 }
 
-void Class_dict::Prepare(Environment &env)
+void Class_dict::DoPrepare(Environment &env)
 {
+	// Assignment of functions
 	Gura_AssignFunction(dict);
 	Gura_AssignFunctionEx(dict, "%");
+	// Assignment of properties
+	Gura_AssignProperty(dict, writable);
+	// Assignment of methods
 	Gura_AssignMethod(dict, append);
 	Gura_AssignMethod(dict, clear);
 	Gura_AssignMethod(dict, erase);
 	Gura_AssignMethod(dict, get);
 	Gura_AssignMethod(dict, haskey);
 	Gura_AssignMethod(dict, items);
+	Gura_AssignMethod(dict, isempty);
 	Gura_AssignMethod(dict, keys);
 	Gura_AssignMethod(dict, len);
 	Gura_AssignMethod(dict, put);
 	Gura_AssignMethod(dict, values);
+	// help document
+	AddHelpTemplate(env, Gura_Symbol(en), helpDoc_en);
 }
 
-bool Class_dict::Serialize(Environment &env, Signal sig, Stream &stream, const Value &value) const
+Class::SerializeFmtVer Class_dict::GetSerializeFmtVer() const
 {
+	return SerializeFmtVer_1;
+}
+
+bool Class_dict::Serialize(Environment &env, Stream &stream, const Value &value) const
+{
+	Signal &sig = GetSignal();
 	bool ignoreCaseFlag = Object_dict::GetObject(value)->GetIgnoreCaseFlag();
 	if (!stream.SerializeBoolean(sig, ignoreCaseFlag)) return false;
-	return value.GetDict().Serialize(env, sig, stream);
+	return value.GetDict().Serialize(env, stream);
 }
 
-bool Class_dict::Deserialize(Environment &env, Signal sig, Stream &stream, Value &value) const
+bool Class_dict::Deserialize(Environment &env, Stream &stream, Value &value, SerializeFmtVer serializeFmtVer) const
 {
-	bool ignoreCaseFlag = false;
-	if (!stream.DeserializeBoolean(sig, ignoreCaseFlag)) return false;
-	ValueDict &valDict = value.InitAsDict(env, ignoreCaseFlag);
-	return valDict.Deserialize(env, sig, stream);
+	if (serializeFmtVer == SerializeFmtVer_1) {
+		bool ignoreCaseFlag = false;
+		if (!stream.DeserializeBoolean(env, ignoreCaseFlag)) return false;
+		ValueDict &valDict = value.InitAsDict(env, ignoreCaseFlag);
+		return valDict.Deserialize(env, stream);
+	}
+	SetError_UnsupportedSerializeFmtVer(serializeFmtVer);
+	return false;
 }
 
-Object *Class_dict::CreateDescendant(Environment &env, Signal sig, Class *pClass)
+Object *Class_dict::CreateDescendant(Environment &env, Class *pClass)
 {
-	return new Object_dict((pClass == NULL)? this : pClass, new ValueDict());
+	return new Object_dict((pClass == nullptr)? this : pClass, new ValueDict(), true);
 }
 
 }
