@@ -5,6 +5,9 @@
 
 namespace Gura {
 
+static const char *helpDoc_en = R"**(
+)**";
+
 //-----------------------------------------------------------------------------
 // Object_template
 //-----------------------------------------------------------------------------
@@ -20,27 +23,13 @@ Object_template::Object_template(Class *pClass, Template *pTemplate) :
 
 Object *Object_template::Clone() const
 {
-	return NULL;
-}
-
-bool Object_template::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	return true;
-}
-
-Value Object_template::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-						const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
+	return nullptr;
 }
 
 String Object_template::ToString(bool exprFlag)
 {
 	String str;
-	str += "<template:";
-	str += ">";
+	str += "<template>";
 	return str;
 }
 
@@ -57,7 +46,7 @@ Gura_DeclareFunctionAlias(template_, "template")
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(env.LookupClass(VTYPE_template));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `template` instance.\n"
 		"\n"
 		"If the stream `src` is specified, the instance would be initialized\n"
@@ -71,14 +60,14 @@ Gura_DeclareFunctionAlias(template_, "template")
 
 Gura_ImplementFunction(template_)
 {
-	bool autoIndentFlag = !args.IsSet(Gura_Symbol(noindent));
-	bool appendLastEOLFlag = args.IsSet(Gura_Symbol(lasteol));
+	bool autoIndentFlag = !arg.IsSet(Gura_Symbol(noindent));
+	bool appendLastEOLFlag = arg.IsSet(Gura_Symbol(lasteol));
 	AutoPtr<Template> pTemplate(new Template());
-	if (args.Is_stream(0)) {
-		if (!pTemplate->Read(env, sig, args.GetStream(0),
-					autoIndentFlag, appendLastEOLFlag)) return Value::Null;
+	if (arg.Is_stream(0)) {
+		if (!pTemplate->Read(env, arg.GetStream(0),
+					autoIndentFlag, appendLastEOLFlag)) return Value::Nil;
 	}
-	return ReturnValue(env, sig, args,
+	return ReturnValue(env, arg,
 					Value(new Object_template(env, pTemplate.release())));
 }
 
@@ -93,7 +82,7 @@ Gura_DeclareMethod(template_, parse)
 	DeclareAttr(Gura_Symbol(noindent));
 	DeclareAttr(Gura_Symbol(lasteol));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `template` instance by parsing a script-embedded text in a string.\n"
 		"\n"
 		"Following attributes would customize the parser's behavior:\n"
@@ -104,13 +93,13 @@ Gura_DeclareMethod(template_, parse)
 
 Gura_ImplementMethod(template_, parse)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	bool autoIndentFlag = !args.IsSet(Gura_Symbol(noindent));
-	bool appendLastEOLFlag = args.IsSet(Gura_Symbol(lasteol));
-	//SimpleStream_CStringReader streamSrc(args.GetString(0));
-	//pTemplate->Read(env, sig, streamSrc, autoIndentFlag, appendLastEOLFlag);
-	pTemplate->Parse(env, sig, args.GetString(0), NULL, autoIndentFlag, appendLastEOLFlag);
-	return Value::Null;
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	bool autoIndentFlag = !arg.IsSet(Gura_Symbol(noindent));
+	bool appendLastEOLFlag = arg.IsSet(Gura_Symbol(lasteol));
+	//SimpleStream_CStringReader streamSrc(arg.GetString(0));
+	//pTemplate->Read(env, streamSrc, autoIndentFlag, appendLastEOLFlag);
+	pTemplate->Parse(env, arg.GetString(0), nullptr, autoIndentFlag, appendLastEOLFlag);
+	return Value::Nil;
 }
 
 // template#read(src:stream:r):void:[lasteol,noindent]
@@ -121,7 +110,7 @@ Gura_DeclareMethod(template_, read)
 	DeclareAttr(Gura_Symbol(noindent));
 	DeclareAttr(Gura_Symbol(lasteol));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `template` instance by parsing a script-embedded text from a stream.\n"
 		"\n"
 		"Following attributes would customize the parser's behavior:\n"
@@ -132,11 +121,11 @@ Gura_DeclareMethod(template_, read)
 
 Gura_ImplementMethod(template_, read)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	bool autoIndentFlag = !args.IsSet(Gura_Symbol(noindent));
-	bool appendLastEOLFlag = args.IsSet(Gura_Symbol(lasteol));
-	pTemplate->Read(env, sig, args.GetStream(0), autoIndentFlag, appendLastEOLFlag);
-	return Value::Null;
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	bool autoIndentFlag = !arg.IsSet(Gura_Symbol(noindent));
+	bool appendLastEOLFlag = arg.IsSet(Gura_Symbol(lasteol));
+	pTemplate->Read(env, arg.GetStream(0), autoIndentFlag, appendLastEOLFlag);
+	return Value::Nil;
 }
 
 // template#render(dst?:stream:w)
@@ -145,7 +134,7 @@ Gura_DeclareMethod(template_, render)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "dst", VTYPE_stream, OCCUR_ZeroOrOnce, FLAG_Write);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Renders stored content to the specified stream.\n"
 		"\n"
 		"If the stream is omitted, the function returns the rendered result as a string.\n");
@@ -153,15 +142,15 @@ Gura_DeclareMethod(template_, render)
 
 Gura_ImplementMethod(template_, render)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	if (args.Is_stream(0)) {
-		Stream &streamDst = args.GetStream(0);
-		pTemplate->Render(env, sig, &streamDst);
-		return Value::Null;
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	if (arg.Is_stream(0)) {
+		Stream &streamDst = arg.GetStream(0);
+		pTemplate->Render(env, &streamDst);
+		return Value::Nil;
 	} else {
 		String strDst;
 		SimpleStream_StringWriter streamDst(strDst);
-		if (!pTemplate->Render(env, sig, &streamDst)) return Value::Null;
+		if (!pTemplate->Render(env, &streamDst)) return Value::Nil;
 		return Value(strDst);
 	}
 }
@@ -175,7 +164,7 @@ Gura_DeclareMethod(template_, block)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "symbol", VTYPE_symbol);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a template block which content is supposed to be replaced by a derived template.\n"
 		"\n"
 		"This method is called by template directive `${=block()}`\n"
@@ -223,15 +212,16 @@ Gura_DeclareMethod(template_, block)
 
 Gura_ImplementMethod(template_, block)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	const Symbol *pSymbol = args.GetSymbol(0);
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	const Symbol *pSymbol = arg.GetSymbol(0);
 	const ValueEx *pValue = pTemplate->LookupValue(pSymbol);
-	if (pValue != NULL && pValue->Is_function()) {
-		AutoPtr<Args> pArgs(new Args());
-		pArgs->SetThis(args.GetThis());
-		pValue->GetFunction()->Eval(env, sig, *pArgs);
+	if (pValue != nullptr && pValue->Is_function()) {
+		const Function *pFunc = pValue->GetFunction();
+		AutoPtr<Argument> pArg(new Argument(pFunc));
+		pArg->SetValueThis(arg.GetValueThis());
+		pFunc->Eval(env, *pArg);
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#call(symbol:symbol, args*)
@@ -241,7 +231,7 @@ Gura_DeclareMethod(template_, call)
 	DeclareArg(env, "symbol", VTYPE_symbol);
 	DeclareArg(env, "args", VTYPE_any, OCCUR_ZeroOrMore);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Calls a template macro that has been created by directive `${=define}`.\n"
 		"\n"
 		"This method is called by template directive `${=call()}`\n"
@@ -257,18 +247,19 @@ Gura_DeclareMethod(template_, call)
 
 Gura_ImplementMethod(template_, call)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	const Symbol *pSymbol = args.GetSymbol(0);
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	const Symbol *pSymbol = arg.GetSymbol(0);
 	const ValueEx *pValue = pTemplate->LookupValue(pSymbol);
-	if (pValue == NULL || !pValue->Is_function()) {
-		return Value::Null;
+	if (pValue == nullptr || !pValue->Is_function()) {
+		return Value::Nil;
 	}
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetThis(args.GetThis());
-	pArgs->SetValueListArg(args.GetList(1));
+	const Function *pFunc = pValue->GetFunction();
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	pArg->SetValueThis(arg.GetValueThis());
+	if (!pArg->StoreValues(env, arg.GetList(1))) return Value::Nil;
 	pTemplate->ClearLastChar();
-	pValue->GetFunction()->Eval(env, sig, *pArgs);
-	return (pTemplate->GetLastChar() == '\n')? Value::Null : Value("");
+	pFunc->Eval(env, *pArg);
+	return (pTemplate->GetLastChar() == '\n')? Value::Nil : Value("");
 }
 
 // template#define(symbol:symbol, `args*):void
@@ -278,7 +269,7 @@ Gura_DeclareMethod(template_, define)
 	DeclareArg(env, "symbol", VTYPE_symbol);
 	DeclareArg(env, "args", VTYPE_quote, OCCUR_ZeroOrMore);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a template macro from the specified block,\n"
 		"which is supposed to be called by `${=call}` directive,\n"
 		"and associates it with the specified symbol.\n"
@@ -296,7 +287,7 @@ Gura_DeclareMethod(template_, define)
 Gura_ImplementMethod(template_, define)
 {
 	// nothing to do
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#embed(template:template)
@@ -305,7 +296,7 @@ Gura_DeclareMethod(template_, embed)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "template", VTYPE_template);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Renders the specified template at the current position.\n"
 		"\n"
 		"This method is called by template directive `${=embed()}`\n"
@@ -325,12 +316,12 @@ Gura_DeclareMethod(template_, embed)
 
 Gura_ImplementMethod(template_, embed)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	Template *pTemplateEmbedded = Object_template::GetObject(args, 0)->GetTemplate();
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	Template *pTemplateEmbedded = Object_template::GetObject(arg, 0)->GetTemplate();
 	SimpleStream *pStreamDst = pTemplate->GetStreamDst();
 	pTemplateEmbedded->ClearLastChar();
-	pTemplateEmbedded->Render(env, sig, pStreamDst);
-	return (pTemplateEmbedded->GetLastChar() == '\n')? Value::Null : Value("");
+	pTemplateEmbedded->Render(env, pStreamDst);
+	return (pTemplateEmbedded->GetLastChar() == '\n')? Value::Nil : Value("");
 }
 
 // template#extends(template:template):void
@@ -339,7 +330,7 @@ Gura_DeclareMethod(template_, extends)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "template", VTYPE_template);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Declares the current template as a derived one from the specified template.\n"
 		"\n"
 		"This method is called by template directive `${=extends()}`\n"
@@ -356,7 +347,7 @@ Gura_DeclareMethod(template_, extends)
 Gura_ImplementMethod(template_, extends)
 {
 	// nothing to do
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#super(symbol:symbol):void
@@ -365,7 +356,7 @@ Gura_DeclareMethod(template_, super)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "symbol", VTYPE_symbol);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Evaluates a template block registered with the specified symbol in a template\n"
 		"from which the current template has derived.\n"
 		"\n"
@@ -413,17 +404,18 @@ Gura_DeclareMethod(template_, super)
 
 Gura_ImplementMethod(template_, super)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	const Symbol *pSymbol = args.GetSymbol(0);
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	const Symbol *pSymbol = arg.GetSymbol(0);
 	Template *pTemplateSuper = pTemplate->GetTemplateSuper();
-	if (pTemplateSuper == NULL) return Value::Null;
+	if (pTemplateSuper == nullptr) return Value::Nil;
 	const ValueEx *pValue = pTemplateSuper->LookupValue(pSymbol);
-	if (pValue != NULL && pValue->Is_function()) {
-		AutoPtr<Args> pArgs(new Args());
-		pArgs->SetThis(args.GetThis());
-		pValue->GetFunction()->Eval(env, sig, *pArgs);
+	if (pValue != nullptr && pValue->Is_function()) {
+		const Function *pFunc = pValue->GetFunction();
+		AutoPtr<Argument> pArg(new Argument(pFunc));
+		pArg->SetValueThis(arg.GetValueThis());
+		pFunc->Eval(env, *pArg);
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#init_block(symbol:symbol):void {block}
@@ -437,20 +429,21 @@ Gura_DeclareMethod(template_, init_block)
 
 Gura_ImplementMethod(template_, init_block)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	const Symbol *pSymbol = args.GetSymbol(0);
-	const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-	if (sig.IsSignalled()) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	const Symbol *pSymbol = arg.GetSymbol(0);
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (sig.IsSignalled()) return Value::Nil;
 	AutoPtr<FunctionCustom> pFunc(new FunctionCustom(env,
 						pSymbol, Expr::Reference(pExprBlock), FUNCTYPE_Instance));
 	pFunc->SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_DynamicScope);
-	ValueMap &valueMap = pTemplate->GetValueMap();
-	if (valueMap.find(pSymbol) != valueMap.end()) {
+	ValueExMap &valueExMap = pTemplate->GetValueExMap();
+	if (valueExMap.find(pSymbol) != valueExMap.end()) {
 		sig.SetError(ERR_KeyError, "duplicated symbol: %s", pSymbol->GetName());
-		return Value::Null;
+		return Value::Nil;
 	}
-	valueMap[pSymbol] = Value(new Object_function(env, pFunc->Reference()));
-	return Value::Null;
+	valueExMap[pSymbol] = Value(new Object_function(env, pFunc->Reference()));
+	return Value::Nil;
 }
 
 // template#init_call(symbol:symbol, args*):void
@@ -465,7 +458,7 @@ Gura_DeclareMethod(template_, init_call)
 Gura_ImplementMethod(template_, init_call)
 {
 	// nothing to do
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#init_define(symbol:symbol, `args*):void {block}
@@ -480,30 +473,27 @@ Gura_DeclareMethod(template_, init_define)
 
 Gura_ImplementMethod(template_, init_define)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	const Symbol *pSymbol = args.GetSymbol(0);
-	const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-	if (sig.IsSignalled()) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	const Symbol *pSymbol = arg.GetSymbol(0);
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (sig.IsSignalled()) return Value::Nil;
 	AutoPtr<FunctionCustom> pFunc(new FunctionCustom(env,
 						pSymbol, Expr::Reference(pExprBlock), FUNCTYPE_Instance));
 	pFunc->SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_DynamicScope);
-	AutoPtr<Args> pArgsSub(new Args());
-	do {
-		AutoPtr<ExprOwner> pExprOwnerArg(new ExprOwner());
-		foreach_const (ValueList, pValue, args.GetList(1)) {
-			pExprOwnerArg->push_back(pValue->GetExpr()->Reference());
-		}
-		pArgsSub->SetExprOwnerArg(pExprOwnerArg.release());
-	} while (0);
-	//pArgsSub->SetAttrs(args.GetAttrs());
-	if (!pFunc->CustomDeclare(env, sig, SymbolSet::Null, *pArgsSub)) return Value::Null;
-	ValueMap &valueMap = pTemplate->GetValueMap();
-	if (valueMap.find(pSymbol) != valueMap.end()) {
-		sig.SetError(ERR_KeyError, "duplicated symbol: %s", pSymbol->GetName());
-		return Value::Null;
+	AutoPtr<ExprOwner> pExprOwnerArg(new ExprOwner());
+	foreach_const (ValueList, pValue, arg.GetList(1)) {
+		pExprOwnerArg->push_back(pValue->GetExpr()->Reference());
 	}
-	valueMap[pSymbol] = Value(new Object_function(env, pFunc->Reference()));
-	return Value::Null;
+	CallerInfo callerInfo(*pExprOwnerArg, nullptr, nullptr, nullptr);
+	if (!pFunc->CustomDeclare(env, callerInfo, SymbolSet::Empty)) return Value::Nil;
+	ValueExMap &valueExMap = pTemplate->GetValueExMap();
+	if (valueExMap.find(pSymbol) != valueExMap.end()) {
+		sig.SetError(ERR_KeyError, "duplicated symbol: %s", pSymbol->GetName());
+		return Value::Nil;
+	}
+	valueExMap[pSymbol] = Value(new Object_function(env, pFunc->Reference()));
+	return Value::Nil;
 }
 
 // template#init_embed(template:template):void
@@ -517,7 +507,7 @@ Gura_DeclareMethod(template_, init_embed)
 Gura_ImplementMethod(template_, init_embed)
 {
 	// nothing to do
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#init_extends(template:template):void
@@ -530,10 +520,10 @@ Gura_DeclareMethod(template_, init_extends)
 
 Gura_ImplementMethod(template_, init_extends)
 {
-	Template *pTemplate = Object_template::GetThisObj(args)->GetTemplate();
-	Template *pTemplateSuper = Object_template::GetObject(args, 0)->GetTemplate();
+	Template *pTemplate = Object_template::GetObjectThis(arg)->GetTemplate();
+	Template *pTemplateSuper = Object_template::GetObject(arg, 0)->GetTemplate();
 	pTemplate->SetTemplateSuper(pTemplateSuper->Reference());
-	return Value::Null;
+	return Value::Nil;
 }
 
 // template#init_super(symbol:symbol):void
@@ -547,17 +537,29 @@ Gura_DeclareMethod(template_, init_super)
 Gura_ImplementMethod(template_, init_super)
 {
 	// nothing to do
-	return Value::Null;
+	return Value::Nil;
+}
+
+//-----------------------------------------------------------------------------
+// Implementation of suffix manager
+//-----------------------------------------------------------------------------
+Gura_ImplementSuffixMgrForString(T)
+{
+	bool autoIndentFlag = true;
+	bool appendLastEOLFlag = false;
+	AutoPtr<Template> pTemplate(new Template());
+	if (!pTemplate->Parse(env, body, nullptr, autoIndentFlag, appendLastEOLFlag)) return Value::Nil;
+	return Value(new Object_template(env, pTemplate.release()));
 }
 
 //-----------------------------------------------------------------------------
 // Implementation of class
 //-----------------------------------------------------------------------------
-Class_template::Class_template(Environment *pEnvOuter) : Class(pEnvOuter, VTYPE_template)
+Class_template::Class_template(Environment *pEnvOuter) : ClassFundamental(pEnvOuter, VTYPE_template)
 {
 }
 
-void Class_template::Prepare(Environment &env)
+void Class_template::DoPrepare(Environment &env)
 {
 	Gura_AssignFunction(template_);
 	// assignment of methods
@@ -577,16 +579,20 @@ void Class_template::Prepare(Environment &env)
 	Gura_AssignMethod(template_, init_embed);
 	Gura_AssignMethod(template_, init_extends);
 	Gura_AssignMethod(template_, init_super);
+	// assignment of suffix manager
+	Gura_AssignSuffixMgrForString(T);
+	// help document
+	AddHelpTemplate(env, Gura_Symbol(en), helpDoc_en);
 }
 
-bool Class_template::CastFrom(Environment &env, Signal sig, Value &value, const Declaration *pDecl)
+bool Class_template::CastFrom(Environment &env, Value &value, ULong flags)
 {
-	env.LookupClass(VTYPE_stream)->CastFrom(env, sig, value, pDecl);
+	env.LookupClass(VTYPE_stream)->CastFrom(env, value, flags);
 	if (value.Is_stream()) {
 		bool autoIndentFlag = true;
 		bool appendLastEOLFlag = false;
 		AutoPtr<Template> pTemplate(new Template());
-		if (!pTemplate->Read(env, sig, value.GetStream(),
+		if (!pTemplate->Read(env, value.GetStream(),
 							autoIndentFlag, appendLastEOLFlag)) return false;
 		value = Value(new Object_template(env, pTemplate.release()));
 		return true;
@@ -594,10 +600,10 @@ bool Class_template::CastFrom(Environment &env, Signal sig, Value &value, const
 	return false;
 }
 
-Object *Class_template::CreateDescendant(Environment &env, Signal sig, Class *pClass)
+Object *Class_template::CreateDescendant(Environment &env, Class *pClass)
 {
 	GURA_ERROREND(env, "this function must not be called");
-	return NULL;
+	return nullptr;
 }
 
 }
