@@ -8,7 +8,7 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // Color
 //-----------------------------------------------------------------------------
-ColorMap *Color::_pColorMap = NULL;
+ColorMap *Color::_pColorMap = nullptr;
 
 const Color::ElementEntry Color::_elementEntries[] = {
 	// basic color
@@ -802,12 +802,58 @@ const Color Color::fuchsia(	255,   0, 255, 255);
 const Color Color::aqua(	  0, 255, 255, 255);
 const Color Color::white(	255, 255, 255, 255);
 
-Color Color::CreateNamedColor(Signal sig, const char *name, UChar a)
+Color Color::CreateFromValues(Environment &env, const ValueList &valList)
+{
+	Signal &sig = env.GetSignal();
+	if (valList.empty()) {
+		Declaration::SetError_NotEnoughArguments(env);
+		return zero;
+	}
+	if (valList[0].Is_string() || valList[0].Is_symbol()) {
+		UChar a = 255;
+		if (valList.size() < 2) {
+			// nothing to do
+		} else if (valList[1].Is_number()) {
+			a = valList[1].GetUChar();
+		} else {
+			Declaration::SetError_InvalidArgument(env);
+			return zero;
+		}
+		const char *name = valList[0].Is_string()?
+			valList[0].GetString() : valList[0].GetSymbol()->GetName();
+		Color color = CreateNamedColor(env, name, a);
+		if (env.IsSignalled()) return zero;
+		return color;
+	} else if (valList[0].Is_number()) {
+		if (valList.size() < 3) {
+			Declaration::SetError_NotEnoughArguments(env);
+			return zero;
+		}
+		if (!valList[1].MustBe_number(sig)) return zero;
+		if (!valList[2].MustBe_number(sig)) return zero;
+		if (valList.size() < 4) {
+			return Color(valList[0].GetUChar(),
+						 valList[1].GetUChar(),
+						 valList[2].GetUChar(),
+						 255);
+		} else {
+			if (!valList[3].MustBe_number(sig)) return zero;
+			return Color(valList[0].GetUChar(),
+						 valList[1].GetUChar(),
+						 valList[2].GetUChar(),
+						 valList[3].GetUChar());
+		}
+	}
+	Declaration::SetError_InvalidArgument(env);
+	return zero;
+}
+
+Color Color::CreateNamedColor(Environment &env, const char *name, UChar a)
 {
 	if (*name == '#') {
 		name++;
 		int nCols = 0;
-		ULong num = 0;
+		UInt32 num = 0;
 		for ( ; *name != '\0'; name++, nCols++) {
 			char ch = *name;
 			if (IsDigit(ch)) {
@@ -817,7 +863,7 @@ Color Color::CreateNamedColor(Signal sig, const char *name, UChar a)
 			} else if ('A' <= ch && ch <= 'F') {
 				num = (num << 4) + ch - 'A' + 10;
 			} else {
-				sig.SetError(ERR_ValueError, "invalid color name");
+				env.SetError(ERR_ValueError, "invalid color name");
 				return zero;
 			}
 		}
@@ -831,14 +877,14 @@ Color Color::CreateNamedColor(Signal sig, const char *name, UChar a)
 			g = static_cast<UChar>((num >> 8) & 0xff);
 			b = static_cast<UChar>((num >> 0) & 0xff);
 		} else {
-			sig.SetError(ERR_ValueError, "invalid color name");
+			env.SetError(ERR_ValueError, "invalid color name");
 			return zero;
 		}
 		return Color(r, g, b, a);
 	}
-	if (_pColorMap == NULL) {
+	if (_pColorMap == nullptr) {
 		_pColorMap = new ColorMap();
-		for (int i = 0; i < ArraySizeOf(_elementEntries); i++) {
+		for (size_t i = 0; i < ArraySizeOf(_elementEntries); i++) {
 			const ElementEntry &elementEntry = _elementEntries[i];
 			const Symbol *pSymbol = Symbol::Add(elementEntry.name);
 			(*_pColorMap)[pSymbol] = Color(elementEntry.r,
@@ -848,7 +894,7 @@ Color Color::CreateNamedColor(Signal sig, const char *name, UChar a)
 	const Symbol *pSymbol = Symbol::Add(name);
 	ColorMap::iterator iter = _pColorMap->find(pSymbol);
 	if (iter == _pColorMap->end()) {
-		sig.SetError(ERR_ValueError, "unknown color name %s\n", pSymbol->GetName());
+		env.SetError(ERR_ValueError, "unknown color name %s", pSymbol->GetName());
 		return zero;
 	}
 	Color color = iter->second;
