@@ -9,7 +9,7 @@ namespace Gura {
 // Image
 //-----------------------------------------------------------------------------
 Image::Image(Format format) : _cntRef(1),
-			_format(format), _width(0), _height(0), _pPalette(NULL)
+			_format(format), _width(0), _height(0), _pPalette(nullptr)
 {
 	InitMetrics();
 }
@@ -33,7 +33,7 @@ Image *Image::Clone() const
 	return new Image(*this);
 }
 
-bool Image::AllocBuffer(size_t width, size_t height, UChar fillValue)
+bool Image::AllocBuffer(size_t width, size_t height)
 {
 	if (width == 0 || height == 0) return false;
 	_width = width, _height = height;
@@ -50,12 +50,24 @@ bool Image::AllocBuffer(size_t width, size_t height, UChar fillValue)
 #else
 	_pMemory.reset(new MemoryHeap(GetBufferSize()));
 #endif
+	return true;
+}
+
+bool Image::AllocBuffer(size_t width, size_t height, UChar fillValue)
+{
+	if (!AllocBuffer(width, height)) return false;
 	::memset(GetBuffer(), fillValue, GetBufferSize());
 	return true;
 }
 
-bool Image::AllocBuffer(Signal sig,
-					size_t width, size_t height, UChar fillValue)
+bool Image::AllocBuffer(Signal &sig, size_t width, size_t height)
+{
+	if (AllocBuffer(width, height)) return true;
+	sig.SetError(ERR_MemoryError, "failed to allocate image buffer");
+	return false;
+}
+
+bool Image::AllocBuffer(Signal &sig, size_t width, size_t height, UChar fillValue)
 {
 	if (AllocBuffer(width, height, fillValue)) return true;
 	sig.SetError(ERR_MemoryError, "failed to allocate image buffer");
@@ -64,18 +76,18 @@ bool Image::AllocBuffer(Signal sig,
 
 void Image::FreeBuffer()
 {
-	_pMemory.reset(NULL);
+	_pMemory.reset(nullptr);
 	_width = 0, _height = 0;
 }
 
-bool Image::CheckEmpty(Signal sig) const
+bool Image::CheckEmpty(Signal &sig) const
 {
 	if (!IsValid()) return true;
 	sig.SetError(ERR_ValueError, "image has already been initialized with a buffer");
 	return false;
 }
 
-bool Image::CheckValid(Signal sig) const
+bool Image::CheckValid(Signal &sig) const
 {
 	if (IsValid()) return true;
 	sig.SetError(ERR_ValueError, "image does not have a buffer");
@@ -105,7 +117,7 @@ Image::ScanDir Image::SymbolToScanDir(const Symbol *pSymbol)
 	}
 }
 
-size_t Image::SymbolToPixelOffset(Signal sig, const Symbol *pSymbol) const
+size_t Image::SymbolToPixelOffset(Signal &sig, const Symbol *pSymbol) const
 {
 	if (pSymbol->IsIdentical(Gura_Symbol(r))) {
 		return OffsetR;
@@ -124,7 +136,7 @@ size_t Image::SymbolToPixelOffset(Signal sig, const Symbol *pSymbol) const
 	return 0;
 }
 
-Image::Format Image::SymbolToFormat(Signal sig, const Symbol *pSymbol)
+Image::Format Image::SymbolToFormat(Signal &sig, const Symbol *pSymbol)
 {
 	if (pSymbol->IsIdentical(Gura_Symbol(rgb))) {
 		return FORMAT_RGB;
@@ -158,12 +170,12 @@ void Image::InitMetrics()
 			(_format == FORMAT_RGBA)? _width * 4 : 0;
 }
 
-Image *Image::CreateDerivation(Signal sig,
+Image *Image::CreateDerivation(Signal &sig,
 						size_t width, size_t height, Palette *pPalette)
 {
 	AutoPtr<Image> pImage(new Image(_format));
-	if (!pImage->AllocBuffer(sig, width, height, 0x00)) return NULL;
-	if (pPalette != NULL) {
+	if (!pImage->AllocBuffer(sig, width, height, 0x00)) return nullptr;
+	if (pPalette != nullptr) {
 		pImage->_pPalette.reset(pPalette);
 	} else if (!_pPalette.IsNull()) {
 		pImage->_pPalette.reset(Palette::Reference(_pPalette.get()));
@@ -171,7 +183,7 @@ Image *Image::CreateDerivation(Signal sig,
 	return pImage.release();
 }
 
-bool Image::CheckCoord(Signal sig, size_t x, size_t y) const
+bool Image::CheckCoord(Signal &sig, size_t x, size_t y) const
 {
 	if (CheckCoord(static_cast<int>(x), static_cast<int>(y))) return true;
 	sig.SetError(ERR_ValueError, "coordinate is out of range");
@@ -224,32 +236,10 @@ void Image::GetPixel(const UChar *buff, Color &color)
 	}
 }
 
-bool Image::Store(Signal sig, size_t x, size_t y, size_t width, size_t height,
-							const Symbol *pSymbol, const Matrix *pMat)
-{
-	if (pMat->GetRows() < height || pMat->GetCols() < width) {
-		sig.SetError(ERR_ValueError, "matrix size is too small");
-		return false;
-	}
-	size_t bytesPerLine = GetBytesPerLine();
-	size_t bytesPerPixel = GetBytesPerPixel();
-	UChar *pLine = GetPointer(x, y);
-	size_t offPixel = SymbolToPixelOffset(sig, pSymbol);
-	if (sig.IsSignalled()) return false;
-	for (size_t iLine = 0; iLine < height; iLine++, pLine += bytesPerLine) {
-		UChar *pPixel = pLine + offPixel;
-		ValueList::const_iterator pValueElem = pMat->GetPointer(iLine, 0);
-		for (size_t iPixel = 0; iPixel < width;
-							iPixel++, pPixel += bytesPerPixel, pValueElem++) {
-			*pPixel = pValueElem->GetUChar();
-		}
-	}
-	return true;
-}
-
-bool Image::Store(Environment &env, Signal sig, size_t x, size_t y, size_t width, size_t height,
+bool Image::Store(Environment &env, size_t x, size_t y, size_t width, size_t height,
 							const Symbol *pSymbol, Iterator *pIterator)
 {
+	Signal &sig = env.GetSignal();
 	size_t bytesPerLine = GetBytesPerLine();
 	size_t bytesPerPixel = GetBytesPerPixel();
 	UChar *pLine = GetPointer(x, y);
@@ -259,37 +249,14 @@ bool Image::Store(Environment &env, Signal sig, size_t x, size_t y, size_t width
 		UChar *pPixel = pLine + offPixel;
 		for (size_t iPixel = 0; iPixel < width; iPixel++, pPixel += bytesPerPixel) {
 			Value value;
-			if (!pIterator->Next(env, sig, value)) return false;
+			if (!pIterator->Next(env, value)) return false;
 			*pPixel = value.GetUChar();
 		}
 	}
 	return true;
 }
 
-bool Image::Extract(Signal sig, size_t x, size_t y, size_t width, size_t height,
-							const Symbol *pSymbol, Matrix *pMat)
-{
-	if (pMat->GetRows() < height || pMat->GetCols() < width) {
-		sig.SetError(ERR_ValueError, "matrix size is too small");
-		return false;
-	}
-	size_t bytesPerLine = GetBytesPerLine();
-	size_t bytesPerPixel = GetBytesPerPixel();
-	const UChar *pLine = GetPointer(x, y);
-	size_t offPixel = SymbolToPixelOffset(sig, pSymbol);
-	if (sig.IsSignalled()) return false;
-	for (size_t iLine = 0; iLine < height; iLine++, pLine += bytesPerLine) {
-		const UChar *pPixel = pLine + offPixel;
-		ValueList::iterator pValueElem = pMat->GetPointer(iLine, 0);
-		for (size_t iPixel = 0; iPixel < width;
-							iPixel++, pPixel += bytesPerPixel, pValueElem++) {
-			*pValueElem = Value(*pPixel);
-		}
-	}
-	return true;
-}
-
-bool Image::Extract(Signal sig, size_t x, size_t y, size_t width, size_t height,
+bool Image::Extract(Signal &sig, size_t x, size_t y, size_t width, size_t height,
 									const Symbol *pSymbol, ValueList &valList)
 {
 	if (valList.size() < height * width) {
@@ -315,7 +282,7 @@ bool Image::Extract(Signal sig, size_t x, size_t y, size_t width, size_t height,
 void Image::ReplaceColorRect(size_t x, size_t y, size_t width, size_t height,
 				const Color &colorOrg, const Color &color, double tolerance)
 {
-	std::auto_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
+	std::unique_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
 	UChar buff[8];
 	PutPixel(buff, color);
 	if (tolerance == 0.) {
@@ -365,7 +332,7 @@ void Image::FillRect(size_t x, size_t y, size_t width, size_t height,
 {
 	UChar buff[8];
 	PutPixel(buff, color);
-	std::auto_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
+	std::unique_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
 	if (_format == FORMAT_RGBA) {
 		do {
 			StorePixelRGBA(pScanner->GetPointer(), buff);
@@ -380,7 +347,7 @@ void Image::FillRect(size_t x, size_t y, size_t width, size_t height,
 void Image::FillRectAlpha(size_t x, size_t y,
 					size_t width, size_t height, UChar a)
 {
-	std::auto_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
+	std::unique_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
 	do {
 		UChar *pPixel = pScanner->GetPointer();
 		*(pPixel + OffsetA) = a;
@@ -390,7 +357,7 @@ void Image::FillRectAlpha(size_t x, size_t y,
 void Image::FillRectAlpha(size_t x, size_t y,
 	size_t width, size_t height, UChar a, const Color &color, double tolerance)
 {
-	std::auto_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
+	std::unique_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
 	if (tolerance == 0.) {
 		UChar buff[8];
 		PutPixel(buff, color);
@@ -414,13 +381,13 @@ void Image::FillRectAlpha(size_t x, size_t y,
 	}
 }
 
-Image *Image::ReduceColor(Signal sig, const Palette *pPalette)
+Image *Image::ReduceColor(Signal &sig, const Palette *pPalette)
 {
 	AutoPtr<Image> pImage(CreateDerivation(sig, _width, _height,
 										Palette::Reference(pPalette)));
-	if (sig.IsSignalled()) return NULL;
-	std::auto_ptr<Scanner> pScannerSrc(CreateScanner());
-	std::auto_ptr<Scanner> pScannerDst(pImage->CreateScanner());
+	if (sig.IsSignalled()) return nullptr;
+	std::unique_ptr<Scanner> pScannerSrc(CreateScanner());
+	std::unique_ptr<Scanner> pScannerDst(pImage->CreateScanner());
 	if (_format == FORMAT_RGBA) {
 		do {
 			size_t idx = pPalette->LookupNearest(pScannerSrc->GetPointer());
@@ -436,12 +403,12 @@ Image *Image::ReduceColor(Signal sig, const Palette *pPalette)
 	return pImage.release();
 }
 
-Image *Image::GrayScale(Signal sig)
+Image *Image::GrayScale(Signal &sig)
 {
 	AutoPtr<Image> pImage(CreateDerivation(sig, _width, _height));
-	if (sig.IsSignalled()) return NULL;
-	std::auto_ptr<Scanner> pScannerSrc(CreateScanner());
-	std::auto_ptr<Scanner> pScannerDst(pImage->CreateScanner());
+	if (sig.IsSignalled()) return nullptr;
+	std::unique_ptr<Scanner> pScannerSrc(CreateScanner());
+	std::unique_ptr<Scanner> pScannerDst(pImage->CreateScanner());
 	if (_format == FORMAT_RGBA) {
 		do {
 			UChar gray = GetPixelGray(pScannerSrc->GetPointer());
@@ -456,12 +423,12 @@ Image *Image::GrayScale(Signal sig)
 	return pImage.release();
 }
 
-Image *Image::MapColorLevel(Signal sig, const UChar *mapR, const UChar *mapG, const UChar *mapB)
+Image *Image::MapColorLevel(Signal &sig, const UChar *mapR, const UChar *mapG, const UChar *mapB)
 {
 	AutoPtr<Image> pImage(CreateDerivation(sig, _width, _height));
-	if (sig.IsSignalled()) return NULL;
-	std::auto_ptr<Scanner> pScannerSrc(CreateScanner());
-	std::auto_ptr<Scanner> pScannerDst(pImage->CreateScanner());
+	if (sig.IsSignalled()) return nullptr;
+	std::unique_ptr<Scanner> pScannerSrc(CreateScanner());
+	std::unique_ptr<Scanner> pScannerDst(pImage->CreateScanner());
 	if (_format == FORMAT_RGBA) {
 		do {
 			UChar r = mapR[pScannerSrc->GetR()];
@@ -480,11 +447,11 @@ Image *Image::MapColorLevel(Signal sig, const UChar *mapR, const UChar *mapG, co
 	return pImage.release();
 }
 
-Image *Image::Blur(Signal sig, int radius, Number sigma)
+Image *Image::Blur(Signal &sig, int radius, Number sigma)
 {
 	int diameter = radius * 2 + 1;
 	AutoPtr<Image> pImage(CreateDerivation(sig, _width, _height));
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return nullptr;
 	int nKernels = diameter * diameter;
 	Number *kernel = new Number[nKernels];
 	Number factor = 2 * sigma * sigma;
@@ -519,9 +486,9 @@ Image *Image::Blur(Signal sig, int radius, Number sigma)
 	} while (0);
 	//pImage->Fill(Color(255, 0, 0, 255));
 	size_t width = GetWidth() - diameter, height = GetHeight() - diameter;
-	std::auto_ptr<Scanner> pScannerSrc(CreateScanner(0, 0, width, height));
-	std::auto_ptr<Scanner> pScannerDst(pImage->CreateScanner(radius, radius, width, height));
-	std::auto_ptr<Scanner> pScanner(pImage->CreateScanner(0, 0, diameter, diameter));
+	std::unique_ptr<Scanner> pScannerSrc(CreateScanner(0, 0, width, height));
+	std::unique_ptr<Scanner> pScannerDst(pImage->CreateScanner(radius, radius, width, height));
+	std::unique_ptr<Scanner> pScanner(pImage->CreateScanner(0, 0, diameter, diameter));
 	if (_format == FORMAT_RGBA) {
 		//
 		// image processing around border has not been implemented yet.
@@ -564,13 +531,13 @@ Image *Image::Blur(Signal sig, int radius, Number sigma)
 	return pImage.release();
 }
 
-Image *Image::Flip(Signal sig, bool horzFlag, bool vertFlag)
+Image *Image::Flip(Signal &sig, bool horzFlag, bool vertFlag)
 {
 	AutoPtr<Image> pImage(CreateDerivation(sig, _width, _height));
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return nullptr;
 	if (horzFlag) {
-		std::auto_ptr<Scanner> pScannerSrc(CreateScanner());
-		std::auto_ptr<Scanner> pScannerDst(pImage->CreateScanner(
+		std::unique_ptr<Scanner> pScannerSrc(CreateScanner());
+		std::unique_ptr<Scanner> pScannerDst(pImage->CreateScanner(
 				vertFlag? SCAN_RightBottomHorz : SCAN_RightTopHorz));
 		if (_format == FORMAT_RGBA) {
 			do {
@@ -594,13 +561,13 @@ Image *Image::Flip(Signal sig, bool horzFlag, bool vertFlag)
 	return pImage.release();
 }
 
-Image *Image::Rotate90(Signal sig, bool clockwiseFlag)
+Image *Image::Rotate90(Signal &sig, bool clockwiseFlag)
 {
 	size_t width = _height, height = _width;
 	AutoPtr<Image> pImage(CreateDerivation(sig, width, height));
-	if (sig.IsSignalled()) return NULL;
-	std::auto_ptr<Scanner> pScannerSrc(CreateScanner());
-	std::auto_ptr<Scanner> pScannerDst(pImage->CreateScanner(
+	if (sig.IsSignalled()) return nullptr;
+	std::unique_ptr<Scanner> pScannerSrc(CreateScanner());
+	std::unique_ptr<Scanner> pScannerDst(pImage->CreateScanner(
 			clockwiseFlag? SCAN_RightTopVert : SCAN_LeftBottomVert));
 	if (_format == FORMAT_RGBA) {
 		do {
@@ -614,7 +581,7 @@ Image *Image::Rotate90(Signal sig, bool clockwiseFlag)
 	return pImage.release();
 }
 
-Image *Image::Rotate(Signal sig, double angle, const Color &color)
+Image *Image::Rotate(Signal &sig, double angle, const Color &color)
 {
 	int angleInt = static_cast<int>(angle);
 	if (static_cast<double>(angleInt) != angle) {
@@ -653,7 +620,7 @@ Image *Image::Rotate(Signal sig, double angle, const Color &color)
 		yCenterNew = height / 2;
 	} while (0);
 	AutoPtr<Image> pImage(CreateDerivation(sig, width, height));
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return nullptr;
 	UChar *pLineDst = pImage->GetPointer(0);
 	size_t bytesPerLineDst = pImage->GetBytesPerLine();
 	size_t bytesPerPixel = GetBytesPerPixel();
@@ -679,10 +646,10 @@ Image *Image::Rotate(Signal sig, double angle, const Color &color)
 	return pImage.release();
 }
 
-Image *Image::Crop(Signal sig, size_t x, size_t y, size_t width, size_t height)
+Image *Image::Crop(Signal &sig, size_t x, size_t y, size_t width, size_t height)
 {
 	AutoPtr<Image> pImage(CreateDerivation(sig, width, height));
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return nullptr;
 	const UChar *pLineSrc = GetPointer(x, y);
 	UChar *pLineDst = pImage->GetPointer(0);
 	size_t bytesPerLineSrc = GetBytesPerLine();
@@ -695,10 +662,10 @@ Image *Image::Crop(Signal sig, size_t x, size_t y, size_t width, size_t height)
 	return pImage.release();
 }
 
-Image *Image::Resize(Signal sig, size_t width, size_t height)
+Image *Image::Resize(Signal &sig, size_t width, size_t height)
 {
 	AutoPtr<Image> pImage(CreateDerivation(sig, width, height));
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return nullptr;
 	const UChar *pLineSrc = GetPointer(0);
 	UChar *pLineDst = pImage->GetPointer(0);
 	size_t bytesPerPixel = GetBytesPerPixel();
@@ -714,7 +681,6 @@ Image *Image::Resize(Signal sig, size_t width, size_t height)
 		for (size_t ySrc = 0; ySrc <= _height; ySrc++) {
 			if (ySrc < _height) {
 				const UChar *pPixelSrc = pLineSrc;
-				UChar *pPixelDst = pLineDst;
 				Accum *pAccum = accums;
 				size_t xDst = 0;
 				size_t numerX = 0;
@@ -773,7 +739,6 @@ Image *Image::Resize(Signal sig, size_t width, size_t height)
 		for (size_t ySrc = 0; ySrc <= _height; ySrc++) {
 			if (ySrc < _height) {
 				const UChar *pPixelSrc = pLineSrc;
-				UChar *pPixelDst = pLineDst;
 				Accum *pAccum = accums;
 				size_t xDst = 0;
 				size_t numerX = 0;
@@ -889,33 +854,35 @@ void Image::SetPalette(Palette *pPalette)
 	_pPalette.reset(pPalette);
 }
 
-bool Image::Read(Environment &env, Signal sig, Stream &stream, const char *imageType)
+bool Image::Read(Environment &env, Stream &stream, const char *imageType)
 {
-	ImageStreamer *pImageStreamer = NULL;
+	Signal &sig = env.GetSignal();
+	ImageStreamer *pImageStreamer = nullptr;
 	pImageStreamer = ImageStreamer::FindResponsible(sig, stream, imageType);
 	if (sig.IsSignalled()) return false;
-	if (pImageStreamer == NULL) {
+	if (pImageStreamer == nullptr) {
 		sig.SetError(ERR_FormatError, "unsupported image type");
 		return false;
 	}
-	return pImageStreamer->Read(env, sig, this, stream);
+	return pImageStreamer->Read(env, this, stream);
 }
 
-bool Image::Write(Environment &env, Signal sig, Stream &stream, const char *imageType)
+bool Image::Write(Environment &env, Stream &stream, const char *imageType)
 {
-	ImageStreamer *pImageStreamer = NULL;
+	Signal &sig = env.GetSignal();
+	ImageStreamer *pImageStreamer = nullptr;
 	pImageStreamer = ImageStreamer::FindResponsible(sig, stream, imageType);
 	if (sig.IsSignalled()) return false;
-	if (pImageStreamer == NULL) {
+	if (pImageStreamer == nullptr) {
 		sig.SetError(ERR_FormatError, "unsupported image type");
 		return false;
 	}
-	return pImageStreamer->Write(env, sig, this, stream);
+	return pImageStreamer->Write(env, this, stream);
 }
 
 int Image::CalcDIBBitCount() const
 {
-	if (GetPalette() == NULL) return static_cast<int>(GetBitsPerPixel());
+	if (GetPalette() == nullptr) return static_cast<int>(GetBitsPerPixel());
 	size_t nEntries = GetPalette()->CountEntries();
 	size_t nBits = 1;
 	for ( ; nEntries > static_cast<size_t>(1 << nBits); nBits++) ;
@@ -948,8 +915,9 @@ size_t Image::CalcDIBImageSize(int biBitCount, bool maskFlag) const
 	return bytes;
 }
 
-bool Image::ReadDIBPalette(Environment &env, Signal sig, Stream &stream, int biBitCount)
+bool Image::ReadDIBPalette(Environment &env, Stream &stream, int biBitCount)
 {
+	Signal &sig = env.GetSignal();
 	if (biBitCount == 24 || biBitCount == 32) return true;
 	if (!(biBitCount == 1 || biBitCount == 4 || biBitCount == 8)) {
 		sig.SetError(ERR_FormatError, "unsupported pixel depth %d", biBitCount);
@@ -968,8 +936,9 @@ bool Image::ReadDIBPalette(Environment &env, Signal sig, Stream &stream, int biB
 	return true;
 }
 
-bool Image::WriteDIBPalette(Environment &env, Signal sig, Stream &stream, int biBitCount)
+bool Image::WriteDIBPalette(Environment &env, Stream &stream, int biBitCount)
 {
+	Signal &sig = env.GetSignal();
 	if (biBitCount == 24 || biBitCount == 32) return true;
 	if (!(biBitCount == 1 || biBitCount == 4 || biBitCount == 8)) {
 		sig.SetError(ERR_FormatError, "unsupported pixel depth %d", biBitCount);
@@ -1007,7 +976,7 @@ bool Image::WriteDIBPalette(Environment &env, Signal sig, Stream &stream, int bi
 	return true;
 }
 
-bool Image::ReadDIB(Signal sig, Stream &stream,
+bool Image::ReadDIB(Signal &sig, Stream &stream,
 				int biWidth, int biHeight, int biBitCount, bool maskFlag)
 {
 	bool vertRevFlag = true;
@@ -1049,7 +1018,7 @@ bool Image::ReadDIB(Signal sig, Stream &stream,
 		size_t bytesPerLine = (biWidth + 1) / 2;
 		size_t bytesAlign = (bytesPerLine + 3) / 4 * 4 - bytesPerLine;
 		UChar ch;
-		std::auto_ptr<Scanner> pScanner(CreateScanner(
+		std::unique_ptr<Scanner> pScanner(CreateScanner(
 				vertRevFlag? SCAN_LeftBottomHorz : SCAN_LeftTopHorz));
 		if (stream.Read(sig, &ch, 1) < 1) return false;
 		int bitsRest = 8;
@@ -1072,7 +1041,7 @@ bool Image::ReadDIB(Signal sig, Stream &stream,
 	} else if (biBitCount == 8) {
 		size_t bytesAlign = (biWidth + 3) / 4 * 4 - biWidth;
 		UChar ch;
-		std::auto_ptr<Scanner> pScanner(CreateScanner(
+		std::unique_ptr<Scanner> pScanner(CreateScanner(
 				vertRevFlag? SCAN_LeftBottomHorz : SCAN_LeftTopHorz));
 		if (stream.Read(sig, &ch, 1) < 1) return false;
 		for (;;) {
@@ -1088,7 +1057,7 @@ bool Image::ReadDIB(Signal sig, Stream &stream,
 	} else if (biBitCount == 24) {
 		size_t bytesAlign = (3 * biWidth + 3) / 4 * 4 - 3 * biWidth;
 		UChar buff[3];
-		std::auto_ptr<Scanner> pScanner(CreateScanner(
+		std::unique_ptr<Scanner> pScanner(CreateScanner(
 				vertRevFlag? SCAN_LeftBottomHorz : SCAN_LeftTopHorz));
 		for (;;) {
 			if (stream.Read(sig, buff, 3) < 3) break;
@@ -1102,7 +1071,7 @@ bool Image::ReadDIB(Signal sig, Stream &stream,
 		if (sig.IsSignalled()) return false;
 	} else if (biBitCount == 32) {
 		UChar buff[4];
-		std::auto_ptr<Scanner> pScanner(CreateScanner(
+		std::unique_ptr<Scanner> pScanner(CreateScanner(
 				vertRevFlag? SCAN_LeftBottomHorz : SCAN_LeftTopHorz));
 		if (_format == FORMAT_RGBA) {
 			while (stream.Read(sig, buff, 4) == 4) {
@@ -1161,17 +1130,17 @@ bool Image::ReadDIB(Signal sig, Stream &stream,
 	return true;
 }
 
-bool Image::WriteDIB(Signal sig, Stream &stream, int biBitCount, bool maskFlag)
+bool Image::WriteDIB(Signal &sig, Stream &stream, int biBitCount, bool maskFlag)
 {
 	int biWidth = static_cast<int>(GetWidth());
-	int biHeight = static_cast<int>(GetHeight());
+	//int biHeight = static_cast<int>(GetHeight());
 	if (biBitCount == 1) {
 		if (_pPalette.IsNull()) return false;
 		size_t bytesPerLine = (biWidth + 7) / 8;
 		size_t bytesAlign = (bytesPerLine + 3) / 4 * 4 - bytesPerLine;
 		int bitsAccum = 0;
 		UChar chAccum = 0x00;
-		std::auto_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
+		std::unique_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
 		for (;;) {
 			UChar ch = static_cast<UChar>(
 							_pPalette->LookupNearest(pScanner->GetPointer()));
@@ -1201,7 +1170,7 @@ bool Image::WriteDIB(Signal sig, Stream &stream, int biBitCount, bool maskFlag)
 		size_t bytesAlign = (bytesPerLine + 3) / 4 * 4 - bytesPerLine;
 		int bitsAccum = 0;
 		UChar chAccum = 0x00;
-		std::auto_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
+		std::unique_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
 		for (;;) {
 			UChar ch = static_cast<UChar>(
 							_pPalette->LookupNearest(pScanner->GetPointer()));
@@ -1228,7 +1197,7 @@ bool Image::WriteDIB(Signal sig, Stream &stream, int biBitCount, bool maskFlag)
 	} else if (biBitCount == 8) {
 		if (_pPalette.IsNull()) return false;
 		size_t bytesAlign = (biWidth + 3) / 4 * 4 - biWidth;
-		std::auto_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
+		std::unique_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
 		for (;;) {
 			UChar ch = static_cast<UChar>(
 							_pPalette->LookupNearest(pScanner->GetPointer()));
@@ -1243,7 +1212,7 @@ bool Image::WriteDIB(Signal sig, Stream &stream, int biBitCount, bool maskFlag)
 	} else if (biBitCount == 24) {
 		size_t bytesAlign = ((3 * biWidth) + 3) / 4 * 4 - 3 * biWidth;
 		UChar buff[3];
-		std::auto_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
+		std::unique_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
 		for (;;) {
 			buff[0] = pScanner->GetB();
 			buff[1] = pScanner->GetG();
@@ -1258,7 +1227,7 @@ bool Image::WriteDIB(Signal sig, Stream &stream, int biBitCount, bool maskFlag)
 		}
 	} else if (biBitCount == 32) {
 		UChar buff[4];
-		std::auto_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
+		std::unique_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
 		for (;;) {
 			buff[0] = pScanner->GetB();
 			buff[1] = pScanner->GetG();
@@ -1280,7 +1249,7 @@ bool Image::WriteDIB(Signal sig, Stream &stream, int biBitCount, bool maskFlag)
 			// write AND bitmap
 			int bitsAccum = 0;
 			UChar chAccum = 0x00;
-			std::auto_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
+			std::unique_ptr<Scanner> pScanner(CreateScanner(SCAN_LeftBottomHorz));
 			for (;;) {
 				UChar ch = (pScanner->GetA() < 128)? 1 : 0;
 				chAccum |= ch << ((8 - 1) - bitsAccum);
@@ -1389,10 +1358,10 @@ Image::Scanner::~Scanner()
 //-----------------------------------------------------------------------------
 Iterator *Image::IteratorScan::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Image::IteratorScan::DoNext(Environment &env, Signal sig, Value &value)
+bool Image::IteratorScan::DoNext(Environment &env, Value &value)
 {
 	Image *pImage = _scanner.GetImage();
 	if (_doneFlag) return false;
@@ -1417,35 +1386,35 @@ void Image::IteratorScan::GatherFollower(Environment::Frame *pFrame, Environment
 //-----------------------------------------------------------------------------
 // ImageStreamer
 //-----------------------------------------------------------------------------
-ImageStreamer::List *ImageStreamer::_pList = NULL;
+ImageStreamer::List *ImageStreamer::_pList = nullptr;
 void ImageStreamer::Register(ImageStreamer *pImageStreamer)
 {
-	if (_pList == NULL) _pList = new List();
+	if (_pList == nullptr) _pList = new List();
 	_pList->push_back(pImageStreamer);
 }
 
-ImageStreamer *ImageStreamer::FindResponsible(Signal sig, Stream &stream, const char *imageType)
+ImageStreamer *ImageStreamer::FindResponsible(Signal &sig, Stream &stream, const char *imageType)
 {
-	if (_pList == NULL) return NULL;
-	if (imageType != NULL) return FindByImageType(imageType);
+	if (_pList == nullptr) return nullptr;
+	if (imageType != nullptr) return FindByImageType(imageType);
 	foreach (List, ppImageStreamer, *_pList) {
 		ImageStreamer *pImageStreamer = *ppImageStreamer;
 		if (pImageStreamer->IsResponsible(sig, stream)) return pImageStreamer;
 		if (sig.IsSignalled()) break;
 	}
-	return NULL;
+	return nullptr;
 }
 
 ImageStreamer *ImageStreamer::FindByImageType(const char *imageType)
 {
-	if (_pList == NULL) return NULL;
+	if (_pList == nullptr) return nullptr;
 	foreach (List, ppImageStreamer, *_pList) {
 		ImageStreamer *pImageStreamer = *ppImageStreamer;
 		if (::strcasecmp(pImageStreamer->GetImageType(), imageType) == 0) {
 			return pImageStreamer;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 }
