@@ -16,9 +16,16 @@ Iterator::~Iterator()
 bool Iterator::IsSequence() const { return false; }
 bool Iterator::IsSequenceInf() const { return false; }
 
+size_t Iterator::GetLength() const
+{
+	// This function should return a valid result when the finiteness is
+	// set to FinitePredictable.
+	return 0;
+}
+
 Iterator *Iterator::_Clone()
 {
-	if (_pShare.get() == NULL) _pShare.reset(new Share());
+	if (_pShare.get() == nullptr) _pShare.reset(new Share());
 	int id = _pShare->Register();
 	return new Iterator_GenericClone(Reference(this), id);
 }
@@ -28,11 +35,11 @@ Iterator *Iterator::Clone() const
 	return const_cast<Iterator *>(this)->_Clone();
 }
 
-bool Iterator::NextShared(Environment &env, Signal sig, int id, Value &value)
+bool Iterator::NextShared(Environment &env, int id, Value &value)
 {
-	if (_pShare.get() == NULL) {
+	if (_pShare.get() == nullptr) {
 		for (;;) {
-			if (!DoNext(env, sig, value)) return false;
+			if (!DoNext(env, value)) return false;
 			if (!IsSkipInvalid() || value.IsValid()) break;
 		}
 	} else if (_pShare->Next(id, value)) {
@@ -41,7 +48,7 @@ bool Iterator::NextShared(Environment &env, Signal sig, int id, Value &value)
 		return false;
 	} else {
 		for (;;) {
-			if (!DoNext(env, sig, value)) {
+			if (!DoNext(env, value)) {
 				_pShare->SetDone();
 				return false;
 			}
@@ -52,78 +59,64 @@ bool Iterator::NextShared(Environment &env, Signal sig, int id, Value &value)
 	return true;
 }
 
-bool Iterator::Consume(Environment &env, Signal sig)
+bool Iterator::Consume(Environment &env)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return false;
 	}
 	Value value;
-	while (Next(env, sig, value)) ;
+	while (Next(env, value)) ;
 	return !sig.IsSignalled();
 }
 
-Value Iterator::ToList(Environment &env, Signal sig,
-							bool alwaysListFlag, bool excludeNilFlag)
+Value Iterator::ToList(Environment &env, bool alwaysListFlag, bool excludeNilFlag)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value result;
-	ValueList *pValList = NULL;
+	Object_list *pObjList = nullptr;
 	size_t cnt = 0;
 	Value value;
 	if (alwaysListFlag) {
-		pValList = &result.InitAsList(env);
+		pObjList = result.InitAsList(env);
 	}
-	while (Next(env, sig, value)) {
-		if (pValList == NULL && !value.IsUndefined()) {
-			pValList = &result.InitAsList(env, cnt, Value::Null);
+	while (Next(env, value)) {
+		if (pObjList == nullptr && !value.IsUndefined()) {
+			pObjList = result.InitAsList(env, cnt, Value::Nil);
 		}
 		if (value.IsValid()) {
-			if (pValList == NULL) {
-				pValList = &result.InitAsList(env, cnt, Value::Null);
+			if (pObjList == nullptr) {
+				pObjList = result.InitAsList(env, cnt, Value::Nil);
 			}
-			pValList->push_back(value);
+			pObjList->Add(value);
 		} else if (excludeNilFlag) {
 			// nothing to do
-		} else if (pValList != NULL) {
-			pValList->push_back(value);
+		} else if (pObjList != nullptr) {
+			pObjList->Add(value);
 		}
 		cnt++;
 	}
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	return result;
 }
 
-Value Iterator::Eval(Environment &env, Signal sig, Args &args)
+Value Iterator::Reduce(Environment &env, Value valueAccum, const Function *pFuncBlock)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
-	}
-	Value value, result;
-	Function::ResultComposer resultComposer(env, args, result);
-	while (Next(env, sig, value)) {
-		if (!resultComposer.Store(env, sig, value)) return Value::Null;
-	}
-	if (sig.IsSignalled()) return Value::Null;
-	return result;
-}
-
-Value Iterator::Reduce(Environment &env, Signal sig,
-							Value valueAccum, const Function *pFuncBlock)
-{
-	if (IsInfinite()) {
-		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value value;
-	while (Next(env, sig, value)) {
-		AutoPtr<Args> pArgsSub(new Args());
-		pArgsSub->SetValues(value, valueAccum);
-		Value result = pFuncBlock->Eval(env, sig, *pArgsSub);
+	while (Next(env, value)) {
+		AutoPtr<Argument> pArgSub(new Argument(pFuncBlock));
+		if (!pArgSub->StoreValue(env, value, valueAccum)) return Value::Nil;
+		Value result = pFuncBlock->Eval(env, *pArgSub);
 		if (!sig.IsSignalled()) {
 			// nothing to do
 		} else if (sig.IsBreak()) {
@@ -136,119 +129,120 @@ Value Iterator::Reduce(Environment &env, Signal sig,
 			sig.ClearSignal();
 			if (result.IsInvalid()) continue;
 		} else if (sig.IsReturn()) {
-			return Value::Null;
+			return Value::Nil;
 		} else {
-			return Value::Null;
+			return Value::Nil;
 		}
 		valueAccum = result;
 	}
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	return valueAccum;
 }
 
-Value Iterator::MinMax(Environment &env, Signal sig,
-									bool maxFlag, const SymbolSet &attrs)
+Value Iterator::MinMax(Environment &env, bool maxFlag, const SymbolSet &attrs)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value valueHit;
-	if (!Next(env, sig, valueHit)) return Value::Null;
+	if (!Next(env, valueHit)) return Value::Nil;
 	Value result;
 	if (attrs.IsSet(Gura_Symbol(index))) {
 		int idxHit = GetIndexCur();
 		Value value;
-		while (Next(env, sig, value)) {
-			int cmp = Value::Compare(env, sig, valueHit, value);
-			if (sig.IsSignalled()) return Value::Null;
+		while (Next(env, value)) {
+			int cmp = Value::Compare(env, valueHit, value);
+			if (sig.IsSignalled()) return Value::Nil;
 			if (maxFlag) cmp = -cmp;
 			if (cmp > 0) {
 				valueHit = value;
 				idxHit = GetIndexCur();
 			}
 		}
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		result.SetNumber(idxHit);
 	} else if (attrs.IsSet(Gura_Symbol(last_index))) {
 		int idxHit = GetIndexCur();
 		Value value;
-		while (Next(env, sig, value)) {
-			int cmp = Value::Compare(env, sig, valueHit, value);
-			if (sig.IsSignalled()) return Value::Null;
+		while (Next(env, value)) {
+			int cmp = Value::Compare(env, valueHit, value);
+			if (sig.IsSignalled()) return Value::Nil;
 			if (maxFlag) cmp = -cmp;
 			if (cmp >= 0) {
 				valueHit = value;
 				idxHit = GetIndexCur();
 			}
 		}
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		result.SetNumber(idxHit);
 	} else if (attrs.IsSet(Gura_Symbol(indices))) {
 		int idxHit = GetIndexCur();
-		ValueList &resultList = result.InitAsList(env);
-		resultList.push_back(Value(idxHit));
+		Object_list *pObjListResult = result.InitAsList(env);
+		pObjListResult->Add(Value(idxHit));
 		Value value;
-		while (Next(env, sig, value)) {
-			int cmp = Value::Compare(env, sig, valueHit, value);
-			if (sig.IsSignalled()) return Value::Null;
+		while (Next(env, value)) {
+			int cmp = Value::Compare(env, valueHit, value);
+			if (sig.IsSignalled()) return Value::Nil;
 			if (maxFlag) cmp = -cmp;
 			if (cmp > 0) {
 				int idxHit = GetIndexCur();
 				valueHit = value;
-				resultList.clear();
-				resultList.push_back(Value(idxHit));
+				pObjListResult->Clear();
+				pObjListResult->Add(Value(idxHit));
 			} else if (cmp == 0) {
 				int idxHit = GetIndexCur();
-				resultList.push_back(Value(static_cast<Number>(idxHit)));
+				pObjListResult->Add(Value(static_cast<Number>(idxHit)));
 			}
 		}
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 	} else {
 		Value value;
-		while (Next(env, sig, value)) {
-			int cmp = Value::Compare(env, sig, valueHit, value);
-			if (sig.IsSignalled()) return Value::Null;
+		while (Next(env, value)) {
+			int cmp = Value::Compare(env, valueHit, value);
+			if (sig.IsSignalled()) return Value::Nil;
 			if (maxFlag) cmp = -cmp;
 			if (cmp > 0) {
 				valueHit = value;
 			}
 		}
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		result = valueHit;
 	}
 	return result;
 }
 
-void Iterator::SetError_InvalidDataTypeOfElement(Signal sig)
+void Iterator::SetError_InvalidDataTypeOfElement(Signal &sig)
 {
 	sig.SetError(ERR_ValueError, "invalid data type of element");
 }
 
-void Iterator::SetError_InfiniteNotAllowed(Signal sig)
+void Iterator::SetError_InfiniteNotAllowed(Signal &sig)
 {
 	sig.SetError(ERR_IteratorError, "cannot evaluate infinite iterator");
 }
 
-Value Iterator::Sum(Environment &env, Signal sig, size_t &cnt)
+Value Iterator::Sum(Environment &env, size_t &cnt)
 {
+	Signal &sig = env.GetSignal();
 	cnt = 0;
 	Value value;
-	if (!Next(env, sig, value)) return Value::Null;
+	if (!Next(env, value)) return Value::Nil;
 	if (!value.Is_number()) {
 		const Operator *pOperatorAdd = env.GetOperator(OPTYPE_Add);
 		Value valResult(value);
 		cnt = 1;
-		while (Next(env, sig, value)) {
-			valResult = pOperatorAdd->EvalBinary(env, sig, valResult, value);
+		while (Next(env, value)) {
+			valResult = pOperatorAdd->EvalBinary(env, valResult, value, FLAG_None);
 			cnt++;
-			if (sig.IsSignalled()) return Value::Null;
+			if (sig.IsSignalled()) return Value::Nil;
 		}
 		return valResult;
 	}
 	Number result = value.GetNumber();
 	cnt = 1;
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (value.Is_number()) {
 			result += value.GetNumber();
 			cnt++;
@@ -256,31 +250,32 @@ Value Iterator::Sum(Environment &env, Signal sig, size_t &cnt)
 			const Operator *pOperatorAdd = env.GetOperator(OPTYPE_Add);
 			Value valResult(result);
 			do {
-				valResult = pOperatorAdd->EvalBinary(env, sig, valResult, value);
+				valResult = pOperatorAdd->EvalBinary(env, valResult, value, FLAG_None);
 				cnt++;
-				if (sig.IsSignalled()) return Value::Null;
-			} while (Next(env, sig, value));
+				if (sig.IsSignalled()) return Value::Nil;
+			} while (Next(env, value));
 			return valResult;
 		}
 	}
 	return Value(result);
 }
 
-Value Iterator::Prod(Environment &env, Signal sig)
+Value Iterator::Prod(Environment &env)
 {
+	Signal &sig = env.GetSignal();
 	Value value;
-	if (!Next(env, sig, value)) return Value::Null;
+	if (!Next(env, value)) return Value::Nil;
 	if (!value.Is_number()) {
 		const Operator *pOperatorMul = env.GetOperator(OPTYPE_Mul);
 		Value valResult(value);
-		while (Next(env, sig, value)) {
-			valResult = pOperatorMul->EvalBinary(env, sig, valResult, value);
-			if (sig.IsSignalled()) return Value::Null;
+		while (Next(env, value)) {
+			valResult = pOperatorMul->EvalBinary(env, valResult, value, FLAG_None);
+			if (sig.IsSignalled()) return Value::Nil;
 		}
 		return valResult;
 	}
 	Number result = value.GetNumber();
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (value.Is_number()) {
 			if (result == 0) break;
 			result *= value.GetNumber();
@@ -288,46 +283,48 @@ Value Iterator::Prod(Environment &env, Signal sig)
 			const Operator *pOperatorMul = env.GetOperator(OPTYPE_Mul);
 			Value valResult(result);
 			do {
-				valResult = pOperatorMul->EvalBinary(env, sig, valResult, value);
-				if (sig.IsSignalled()) return Value::Null;
-			} while (Next(env, sig, value));
+				valResult = pOperatorMul->EvalBinary(env, valResult, value, FLAG_None);
+				if (sig.IsSignalled()) return Value::Nil;
+			} while (Next(env, value));
 			return valResult;
 		}
 	}
 	return Value(result);
 }
 
-Value Iterator::Average(Environment &env, Signal sig, size_t &cnt)
+Value Iterator::Average(Environment &env, size_t &cnt)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
-	Value valueSum = Clone()->Sum(env, sig, cnt);
+	Value valueSum = Clone()->Sum(env, cnt);
 	if (valueSum.IsInvalid()) {
-		return Value::Null;
+		return Value::Nil;
 	} else if (valueSum.Is_number()) {
 		return Value(valueSum.GetNumber() / static_cast<Number>(cnt));
 	} else if (valueSum.Is_complex()) {
 		return Value(valueSum.GetComplex() / static_cast<Number>(cnt));
 	} else {
 		const Operator *pOperatorDiv = env.GetOperator(OPTYPE_Div);
-		return pOperatorDiv->EvalBinary(env, sig, valueSum, Value(cnt));
+		return pOperatorDiv->EvalBinary(env, valueSum, Value(cnt), FLAG_None);
 	}
 }
 
-Value Iterator::Variance(Environment &env, Signal sig, size_t &cnt)
+Value Iterator::Variance(Environment &env, size_t &cnt)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	// this doesn't use a variance calculation formula V(x) = E(x**2) - E(x)**2
 	// to minimize calculation error.
-	Value valueAve = Clone()->Average(env, sig, cnt);
-	if (!valueAve.IsNumberOrComplex()) return Value::Null;
+	Value valueAve = Clone()->Average(env, cnt);
+	if (!valueAve.IsNumberOrComplex()) return Value::Nil;
 	Value value;
-	if (!Next(env, sig, value)) return Value::Null;
+	if (!Next(env, value)) return Value::Nil;
 	if (value.Is_number() && valueAve.Is_number()) {
 		Number result;
 		Number average = valueAve.GetNumber();
@@ -335,26 +332,26 @@ Value Iterator::Variance(Environment &env, Signal sig, size_t &cnt)
 			Number tmp = value.GetNumber() - average;
 			result = tmp * tmp;
 		} while (0);
-		while (Next(env, sig, value)) {
+		while (Next(env, value)) {
 			if (value.Is_number()) {
 				Number tmp = value.GetNumber() - average;
 				result += tmp * tmp;
 			} else if (value.Is_complex()) {
-				while (Next(env, sig, value)) {
+				while (Next(env, value)) {
 					if (value.IsNumberOrComplex()) {
 						Complex tmp = value.GetComplex() - average;
 						result += std::norm(tmp);
 					} else {
 						SetError_InvalidDataTypeOfElement(sig);
-						return Value::Null;
+						return Value::Nil;
 					}
 				}
 			} else {
 				SetError_InvalidDataTypeOfElement(sig);
-				return Value::Null;
+				return Value::Nil;
 			}
 		}
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		return Value(result / static_cast<Number>(cnt));
 	} else if (value.IsNumberOrComplex()) {
 		Number result;
@@ -363,78 +360,82 @@ Value Iterator::Variance(Environment &env, Signal sig, size_t &cnt)
 			Complex tmp = value.GetComplex() - average;
 			result = std::norm(tmp);
 		} while (0);
-		while (Next(env, sig, value)) {
+		while (Next(env, value)) {
 			if (value.IsNumberOrComplex()) {
 				Complex tmp = value.GetComplex() - average;
 				result += std::norm(tmp);
 			} else {
 				SetError_InvalidDataTypeOfElement(sig);
-				return Value::Null;
+				return Value::Nil;
 			}
 		}
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		return Value(result / static_cast<Number>(cnt));
 	} else {
 		SetError_InvalidDataTypeOfElement(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 }
 
-Value Iterator::StandardDeviation(Environment &env, Signal sig, size_t &cnt)
+Value Iterator::StandardDeviation(Environment &env, size_t &cnt)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
-	Value valueVar = Clone()->Variance(env, sig, cnt);
-	if (!valueVar.Is_number()) return Value::Null;
+	Value valueVar = Clone()->Variance(env, cnt);
+	if (!valueVar.Is_number()) return Value::Nil;
 	return Value(::sqrt(valueVar.GetNumber()));
 }
 
-Value Iterator::And(Environment &env, Signal sig)
+Value Iterator::And(Environment &env)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value value;
-	if (!Next(env, sig, value)) return Value::Null;
+	if (!Next(env, value)) return Value::Nil;
 	if (!value.GetBoolean()) return Value(false);
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (!value.GetBoolean()) return Value(false);
 	}
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	return Value(true);
 }
 
-Value Iterator::Or(Environment &env, Signal sig)
+Value Iterator::Or(Environment &env)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value value;
-	if (!Next(env, sig, value)) return Value::Null;
+	if (!Next(env, value)) return Value::Nil;
 	if (value.GetBoolean()) return Value(true);
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (value.GetBoolean()) return Value(true);
 	}
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	return Value(false);
 }
 
-size_t Iterator::Find(Environment &env, Signal sig, const Value &criteria, Value &value)
+size_t Iterator::Find(Environment &env, const Value &criteria, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	if (criteria.Is_function()) {
 		if (IsInfinite()) {
 			SetError_InfiniteNotAllowed(sig);
 			return InvalidSize;
 		}
 		const Function *pFunc = criteria.GetFunction();
-		while (Next(env, sig, value)) {
-			AutoPtr<Args> pArgs(new Args());
-			pArgs->SetValue(value);
-			Value valueFlag = pFunc->Eval(env, sig, *pArgs);
+		while (Next(env, value)) {
+			AutoPtr<Argument> pArg(new Argument(pFunc));
+			if (!pArg->StoreValue(env, value)) return InvalidSize;
+			Value valueFlag = pFunc->Eval(env, *pArg);
 			if (sig.IsSignalled()) return InvalidSize;
 			if (valueFlag.GetBoolean()) return GetIndexCur();
 		}
@@ -446,15 +447,15 @@ size_t Iterator::Find(Environment &env, Signal sig, const Value &criteria, Value
 			SetError_InfiniteNotAllowed(sig);
 			return InvalidSize;
 		}
-		while (Next(env, sig, value)) {
+		while (Next(env, value)) {
 			Value valueCriteria;
-			if (!pIteratorCriteria->Next(env, sig, valueCriteria)) break;
+			if (!pIteratorCriteria->Next(env, valueCriteria)) break;
 			if (valueCriteria.GetBoolean()) return GetIndexCur();
 		}
 		return InvalidSize;
 	} else {
-		while (Next(env, sig, value)) {
-			//int cmp = Value::Compare(env, sig, value, criteria);
+		while (Next(env, value)) {
+			//int cmp = Value::Compare(env, value, criteria);
 			//if (sig.IsSignalled()) return InvalidSize;
 			//if (cmp == 0) return GetIndexCur();
 			if (value.Is(criteria)) return GetIndexCur();
@@ -463,20 +464,22 @@ size_t Iterator::Find(Environment &env, Signal sig, const Value &criteria, Value
 	return InvalidSize;
 }
 
-size_t Iterator::FindTrue(Environment &env, Signal sig, Value &value)
+size_t Iterator::FindTrue(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return 0;
 	}
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (value.GetBoolean()) return GetIndexCur();
 	}
 	return InvalidSize;
 }
 
-size_t Iterator::Count(Environment &env, Signal sig, const Value &criteria)
+size_t Iterator::Count(Environment &env, const Value &criteria)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return 0;
@@ -485,18 +488,18 @@ size_t Iterator::Count(Environment &env, Signal sig, const Value &criteria)
 	if (criteria.Is_function()) {
 		const Function *pFunc = criteria.GetFunction();
 		Value value;
-		while (Next(env, sig, value)) {
-			AutoPtr<Args> pArgs(new Args());
-			pArgs->SetValue(value);
-			Value valueFlag = pFunc->Eval(env, sig, *pArgs);
+		while (Next(env, value)) {
+			AutoPtr<Argument> pArg(new Argument(pFunc));
+			if (!pArg->StoreValue(env, value)) return 0;
+			Value valueFlag = pFunc->Eval(env, *pArg);
 			if (sig.IsSignalled()) return 0;
 			if (valueFlag.GetBoolean()) cnt++;
 		}
 		if (sig.IsSignalled()) return 0;
 	} else {
 		Value value;
-		while (Next(env, sig, value)) {
-			int cmp = Value::Compare(env, sig, value, criteria);
+		while (Next(env, value)) {
+			int cmp = Value::Compare(env, value, criteria);
 			if (sig.IsSignalled()) return 0;
 			if (cmp == 0) cnt++;
 		}
@@ -504,112 +507,117 @@ size_t Iterator::Count(Environment &env, Signal sig, const Value &criteria)
 	return cnt;
 }
 
-size_t Iterator::CountTrue(Environment &env, Signal sig)
+size_t Iterator::CountTrue(Environment &env)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return 0;
 	}
 	size_t cnt = 0;
 	Value value;
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (value.GetBoolean()) cnt++;
 	}
 	return cnt;
 }
 
-Iterator *Iterator::Filter(Environment &env, Signal sig, const Value &criteria)
+Iterator *Iterator::Filter(Environment &env, const Value &criteria)
 {
+	Signal &sig = env.GetSignal();
 	if (criteria.Is_function()) {
 		Object_function *pFuncObjCriteria =
 			Object_function::Reference(Object_function::GetObject(criteria));
-		return new Iterator_FilterWithFunc(new Environment(env), this, pFuncObjCriteria);
+		return new Iterator_FilterWithFunc(env.Clone(), this, pFuncObjCriteria);
 	} else if (criteria.Is_list() || criteria.Is_iterator()) {
 		Iterator *pIteratorCriteria = criteria.CreateIterator(sig);
-		if (sig.IsSignalled()) return NULL;
+		if (sig.IsSignalled()) return nullptr;
 		return new Iterator_FilterWithIter(this, pIteratorCriteria);
 	} else {
 		sig.SetError(ERR_ValueError, "invalid type of criteria for filter");
-		return NULL;
+		return nullptr;
 	}
 }
 
-Iterator *Iterator::While(Environment &env, Signal sig, const Value &criteria)
+Iterator *Iterator::While(Environment &env, const Value &criteria)
 {
+	Signal &sig = env.GetSignal();
 	if (criteria.Is_function()) {
 		Object_function *pFuncObjCriteria = 
 			Object_function::Reference(Object_function::GetObject(criteria));
-		return new Iterator_WhileWithFunc(new Environment(env), this, pFuncObjCriteria);
+		return new Iterator_WhileWithFunc(env.Clone(), this, pFuncObjCriteria);
 	} else if (criteria.Is_list() || criteria.Is_iterator()) {
 		Iterator *pIteratorCriteria = criteria.CreateIterator(sig);
-		if (sig.IsSignalled()) return NULL;
+		if (sig.IsSignalled()) return nullptr;
 		return new Iterator_WhileWithIter(this, pIteratorCriteria);
 	} else {
 		sig.SetError(ERR_ValueError, "invalid type of criteria for while");
-		return NULL;
+		return nullptr;
 	}
 }
 
-Iterator *Iterator::Since(Environment &env, Signal sig,
-									const Value &criteria, bool containFirstFlag)
+Iterator *Iterator::Since(Environment &env, const Value &criteria, bool containFirstFlag)
 {
+	Signal &sig = env.GetSignal();
 	if (criteria.Is_function()) {
 		Object_function *pFuncObjCriteria = 
 			Object_function::Reference(Object_function::GetObject(criteria));
-		return new Iterator_SinceWithFunc(new Environment(env), this, pFuncObjCriteria, containFirstFlag);
+		return new Iterator_SinceWithFunc(env.Clone(), this, pFuncObjCriteria, containFirstFlag);
 	} else if (criteria.Is_list() || criteria.Is_iterator()) {
 		Iterator *pIteratorCriteria = criteria.CreateIterator(sig);
-		if (sig.IsSignalled()) return NULL;
+		if (sig.IsSignalled()) return nullptr;
 		return new Iterator_SinceWithIter(this, pIteratorCriteria, containFirstFlag);
 	} else {
 		sig.SetError(ERR_ValueError, "invalid type of criteria for since");
-		return NULL;
+		return nullptr;
 	}
 }
 
-Iterator *Iterator::Until(Environment &env, Signal sig,
-									const Value &criteria, bool containLastFlag)
+Iterator *Iterator::Until(Environment &env, const Value &criteria, bool containLastFlag)
 {
+	Signal &sig = env.GetSignal();
 	if (criteria.Is_function()) {
 		Object_function *pFuncObjCriteria = 
 			Object_function::Reference(Object_function::GetObject(criteria));
-		return new Iterator_UntilWithFunc(new Environment(env), this, pFuncObjCriteria, containLastFlag);
+		return new Iterator_UntilWithFunc(env.Clone(), this, pFuncObjCriteria, containLastFlag);
 	} else if (criteria.Is_list() || criteria.Is_iterator()) {
 		Iterator *pIteratorCriteria = criteria.CreateIterator(sig);
-		if (sig.IsSignalled()) return NULL;
+		if (sig.IsSignalled()) return nullptr;
 		return new Iterator_UntilWithIter(this, pIteratorCriteria, containLastFlag);
 	} else {
 		sig.SetError(ERR_ValueError, "invalid type of criteria for since");
-		return NULL;
+		return nullptr;
 	}
 }
 
-bool Iterator::DoesContain(Environment &env, Signal sig, const Value &value)
+bool Iterator::DoesContain(Environment &env, const Value &value)
 {
+	Signal &sig = env.GetSignal();
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return false;
 	}
 	Value valueToFind;
-	while (Next(env, sig, valueToFind)) {
-		int cmp = Value::Compare(env, sig, value, valueToFind);
+	while (Next(env, valueToFind)) {
+		int cmp = Value::Compare(env, value, valueToFind);
 		if (sig.IsSignalled()) return false;
 		if (cmp == 0) return true;
 	}
 	return false;
 }
 
-String Iterator::Join(Environment &env, Signal sig, const char *sep)
+String Iterator::Join(Environment &env, const char *sep)
 {
+	Signal &sig = env.GetSignal();
 	String rtn;
 	Value value;
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return rtn;
 	}
-	if (Next(env, sig, value)) {
+	if (Next(env, value)) {
 		rtn += value.ToString(false);
-		while (Next(env, sig, value)) {
+		while (Next(env, value)) {
 			rtn += sep;
 			rtn += value.ToString(false);
 		}
@@ -617,15 +625,16 @@ String Iterator::Join(Environment &env, Signal sig, const char *sep)
 	return rtn;
 }
 
-Binary Iterator::Joinb(Environment &env, Signal sig)
+Binary Iterator::Joinb(Environment &env)
 {
+	Signal &sig = env.GetSignal();
 	Binary rtn;
 	Value value;
 	if (IsInfinite()) {
 		SetError_InfiniteNotAllowed(sig);
 		return rtn;
 	}
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (!value.Is_binary()) {
 			sig.SetError(ERR_ValueError, "invalid value type");
 			return "";
@@ -635,19 +644,21 @@ Binary Iterator::Joinb(Environment &env, Signal sig)
 	return rtn;
 }
 
-void Iterator::PrintEach(Environment &env, Signal sig, Stream *pStream)
+void Iterator::PrintEach(Environment &env, Stream *pStream)
 {
+	Signal &sig = env.GetSignal();
 	Value value;
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		pStream->Print(sig, value.ToString(false).c_str());
 		if (sig.IsSignalled()) break;
 	}
 }
 
-void Iterator::PrintfEach(Environment &env, Signal sig, Stream *pStream, const char *format)
+void Iterator::PrintfEach(Environment &env, Stream *pStream, const char *format)
 {
+	Signal &sig = env.GetSignal();
 	Value value;
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		if (value.Is_list()) {
 			pStream->PrintFmt(sig, format, value.GetList());
 		} else {
@@ -657,21 +668,54 @@ void Iterator::PrintfEach(Environment &env, Signal sig, Stream *pStream, const c
 	}
 }
 
-void Iterator::PrintlnEach(Environment &env, Signal sig, Stream *pStream)
+void Iterator::PrintlnEach(Environment &env, Stream *pStream)
 {
+	Signal &sig = env.GetSignal();
 	Value value;
-	while (Next(env, sig, value)) {
+	while (Next(env, value)) {
 		pStream->Println(sig, value.ToString(false).c_str());
 		if (sig.IsSignalled()) break;
 	}
 }
 
+size_t Iterator::GetLengthEx(Environment &env)
+{
+	if (IsFinitePredictable()) return GetLength();
+	Signal &sig = env.GetSignal();
+	if (IsInfinite()) {
+		SetError_InfiniteNotAllowed(sig);
+		return 0;
+	}
+	size_t len = 0;
+	AutoPtr<Iterator> pIterator(Clone());
+	Value value;
+	for ( ; pIterator->Next(env, value); len++) ;
+	return sig.IsSignalled()? 0 : len;
+}
+
 String Iterator::ToString() const
 {
 	return String("");
 }
 
-//-----------------------------------------------------------------------------
+bool Iterator::DoDirProp(Environment &env, SymbolSet &symbols)
+{
+	return true;
+}
+
+Value Iterator::DoGetProp(Environment &env, const Symbol *pSymbol,
+					const SymbolSet &attrs, bool &evaluatedFlag)
+{
+	return Value::Nil;
+}
+
+Value Iterator::DoSetProp(Environment &env, const Symbol *pSymbol, const Value &value,
+						  const SymbolSet &attrs, bool &evaluatedFlag)
+{
+	return Value::Nil;
+}
+
+///-----------------------------------------------------------------------------
 // Iterator::Share
 //-----------------------------------------------------------------------------
 Iterator::Share::Share() : _doneFlag(false), _indexMin(0)
@@ -727,13 +771,13 @@ IteratorOwner::~IteratorOwner()
 	}
 }
 
-bool IteratorOwner::Next(Environment &env, Signal sig, ValueList &valList)
+bool IteratorOwner::Next(Environment &env, ValueList &valList)
 {
 	valList.clear();
 	foreach (IteratorOwner, ppIterator, *this) {
 		Iterator *pIterator = *ppIterator;
 		Value value;
-		if (!pIterator->Next(env, sig, value)) return false;
+		if (!pIterator->Next(env, value)) return false;
 		valList.push_back(value);
 	}
 	return true;
@@ -755,24 +799,4 @@ bool IteratorOwner::IsInfinite() const
 	return true;
 }
 
-bool IteratorOwner::PrepareForMap(Signal sig,
-				const DeclarationList &declList, const ValueList &valListArg)
-{
-	ValueList::const_iterator pValue = valListArg.begin();
-	DeclarationList::const_iterator ppDecl = declList.begin();
-	for ( ; pValue != valListArg.end() && ppDecl != declList.end(); pValue++) {
-		const Declaration *pDecl = *ppDecl;
-		Iterator *pIterator = NULL;
-		if (pDecl->ShouldImplicitMap(*pValue)) {
-			pIterator = pValue->CreateIterator(sig);
-			if (pIterator == NULL) return false;
-		} else {
-			pIterator = new Iterator_Constant(*pValue);
-		}
-		push_back(pIterator);
-		if (!pDecl->IsVariableLength()) ppDecl++;
-	}
-	return true;
-}
-
 }
