@@ -8,7 +8,7 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // Palette
 //-----------------------------------------------------------------------------
-Palette::Palette() : _cntRef(1), _nEntries(0), _buff(NULL)
+Palette::Palette() : _cntRef(1), _nEntries(0), _buff(nullptr)
 {
 }
 
@@ -26,7 +26,7 @@ Palette::~Palette()
 
 void Palette::AllocBuff(size_t nEntries)
 {
-	_buff = NULL;
+	_buff = nullptr;
 	_nEntries = nEntries;
 	if (_nEntries > 0) {
 		_pMemory.reset(new MemoryHeap(GetBuffSize()));
@@ -53,10 +53,10 @@ void Palette::ResizeBuff(size_t nEntries, size_t nEntriesToCopy)
 	}
 }
 
-bool Palette::Prepare(Signal sig, const Symbol *pSymbol)
+bool Palette::Prepare(Signal &sig, const Symbol *pSymbol)
 {
 	size_t nEntries = 0;
-	const UChar *rgb = NULL;
+	const UChar *rgb = nullptr;
 	if (pSymbol->IsIdentical(Gura_Symbol(mono))) {
 		nEntries = 2, rgb = _rgb_Mono;
 	} else if (pSymbol->IsIdentical(Gura_Symbol(basic))) {
@@ -135,7 +135,7 @@ bool Palette::UpdateByImage(const Image *pImage, ShrinkMode shrinkMode)
 	return true;
 }
 
-bool Palette::UpdateByImage(Signal sig, const Image *pImage, ShrinkMode shrinkMode)
+bool Palette::UpdateByImage(Signal &sig, const Image *pImage, ShrinkMode shrinkMode)
 {
 	if (UpdateByImage(pImage, shrinkMode)) return true;
 	sig.SetError(ERR_ValueError,
@@ -163,7 +163,7 @@ bool Palette::UpdateByPalette(const Palette *pPalette, ShrinkMode shrinkMode)
 	return true;
 }
 
-bool Palette::UpdateByPalette(Signal sig, const Palette *pPalette, ShrinkMode shrinkMode)
+bool Palette::UpdateByPalette(Signal &sig, const Palette *pPalette, ShrinkMode shrinkMode)
 {
 	if (UpdateByPalette(pPalette, shrinkMode)) return true;
 	sig.SetError(ERR_ValueError,
@@ -747,10 +747,10 @@ const UChar Palette::_rgb_WebSafe[] = {
 //-----------------------------------------------------------------------------
 Iterator *Palette::IteratorEach::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Palette::IteratorEach::DoNext(Environment &env, Signal sig, Value &value)
+bool Palette::IteratorEach::DoNext(Environment &env, Value &value)
 {
 	if (_idx >= _pPalette->CountEntries()) return false;
 	value = _pPalette->GetColorValue(env, _idx);
