@@ -8,25 +8,25 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // SimpleStream
 //-----------------------------------------------------------------------------
-void SimpleStream::Print(Signal sig, const char *str)
+void SimpleStream::Print(Signal &sig, const char *str)
 {
 	for ( ; *str != '\0'; str++) PutChar(sig, *str);
 }
 
-void SimpleStream::Println(Signal sig, const char *str)
+void SimpleStream::Println(Signal &sig, const char *str)
 {
 	Print(sig, str);
 	PutChar(sig, '\n');
 }
 
-void SimpleStream::PrintFmt(Signal sig, const char *format, const ValueList &valList)
+void SimpleStream::PrintFmt(Signal &sig, const char *format, const ValueList &valList)
 {
 	String str = Formatter::FormatValueList(sig, format, valList);
 	if (sig.IsSignalled()) return;
 	Print(sig, str.c_str());
 }
 
-void SimpleStream::Printf(Signal sig, const char *format, ...)
+void SimpleStream::Printf(Signal &sig, const char *format, ...)
 {
 	va_list ap;
 	va_start(ap, format);
@@ -36,7 +36,7 @@ void SimpleStream::Printf(Signal sig, const char *format, ...)
 	Print(sig, str.c_str());
 }
 
-bool SimpleStream::ReadLine(Signal sig, String &str, bool includeEOLFlag)
+bool SimpleStream::ReadLine(Signal &sig, String &str, bool includeEOLFlag)
 {
 	int ch = GetChar(sig);
 	if (ch < 0) return false;
@@ -50,7 +50,7 @@ bool SimpleStream::ReadLine(Signal sig, String &str, bool includeEOLFlag)
 	return !sig.IsSignalled();
 }
 
-bool SimpleStream::ReadLines(Signal sig, StringList &strList, bool includeEOLFlag)
+bool SimpleStream::ReadLines(Signal &sig, StringList &strList, bool includeEOLFlag)
 {
 	for (;;) {
 		String str;
@@ -60,7 +60,7 @@ bool SimpleStream::ReadLines(Signal sig, StringList &strList, bool includeEOLFla
 	return !sig.IsSignalled();
 }
 
-void SimpleStream::Dump(Signal sig, const void *buff, size_t bytes, bool upperFlag)
+void SimpleStream::Dump(Signal &sig, const void *buff, size_t bytes, bool upperFlag)
 {
 	int iCol = 0;
 	String strHex, strASCII;
@@ -99,11 +99,11 @@ void SimpleStream::Dump(Signal sig, const void *buff, size_t bytes, bool upperFl
 //-----------------------------------------------------------------------------
 // Stream
 //-----------------------------------------------------------------------------
-Stream::Stream(Environment &env, Signal sig, ULong attr) :
-		_cntRef(1), _sig(sig), _attr(attr), _offsetCur(0), _blockingFlag(false),
-		_pCodec(Codec::CreateCodecNone(true, false))
+Stream::Stream(Environment &env, ULong attr) :
+	_cntRef(1), _sig(env.GetSignal()), _attr(attr), _offsetCur(0), _blockingFlag(false),
+	_pCodec(Codec::CreateCodecNone(true, false))
 {
-	_peek.buff = NULL;
+	_peek.buff = nullptr;
 	_peek.bytes = 0;
 	_peek.offsetRead = 0;
 }
@@ -130,15 +130,15 @@ void Stream::CopyCodec(Stream *pStream)
 
 void Stream::CopyCodec(const Codec *pCodec)
 {
-	if (pCodec != NULL) {
+	if (pCodec != nullptr) {
 		_pCodec.reset(pCodec->Duplicate());
 	}
 }
 
-void Stream::PutChar(Signal sig, char ch)
+void Stream::PutChar(Signal &sig, char ch)
 {
 	Codec::Encoder *pEncoder = GetCodec()->GetEncoder();
-	if (pEncoder == NULL) {
+	if (pEncoder == nullptr) {
 		DoPutChar(sig, ch);
 	} else {
 		char chConv;
@@ -152,7 +152,7 @@ void Stream::PutChar(Signal sig, char ch)
 	}
 }
 
-String Stream::ReadChar(Signal sig)
+String Stream::ReadChar(Signal &sig)
 {
 	char chConv = '\0';
 	String str;
@@ -173,7 +173,7 @@ String Stream::ReadChar(Signal sig)
 	return str;
 }
 
-int Stream::GetChar(Signal sig)
+int Stream::GetChar(Signal &sig)
 {
 	char chConv = '\0';
 	Codec::Decoder *pDecoder = GetCodec()->GetDecoder();
@@ -211,27 +211,27 @@ bool Stream::GetBlocking() const
 	return _blockingFlag;
 }
 
-size_t Stream::DoRead(Signal sig, void *buff, size_t len)
+size_t Stream::DoRead(Signal &sig, void *buff, size_t len)
 {
 	return 0;
 }
 
-size_t Stream::DoWrite(Signal sig, const void *buff, size_t len)
+size_t Stream::DoWrite(Signal &sig, const void *buff, size_t len)
 {
 	return 0;
 }
 
-bool Stream::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode seekMode)
+bool Stream::DoSeek(Signal &sig, long offset, size_t offsetPrev, SeekMode seekMode)
 {
 	return true;
 }
 
-bool Stream::DoFlush(Signal sig)
+bool Stream::DoFlush(Signal &sig)
 {
 	return true;
 }
 
-bool Stream::DoClose(Signal sig)
+bool Stream::DoClose(Signal &sig)
 {
 	_attr &= ~(ATTR_Readable | ATTR_Writable | ATTR_Append);
 	return true;
@@ -242,29 +242,29 @@ size_t Stream::DoGetSize()
 	return InvalidSize;
 }
 
-int Stream::DoGetChar(Signal sig)
+int Stream::DoGetChar(Signal &sig)
 {
 	UChar ch;
 	if (Read(sig, &ch, 1) == 0) return -1;
 	return ch;
 }
 
-void Stream::DoPutChar(Signal sig, char ch)
+void Stream::DoPutChar(Signal &sig, char ch)
 {
 	Write(sig, &ch, 1);
 }
 
-Object *Stream::DoGetStatObj(Signal sig)
+Object *Stream::DoGetStatObj(Signal &sig)
 {
 	sig.SetError(ERR_IOError, "can't retrieve stat object");
-	return NULL;
+	return nullptr;
 }
 
-size_t Stream::Read(Signal sig, void *buff, size_t len)
+size_t Stream::Read(Signal &sig, void *buff, size_t len)
 {
 	char *p = reinterpret_cast<char *>(buff);
 	size_t bytesFromPeek = 0;
-	if (_peek.buff != NULL) {
+	if (_peek.buff != nullptr) {
 		bytesFromPeek = _peek.bytes - _peek.offsetRead;
 		if (bytesFromPeek > len) bytesFromPeek = len;
 		::memcpy(p, _peek.buff + _peek.offsetRead, bytesFromPeek);
@@ -272,7 +272,7 @@ size_t Stream::Read(Signal sig, void *buff, size_t len)
 		_peek.offsetRead += bytesFromPeek;
 		if (_peek.offsetRead >= _peek.bytes) {
 			delete[] _peek.buff;
-			_peek.buff = NULL;
+			_peek.buff = nullptr;
 			_peek.bytes = 0;
 			_peek.offsetRead = 0;
 		}
@@ -287,17 +287,17 @@ size_t Stream::Read(Signal sig, void *buff, size_t len)
 	return bytesRead;
 }
 
-size_t Stream::Write(Signal sig, const void *buff, size_t len)
+size_t Stream::Write(Signal &sig, const void *buff, size_t len)
 {
 	size_t rtn = DoWrite(sig, buff, len);
 	_offsetCur += rtn;
 	return rtn;
 }
 
-size_t Stream::Peek(Signal sig, void *buff, size_t len)
+size_t Stream::Peek(Signal &sig, void *buff, size_t len)
 {
 	if (len == 0) return 0;
-	if (_peek.buff == NULL) {
+	if (_peek.buff == nullptr) {
 		_peek.buff = new char [len];
 		_peek.bytes = DoRead(sig, _peek.buff, len);
 		_peek.offsetRead = 0;
@@ -317,7 +317,7 @@ size_t Stream::Peek(Signal sig, void *buff, size_t len)
 	return bytesToPeek;
 }
 
-bool Stream::Seek(Signal sig, long offset, SeekMode seekMode)
+bool Stream::Seek(Signal &sig, long offset, SeekMode seekMode)
 {
 	size_t offsetPrev = _offsetCur;
 	if (seekMode == SeekSet) {
@@ -334,7 +334,7 @@ bool Stream::Seek(Signal sig, long offset, SeekMode seekMode)
 		// this must not happen because illegal value has to be rejected before.
 		return false;
 	}
-	if (_peek.buff == NULL) return DoSeek(sig, offset, offsetPrev, seekMode);
+	if (_peek.buff == nullptr) return DoSeek(sig, offset, offsetPrev, seekMode);
 	if (_offsetCur < offsetPrev) {
 		size_t bytesPeeked = _peek.bytes;
 		if (_peek.offsetRead >= offsetPrev - _offsetCur) {
@@ -342,7 +342,7 @@ bool Stream::Seek(Signal sig, long offset, SeekMode seekMode)
 			return true;
 		}
 		delete[] _peek.buff;
-		_peek.buff = NULL;
+		_peek.buff = nullptr;
 		_peek.bytes = 0;
 		_peek.offsetRead = 0;
 		if (seekMode == SeekSet) return DoSeek(sig, offset, offsetPrev, SeekSet);
@@ -355,7 +355,7 @@ bool Stream::Seek(Signal sig, long offset, SeekMode seekMode)
 		}
 		size_t bytesTrail = _peek.bytes - _peek.offsetRead;
 		delete[] _peek.buff;
-		_peek.buff = NULL;
+		_peek.buff = nullptr;
 		_peek.bytes = 0;
 		_peek.offsetRead = 0;
 		if (seekMode == SeekSet) return DoSeek(sig, offset, offsetPrev, SeekSet);
@@ -364,38 +364,56 @@ bool Stream::Seek(Signal sig, long offset, SeekMode seekMode)
 	}
 }
 
-bool Stream::Flush(Signal sig)
+bool Stream::SkipLines(Signal &sig, size_t nLines)
+{
+	bool rtn = true;
+	if (nLines == 0) return true;
+	for (;;) {
+		int ch = DoGetChar(sig);
+		if (ch < 0) {
+			rtn = sig.IsNoSignalled();
+			break;
+		}
+		if (ch == '\n') {
+			nLines--;
+			if (nLines == 0) break;
+		}
+	}
+	return rtn;
+}
+
+bool Stream::Flush(Signal &sig)
 {
 	return DoFlush(sig);
 }
 
 bool Stream::HasNameSuffix(const char *suffix, bool ignoreCase) const
 {
-	return EndsWith(GetName(), suffix, ignoreCase) != NULL;
+	return EndsWith(GetName(), suffix, ignoreCase) != nullptr;
 }
 
-bool Stream::CheckReadable(Signal sig) const
+bool Stream::CheckReadable(Signal &sig) const
 {
 	if (IsReadable()) return true;
 	sig.SetError(ERR_IOError, "stream is not readable");
 	return false;
 }
 
-bool Stream::CheckWritable(Signal sig) const
+bool Stream::CheckWritable(Signal &sig) const
 {
 	if (IsWritable()) return true;
 	sig.SetError(ERR_IOError, "stream is not writable");
 	return false;
 }
 
-bool Stream::CheckBwdSeekable(Signal sig) const
+bool Stream::CheckBwdSeekable(Signal &sig) const
 {
 	if (IsBwdSeekable()) return true;
 	sig.SetError(ERR_IOError, "stream is not capable of backward seeking");
 	return false;
 }
 
-bool Stream::Compare(Signal sig, Stream &stream)
+bool Stream::Compare(Signal &sig, Stream &stream)
 {
 	if (!CheckReadable(sig) || !stream.CheckReadable(sig)) return false;
 	const size_t bytesBuff = 1024 * 16;
@@ -420,9 +438,10 @@ bool Stream::Compare(Signal sig, Stream &stream)
 	return sameFlag;
 }
 
-bool Stream::ReadToStream(Environment &env, Signal sig, Stream &streamDst,
+bool Stream::ReadToStream(Environment &env, Stream &streamDst,
 			size_t bytesUnit, bool finalizeFlag, const Function *pFuncFilter)
 {
+	Signal &sig = env.GetSignal();
 	if (!CheckReadable(sig) || !streamDst.CheckWritable(sig)) return false;
 	Attribute attr;
 	bool validAttrFlag = false;
@@ -434,11 +453,11 @@ bool Stream::ReadToStream(Environment &env, Signal sig, Stream &streamDst,
 	for (;;) {
 		size_t bytesRead = Read(sig, buff, bytesUnit);
 		if (bytesRead == 0) break;
-		if (pFuncFilter != NULL) {
+		if (pFuncFilter != nullptr) {
 			Value value(new Object_binary(env, buff, bytesUnit, false));
-			AutoPtr<Args> pArgsSub(new Args());
-			pArgsSub->SetValue(value);
-			Value rtn = pFuncFilter->Eval(env, sig, *pArgsSub);
+			AutoPtr<Argument> pArgSub(new Argument(pFuncFilter));
+			if (!pArgSub->StoreValue(env, value)) return false;
+			Value rtn = pFuncFilter->Eval(env, *pArgSub);
 			if (sig.IsSignalled()) return false;
 			if (rtn.Is_binary()) {
 				const Binary &buffRtn = rtn.GetBinary();
@@ -461,13 +480,13 @@ bool Stream::ReadToStream(Environment &env, Signal sig, Stream &streamDst,
 	return true;
 }
 
-bool Stream::SerializeBoolean(Signal sig, bool num)
+bool Stream::SerializeBoolean(Signal &sig, bool num)
 {
 	UChar numRaw = static_cast<UChar>(num);
 	return Write(sig, &numRaw, sizeof(numRaw)) == sizeof(numRaw);
 }
 
-bool Stream::DeserializeBoolean(Signal sig, bool &num)
+bool Stream::DeserializeBoolean(Signal &sig, bool &num)
 {
 	UChar numRaw = 0;
 	if (Read(sig, &numRaw, sizeof(numRaw)) != sizeof(numRaw)) return false;
@@ -475,17 +494,17 @@ bool Stream::DeserializeBoolean(Signal sig, bool &num)
 	return true;
 }
 
-bool Stream::SerializeUChar(Signal sig, UChar num)
+bool Stream::SerializeUInt8(Signal &sig, UInt8 num)
 {
 	return Write(sig, &num, sizeof(num)) == sizeof(num);
 }
 
-bool Stream::DeserializeUChar(Signal sig, UChar &num)
+bool Stream::DeserializeUInt8(Signal &sig, UInt8 &num)
 {
 	return Read(sig, &num, sizeof(num)) == sizeof(num);
 }
 
-bool Stream::SerializeUShort(Signal sig, UShort num)
+bool Stream::SerializeUInt16(Signal &sig, UInt16 num)
 {
 	UChar buff[2] = {
 		static_cast<UChar>((num >> 0) & 0xff),
@@ -494,17 +513,17 @@ bool Stream::SerializeUShort(Signal sig, UShort num)
 	return Write(sig, buff, sizeof(buff)) == sizeof(buff);
 }
 
-bool Stream::DeserializeUShort(Signal sig, UShort &num)
+bool Stream::DeserializeUInt16(Signal &sig, UInt16 &num)
 {
 	UChar buff[2];
 	if (Read(sig, buff, sizeof(buff)) != sizeof(buff)) return false;
 	num =
-		(static_cast<UShort>(buff[0]) << 0) +
-		(static_cast<UShort>(buff[1]) << 8);
+		(static_cast<UInt16>(buff[0]) << 0) +
+		(static_cast<UInt16>(buff[1]) << 8);
 	return true;
 }
 
-bool Stream::SerializeULong(Signal sig, ULong num)
+bool Stream::SerializeUInt32(Signal &sig, UInt32 num)
 {
 	UChar buff[4] = {
 		static_cast<UChar>((num >> 0) & 0xff),
@@ -515,19 +534,19 @@ bool Stream::SerializeULong(Signal sig, ULong num)
 	return Write(sig, buff, sizeof(buff)) == sizeof(buff);
 }
 
-bool Stream::DeserializeULong(Signal sig, ULong &num)
+bool Stream::DeserializeUInt32(Signal &sig, UInt32 &num)
 {
 	UChar buff[4];
 	if (Read(sig, buff, sizeof(buff)) != sizeof(buff)) return false;
 	num =
-		(static_cast<ULong>(buff[0]) << 0) +
-		(static_cast<ULong>(buff[1]) << 8) +
-		(static_cast<ULong>(buff[2]) << 16) +
-		(static_cast<ULong>(buff[3]) << 24);
+		(static_cast<UInt32>(buff[0]) << 0) +
+		(static_cast<UInt32>(buff[1]) << 8) +
+		(static_cast<UInt32>(buff[2]) << 16) +
+		(static_cast<UInt32>(buff[3]) << 24);
 	return true;
 }
 
-bool Stream::SerializeUInt64(Signal sig, UInt64 num)
+bool Stream::SerializeUInt64(Signal &sig, UInt64 num)
 {
 	UChar buff[8] = {
 		static_cast<UChar>((num >> 0) & 0xff),
@@ -542,7 +561,7 @@ bool Stream::SerializeUInt64(Signal sig, UInt64 num)
 	return Write(sig, buff, sizeof(buff)) == sizeof(buff);
 }
 
-bool Stream::DeserializeUInt64(Signal sig, UInt64 &num)
+bool Stream::DeserializeUInt64(Signal &sig, UInt64 &num)
 {
 	UChar buff[8];
 	if (Read(sig, buff, sizeof(buff)) != sizeof(buff)) return false;
@@ -558,75 +577,65 @@ bool Stream::DeserializeUInt64(Signal sig, UInt64 &num)
 	return true;
 }
 
-bool Stream::SerializeDouble(Signal sig, double num)
+bool Stream::SerializeDouble(Signal &sig, Double num)
 {
 	UChar *buff = reinterpret_cast<UChar *>(&num);
 	return Write(sig, buff, sizeof(num)) == sizeof(num);
 }
 
-bool Stream::DeserializeDouble(Signal sig, double &num)
+bool Stream::DeserializeDouble(Signal &sig, Double &num)
 {
 	UChar *buff = reinterpret_cast<UChar *>(&num);
 	return Read(sig, buff, sizeof(num)) == sizeof(num);
 }
 
-bool Stream::SerializeString(Signal sig, const char *str)
+bool Stream::SerializeString(Signal &sig, const char *str)
 {
 	ULong len = static_cast<ULong>(::strlen(str));
-	if (!SerializePackedULong(sig, len)) return false;
+	if (!SerializePackedUInt32(sig, len)) return false;
 	return Write(sig, str, len) == len;
 }
 
-bool Stream::DeserializeString(Signal sig, String &str)
+bool Stream::DeserializeString(Signal &sig, String &str)
 {
-	ULong len = 0;
-	if (!DeserializePackedULong(sig, len)) return false;
+	UInt32 len = 0;
+	if (!DeserializePackedUInt32(sig, len)) return false;
 	if (len == 0) {
 		str.clear();
 		return true;
 	}
-	char *buff = new char [len + 1];
-	if (Read(sig, buff, len) != len) {
-		delete[] buff;
-		return false;
-	}
-	buff[len] = '\0';
-	str = buff;
-	delete[] buff;
+	str = String(len + 1, '\0');
+	if (Read(sig, &str[0], len) != len) return false;
+	str.resize(len);
 	return true;
 }
 
-bool Stream::SerializeBinary(Signal sig, const Binary &binary)
+bool Stream::SerializeBinary(Signal &sig, const Binary &binary)
 {
 	ULong len = static_cast<ULong>(binary.size());
-	if (!SerializePackedULong(sig, len)) return false;
+	if (!SerializePackedUInt32(sig, len)) return false;
 	return Write(sig, binary.data(), len) == len;
 }
 
-bool Stream::DeserializeBinary(Signal sig, Binary &binary)
+bool Stream::DeserializeBinary(Signal &sig, Binary &binary)
 {
-	ULong len = 0;
-	if (!DeserializePackedULong(sig, len)) return false;
+	UInt32 len = 0;
+	if (!DeserializePackedUInt32(sig, len)) return false;
 	if (len == 0) {
 		binary.clear();
 		return true;
 	}
-	char *buff = new char [len];
-	if (Read(sig, buff, len) != len) {
-		delete[] buff;
-		return false;
-	}
-	binary = Binary(buff, len);
-	delete[] buff;
+	binary = Binary(len);
+	if (Read(sig, &binary[0], len) != len) return false;
 	return true;
 }
 
-bool Stream::SerializeSymbol(Signal sig, const Symbol *pSymbol)
+bool Stream::SerializeSymbol(Signal &sig, const Symbol *pSymbol)
 {
 	return SerializeString(sig, pSymbol->GetName());
 }
 
-bool Stream::DeserializeSymbol(Signal sig, const Symbol **ppSymbol)
+bool Stream::DeserializeSymbol(Signal &sig, const Symbol **ppSymbol)
 {
 	String str;
 	if (!DeserializeString(sig, str)) return false;
@@ -634,23 +643,23 @@ bool Stream::DeserializeSymbol(Signal sig, const Symbol **ppSymbol)
 	return true;
 }
 
-bool Stream::SerializeSymbolSet(Signal sig, const SymbolSet &symbolSet)
+bool Stream::SerializeSymbolSet(Signal &sig, const SymbolSet &symbolSet)
 {
 	ULong len = static_cast<ULong>(symbolSet.size());
-	if (!SerializePackedULong(sig, len)) return false;
+	if (!SerializePackedUInt32(sig, len)) return false;
 	foreach_const (SymbolSet, ppSymbol, symbolSet) {
 		if (!SerializeSymbol(sig, *ppSymbol)) return false;
 	}
 	return true;
 }
 
-bool Stream::DeserializeSymbolSet(Signal sig, SymbolSet &symbolSet)
+bool Stream::DeserializeSymbolSet(Signal &sig, SymbolSet &symbolSet)
 {
-	ULong len = 0;
-	if (!DeserializePackedULong(sig, len)) return false;
+	UInt32 len = 0;
+	if (!DeserializePackedUInt32(sig, len)) return false;
 	symbolSet.clear();
 	if (len == 0) return true;
-	const Symbol *pSymbol = NULL;
+	const Symbol *pSymbol = nullptr;
 	while (len-- > 0) {
 		if (!DeserializeSymbol(sig, &pSymbol)) return false;
 		symbolSet.insert(pSymbol);
@@ -658,24 +667,24 @@ bool Stream::DeserializeSymbolSet(Signal sig, SymbolSet &symbolSet)
 	return true;
 }
 
-bool Stream::SerializeSymbolList(Signal sig, const SymbolList &symbolList)
+bool Stream::SerializeSymbolList(Signal &sig, const SymbolList &symbolList)
 {
 	ULong len = static_cast<ULong>(symbolList.size());
-	if (!SerializePackedULong(sig, len)) return false;
+	if (!SerializePackedUInt32(sig, len)) return false;
 	foreach_const (SymbolList, ppSymbol, symbolList) {
 		if (!SerializeSymbol(sig, *ppSymbol)) return false;
 	}
 	return true;
 }
 
-bool Stream::DeserializeSymbolList(Signal sig, SymbolList &symbolList)
+bool Stream::DeserializeSymbolList(Signal &sig, SymbolList &symbolList)
 {
-	ULong len = 0;
-	if (!DeserializePackedULong(sig, len)) return false;
+	UInt32 len = 0;
+	if (!DeserializePackedUInt32(sig, len)) return false;
 	symbolList.clear();
 	if (len == 0) return true;
 	symbolList.reserve(len);
-	const Symbol *pSymbol = NULL;
+	const Symbol *pSymbol = nullptr;
 	while (len-- > 0) {
 		if (!DeserializeSymbol(sig, &pSymbol)) return false;
 		symbolList.push_back(pSymbol);
@@ -683,7 +692,7 @@ bool Stream::DeserializeSymbolList(Signal sig, SymbolList &symbolList)
 	return true;
 }
 
-bool Stream::SerializePackedULong(Signal sig, ULong num)
+bool Stream::SerializePackedUInt32(Signal &sig, UInt32 num)
 {
 	UChar buff[16];
 	size_t bytesBuff = 0;
@@ -700,24 +709,60 @@ bool Stream::SerializePackedULong(Signal sig, ULong num)
 	return Write(sig, buff, bytesBuff) == bytesBuff;
 }
 
-bool Stream::DeserializePackedULong(Signal sig, ULong &num)
+bool Stream::DeserializePackedUInt32(Signal &sig, UInt32 &num)
 {
+	const size_t bytesBuffMax = 5;	// 32 / 7 = 4.6
 	num = 0;
 	UChar data = 0x00;
-	for (size_t bytesBuff = 0; bytesBuff < 5; bytesBuff++) {
+	for (size_t bytesBuff = 0; bytesBuff < bytesBuffMax; bytesBuff++) {
 		if (Read(sig, &data, sizeof(data)) != sizeof(data)) return false;
 		num = (num << 7) + (data & 0x7f);
 		if ((data & 0x80) == 0x00) break;
 	}
 	if (data & 0x80) {
-		sig.SetError(ERR_FormatError, "invalid format of packed ULong in serialized data");
+		sig.SetError(ERR_FormatError, "invalid serialization format for packed 32bit number");
 		return false;
 	}
 	return true;
 }
 
-Stream *Stream::Open(Environment &env, Signal sig, const char *pathName, ULong attr)
+bool Stream::SerializePackedUInt64(Signal &sig, UInt64 num)
 {
+	UChar buff[16];
+	size_t bytesBuff = 0;
+	if (num == 0) {
+		buff[bytesBuff++] = 0x00;
+	} else {
+		while (num > 0) {
+			UChar data = static_cast<UChar>(num & 0x7f);
+			num >>= 7;
+			if (num != 0) data |= 0x80;
+			buff[bytesBuff++] = data;
+		}
+	}
+	return Write(sig, buff, bytesBuff) == bytesBuff;
+}
+
+bool Stream::DeserializePackedUInt64(Signal &sig, UInt64 &num)
+{
+	const size_t bytesBuffMax = 10;	// 64 / 7 = 9.2
+	num = 0;
+	UChar data = 0x00;
+	for (size_t bytesBuff = 0; bytesBuff < bytesBuffMax; bytesBuff++) {
+		if (Read(sig, &data, sizeof(data)) != sizeof(data)) return false;
+		num = (num << 7) + (data & 0x7f);
+		if ((data & 0x80) == 0x00) break;
+	}
+	if (data & 0x80) {
+		sig.SetError(ERR_FormatError, "invalid serialization format for packed 64bit number");
+		return false;
+	}
+	return true;
+}
+
+Stream *Stream::Open(Environment &env, const char *pathName, ULong attr)
+{
+	Signal &sig = env.GetSignal();
 	if (*pathName == '>') {
 		pathName++;
 		attr = (attr & ~ATTR_Readable) | ATTR_Writable;
@@ -728,26 +773,27 @@ Stream *Stream::Open(Environment &env, Signal sig, const char *pathName, ULong a
 	}
 	PathMgr::NotFoundMode notFoundMode = (attr & ATTR_Writable)?
 								PathMgr::NF_Wouldbe : PathMgr::NF_Signal;
-	AutoPtr<Directory> pDirectory(Directory::Open(env, sig, pathName, notFoundMode));
-	if (sig.IsSignalled()) return NULL;
-	return pDirectory->DoOpenStream(env, sig, attr);
+	AutoPtr<Directory> pDirectory(Directory::Open(env, pathName, notFoundMode));
+	if (sig.IsSignalled()) return nullptr;
+	return pDirectory->DoOpenStream(env, attr);
 }
 
-Stream *Stream::Prefetch(Environment &env, Signal sig, Stream *pStreamSrc,
+Stream *Stream::Prefetch(Environment &env, Stream *pStreamSrc,
 										bool deleteSrcFlag, size_t bytesUnit)
 {
+	Signal &sig = env.GetSignal();
 	Stream_Prefetch *pStreamPrefetch =
-			new Stream_Prefetch(env, sig, Stream::Reference(pStreamSrc), bytesUnit);
+			new Stream_Prefetch(env, Stream::Reference(pStreamSrc), bytesUnit);
 	pStreamPrefetch->DoPrefetch(sig);
 	if (deleteSrcFlag) Stream::Delete(pStreamSrc);
 	if (sig.IsSignalled()) {
 		Stream::Delete(pStreamPrefetch);
-		return NULL;
+		return nullptr;
 	}
 	return pStreamPrefetch;
 }
 
-ULong Stream::ParseOpenMode(Signal sig, const char *mode)
+ULong Stream::ParseOpenMode(Signal &sig, const char *mode)
 {
 	ULong attr = ATTR_None;
 	const char *p = mode;
