@@ -8,7 +8,7 @@ namespace Gura {
 //-----------------------------------------------------------------------------
 // String
 //-----------------------------------------------------------------------------
-const StringList StringList::Null;
+const StringList StringList::Empty;
 
 static const UShort __ctypeTbl[] = {
 	0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
@@ -53,7 +53,7 @@ UShort GetCType(char ch)
 Number ToNumber(const char *str, bool *pSuccessFlag)
 {
 	Number num;
-	char *next = NULL;
+	char *next = nullptr;
 	if (str[0] == '0' && (str[1] == 'x' || str[1] == 'X' || IsOctDigit(str[1]))) {
 		num = ::strtoul(str, &next, 0);
 	} else if (str[0] == '0' && (str[1] == 'b' || str[1] == 'B')) {
@@ -61,7 +61,7 @@ Number ToNumber(const char *str, bool *pSuccessFlag)
 	} else {
 		num = ::strtod(str, &next);
 	}
-	if (pSuccessFlag != NULL) *pSuccessFlag = (*next == '\0');
+	if (pSuccessFlag != nullptr) *pSuccessFlag = (*next == '\0');
 	return num;
 }
 
@@ -82,7 +82,7 @@ char GetEscaped(char ch)
 		{ '\'',	'\''	},
 		{ '"',	'"'		},
 	};
-	for (int i = 0; i < ArraySizeOf(tbl); i++) {
+	for (size_t i = 0; i < ArraySizeOf(tbl); i++) {
 		if (tbl[i].ch == ch) return tbl[i].chConv;
 	}
 	return ch;
@@ -92,7 +92,7 @@ String ZenToHan(const char *str)
 {
 	String rtn;
 	while (*str != '\0') {
-		const char *next = NULL;
+		const char *next = nullptr;
 		char ch = ZenToHanChar(str, &next);
 		if (ch == '\0') {
 			for ( ; str != next; str++) rtn += *str;
@@ -223,10 +223,10 @@ char ZenToHanChar(const char *str, const char **next)
 		{ "\xef\xbd\x9e", 3, 0x7e }, // ~
 		{ "\xef\xbf\xa3", 3, 0x7e }, // ~
 	};
-	for (int i = 0; i < ArraySizeOf(convTbl); i++) {
+	for (size_t i = 0; i < ArraySizeOf(convTbl); i++) {
 		const Convert &conv = convTbl[i];
 		if (::strncmp(str, conv.zenkaku, conv.len) == 0) {
-			if (next != NULL) *next = str + conv.len;
+			if (next != nullptr) *next = str + conv.len;
 			return conv.hankaku;
 		}
 	}
@@ -236,18 +236,18 @@ char ZenToHanChar(const char *str, const char **next)
 	} else if (*str != '\0') {
 		str++;
 	}
-	if (next != NULL) *next = str;
+	if (next != nullptr) *next = str;
 	return '\0';
 }
 
-String MakeQuotedString(const char *str)
+String MakeQuotedString(const char *str, bool surroundFlag)
 {
 	String strDst;
 	char chQuote = '\'';
-	if (::strchr(str, '\'') != NULL && ::strchr(str, '"') == NULL) {
+	if (::strchr(str, '\'') != nullptr && ::strchr(str, '"') == nullptr) {
 		chQuote = '"';
 	}
-	strDst += chQuote;
+	if (surroundFlag) strDst += chQuote;
 	for (const char *p = str; *p != '\0'; p++) {
 		char ch = *p;
 		if (ch == '\a') {
@@ -279,7 +279,7 @@ String MakeQuotedString(const char *str)
 			strDst += ch;
 		}
 	}
-	strDst += chQuote;
+	if (surroundFlag) strDst += chQuote;
 	return strDst;
 }
 
@@ -456,7 +456,7 @@ const char *FindString(const char *str, const char *sub, bool ignoreCaseFlag)
 		}
 		if (*p2 == '\0') return str;
 	}
-	return NULL;
+	return nullptr;
 }
 
 String::const_iterator FindString(String::const_iterator str,
@@ -473,12 +473,63 @@ String::const_iterator FindString(String::const_iterator str,
 	return strEnd;
 }
 
+Value FindString(Environment &env, const char *str, const char *sub, int start,
+				 bool ignoreCaseFlag, bool reverseFlag, bool listFlag)
+{
+	do {
+		int len = static_cast<int>(::strlen(str));
+		if (start < 0) {
+			start += len;
+			if (start < 0) start = 0;
+		}
+		if (start > len) return Value::Nil;
+	} while (0);
+	if (reverseFlag) {
+		const char *p = FindString(str + start, sub, ignoreCaseFlag);
+		if (listFlag) {
+			ValueList valListOrg;
+			for ( ; p != nullptr; p = FindString(p + 1, sub, ignoreCaseFlag)) {
+				valListOrg.push_back(Value(static_cast<Number>(p - str)));
+			}
+			Value result;
+			Object_list *pObjList = result.InitAsList(env);
+			pObjList->Reserve(valListOrg.size());
+			foreach_reverse (ValueList, pValue, valListOrg) {
+				pObjList->AddFast(*pValue);
+			}
+			pObjList->SetValueType(VTYPE_number);
+			return result;
+		} else {
+			const char *pLast = nullptr;
+			for ( ; p != nullptr; p = FindString(p + 1, sub, ignoreCaseFlag)) {
+				pLast = p;
+			}
+			return (pLast == nullptr)? Value::Nil :
+							Value(static_cast<Number>(pLast - str));
+		}
+	} else {
+		const char *p = FindString(str + start, sub, ignoreCaseFlag);
+		if (listFlag) {
+			Value result;
+			Object_list *pObjList = result.InitAsList(env);
+			for ( ; p != nullptr; p = FindString(p + 1, sub, ignoreCaseFlag)) {
+				pObjList->AddFast(Value(static_cast<Number>(p - str)));
+			}
+			pObjList->SetValueType(VTYPE_number);
+			return result;
+		} else {
+			return (p == nullptr)? Value::Nil :
+							Value(static_cast<Number>(p - str));
+		}
+	}
+}
+
 const char *StartsWith(const char *str, const char *prefix, size_t pos, bool ignoreCaseFlag)
 {
 	str = Forward(str, pos);
 	const char *p1 = str, *p2 = prefix;
 	for ( ; *p2 != '\0'; p1++, p2++) {
-		if (CompareChar(*p1, *p2, ignoreCaseFlag) != 0) return NULL;
+		if (CompareChar(*p1, *p2, ignoreCaseFlag) != 0) return nullptr;
 	}
 	return p1;
 }
@@ -487,10 +538,10 @@ const char *EndsWith(const char *str, const char *suffix, bool ignoreCaseFlag)
 {
 	size_t len = ::strlen(suffix);
 	const char *p = str + ::strlen(str);
-	if (str + len > p) return NULL;
+	if (str + len > p) return nullptr;
 	const char *p1 = p - len, *p2 = suffix;
 	for ( ; *p2 != '\0'; p1++, p2++) {
-		if (CompareChar(*p1, *p2, ignoreCaseFlag) != 0) return NULL;
+		if (CompareChar(*p1, *p2, ignoreCaseFlag) != 0) return nullptr;
 	}
 	return p - len;
 }
@@ -499,10 +550,10 @@ const char *EndsWith(const char *str, const char *suffix, size_t posEnd, bool ig
 {
 	size_t len = ::strlen(suffix);
 	const char *p = Forward(str, posEnd);
-	if (str + len > p) return NULL;
+	if (str + len > p) return nullptr;
 	const char *p1 = p - len, *p2 = suffix;
 	for ( ; *p2 != '\0'; p1++, p2++) {
-		if (CompareChar(*p1, *p2, ignoreCaseFlag) != 0) return NULL;
+		if (CompareChar(*p1, *p2, ignoreCaseFlag) != 0) return nullptr;
 	}
 	return p - len;
 }
@@ -516,9 +567,6 @@ String Capitalize(const char *str)
 		p++;
 	}
 	rtn += p;
-	//for ( ; *p != '\0'; p++) {
-	//	rtn += ('A' <= *p && *p <= 'Z')? *p - 'A' + 'a' : *p;
-	//}
 	return rtn;
 }
 
@@ -626,19 +674,6 @@ String Strip(const char *str, bool stripLeftFlag, bool stripRightFlag)
 	return String(p1, p2 - p1 + 1);
 }
 
-String Strip(const char *str, const SymbolSet &attrs)
-{
-	bool stripLeftFlag = true, stripRightFlag = true;
-	if (attrs.IsSet(Gura_Symbol(both))) {
-		// nothing to do
-	} else if (attrs.IsSet(Gura_Symbol(left)) && !attrs.IsSet(Gura_Symbol(right))) {
-		stripRightFlag = false;
-	} else if (!attrs.IsSet(Gura_Symbol(left)) && attrs.IsSet(Gura_Symbol(right))) {
-		stripLeftFlag = false;
-	}
-	return Strip(str, stripLeftFlag, stripRightFlag);
-}
-
 String Chop(const char *str, bool eolOnlyFlag)
 {
 	size_t len = ::strlen(str);
@@ -675,7 +710,7 @@ size_t Length(const char *str)
 size_t Width(const char *str)
 {
 	size_t width = 0;
-	ULong codeUTF32 = 0;
+	UInt32 codeUTF32 = 0;
 	for (const char *p = str; *p != '\0'; ) {
 		p = NextUTF32(p, codeUTF32);
 		Codec::WidthProp widthProp = Codec::GetWidthProp(codeUTF32);
@@ -693,7 +728,7 @@ size_t Width(const char *str)
 bool CheckCType(const char *str, UShort type)
 {
 	if (*str == '\0') return false;
-	ULong codeUTF32 = 0;
+	UInt32 codeUTF32 = 0;
 	for (const char *p = str; *p != '\0'; ) {
 		p = NextUTF32(p, codeUTF32);
 		if (codeUTF32 > 0x7f) return false;
@@ -772,7 +807,7 @@ const char *NextUTF8(const char *p, UInt64 &codeUTF8)
 	return p;
 }
 
-String::const_iterator NextUTF32(const String &str, String::const_iterator p, ULong &codeUTF32)
+String::const_iterator NextUTF32(const String &str, String::const_iterator p, UInt32 &codeUTF32)
 {
 	codeUTF32 = 0x00000000;
 	if (p == str.end()) {
@@ -807,7 +842,7 @@ String::const_iterator NextUTF32(const String &str, String::const_iterator p, UL
 	return p;
 }
 
-const char *NextUTF32(const char *p, ULong &codeUTF32)
+const char *NextUTF32(const char *p, UInt32 &codeUTF32)
 {
 	codeUTF32 = 0x00000000;
 	if (*p == '\0') {
@@ -858,7 +893,7 @@ void AppendUTF8(String &str, UInt64 codeUTF8)
 	}
 }
 
-void AppendUTF32(String &str, ULong codeUTF32)
+void AppendUTF32(String &str, UInt32 codeUTF32)
 {
 	int i = 0;
 	char buff[8];
@@ -923,7 +958,7 @@ const char *Forward(const char *str, size_t len, size_t *pLenForward)
 			while (IsUTF8Follower(*str)) str++;
 		}
 	}
-	if (pLenForward != NULL) *pLenForward = lenForward;
+	if (pLenForward != nullptr) *pLenForward = lenForward;
 	return str;
 }
 
@@ -938,7 +973,7 @@ String::const_iterator Forward(String::const_iterator str,
 			while (IsUTF8Follower(*str)) str++;
 		}
 	}
-	if (pLenForward != NULL) *pLenForward = lenForward;
+	if (pLenForward != nullptr) *pLenForward = lenForward;
 	return str;
 }
 
@@ -1013,59 +1048,9 @@ String Middle(const char *str, int start, int len)
 	}
 }
 
-Value FindString(Environment &env, Signal sig,
-		const char *str, const char *sub, int start, const SymbolSet &attrs)
-{
-	bool ignoreCaseFlag = attrs.IsSet(Gura_Symbol(icase));
-	do {
-		int len = static_cast<int>(::strlen(str));
-		if (start < 0) {
-			start += len;
-			if (start < 0) start = 0;
-		}
-		if (start > len) return Value::Null;
-	} while (0);
-	if (attrs.IsSet(Gura_Symbol(rev))) {
-		const char *p = FindString(str + start, sub, ignoreCaseFlag);
-		if (attrs.IsSet(Gura_Symbol(list))) {
-			ValueList valListOrg;
-			for ( ; p != NULL; p = FindString(p + 1, sub, ignoreCaseFlag)) {
-				valListOrg.push_back(Value(static_cast<Number>(p - str)));
-			}
-			Value result;
-			ValueList &valList = result.InitAsList(env);
-			foreach_reverse (ValueList, pValue, valListOrg) {
-				valList.push_back(*pValue);
-			}
-			return result;
-		} else {
-			const char *pLast = NULL;
-			for ( ; p != NULL; p = FindString(p + 1, sub, ignoreCaseFlag)) {
-				pLast = p;
-			}
-			return (pLast == NULL)? Value::Null :
-							Value(static_cast<Number>(pLast - str));
-		}
-	} else {
-		const char *p = FindString(str + start, sub, ignoreCaseFlag);
-		if (attrs.IsSet(Gura_Symbol(list))) {
-			Value result;
-			ValueList &valList = result.InitAsList(env);
-			for ( ; p != NULL; p = FindString(p + 1, sub, ignoreCaseFlag)) {
-				valList.push_back(Value(static_cast<Number>(p - str)));
-			}
-			return result;
-		} else {
-			return (p == NULL)? Value::Null :
-							Value(static_cast<Number>(p - str));
-		}
-	}
-}
-
 String Replace(const char *str, const char *sub, const char *replace,
-										int nMaxReplace, const SymbolSet &attrs)
+			   int nMaxReplace, bool ignoreCaseFlag)
 {
-	bool ignoreCaseFlag = attrs.IsSet(Gura_Symbol(icase));
 	String result;
 	int lenSub = static_cast<int>(::strlen(sub));
 	if (lenSub == 0) {
@@ -1082,7 +1067,7 @@ String Replace(const char *str, const char *sub, const char *replace,
 	} else {
 		const char *pLeft = str;
 		const char *pRight = FindString(pLeft, sub, ignoreCaseFlag);
-		for ( ; pRight != NULL && nMaxReplace != 0;
+		for ( ; pRight != nullptr && nMaxReplace != 0;
 					pRight = FindString(pLeft, sub, ignoreCaseFlag), nMaxReplace--) {
 			result.append(pLeft, pRight - pLeft);
 			result += replace;
@@ -1094,9 +1079,8 @@ String Replace(const char *str, const char *sub, const char *replace,
 }
 
 GURA_DLLDECLARE String Replaces(const char *str, const ValueList &valList,
-									int nMaxReplace, const SymbolSet &attrs)
+								int nMaxReplace, bool ignoreCaseFlag)
 {
-	bool ignoreCaseFlag = attrs.IsSet(Gura_Symbol(icase));
 	String result;
 	const char *p = str;
 	for (int nReplace = 0; (nMaxReplace < 0 || nReplace < nMaxReplace) && *p != '\0'; ) {
@@ -1181,6 +1165,23 @@ void StringList::operator=(const StringList &stringList)
 	}
 }
 
+//-----------------------------------------------------------------------------
+// StringSet
+//-----------------------------------------------------------------------------
+StringSet::StringSet(const StringSet &stringSet)
+{
+	foreach_const (StringSet, pStr, stringSet) {
+		insert(*pStr);
+	}
+}
+
+void StringSet::operator=(const StringSet &stringSet)
+{
+	foreach_const (StringSet, pStr, stringSet) {
+		insert(*pStr);
+	}
+}
+
 //-----------------------------------------------------------------------------
 // CharConverter
 //-----------------------------------------------------------------------------
@@ -1197,7 +1198,7 @@ void CharConverter::Put(char ch)
 		_readyFlag = true;
 	} else if (ch > 0) {
 		char chConv = '\0';
-		if (_idxPut > 0 && (chConv = ZenToHanChar(_buff, NULL)) != '\0') {
+		if (_idxPut > 0 && (chConv = ZenToHanChar(_buff, nullptr)) != '\0') {
 			_idxGet = _idxPut - 1;
 			_buff[_idxGet] = chConv;
 		}
@@ -1205,7 +1206,7 @@ void CharConverter::Put(char ch)
 		_readyFlag = true;
 	} else if (_idxPut > 0 && IsUTF8First(ch)) {
 		char chConv = '\0';
-		if ((chConv = ZenToHanChar(_buff, NULL)) != '\0') {
+		if ((chConv = ZenToHanChar(_buff, nullptr)) != '\0') {
 			_idxGet = _idxPut - 1;
 			_buff[_idxGet] = chConv;
 		}
