@@ -9,84 +9,89 @@ namespace Gura {
 // Template
 //-----------------------------------------------------------------------------
 Template::Template() : _cntRef(1), _pExprOwnerForInit(new ExprOwner()),
-				   _pValueMap(new ValueMap()), _pStreamDst(NULL), _chLast('\0')
+				   _pValueExMap(new ValueExMap()), _pStreamDst(nullptr), _chLast('\0')
 {
 }
 
-bool Template::Read(Environment &env, Signal sig,
+bool Template::Read(Environment &env,
 			SimpleStream &streamSrc, bool autoIndentFlag, bool appendLastEOLFlag)
 {
 	Parser parser(autoIndentFlag, appendLastEOLFlag);
-	return parser.ParseStream(env, sig, this, streamSrc);
+	return parser.ParseStream(env, this, streamSrc);
 }
 
-bool Template::Parse(Environment &env, Signal sig,
+bool Template::Parse(Environment &env,
 		String::const_iterator strSrc, String::const_iterator strSrcEnd,
 		bool autoIndentFlag, bool appendLastEOLFlag)
 {
 	SimpleStream_StringReader streamSrc(strSrc, strSrcEnd);
-	return Read(env, sig, streamSrc, autoIndentFlag, appendLastEOLFlag);
+	return Read(env, streamSrc, autoIndentFlag, appendLastEOLFlag);
 }
 
-bool Template::Parse(Environment &env, Signal sig,
+bool Template::Parse(Environment &env,
 		const char *strSrc, const char *strSrcEnd, bool autoIndentFlag, bool appendLastEOLFlag)
 {
 	SimpleStream_CStringReader streamSrc(strSrc, strSrcEnd);
-	return Read(env, sig, streamSrc, autoIndentFlag, appendLastEOLFlag);
+	return Read(env, streamSrc, autoIndentFlag, appendLastEOLFlag);
 }
 
-bool Template::Render(Environment &env, Signal sig, SimpleStream *pStreamDst)
+bool Template::Render(Environment &env, SimpleStream *pStreamDst)
 {
-	Template *pTemplateTop = NULL;
-	for (Template *pTemplate = this; pTemplate != NULL;
+	Signal &sig = env.GetSignal();
+	Template *pTemplateTop = nullptr;
+	for (Template *pTemplate = this; pTemplate != nullptr;
 							pTemplate = pTemplate->GetTemplateSuper()) {
-		if (!pTemplate->Prepare(env, sig)) return false;
+		if (!pTemplate->Prepare(env)) return false;
 		pTemplate->SetStreamDst(pStreamDst);
 		pTemplateTop = pTemplate;
 	}
-	if (pTemplateTop->GetFuncForBody() == NULL) return true;
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetThis(Value(new Object_template(env, Reference())));
-	AutoPtr<Environment> pEnvBlock(new Environment(&env, ENVTYPE_local));
-	pTemplateTop->GetFuncForBody()->Eval(*pEnvBlock, sig, *pArgs);
-	for (Template *pTemplate = this; pTemplate != NULL;
+	if (pTemplateTop->GetFuncForBody() == nullptr) return true;
+	AutoPtr<Argument> pArg(new Argument(pTemplateTop->GetFuncForBody()));
+	pArg->SetValueThis(Value(new Object_template(env, Reference())));
+	AutoPtr<Environment> pEnvBlock(env.Derive(ENVTYPE_local));
+	pTemplateTop->GetFuncForBody()->Eval(*pEnvBlock, *pArg);
+	for (Template *pTemplate = this; pTemplate != nullptr;
 							pTemplate = pTemplate->GetTemplateSuper()) {
-		pTemplate->SetStreamDst(NULL);
+		pTemplate->SetStreamDst(nullptr);
 	}
 	return !sig.IsSignalled();
 }
 
-bool Template::Prepare(Environment &env, Signal sig)
+bool Template::Render(Environment &env, String &strDst)
 {
-	AutoPtr<Processor> pProcessor(new Processor());
-	AutoPtr<Environment> pEnvBlock(new Environment(&env, ENVTYPE_local));
+	SimpleStream_StringWriter streamDst(strDst);
+	return Render(env, &streamDst);
+}
+
+bool Template::Prepare(Environment &env)
+{
+	Signal &sig = env.GetSignal();
+	AutoPtr<Environment> pEnvBlock(env.Derive(ENVTYPE_local));
 	pEnvBlock->AssignValue(Gura_Symbol(this_),
 				Value(new Object_template(env, Reference())), EXTRA_Public);
-	_pValueMap->clear();
-	pProcessor->PushSequence(new Expr::SequenceRoot(pEnvBlock.release(),
-									_pExprOwnerForInit->Reference()));
-	pProcessor->Run(sig);
+	_pValueExMap->clear();
+	_pExprOwnerForInit->Exec(*pEnvBlock);
 	return !sig.IsSignalled();
 }
 
 const ValueEx *Template::LookupValue(const Symbol *pSymbol) const
 {
-	for (const Template *pTemplate = this; pTemplate != NULL;
+	for (const Template *pTemplate = this; pTemplate != nullptr;
 							pTemplate = pTemplate->GetTemplateSuper()) {
-		const ValueMap &valueMap = pTemplate->GetValueMap();
-		ValueMap::const_iterator iter = valueMap.find(pSymbol);
-		if (iter != valueMap.end()) return &iter->second;
+		const ValueExMap &valueExMap = pTemplate->GetValueExMap();
+		ValueExMap::const_iterator iter = valueExMap.find(pSymbol);
+		if (iter != valueExMap.end()) return &iter->second;
 	}
-	return NULL;
+	return nullptr;
 }
 
-void Template::PutChar(Signal sig, char ch)
+void Template::PutChar(Signal &sig, char ch)
 {
 	_pStreamDst->PutChar(sig, ch);
 	_chLast = ch;
 }
 
-void Template::Print(Signal sig, const char *str)
+void Template::Print(Signal &sig, const char *str)
 {
 	_pStreamDst->Print(sig, str);
 	size_t len = ::strlen(str);
@@ -101,10 +106,11 @@ Template::Parser::Parser(bool autoIndentFlag, bool appendLastEOLFlag) :
 {
 }
 
-bool Template::Parser::ParseStream(Environment &env, Signal sig,
+bool Template::Parser::ParseStream(Environment &env,
 								Template *pTemplate, SimpleStream &streamSrc)
 {
-	AutoPtr<StringRef> pSourceName(new StringRef(streamSrc.GetName()));
+	Signal &sig = env.GetSignal();
+	AutoPtr<StringShared> pSourceName(new StringShared(streamSrc.GetName()));
 	char chMarker = '$';
 	enum {
 		STAT_LineTop, STAT_Indent, STAT_String,
@@ -122,7 +128,7 @@ bool Template::Parser::ParseStream(Environment &env, Signal sig,
 	int cntLineTop = 0;
 	int nDepth = 0;
 	_exprLeaderStack.clear();
-	if (pTemplate->GetFuncForBody() == NULL) {
+	if (pTemplate->GetFuncForBody() == nullptr) {
 		AutoPtr<FunctionCustom> pFunc(new FunctionCustom(env,
 				Gura_Symbol(_anonymous_), new Expr_Block(), FUNCTYPE_Instance));
 		pFunc->SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_DynamicScope);
@@ -240,10 +246,10 @@ bool Template::Parser::ParseStream(Environment &env, Signal sig,
 		}
 		case STAT_ScriptPost: {
 			const char *strPost = (ch == '\n')? "\n" : "";
-			if (!CreateTmplScript(env, sig,
-								  strIndent.c_str(), strTmplScript.c_str(), strPost,
-								  pTemplate, pExprBlockRoot,
-								  pSourceName.get(), cntLineTop, cntLine)) return false;
+			if (!CreateTmplScript(
+					env, strIndent.c_str(), strTmplScript.c_str(), strPost,
+					pTemplate, pExprBlockRoot,
+					pSourceName.get(), cntLineTop, cntLine)) return false;
 			strIndent.clear();
 			strTmplScript.clear();
 			if (ch == '\n') {
@@ -319,7 +325,6 @@ bool Template::Parser::ParseStream(Environment &env, Signal sig,
 		case STAT_CommentPost: {
 			if (!stringAheadFlag && ch == '\n') {
 				stringAheadFlag = false;
-				Gura_PushbackCond(false);
 				stat = STAT_LineTop;
 			} else {
 				stringAheadFlag = true;
@@ -334,7 +339,7 @@ bool Template::Parser::ParseStream(Environment &env, Signal sig,
 	}
 	if (!strTmplScript.empty()) {
 		const char *strPost = "";
-		if (!CreateTmplScript(env, sig,
+		if (!CreateTmplScript(env,
 				strIndent.c_str(), strTmplScript.c_str(), strPost,
 				pTemplate, pExprBlockRoot,
 				pSourceName.get(), cntLineTop, cntLine)) return false;
@@ -349,16 +354,17 @@ bool Template::Parser::ParseStream(Environment &env, Signal sig,
 		pExprBlockRoot->GetExprOwner().push_back(pExpr);
 		str.clear();
 	}
-	return true;
+	return pExprBlockRoot->Prepare(env);
 }
 
-bool Template::Parser::CreateTmplScript(Environment &env, Signal sig,
+bool Template::Parser::CreateTmplScript(Environment &env,
 			const char *strIndent, const char *strTmplScript, const char *strPost,
 			Template *pTemplate, Expr_Block *pExprBlockRoot,
-			StringRef *pSourceName, int cntLineTop, int cntLineBtm)
+			StringShared *pSourceName, int cntLineTop, int cntLineBtm)
 {
+	Signal &sig = env.GetSignal();
 	Class *pClass = env.LookupClass(VTYPE_template);
-	Expr *pExprLast = NULL;
+	Expr *pExprLast = nullptr;
 	AutoPtr<Expr_TmplScript> pExprTmplScript(new Expr_TmplScript(
 			pTemplate, strIndent, strPost, _autoIndentFlag, _appendLastEOLFlag));
 	pExprTmplScript->SetSourceInfo(pSourceName->Reference(), cntLineTop + 1, cntLineBtm + 1);
@@ -367,19 +373,19 @@ bool Template::Parser::CreateTmplScript(Environment &env, Signal sig,
 		strTmplScript++;
 		AutoPtr<ExprOwner> pExprOwnerForInit(new ExprOwner());
 		do {
-			Gura::Parser parser(pSourceName->GetString(), cntLineTop);
+			Gura::Parser parser(sig, pSourceName->GetString(), cntLineTop, false);
 			// Appends "this.init_" before the script string while parsing
 			// so that it generates an expression "this.init_foo()" from the directive "${=foo()}".
-			if (!parser.ParseString(env, sig, *pExprOwnerForInit, "this.init_", false)) return false;
-			if (!parser.ParseString(env, sig, *pExprOwnerForInit, strTmplScript, true)) return false;
+			if (!parser.ParseString(env, *pExprOwnerForInit, "this.init_", false)) return false;
+			if (!parser.ParseString(env, *pExprOwnerForInit, strTmplScript, true)) return false;
 		} while (0);
 		do {
 			ExprOwner &exprOwner = pExprTmplScript->GetExprOwner();
-			Gura::Parser parser(pSourceName->GetString(), cntLineTop);
+			Gura::Parser parser(sig, pSourceName->GetString(), cntLineTop, false);
 			// Appends "this." before the script string while parsing
 			// so that it generates an expression "this.foo()" from the directive "${=foo()}".
-			if (!parser.ParseString(env, sig, exprOwner, "this.", false)) return false;
-			if (!parser.ParseString(env, sig, exprOwner, strTmplScript, true)) return false;
+			if (!parser.ParseString(env, exprOwner, "this.", false)) return false;
+			if (!parser.ParseString(env, exprOwner, strTmplScript, true)) return false;
 		} while (0);
 		do {
 			ExprOwner &exprOwnerForPresent = _exprLeaderStack.empty()?
@@ -397,20 +403,20 @@ bool Template::Parser::CreateTmplScript(Environment &env, Signal sig,
 		} while (0);
 		if (!pExprLast->IsCaller()) return true;
 		Expr_Caller *pExprLastCaller = dynamic_cast<Expr_Caller *>(pExprLast);
-		if (pExprLastCaller->GetBlock() == NULL) {
-			Callable *pCallable = NULL;
+		if (pExprLastCaller->GetBlock() == nullptr) {
+			Callable *pCallable = nullptr;
 			if (pExprLastCaller->GetCar()->IsMember()) {
 				Expr_Member *pExprCar = dynamic_cast<Expr_Member *>(pExprLastCaller->GetCar());
-				if (pExprCar->GetLeft()->IsIdentifier() &&
-						dynamic_cast<Expr_Identifier *>(pExprCar->GetLeft())->GetSymbol()->
-														IsIdentical(Gura_Symbol(this_))) {
-					pCallable = pExprCar->GetRight()->LookupCallable(*pClass, sig);
+				if (pExprCar->GetTarget()->IsIdentifier() &&
+					dynamic_cast<const Expr_Identifier *>(pExprCar->GetTarget())->
+									GetSymbol()->IsIdentical(Gura_Symbol(this_))) {
+					pCallable = pExprCar->GetSelector()->LookupCallable(*pClass);
 				}
 			} else {
-				pCallable = pExprLastCaller->LookupCallable(env, sig);
+				pCallable = pExprLastCaller->LookupCallable(env);
 			}
 			sig.ClearSignal();
-			if (pCallable != NULL && pCallable->GetBlockOccurPattern() == OCCUR_Once) {
+			if (pCallable != nullptr && pCallable->GetBlockOccurPattern() == OCCUR_Once) {
 				Expr_Block *pExprBlock = new Expr_Block();
 				pExprLastCaller->SetBlock(pExprBlock);
 				_exprLeaderStack.push_back(pExprLastCaller);
@@ -421,16 +427,16 @@ bool Template::Parser::CreateTmplScript(Environment &env, Signal sig,
 	} else {
 		// Parsing a normal script other than template directive.
 		AutoPtr<ExprOwner> pExprOwnerPart(new ExprOwner());
-		Gura::Parser parser(pSourceName->GetString(), cntLineTop);
-		if (!parser.ParseString(env, sig, *pExprOwnerPart, strTmplScript, true)) return false;
+		Gura::Parser parser(sig, pSourceName->GetString(), cntLineTop, false);
+		if (!parser.ParseString(env, *pExprOwnerPart, strTmplScript, true)) return false;
 		ExprOwner::iterator ppExpr = pExprOwnerPart->begin();
 		//::printf("[%s], [%s], [%s]\n", strIndent, strTmplScript, strPost);
 		if (ppExpr != pExprOwnerPart->end()) {
 			// check if the first Expr is a trailer
 			Expr *pExpr = *ppExpr;
-			Callable *pCallable = pExpr->LookupCallable(env, sig);
+			Callable *pCallable = pExpr->LookupCallable(env);
 			sig.ClearSignal();
-			if (pCallable != NULL && pCallable->IsTrailer()) {
+			if (pCallable != nullptr && pCallable->IsTrailer()) {
 				pExprTmplScript->SetStringIndent("");
 				if (_exprLeaderStack.empty()) {
 					sig.SetError(ERR_SyntaxError, "unmatching trailer expression");
@@ -438,11 +444,12 @@ bool Template::Parser::CreateTmplScript(Environment &env, Signal sig,
 					return false;
 				}
 				if (!pCallable->IsEndMarker()) {
-					Expr_Caller *pExprCaller = NULL;
+					Expr_Caller *pExprCaller = nullptr;
 					if (pExpr->IsCaller()) {
 						pExprCaller = dynamic_cast<Expr_Caller *>(Expr::Reference(pExpr));
 					} else {
-						pExprCaller = new Expr_Caller(Expr::Reference(pExpr), NULL, NULL);
+						pExprCaller = new Expr_Caller(
+							Expr::Reference(pExpr), nullptr, nullptr, FLAG_None);
 						pExprCaller->SetSourceInfo(pSourceName->Reference(),
 										pExpr->GetLineNoTop(), pExpr->GetLineNoBtm());
 					}
@@ -464,23 +471,23 @@ bool Template::Parser::CreateTmplScript(Environment &env, Signal sig,
 					_exprLeaderStack.back()->GetBlock()->GetExprOwner();
 			exprOwnerForPresent.push_back(Expr::Reference(pExprTmplScript.get()));
 		}
-		if (pExprLast == NULL) return true;
+		if (pExprLast == nullptr) return true;
 		if (!pExprLast->IsCaller()) return true;
 		Expr_Caller *pExprLastCaller = dynamic_cast<Expr_Caller *>(pExprLast);
-		if (pExprLastCaller->GetBlock() == NULL) {
-			Callable *pCallable = NULL;
+		if (pExprLastCaller->GetBlock() == nullptr) {
+			Callable *pCallable = nullptr;
 			if (pExprLastCaller->GetCar()->IsMember()) {
 				Expr_Member *pExprCar = dynamic_cast<Expr_Member *>(pExprLastCaller->GetCar());
-				if (pExprCar->GetLeft()->IsIdentifier() &&
-						dynamic_cast<Expr_Identifier *>(pExprCar->GetLeft())->GetSymbol()->
+				if (pExprCar->GetTarget()->IsIdentifier() &&
+						dynamic_cast<const Expr_Identifier *>(pExprCar->GetTarget())->GetSymbol()->
 														IsIdentical(Gura_Symbol(this_))) {
-					pCallable = pExprCar->GetRight()->LookupCallable(*pClass, sig);
+					pCallable = pExprCar->GetSelector()->LookupCallable(*pClass);
 				}
 			} else {
-				pCallable = pExprLastCaller->LookupCallable(env, sig);
+				pCallable = pExprLastCaller->LookupCallable(env);
 			}
 			sig.ClearSignal();
-			if (pCallable != NULL && pCallable->GetBlockOccurPattern() == OCCUR_Once) {
+			if (pCallable != nullptr && pCallable->GetBlockOccurPattern() == OCCUR_Once) {
 				Expr_Block *pExprBlock = new Expr_Block();
 				pExprLastCaller->SetBlock(pExprBlock);
 				_exprLeaderStack.push_back(pExprLastCaller);
@@ -504,11 +511,11 @@ Expr *Expr_TmplString::Clone() const
 	return new Expr_TmplString(*this);
 }
 
-Value Expr_TmplString::DoExec(Environment &env, Signal sig, SeqPostHandler *pSeqPostHandler) const
+Value Expr_TmplString::DoExec(Environment &env) const
 {
+	Signal &sig = env.GetSignal();
 	_pTemplate->Print(sig, _str.c_str());
-	if (pSeqPostHandler != NULL && !pSeqPostHandler->DoPost(sig, Value::Null)) return Value::Null;
-	return Value::Null;
+	return Value::Nil;
 }
 
 void Expr_TmplString::Accept(ExprVisitor &visitor)
@@ -516,14 +523,14 @@ void Expr_TmplString::Accept(ExprVisitor &visitor)
 	visitor.Visit(this);
 }
 
-bool Expr_TmplString::GenerateCode(Environment &env, Signal sig, Stream &stream)
+bool Expr_TmplString::GenerateCode(Environment &env, CodeGenerator &codeGenerator) const
 {
-	stream.Println(sig, "TmplString");
+	//stream.Println(sig, "TmplString");
 	return true;
 }
 
-bool Expr_TmplString::GenerateScript(Signal sig, SimpleStream &stream,
-								ScriptStyle scriptStyle, int nestLevel) const
+bool Expr_TmplString::GenerateScript(Signal &sig, SimpleStream &stream,
+							ScriptStyle scriptStyle, int nestLevel, const char *strIndent) const
 {
 	return false;
 }
@@ -536,25 +543,30 @@ Expr *Expr_TmplScript::Clone() const
 	return new Expr_TmplScript(*this);
 }
 
-Value Expr_TmplScript::DoExec(Environment &env, Signal sig, SeqPostHandler *pSeqPostHandler) const
+Value Expr_TmplScript::DoExec(Environment &env) const
 {
-	if (GetExprOwner().empty()) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (GetExprOwner().empty()) return Value::Nil;
 	Value value;
-	SeqPostHandler *pSeqPostHandlerEach = NULL;
 	foreach_const (ExprList, ppExpr, GetExprOwner()) {
-		value = (*ppExpr)->Exec2(env, sig, pSeqPostHandlerEach, true);
-		if (sig.IsSignalled()) return Value::Null;
+		value = (*ppExpr)->Exec(env, true);
+		if (sig.IsSignalled()) return Value::Nil;
 	}
-	if (value.IsInvalid()) return Value::Null;
-	_pTemplate->Print(sig, _strIndent.c_str());
+	if (value.IsInvalid()) return Value::Nil;
 	String strLast;
 	if (value.Is_string()) {
+		_pTemplate->Print(sig, _strIndent.c_str());
 		strLast = value.GetStringSTL();
 	} else if (value.Is_list() || value.Is_iterator()) {
 		AutoPtr<Iterator> pIterator(value.CreateIterator(sig));
-		if (sig.IsSignalled()) return false;
+		if (sig.IsSignalled()) return Value::Nil;
+		bool firstFlag = true;
 		Value valueElem;
-		while (pIterator->Next(env, sig, valueElem)) {
+		while (pIterator->Next(env, valueElem)) {
+			if (firstFlag) {
+				firstFlag = false;
+				_pTemplate->Print(sig, _strIndent.c_str());
+			}
 			foreach_const (String, p, strLast) {
 				char ch = *p;
 				if (ch == '\n') {
@@ -572,22 +584,25 @@ Value Expr_TmplScript::DoExec(Environment &env, Signal sig, SeqPostHandler *pSeq
 				strLast.clear();
 			} else if (valueElem.Is_number()) {
 				strLast = valueElem.ToString();
-				if (sig.IsSignalled()) return false;
+				if (sig.IsSignalled()) return Value::Nil;
 			} else {
 				sig.SetError(ERR_TypeError,
-					"template script must return nil, string or number");
+							 "an iterable returned by a template script must contain "
+							 "elements of nil, string or number");
 				sig.AddExprCause(this);
-				return Value::Null;
+				return Value::Nil;
 			}
 		}
+		if (firstFlag) return Value::Nil;
 	} else if (value.Is_number()) {
+		_pTemplate->Print(sig, _strIndent.c_str());
 		strLast = value.ToString();
-		if (sig.IsSignalled()) return false;
+		if (sig.IsSignalled()) return Value::Nil;
 	} else {
 		sig.SetError(ERR_TypeError,
 			"template script must return nil, string or number");
 		sig.AddExprCause(this);
-		return Value::Null;
+		return Value::Nil;
 	}
 	foreach_const (String, p, strLast) {
 		char ch = *p;
@@ -603,35 +618,19 @@ Value Expr_TmplScript::DoExec(Environment &env, Signal sig, SeqPostHandler *pSeq
 		}
 	}
 	_pTemplate->Print(sig, _strPost.c_str());
-	return Value::Null;
+	return Value::Nil;
 }
 
-bool Expr_TmplScript::GenerateCode(Environment &env, Signal sig, Stream &stream)
+bool Expr_TmplScript::GenerateCode(Environment &env, CodeGenerator &codeGenerator) const
 {
-	stream.Println(sig, "TmplScript");
+	//stream.Println(sig, "TmplScript");
 	return true;
 }
 
-bool Expr_TmplScript::GenerateScript(Signal sig, SimpleStream &stream,
-								ScriptStyle scriptStyle, int nestLevel) const
+bool Expr_TmplScript::GenerateScript(Signal &sig, SimpleStream &stream,
+							ScriptStyle scriptStyle, int nestLevel, const char *strIndent) const
 {
 	return false;
 }
 
-Expr_TmplScript::SequenceEx::SequenceEx(Environment *pEnv) : Sequence(pEnv)
-{
-}
-
-bool Expr_TmplScript::SequenceEx::DoStep(Signal sig, Value &result)
-{
-	return false;
-}
-
-String Expr_TmplScript::SequenceEx::ToString() const
-{
-	String str;
-	str += "<sequence:expr_tmplscript>";
-	return str;
-}
-
 }
