@@ -1151,70 +1151,70 @@ static const UShort _row_FC[] = {
 	0x9d6b, 0xfa2d, 0x9e19, 0x9ed1,
 };
 static const Codec::CodeRow _codeRows[] = {
-	{ 224,  _row_00 }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, { 189,  _row_81 }, { 178,  _row_82 }, { 151,  _row_83 },
-	{ 127,  _row_84 }, {   0,     NULL }, {   0,     NULL }, {  93,  _row_87 },
+	{ 224,  _row_00 }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, { 189,  _row_81 }, { 178,  _row_82 }, { 151,  _row_83 },
+	{ 127,  _row_84 }, {   0,  nullptr }, {   0,  nullptr }, {  93,  _row_87 },
 	{ 189,  _row_88 }, { 189,  _row_89 }, { 189,  _row_8A }, { 189,  _row_8B },
 	{ 189,  _row_8C }, { 189,  _row_8D }, { 189,  _row_8E }, { 189,  _row_8F },
 	{ 189,  _row_90 }, { 189,  _row_91 }, { 189,  _row_92 }, { 189,  _row_93 },
 	{ 189,  _row_94 }, { 189,  _row_95 }, { 189,  _row_96 }, { 189,  _row_97 },
 	{ 189,  _row_98 }, { 189,  _row_99 }, { 189,  _row_9A }, { 189,  _row_9B },
 	{ 189,  _row_9C }, { 189,  _row_9D }, { 189,  _row_9E }, { 189,  _row_9F },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
 	{ 189,  _row_E0 }, { 189,  _row_E1 }, { 189,  _row_E2 }, { 189,  _row_E3 },
 	{ 189,  _row_E4 }, { 189,  _row_E5 }, { 189,  _row_E6 }, { 189,  _row_E7 },
-	{ 189,  _row_E8 }, { 189,  _row_E9 }, { 101,  _row_EA }, {   0,     NULL },
-	{   0,     NULL }, { 189,  _row_ED }, { 189,  _row_EE }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
-	{   0,     NULL }, {   0,     NULL }, { 189,  _row_FA }, { 189,  _row_FB },
-	{  12,  _row_FC }, {   0,     NULL }, {   0,     NULL }, {   0,     NULL },
+	{ 189,  _row_E8 }, { 189,  _row_E9 }, { 101,  _row_EA }, {   0,  nullptr },
+	{   0,  nullptr }, { 189,  _row_ED }, { 189,  _row_EE }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
+	{   0,  nullptr }, {   0,  nullptr }, { 189,  _row_FA }, { 189,  _row_FB },
+	{  12,  _row_FC }, {   0,  nullptr }, {   0,  nullptr }, {   0,  nullptr },
 };
 
 UShort CP932ToUTF16(UShort codeCP932)
@@ -1224,7 +1224,7 @@ UShort CP932ToUTF16(UShort codeCP932)
 
 UShort UTF16ToCP932(UShort codeUTF16)
 {
-	static Codec::Map *pMap = NULL;
+	static Codec::Map *pMap = nullptr;
 	return Codec::UTF16ToDBCS(_codeRows, ArraySizeOf(_codeRows), codeUTF16, &pMap);
 }
 
