@@ -13,13 +13,13 @@ Gura_BeginModuleHeader(bmp)
 class ImageStreamer_BMP : public ImageStreamer {
 public:
 	inline ImageStreamer_BMP() : ImageStreamer("bmp") {}
-	virtual bool IsResponsible(Signal sig, Stream &stream);
-	virtual bool Read(Environment &env, Signal sig, Image *pImage, Stream &stream);
-	virtual bool Write(Environment &env, Signal sig, Image *pImage, Stream &stream);
+	virtual bool IsResponsible(Signal &sig, Stream &stream);
+	virtual bool Read(Environment &env, Image *pImage, Stream &stream);
+	virtual bool Write(Environment &env, Image *pImage, Stream &stream);
 public:
-	static bool ReadStream(Environment &env, Signal sig, Image *pImage, Stream &stream);
-	static bool WriteStream(Environment &env, Signal sig, Image *pImage, Stream &stream);
-	static void SetError_InvalidBMPFormat(Signal sig);
+	static bool ReadStream(Environment &env, Image *pImage, Stream &stream);
+	static bool WriteStream(Environment &env, Image *pImage, Stream &stream);
+	static void SetError_InvalidBMPFormat(Signal &sig);
 };
 
 Gura_EndModuleHeader(bmp)
