@@ -11,8 +11,8 @@ Gura_BeginModuleHeader(bzip2)
 //-----------------------------------------------------------------------------
 // utilities
 //-----------------------------------------------------------------------------
-Object_stream *GenerateDecompressor(Environment &env, Signal sig, Stream &stream);
-Object_stream *GenerateCompressor(Environment &env, Signal sig, Stream &stream, int blockSize100k);
+Object_stream *GenerateDecompressor(Environment &env, Stream &stream);
+Object_stream *GenerateCompressor(Environment &env, Stream &stream, int blockSize100k);
 
 Gura_EndModuleHeader(bzip2)
 
