@@ -14,8 +14,8 @@ public:
 				Object_surface(surface), _pWriter(pWriter) {}
 	virtual ~Object_Writer_surface();
 	inline Writer *GetWriter() { return _pWriter; }
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
+	virtual bool DoDirProp(Environment &env, SymbolSet &symbols);
+	virtual Value DoGetProp(Environment &env, const Symbol *pSymbol,
 							const SymbolSet &attrs, bool &evaluatedFlag);
 };
 
