@@ -23,9 +23,6 @@ public:
 		Object(Gura_UserClass(context)), _cr(cr), _pObjSurface(pObjSurface) {}
 	virtual ~Object_context();
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 	inline cairo_t *GetEntity() { return _cr; }
 	inline Object_surface *GetSurfaceObj() { return _pObjSurface.get(); }
