@@ -12,7 +12,7 @@ Object_pattern::~Object_pattern()
 
 Object *Object_pattern::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_pattern::ToString(bool exprFlag)
@@ -31,7 +31,7 @@ Gura_DeclareClassMethod(pattern, create_rgb)
 	DeclareArg(env, "green", VTYPE_number);
 	DeclareArg(env, "blue", VTYPE_number);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Creates a new cairo.pattern corresponding to an opaque color.\n"
 	"The color components are floating point numbers in the range 0 to 1.\n"
 	"If the values passed in are outside that range, they will be clamped.\n"
@@ -40,13 +40,14 @@ Gura_DeclareClassMethod(pattern, create_rgb)
 
 Gura_ImplementClassMethod(pattern, create_rgb)
 {
+	Signal &sig = env.GetSignal();
 	cairo_pattern_t *pattern = ::cairo_pattern_create_rgb(
-			args.GetDouble(0), args.GetDouble(1), args.GetDouble(2));
+			arg.GetDouble(0), arg.GetDouble(1), arg.GetDouble(2));
 	if (Is_error(sig, pattern)) {
 		::cairo_pattern_destroy(pattern);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_pattern(pattern)));
+	return ReturnValue(env, arg, Value(new Object_pattern(pattern)));
 }
 
 // cairo.pattern.create_rgba(red:number, green:number, blue:number, alpha:number) {block?}
@@ -58,7 +59,7 @@ Gura_DeclareClassMethod(pattern, create_rgba)
 	DeclareArg(env, "blue", VTYPE_number);
 	DeclareArg(env, "alpha", VTYPE_number);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Creates a new cairo,pattern corresponding to a translucent color.\n"
 	"The color components are floating point numbers in the range 0 to 1.\n"
 	"If the values passed in are outside that range, they will be clamped.\n"
@@ -67,13 +68,14 @@ Gura_DeclareClassMethod(pattern, create_rgba)
 
 Gura_ImplementClassMethod(pattern, create_rgba)
 {
+	Signal &sig = env.GetSignal();
 	cairo_pattern_t *pattern = ::cairo_pattern_create_rgba(
-			args.GetDouble(0), args.GetDouble(1), args.GetDouble(2), args.GetDouble(3));
+			arg.GetDouble(0), arg.GetDouble(1), arg.GetDouble(2), arg.GetDouble(3));
 	if (Is_error(sig, pattern)) {
 		::cairo_pattern_destroy(pattern);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_pattern(pattern)));
+	return ReturnValue(env, arg, Value(new Object_pattern(pattern)));
 }
 
 // cairo.pattern.create_color(color:color, alpha?:number) {block?}
@@ -83,29 +85,30 @@ Gura_DeclareClassMethod(pattern, create_color)
 	DeclareArg(env, "color", VTYPE_color);
 	DeclareArg(env, "alpha", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Creates a new cairo,pattern corresponding to a color instance of Gura and an alpha value.\n"
 	);
 }
 
 Gura_ImplementClassMethod(pattern, create_color)
 {
-	const Color &color = Object_color::GetObject(args, 0)->GetColor();
+	Signal &sig = env.GetSignal();
+	const Color &color = Object_color::GetObject(arg, 0)->GetColor();
 	double red = static_cast<double>(color.GetR()) / 255;
 	double green = static_cast<double>(color.GetG()) / 255;
 	double blue = static_cast<double>(color.GetB()) / 255;
 	cairo_pattern_t *pattern;
-	if (args.Is_number(1)) {
-		double alpha = args.GetDouble(1);
+	if (arg.Is_number(1)) {
+		double alpha = arg.GetDouble(1);
 		pattern = ::cairo_pattern_create_rgba(red, green, blue, alpha);
 	} else {
 		pattern = ::cairo_pattern_create_rgb(red, green, blue);
 	}
 	if (Is_error(sig, pattern)) {
 		::cairo_pattern_destroy(pattern);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_pattern(pattern)));
+	return ReturnValue(env, arg, Value(new Object_pattern(pattern)));
 }
 
 // cairo.pattern.create_for_surface(surface:cairo.surface) {block?}
@@ -114,20 +117,21 @@ Gura_DeclareClassMethod(pattern, create_for_surface)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "surface", VTYPE_surface);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Create a new cairo.pattern for the given surface.\n"
 	);
 }
 
 Gura_ImplementClassMethod(pattern, create_for_surface)
 {
-	cairo_surface_t *surface = Object_surface::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	cairo_surface_t *surface = Object_surface::GetObject(arg, 0)->GetEntity();
 	cairo_pattern_t *pattern = ::cairo_pattern_create_for_surface(surface);
 	if (Is_error(sig, pattern)) {
 		::cairo_pattern_destroy(pattern);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_pattern(pattern)));
+	return ReturnValue(env, arg, Value(new Object_pattern(pattern)));
 }
 
 // cairo.pattern.create_linear(x0:number, y0:number, x1:number, y1:number) {block?}
@@ -139,7 +143,7 @@ Gura_DeclareClassMethod(pattern, create_linear)
 	DeclareArg(env, "x1", VTYPE_number);
 	DeclareArg(env, "y1", VTYPE_number);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Create a new linear gradient cairo.pattern along the line defined by (x0, y0) and (x1, y1).\n"
 	"Before using the gradient pattern, a number of color stops should be defined using cairo.pattern#add_color_stop_rgb() or cairo.pattern#add_color_stop_rgba().\n"
 	"\n"
@@ -150,13 +154,14 @@ Gura_DeclareClassMethod(pattern, create_linear)
 
 Gura_ImplementClassMethod(pattern, create_linear)
 {
+	Signal &sig = env.GetSignal();
 	cairo_pattern_t *pattern = ::cairo_pattern_create_linear(
-			args.GetDouble(0), args.GetDouble(1), args.GetDouble(2), args.GetDouble(3));
+			arg.GetDouble(0), arg.GetDouble(1), arg.GetDouble(2), arg.GetDouble(3));
 	if (Is_error(sig, pattern)) {
 		::cairo_pattern_destroy(pattern);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_pattern(pattern)));
+	return ReturnValue(env, arg, Value(new Object_pattern(pattern)));
 }
 
 // cairo.pattern.create_radial(cx0:number, cy0:number, radius0:number, cx1:number, cy1:number, radius1:number) {block?}
@@ -170,7 +175,7 @@ Gura_DeclareClassMethod(pattern, create_radial)
 	DeclareArg(env, "cy1", VTYPE_number);
 	DeclareArg(env, "radius1", VTYPE_number);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Creates a new radial gradient cairo_pattern_t between the two circles defined by (cx0, cy0, radius0) and (cx1, cy1, radius1).\n"
 	"Before using the gradient pattern, a number of color stops should be defined using cairo.pattern#add_color_stop_rgb() or cairo.pattern#add_color_stop_rgba().\n"
 	"\n"
@@ -181,14 +186,15 @@ Gura_DeclareClassMethod(pattern, create_radial)
 
 Gura_ImplementClassMethod(pattern, create_radial)
 {
+	Signal &sig = env.GetSignal();
 	cairo_pattern_t *pattern = ::cairo_pattern_create_radial(
-			args.GetDouble(0), args.GetDouble(1), args.GetDouble(2),
-			args.GetDouble(3), args.GetDouble(4), args.GetDouble(5));
+			arg.GetDouble(0), arg.GetDouble(1), arg.GetDouble(2),
+			arg.GetDouble(3), arg.GetDouble(4), arg.GetDouble(5));
 	if (Is_error(sig, pattern)) {
 		::cairo_pattern_destroy(pattern);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_pattern(pattern)));
+	return ReturnValue(env, arg, Value(new Object_pattern(pattern)));
 }
 
 // cairo.pattern#add_color_stop_rgb(offset:number, red:number, green:number, blue:number):reduce
@@ -199,7 +205,7 @@ Gura_DeclareMethod(pattern, add_color_stop_rgb)
 	DeclareArg(env, "red", VTYPE_number);
 	DeclareArg(env, "green", VTYPE_number);
 	DeclareArg(env, "blue", VTYPE_number);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Adds an opaque color stop to a gradient pattern.\n"
 	"The offset specifies the location along the gradient's control vector.\n"
 	"For example, a linear gradient's control vector is from (x0,y0) to (x1,y1)\n"
@@ -218,12 +224,13 @@ Gura_DeclareMethod(pattern, add_color_stop_rgb)
 
 Gura_ImplementMethod(pattern, add_color_stop_rgb)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
-	::cairo_pattern_add_color_stop_rgb(pattern, args.GetDouble(0),
-		args.GetDouble(1), args.GetDouble(2), args.GetDouble(3));
-	if (Is_error(sig, pattern)) return Value::Null;
-	return args.GetThis();
+	::cairo_pattern_add_color_stop_rgb(pattern, arg.GetDouble(0),
+		arg.GetDouble(1), arg.GetDouble(2), arg.GetDouble(3));
+	if (Is_error(sig, pattern)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // cairo.pattern#add_color_stop_rgba(offset:number, red:number, green:number, blue:number, alpha:number):reduce
@@ -235,7 +242,7 @@ Gura_DeclareMethod(pattern, add_color_stop_rgba)
 	DeclareArg(env, "green", VTYPE_number);
 	DeclareArg(env, "blue", VTYPE_number);
 	DeclareArg(env, "alpha", VTYPE_number);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Adds a translucent color stop to a gradient pattern.\n"
 	"The offset specifies the location along the gradient's control vector.\n"
 	"For example, a linear gradient's control vector is from (x0,y0) to (x1,y1)\n"
@@ -254,30 +261,32 @@ Gura_DeclareMethod(pattern, add_color_stop_rgba)
 
 Gura_ImplementMethod(pattern, add_color_stop_rgba)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
-	::cairo_pattern_add_color_stop_rgba(pattern, args.GetDouble(0),
-		args.GetDouble(1), args.GetDouble(2), args.GetDouble(3), args.GetDouble(4));
-	if (Is_error(sig, pattern)) return Value::Null;
-	return args.GetThis();
+	::cairo_pattern_add_color_stop_rgba(pattern, arg.GetDouble(0),
+		arg.GetDouble(1), arg.GetDouble(2), arg.GetDouble(3), arg.GetDouble(4));
+	if (Is_error(sig, pattern)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // cairo.pattern#get_color_stop_count()
 Gura_DeclareMethod(pattern, get_color_stop_count)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the number of color stops specified in the given gradient pattern.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_color_stop_count)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	int count;
 	cairo_status_t status = ::cairo_pattern_get_color_stop_count(pattern, &count);
-	if (Is_error(sig, status)) return Value::Null;
+	if (Is_error(sig, status)) return Value::Nil;
 	return Value(count);
 }
 
@@ -286,7 +295,7 @@ Gura_DeclareMethod(pattern, get_color_stop_rgba)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "index", VTYPE_number);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the color and offset information at the given index for a gradient pattern.\n"
 	"Values of index are 0 to 1 less than the number returned by cairo.pattern#get_color_stop_count().\n"
 	);
@@ -294,12 +303,13 @@ Gura_DeclareMethod(pattern, get_color_stop_rgba)
 
 Gura_ImplementMethod(pattern, get_color_stop_rgba)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	double offset, red, green, blue, alpha;
-	cairo_status_t status = ::cairo_pattern_get_color_stop_rgba(pattern, args.GetInt(0),
+	cairo_status_t status = ::cairo_pattern_get_color_stop_rgba(pattern, arg.GetInt(0),
 										&offset, &red, &green, &blue, &alpha);
-	if (Is_error(sig, status)) return Value::Null;
+	if (Is_error(sig, status)) return Value::Nil;
 	return CreateValueList(env, offset, red, green, blue, alpha);
 }
 
@@ -307,19 +317,20 @@ Gura_ImplementMethod(pattern, get_color_stop_rgba)
 Gura_DeclareMethod(pattern, get_rgba)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the solid color for a solid color pattern.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_rgba)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	double red, green, blue, alpha;
 	cairo_status_t status = ::cairo_pattern_get_rgba(pattern,
 										&red, &green, &blue, &alpha);
-	if (Is_error(sig, status)) return Value::Null;
+	if (Is_error(sig, status)) return Value::Nil;
 	return CreateValueList(env, red, green, blue, alpha);
 }
 
@@ -327,7 +338,7 @@ Gura_ImplementMethod(pattern, get_rgba)
 Gura_DeclareMethod(pattern, get_surface)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the surface of a surface pattern.\n"
 	"The reference returned in surface is owned by the pattern;\n"
 	"the caller should call cairo_surface_reference() if the surface is to be retained.\n"
@@ -336,16 +347,17 @@ Gura_DeclareMethod(pattern, get_surface)
 
 Gura_ImplementMethod(pattern, get_surface)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
-	cairo_surface_t *surface = NULL;
+	cairo_surface_t *surface = nullptr;
 	cairo_status_t status = ::cairo_pattern_get_surface(pattern, &surface);
-	if (Is_error(sig, status)) return Value::Null;
+	if (Is_error(sig, status)) return Value::Nil;
 	cairo_surface_t *surface_ref = ::cairo_surface_reference(surface);
 	cairo_surface_type_t surface_type = ::cairo_surface_get_type(surface);
-	Object_surface *pObjSurface = NULL;
+	Object_surface *pObjSurface = nullptr;
 	if (surface_type == CAIRO_SURFACE_TYPE_IMAGE) {
-		pObjSurface = new Object_image_surface(surface_ref, NULL);
+		pObjSurface = new Object_image_surface(surface_ref, nullptr);
 	} else if (surface_type == CAIRO_SURFACE_TYPE_PDF) {
 		pObjSurface = new Object_surface(surface_ref);
 	} else if (surface_type == CAIRO_SURFACE_TYPE_PS) {
@@ -402,19 +414,20 @@ Gura_ImplementMethod(pattern, get_surface)
 Gura_DeclareMethod(pattern, get_linear_points)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the gradient endpoints for a linear gradient.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_linear_points)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	double x0, y0, x1, y1;
 	cairo_status_t status =
 			::cairo_pattern_get_linear_points(pattern, &x0, &y0, &x1, &y1);
-	if (Is_error(sig, status)) return Value::Null;
+	if (Is_error(sig, status)) return Value::Nil;
 	return CreateValueList(env, x0, y0, x1, y1);
 }
 
@@ -422,19 +435,20 @@ Gura_ImplementMethod(pattern, get_linear_points)
 Gura_DeclareMethod(pattern, get_radial_circles)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the gradient endpoint circles for a radial gradient, each specified as a center coordinate and a radius.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_radial_circles)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	double x0, y0, r0, x1, y1, r1;
 	cairo_status_t status =
 		::cairo_pattern_get_radial_circles(pattern, &x0, &y0, &r0, &x1, &y1, &r1);
-	if (Is_error(sig, status)) return Value::Null;
+	if (Is_error(sig, status)) return Value::Nil;
 	return CreateValueList(env, x0, y0, r0, x1, y1, r1);
 }
 
@@ -445,14 +459,14 @@ Gura_ImplementMethod(pattern, get_radial_circles)
 Gura_DeclareMethod(pattern, status)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Checks whether an error has previously occurred for this pattern.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, status)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	cairo_status_t rtn = ::cairo_pattern_status(pattern);
 	return Value(rtn);
@@ -463,7 +477,7 @@ Gura_DeclareMethod(pattern, set_extend)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Reduce, FLAG_None);
 	DeclareArg(env, "extend", VTYPE_number);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Sets the mode to be used for drawing outside the area of a pattern.\n"
 	"See cairo_extend_t for details on the semantics of each extend strategy.\n"
 	"\n"
@@ -473,20 +487,21 @@ Gura_DeclareMethod(pattern, set_extend)
 
 Gura_ImplementMethod(pattern, set_extend)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
-	cairo_extend_t extend = static_cast<cairo_extend_t>(args.GetInt(0));
-	if (sig.IsSignalled()) return Value::Null;
+	cairo_extend_t extend = static_cast<cairo_extend_t>(arg.GetInt(0));
+	if (sig.IsSignalled()) return Value::Nil;
 	::cairo_pattern_set_extend(pattern, extend);
-	if (Is_error(sig, pattern)) return Value::Null;
-	return args.GetThis();
+	if (Is_error(sig, pattern)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // cairo.pattern#get_extend()
 Gura_DeclareMethod(pattern, get_extend)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the current extend mode for a pattern.\n"
 	"See cairo_extend_t for details on the semantics of each extend strategy.\n"
 	);
@@ -494,10 +509,11 @@ Gura_DeclareMethod(pattern, get_extend)
 
 Gura_ImplementMethod(pattern, get_extend)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	cairo_extend_t extend = ::cairo_pattern_get_extend(pattern);
-	if (Is_error(sig, pattern)) return Value::Null;
+	if (Is_error(sig, pattern)) return Value::Nil;
 	return Value(extend);
 }
 
@@ -506,7 +522,7 @@ Gura_DeclareMethod(pattern, set_filter)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Reduce, FLAG_None);
 	DeclareArg(env, "filter", VTYPE_number);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Sets the filter to be used for resizing when using this pattern. See cairo_filter_t for details on each filter.\n"
 	"\n"
 	"* Note that you might want to control filtering even when you do not have an explicit cairo.pattern object,\n"
@@ -520,39 +536,41 @@ Gura_DeclareMethod(pattern, set_filter)
 
 Gura_ImplementMethod(pattern, set_filter)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
-	cairo_filter_t filter = static_cast<cairo_filter_t>(args.GetInt(0));
-	if (sig.IsSignalled()) return Value::Null;
+	cairo_filter_t filter = static_cast<cairo_filter_t>(arg.GetInt(0));
+	if (sig.IsSignalled()) return Value::Nil;
 	::cairo_pattern_set_filter(pattern, filter);
-	if (Is_error(sig, pattern)) return Value::Null;
-	return args.GetThis();
+	if (Is_error(sig, pattern)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // cairo.pattern#get_filter()
 Gura_DeclareMethod(pattern, get_filter)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Gets the current filter for a pattern. See cairo_filter_t for details on each filter.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_filter)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	cairo_filter_t filter = ::cairo_pattern_get_filter(pattern);
-	if (Is_error(sig, pattern)) return Value::Null;
+	if (Is_error(sig, pattern)) return Value::Nil;
 	return Value(pattern);
 }
 
-// cairo.pattern#set_matrix(matrix:matrix):reduce
+// cairo.pattern#set_matrix(array:array@double):reduce
 Gura_DeclareMethod(pattern, set_matrix)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Reduce, FLAG_None);
-	DeclareArg(env, "matrix", VTYPE_matrix);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	DeclareArg(env, "array", VTYPE_array_at_double);
+	AddHelp(Gura_Symbol(en),
 	"Sets the pattern's transformation matrix to matrix. This matrix is a transformation from user space to pattern space.\n"
 	"\n"
 	"When a pattern is first created it always has the identity matrix for its transformation matrix, which means that pattern space is initially identical to user space.\n"
@@ -574,51 +592,54 @@ Gura_DeclareMethod(pattern, set_matrix)
 
 Gura_ImplementMethod(pattern, set_matrix)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
-	Object_matrix *pObjMatrix = Object_matrix::GetObject(args, 0);
+	Object_arrayT<Double> *pObjArray = Object_arrayT<Double>::GetObject(arg, 0);
 	cairo_matrix_t matrix;
-	if (!MatrixToCairo(sig, matrix, pObjMatrix->GetMatrix())) return Value::Null;
+	if (!ArrayToCairo(sig, matrix, pObjArray->GetArrayT())) return Value::Nil;
 	::cairo_pattern_set_matrix(pattern, &matrix);
-	if (Is_error(sig, pattern)) return Value::Null;
-	return args.GetThis();
+	if (Is_error(sig, pattern)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // cairo.pattern#get_matrix()
 Gura_DeclareMethod(pattern, get_matrix)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"Stores the pattern's transformation matrix into matrix.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_matrix)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	cairo_matrix_t matrix;
 	::cairo_pattern_get_matrix(pattern, &matrix);
-	if (Is_error(sig, pattern)) return Value::Null;
-	AutoPtr<Matrix> pMat(CairoToMatrix(matrix));
-	return Value(new Object_matrix(env, pMat.release()));
+	if (Is_error(sig, pattern)) return Value::Nil;
+	AutoPtr<ArrayT<Double> > pArray(CairoToArray(matrix));
+	return Value(new Object_array(env, pArray.release()));
 }
 
 // cairo.pattern#get_type()
 Gura_DeclareMethod(pattern, get_type)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown,
+	AddHelp(Gura_Symbol(en),
 	"This function returns the type a pattern. See cairo_pattern_type_t for available types.\n"
 	);
 }
 
 Gura_ImplementMethod(pattern, get_type)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	cairo_pattern_t *pattern = pThis->GetEntity();
 	cairo_pattern_type_t rtn = ::cairo_pattern_get_type(pattern);
-	if (Is_error(sig, pattern)) return Value::Null;
+	if (Is_error(sig, pattern)) return Value::Nil;
 	return Value(rtn);
 }
 
@@ -655,8 +676,9 @@ Gura_ImplementUserClassWithCast(pattern)
 
 Gura_ImplementCastFrom(pattern)
 {
+	Signal &sig = GetSignal();
 	Value valueCast(value);
-	env.LookupClass(VTYPE_surface)->CastFrom(env, sig, valueCast, pDecl);
+	env.LookupClass(VTYPE_surface)->CastFrom(env, valueCast, flags);
 	if (valueCast.GetValueType() == VTYPE_surface) {
 		cairo_surface_t *surface = Object_surface::GetObject(valueCast)->GetEntity();
 		cairo_pattern_t *pattern = ::cairo_pattern_create_for_surface(surface);
