@@ -18,11 +18,6 @@ public:
 					Object(Gura_UserClass(rectangle_int)), _rectangle(rectangle) {}
 	virtual ~Object_rectangle_int();
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-								const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-								const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 	inline cairo_rectangle_int_t &GetEntity() { return _rectangle; }
 };
