@@ -18,9 +18,6 @@ public:
 					Object(Gura_UserClass(surface)), _surface(surface) {}
 	virtual ~Object_surface();
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 	inline cairo_surface_t *GetEntity() { return _surface; }
 };
