@@ -18,9 +18,6 @@ public:
 			Object(Gura_UserClass(text_extents)), _text_extents(text_extents) {}
 	virtual ~Object_text_extents();
 	virtual Object *Clone() const;
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-								const SymbolSet &attrs, bool &evaluatedFlag);
 	virtual String ToString(bool exprFlag);
 	inline cairo_text_extents_t &GetEntity() { return _text_extents; }
 };
