@@ -25,16 +25,17 @@ Gura_DeclareMethod(image, cairo)
 
 Gura_ImplementMethod(image, cairo)
 {
-	Object_image *pThis = Object_image::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_image *pThis = Object_image::GetObjectThis(arg);
 	Image *pImage = Image::Reference(pThis->GetImage());
 	cairo_surface_t *surface = CreateSurfaceFromImage(sig, pImage);
 	if (sig.IsSignalled()) {
 		Image::Delete(pImage);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Object_surface *pObjSurface = new Object_image_surface(surface, pImage);
 	cairo_t *cr = ::cairo_create(surface);
-	return ReturnValue(env, sig, args, Value(new Object_context(cr, pObjSurface)));
+	return ReturnValue(env, arg, Value(new Object_context(cr, pObjSurface)));
 }
 
 //-----------------------------------------------------------------------------
@@ -50,9 +51,9 @@ Gura_DeclareFunction(create)
 
 Gura_ImplementFunction(create)
 {
-	Object_surface *pObjSurface = Object_surface::GetObject(args, 0);
+	Object_surface *pObjSurface = Object_surface::GetObject(arg, 0);
 	cairo_t *cr = ::cairo_create(pObjSurface->GetEntity());
-	return ReturnValue(env, sig, args,
+	return ReturnValue(env, arg,
 		Value(new Object_context(cr, Object_surface::Reference(pObjSurface))));
 }
 
@@ -64,15 +65,15 @@ Gura_DeclareFunction(pdf_get_versions)
 
 Gura_ImplementFunction(pdf_get_versions)
 {
-	cairo_pdf_version_t const *versions = NULL;
+	cairo_pdf_version_t const *versions = nullptr;
 	int num_versions = 0;
 	::cairo_pdf_get_versions(&versions, &num_versions);
 	Value rtn;
-	ValueList &valList = rtn.InitAsList(env);
+	Object_list *pObjList = rtn.InitAsList(env);
 	if (num_versions > 0) {
-		valList.reserve(num_versions);
+		pObjList->Reserve(num_versions);
 		for (int i = 0; i < num_versions; i++) {
-			valList.push_back(Value(versions[i]));
+			pObjList->Add(Value(versions[i]));
 		}
 	}
 	return rtn;
@@ -88,15 +89,15 @@ Gura_DeclareFunction(ps_get_levels)
 
 Gura_ImplementFunction(ps_get_levels)
 {
-	cairo_ps_level_t const *levels = NULL;
+	cairo_ps_level_t const *levels = nullptr;
 	int num_levels = 0;
 	::cairo_ps_get_levels(&levels, &num_levels);
 	Value rtn;
-	ValueList &valList = rtn.InitAsList(env);
+	Object_list *pObjList = rtn.InitAsList(env);
 	if (num_levels > 0) {
-		valList.reserve(num_levels);
+		pObjList->Reserve(num_levels);
 		for (int i = 0; i < num_levels; i++) {
-			valList.push_back(Value(levels[i]));
+			pObjList->Add(Value(levels[i]));
 		}
 	}
 	return rtn;
@@ -111,9 +112,9 @@ Gura_DeclareFunction(ps_level_to_string)
 
 Gura_ImplementFunction(ps_level_to_string)
 {
-	cairo_ps_level_t level = static_cast<cairo_ps_level_t>(args.GetInt(0));
+	cairo_ps_level_t level = static_cast<cairo_ps_level_t>(arg.GetInt(0));
 	const char *rtn = ::cairo_ps_level_to_string(level);
-	if (rtn == NULL) return Value::Null;
+	if (rtn == nullptr) return Value::Nil;
 	return Value(rtn);
 }
 #endif
@@ -126,15 +127,15 @@ Gura_DeclareFunction(svg_get_versions)
 
 Gura_ImplementFunction(svg_get_versions)
 {
-	cairo_svg_version_t const *versions = NULL;
+	cairo_svg_version_t const *versions = nullptr;
 	int num_versions = 0;
 	::cairo_svg_get_versions(&versions, &num_versions);
 	Value rtn;
-	ValueList &valList = rtn.InitAsList(env);
+	Object_list *pObjList = rtn.InitAsList(env);
 	if (num_versions > 0) {
-		valList.reserve(num_versions);
+		pObjList->Reserve(num_versions);
 		for (int i = 0; i < num_versions; i++) {
-			valList.push_back(Value(versions[i]));
+			pObjList->Add(Value(versions[i]));
 		}
 	}
 	return rtn;
@@ -149,9 +150,9 @@ Gura_DeclareFunction(pdf_version_to_string)
 
 Gura_ImplementFunction(pdf_version_to_string)
 {
-	cairo_pdf_version_t version = static_cast<cairo_pdf_version_t>(args.GetInt(0));
+	cairo_pdf_version_t version = static_cast<cairo_pdf_version_t>(arg.GetInt(0));
 	const char *rtn = ::cairo_pdf_version_to_string(version);
-	if (rtn == NULL) return Value::Null;
+	if (rtn == nullptr) return Value::Nil;
 	return Value(rtn);
 }
 
@@ -164,9 +165,9 @@ Gura_DeclareFunction(svg_version_to_string)
 
 Gura_ImplementFunction(svg_version_to_string)
 {
-	cairo_svg_version_t version = static_cast<cairo_svg_version_t>(args.GetInt(0));
+	cairo_svg_version_t version = static_cast<cairo_svg_version_t>(arg.GetInt(0));
 	const char *rtn = ::cairo_svg_version_to_string(version);
-	if (rtn == NULL) return Value::Null;
+	if (rtn == nullptr) return Value::Nil;
 	return Value(rtn);
 }
 
@@ -179,9 +180,9 @@ Gura_DeclareFunction(status_to_string)
 
 Gura_ImplementFunction(status_to_string)
 {
-	cairo_status_t status = static_cast<cairo_status_t>(args.GetInt(0));
+	cairo_status_t status = static_cast<cairo_status_t>(arg.GetInt(0));
 	const char *rtn = ::cairo_status_to_string(status);
-	if (rtn == NULL) return Value::Null;
+	if (rtn == nullptr) return Value::Nil;
 	return Value(rtn);
 }
 
@@ -195,8 +196,8 @@ Gura_DeclareFunction(format_stride_for_width)
 
 Gura_ImplementFunction(format_stride_for_width)
 {
-	cairo_format_t format = static_cast<cairo_format_t>(args.GetInt(0));
-	int width = args.GetInt(1);
+	cairo_format_t format = static_cast<cairo_format_t>(arg.GetInt(0));
+	int width = arg.GetInt(1);
 	int rtn = ::cairo_format_stride_for_width(format, width);
 	return Value(rtn);
 }
@@ -210,7 +211,7 @@ Gura_DeclareFunction(debug_reset_static_data)
 Gura_ImplementFunction(debug_reset_static_data)
 {
 	::cairo_debug_reset_static_data();
-	return Value::Null;
+	return Value::Nil;
 }
 
 // cairo.test()
@@ -227,11 +228,11 @@ Gura_ImplementFunction(test)
 	DWORD cch = ArraySizeOf(printerName) - 1;
 	if (!::GetDefaultPrinter(printerName, &cch)) {
 		::printf("failed to get a default printer");
-		return Value::Null;
+		return Value::Nil;
 	}
-	if (!(hdc = ::CreateDC(NULL, printerName, NULL , NULL))) {
+	if (!(hdc = ::CreateDC(nullptr, printerName, nullptr , nullptr))) {
 		::printf("error in CreateDC()\n");
-		return Value::Null;
+		return Value::Nil;
 	}
 	DOCINFO diInfo;
 	::memset(&diInfo, 0x00, sizeof(diInfo));
@@ -246,10 +247,17 @@ Gura_ImplementFunction(test)
 	}
 	::DeleteDC(hdc);
 #endif
-	return Value::Null;
+	return Value::Nil;
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	// symbol realization
@@ -607,7 +615,7 @@ Writer_EnhMetaFile::~Writer_EnhMetaFile()
 
 Stream *Writer_EnhMetaFile::GetStream()
 {
-	return NULL;
+	return nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -621,65 +629,65 @@ Writer_WindowsDC::~Writer_WindowsDC()
 
 Stream *Writer_WindowsDC::GetStream()
 {
-	return NULL;
+	return nullptr;
 }
 #endif
 
 //-----------------------------------------------------------------------------
 // Error handling
 //-----------------------------------------------------------------------------
-bool IsInvalid(Signal sig, cairo_t *cr)
+bool IsInvalid(Signal &sig, cairo_t *cr)
 {
-	if (cr == NULL) {
+	if (cr == nullptr) {
 		sig.SetError(ERR_ValueError, "invalid context");
 		return true;
 	}
 	return false;
 }
 
-bool Is_error(Signal sig, cairo_status_t status)
+bool Is_error(Signal &sig, cairo_status_t status)
 {
 	if (status == CAIRO_STATUS_SUCCESS) return false;
 	sig.SetError(ERR_RuntimeError, "%s", ::cairo_status_to_string(status));
 	return true;
 }
 
-bool Is_error(Signal sig, cairo_t *cr)
+bool Is_error(Signal &sig, cairo_t *cr)
 {
 	return Is_error(sig, ::cairo_status(cr));
 }
 
-bool Is_error(Signal sig, cairo_pattern_t *pattern)
+bool Is_error(Signal &sig, cairo_pattern_t *pattern)
 {
 	return Is_error(sig, ::cairo_pattern_status(pattern));
 }
 
-bool Is_error(Signal sig, cairo_region_t *region)
+bool Is_error(Signal &sig, cairo_region_t *region)
 {
 	return Is_error(sig, ::cairo_region_status(region));
 }
 
-bool Is_error(Signal sig, cairo_font_face_t *font_face)
+bool Is_error(Signal &sig, cairo_font_face_t *font_face)
 {
 	return Is_error(sig, ::cairo_font_face_status(font_face));
 }
 
-bool Is_error(Signal sig, cairo_scaled_font_t *scaled_font)
+bool Is_error(Signal &sig, cairo_scaled_font_t *scaled_font)
 {
 	return Is_error(sig, ::cairo_scaled_font_status(scaled_font));
 }
 
-bool Is_error(Signal sig, cairo_device_t *device)
+bool Is_error(Signal &sig, cairo_device_t *device)
 {
 	return Is_error(sig, ::cairo_device_status(device));
 }
 
-bool Is_error(Signal sig, cairo_surface_t *surface)
+bool Is_error(Signal &sig, cairo_surface_t *surface)
 {
 	return Is_error(sig, ::cairo_surface_status(surface));
 }
 
-bool Is_error(Signal sig, cairo_font_options_t *options)
+bool Is_error(Signal &sig, cairo_font_options_t *options)
 {
 	return Is_error(sig, ::cairo_font_options_status(options));
 }
@@ -728,17 +736,17 @@ const char *SurfaceTypeToName(cairo_surface_type_t surface_type)
 Value RectangleToValue(Environment &env, const cairo_rectangle_t &rectangle)
 {
 	Value value;
-	ValueList &valList = value.InitAsList(env);
-	valList.reserve(4);
-	valList.push_back(Value(rectangle.x));
-	valList.push_back(Value(rectangle.y));
-	valList.push_back(Value(rectangle.width));
-	valList.push_back(Value(rectangle.height));
-	valList.push_back(value);
+	Object_list *pObjList = value.InitAsList(env);
+	pObjList->Reserve(5);
+	pObjList->Add(Value(rectangle.x));
+	pObjList->Add(Value(rectangle.y));
+	pObjList->Add(Value(rectangle.width));
+	pObjList->Add(Value(rectangle.height));
+	pObjList->Add(value);
 	return value;
 }
 
-bool ValueListToRectangle(Signal sig, cairo_rectangle_t &rectangle, const ValueList &valList)
+bool ValueListToRectangle(Signal &sig, cairo_rectangle_t &rectangle, const ValueList &valList)
 {
 	if (valList.size() != 4) {
 		sig.SetError(ERR_ValueError, "list must have four elements");
@@ -751,7 +759,7 @@ bool ValueListToRectangle(Signal sig, cairo_rectangle_t &rectangle, const ValueL
 	return true;
 }
 
-bool ValueListToRectangle(Signal sig, cairo_rectangle_int_t &rectangle, const ValueList &valList)
+bool ValueListToRectangle(Signal &sig, cairo_rectangle_int_t &rectangle, const ValueList &valList)
 {
 	if (valList.size() != 4) {
 		sig.SetError(ERR_ValueError, "list must have four elements");
@@ -764,66 +772,62 @@ bool ValueListToRectangle(Signal sig, cairo_rectangle_int_t &rectangle, const Va
 	return true;
 }
 
-Matrix *CairoToMatrix(const cairo_matrix_t &matrix)
+ArrayT<Double> *CairoToArray(const cairo_matrix_t &matrix)
 {
-	Matrix *pMat = new Matrix(3, 3);
-	pMat->GetList().push_back(Value(matrix.xx));
-	pMat->GetList().push_back(Value(matrix.xy));
-	pMat->GetList().push_back(Value(matrix.x0));
-	pMat->GetList().push_back(Value(matrix.yx));
-	pMat->GetList().push_back(Value(matrix.yy));
-	pMat->GetList().push_back(Value(matrix.y0));
-	pMat->GetList().push_back(Value(0.));
-	pMat->GetList().push_back(Value(0.));
-	pMat->GetList().push_back(Value(1.));
-	return pMat;
+	AutoPtr<ArrayT<Double> > pArrayT(new ArrayT<Double>(3, 3));
+	Double *pElem = pArrayT->GetPointer();
+	*pElem++ = matrix.xx;	*pElem++ = matrix.xy;	*pElem++ = matrix.x0;
+	*pElem++ = matrix.yx;	*pElem++ = matrix.yy;	*pElem++ = matrix.y0;
+	*pElem++ = 0;			*pElem++ = 0;			*pElem++ = 1;
+	return pArrayT.release();
 }
 
-bool MatrixToCairo(Signal sig, cairo_matrix_t &matrix, Matrix *pMat)
+bool ArrayToCairo(Signal &sig, cairo_matrix_t &matrix, const ArrayT<Double> *pArrayT)
 {
-	if (pMat->GetRows() != 3 || pMat->GetCols() != 3) {
+	if (pArrayT->GetElemNum() != 9) {
 		sig.SetError(ERR_ValueError, "matrix size must be 3x3");
 		return false;
 	}
-	matrix.xx = pMat->GetElement(0, 0).GetDouble();
-	matrix.xy = pMat->GetElement(0, 1).GetDouble();
-	matrix.yx = pMat->GetElement(1, 0).GetDouble();
-	matrix.yy = pMat->GetElement(1, 1).GetDouble();
-	matrix.x0 = pMat->GetElement(0, 2).GetDouble();
-	matrix.y0 = pMat->GetElement(1, 2).GetDouble();
+	const Double *pElem = pArrayT->GetPointer();
+	matrix.xx = *pElem++;
+	matrix.xy = *pElem++;
+	matrix.x0 = *pElem++;
+	matrix.yx = *pElem++;
+	matrix.yy = *pElem++;
+	matrix.y0 = *pElem++;
 	return true;
 }
 
 Value CreateValueList(Environment &env, double x1, double x2)
 {
 	Value result;
-	ValueList &valList = result.InitAsList(env);
-	valList.reserve(2);
-	valList.push_back(Value(x1));
-	valList.push_back(Value(x2));
+	Object_list *pObjList = result.InitAsList(env);
+	pObjList->Reserve(2);
+	pObjList->Add(Value(x1));
+	pObjList->Add(Value(x2));
 	return result;
 }
 
 Value CreateValueList(Environment &env, double x1, double x2, double x3)
 {
 	Value result;
-	ValueList &valList = result.InitAsList(env);
-	valList.reserve(3);
-	valList.push_back(Value(x1));
-	valList.push_back(Value(x2));
-	valList.push_back(Value(x3));
+	Object_list *pObjList = result.InitAsList(env);
+	pObjList->Reserve(3);
+	pObjList->Add(Value(x1));
+	pObjList->Add(Value(x2));
+	pObjList->Add(Value(x3));
 	return result;
 }
 
 Value CreateValueList(Environment &env, double x1, double x2, double x3, double x4)
 {
 	Value result;
-	ValueList &valList = result.InitAsList(env);
-	valList.reserve(4);
-	valList.push_back(Value(x1));
-	valList.push_back(Value(x2));
-	valList.push_back(Value(x3));
-	valList.push_back(Value(x4));
+	Object_list *pObjList = result.InitAsList(env);
+	pObjList->Reserve(4);
+	pObjList->Add(Value(x1));
+	pObjList->Add(Value(x2));
+	pObjList->Add(Value(x3));
+	pObjList->Add(Value(x4));
 	return result;
 }
 
@@ -831,13 +835,13 @@ Value CreateValueList(Environment &env,
 				double x1, double x2, double x3, double x4, double x5)
 {
 	Value result;
-	ValueList &valList = result.InitAsList(env);
-	valList.reserve(5);
-	valList.push_back(Value(x1));
-	valList.push_back(Value(x2));
-	valList.push_back(Value(x3));
-	valList.push_back(Value(x4));
-	valList.push_back(Value(x5));
+	Object_list *pObjList = result.InitAsList(env);
+	pObjList->Reserve(5);
+	pObjList->Add(Value(x1));
+	pObjList->Add(Value(x2));
+	pObjList->Add(Value(x3));
+	pObjList->Add(Value(x4));
+	pObjList->Add(Value(x5));
 	return result;
 }
 
@@ -845,23 +849,23 @@ Value CreateValueList(Environment &env,
 				double x1, double x2, double x3, double x4, double x5, double x6)
 {
 	Value result;
-	ValueList &valList = result.InitAsList(env);
-	valList.reserve(6);
-	valList.push_back(Value(x1));
-	valList.push_back(Value(x2));
-	valList.push_back(Value(x3));
-	valList.push_back(Value(x4));
-	valList.push_back(Value(x5));
-	valList.push_back(Value(x6));
+	Object_list *pObjList = result.InitAsList(env);
+	pObjList->Reserve(6);
+	pObjList->Add(Value(x1));
+	pObjList->Add(Value(x2));
+	pObjList->Add(Value(x3));
+	pObjList->Add(Value(x4));
+	pObjList->Add(Value(x5));
+	pObjList->Add(Value(x6));
 	return result;
 }
 
-cairo_surface_t *CreateSurfaceFromImage(Signal sig, Image *pImage)
+cairo_surface_t *CreateSurfaceFromImage(Signal &sig, Image *pImage)
 {
-	if (!pImage->CheckValid(sig)) return NULL;
+	if (!pImage->CheckValid(sig)) return nullptr;
 	if (pImage->GetFormat() != Image::FORMAT_RGBA) {
 		sig.SetError(ERR_FormatError, "cairo can only be applied to image in `rgba format");
-		return NULL;
+		return nullptr;
 	}
 	size_t width = pImage->GetWidth();
 	size_t height = pImage->GetHeight();
