@@ -13,27 +13,32 @@ Gura_DeclareFunction(dir)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns a list of registered encoding names.");
 }
 
 Gura_ImplementFunction(dir)
 {
 	Value rtn;
-	ValueList &valList = rtn.InitAsList(env);
+	Object_list *pObjList = rtn.InitAsList(env);
 	const CodecFactory::List *pList = CodecFactory::GetList();
-	if (pList != NULL) {
+	if (pList != nullptr) {
 		foreach_const (CodecFactory::List, ppFactory, *pList) {
 			CodecFactory *pFactory = *ppFactory;
-			valList.push_back(Value(pFactory->GetEncoding()));
+			pObjList->Add(Value(pFactory->GetEncoding()));
 		}
 	}
 	return rtn;
 }
 
 //-----------------------------------------------------------------------------
-// Module entry
+// Module Entries
 //-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	// function assignment
