@@ -19,9 +19,13 @@ UShort Codec_CP949::Encoder::UTF16ToDBCS(UShort codeUTF16)
 }
 
 //-----------------------------------------------------------------------------
-// Gura module functions: korean
+// Module Entries
 //-----------------------------------------------------------------------------
-// Module entry
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	CodecFactory::Register(new CodecFactoryTmpl<Codec_CP949>("cp949"));
