@@ -3,6 +3,18 @@
 //=============================================================================
 #include "stdafx.h"
 
+#undef black
+#undef blue
+#undef green
+#undef aqua
+#undef cyan
+#undef red
+#undef purple
+#undef magenta
+#undef yellow
+#undef white
+#undef gray
+
 #define Gura_AssignValueOf(v) Gura_AssignValue(v, v)
 
 Gura_BeginModuleBody(conio)
@@ -52,7 +64,15 @@ enum {
 	K_DELETE,
 };
 
-bool SymbolToNumber(Signal sig, const Symbol *pSymbol, int *pNum);
+void Clear(Environment &env, const Symbol *pSymbol);
+void GetWinSize(Environment &env, size_t *pWidth, size_t *pHeight);
+void SetColor(Environment &env, const Symbol *pSymbolFg,
+			  const Symbol *pSymbolBg, const Expr_Block *pExprBlock);
+void MoveTo(Environment &env, int x, int y, const Expr_Block *pExprBlock);
+bool CheckKey();
+int WaitKey(Environment &env, bool raiseFlag);
+
+bool SymbolToNumber(Signal &sig, const Symbol *pSymbol, int *pNum);
 
 //-----------------------------------------------------------------------------
 // Gura module functions: conio
@@ -63,7 +83,7 @@ Gura_DeclareFunction(clear)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "region", VTYPE_symbol, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Clears the screen.\n"
 		"\n"
 		"In default, it clears whole the screen.\n"
@@ -77,15 +97,29 @@ Gura_DeclareFunction(clear)
 		"- `` `bottom`` .. clears characters on the below side of the cursor.\n");
 }
 
+Gura_ImplementFunction(clear)
+{
+	Clear(env, arg.Is_symbol(0)? arg.GetSymbol(0) : nullptr);
+	return Value::Nil;
+}
+
 // conio.getwinsize()
 Gura_DeclareFunction(getwinsize)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns the screen size as a list `[width, height]`.");
 }
 
+Gura_ImplementFunction(getwinsize)
+{
+	size_t width, height;
+	GetWinSize(env, &width, &height);
+	return ReturnValue(env, arg,
+		Value::CreateList(env, Value(width), Value(height)));
+}
+
 // conio.setcolor(fg:symbol:nil, bg?:symbol):map:void {block?}
 Gura_DeclareFunction(setcolor)
 {
@@ -94,7 +128,7 @@ Gura_DeclareFunction(setcolor)
 	DeclareArg(env, "bg", VTYPE_symbol, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Sets foreground and background color of text by specifying a color symbol.\n"
 		"Available color symbols are listed below:\n"
 		"\n"
@@ -126,6 +160,16 @@ Gura_DeclareFunction(setcolor)
 		"and then gets back to what has been set when done.\n");
 }
 
+Gura_ImplementFunction(setcolor)
+{
+	Signal &sig = env.GetSignal();
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (sig.IsSignalled()) return Value::Nil;
+	SetColor(env, arg.Is_symbol(0)? arg.GetSymbol(0) : nullptr,
+			 arg.Is_symbol(1)? arg.GetSymbol(1) : nullptr, pExprBlock);
+	return Value::Nil;
+}
+
 // conio.moveto(x:number, y:number):map:void {block?}
 Gura_DeclareFunction(moveto)
 {
@@ -134,7 +178,7 @@ Gura_DeclareFunction(moveto)
 	DeclareArg(env, "y", VTYPE_number);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Moves cursor to the specified position.\n"
 		"The most top-left position on the screen is represented as `0, 0`.\n"
 		"\n"
@@ -142,13 +186,21 @@ Gura_DeclareFunction(moveto)
 		"and then gets back to where it has been when done.\n");
 }
 
+Gura_ImplementFunction(moveto)
+{
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (env.IsSignalled()) return Value::Nil;
+	MoveTo(env, arg.GetInt(0), arg.GetInt(1), pExprBlock);
+	return Value::Nil;
+}
+
 // conio.waitkey():[raise]
 Gura_DeclareFunction(waitkey)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareAttr(Gura_Symbol(raise));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Waits for a keyboard input and returns a character code number associated with the key.\n"
 		"\n"
 		"If `:raise` attribute is specified, hitting `Ctrl-C` issues a terminating signal\n"
@@ -173,17 +225,65 @@ Gura_DeclareFunction(waitkey)
 		"- `conio.K_DELETE`\n");
 }
 
-#if defined(GURA_ON_MSWIN)
-Gura_ImplementFunction(clear)
+Gura_ImplementFunction(waitkey)
 {
+	int chRtn = WaitKey(env, arg.IsSet(Gura_Symbol(raise)));
+	if (env.IsSignalled()) return Value::Nil;
+	return Value(chRtn);
+}
+
+// conio.readkey():[raise]
+Gura_DeclareFunction(readkey)
+{
+	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
+	DeclareAttr(Gura_Symbol(raise));
+	AddHelp(
+		Gura_Symbol(en),
+		"Reads a keyboard input and returns a character code number associated with the key\n"
+		"without blocking."
+		"\n"
+		"If `:raise` attribute is specified, hitting `Ctrl-C` issues a terminating signal\n"
+		"that causes the program done.\n"
+		"\n"
+		"Character code numbers of some of the special keys are defined as below:\n"
+		"\n"
+		"- `conio.K_BACKSPACE`\n"
+		"- `conio.K_TAB`\n"
+		"- `conio.K_RETURN`\n"
+		"- `conio.K_ESCAPE`\n"
+		"- `conio.K_SPACE`\n"
+		"- `conio.K_UP`\n"
+		"- `conio.K_DOWN`\n"
+		"- `conio.K_RIGHT`\n"
+		"- `conio.K_LEFT`\n"
+		"- `conio.K_INSERT`\n"
+		"- `conio.K_HOME`\n"
+		"- `conio.K_END`\n"
+		"- `conio.K_PAGEUP`\n"
+		"- `conio.K_PAGEDOWN`\n"
+		"- `conio.K_DELETE`\n");
+}
+
+Gura_ImplementFunction(readkey)
+{
+	if (!CheckKey()) return Value::Nil;
+	int chRtn = WaitKey(env, arg.IsSet(Gura_Symbol(raise)));
+	if (env.IsSignalled()) return Value::Nil;
+	return Value(chRtn);
+}
+
+#if defined(GURA_ON_MSWIN)
+void Clear(Environment &env, const Symbol *pSymbol)
+{
+	Signal &sig = env.GetSignal();
 	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
 	CONSOLE_SCREEN_BUFFER_INFO csbi;
 	::GetConsoleScreenBufferInfo(hConsole, &csbi);
-	const Symbol *pSymbol = args.Is_symbol(0)? args.GetSymbol(0) : NULL;
+	//const Symbol *pSymbol = arg.Is_symbol(0)? arg.GetSymbol(0) : nullptr;
 	COORD coordStart = { 0, 0 };
 	COORD coordHome = { 0, 0 };
 	DWORD dwConSize = 0;
-	if (pSymbol == NULL) {
+	if (pSymbol == nullptr) {
 		dwConSize = csbi.dwSize.X * csbi.dwSize.Y;
 	} else if (pSymbol == Gura_Symbol(line_)) {
 		int width = csbi.dwSize.X;
@@ -214,7 +314,7 @@ Gura_ImplementFunction(clear)
 		dwConSize = width;
 	} else {
 		sig.SetError(ERR_ValueError, "invalid symbol %s", pSymbol->GetName());
-		return Value::Null;
+		return;
 	}
 	do {
 		DWORD cCharsWritten;
@@ -224,66 +324,61 @@ Gura_ImplementFunction(clear)
 							dwConSize, coordStart, &cCharsWritten );
 		::SetConsoleCursorPosition(hConsole, coordHome);
 	} while (0);
-	return Value::Null;
 }
 
-Gura_ImplementFunction(getwinsize)
+void GetWinSize(Environment &env, size_t *pWidth, size_t *pHeight)
 {
 	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
 	CONSOLE_SCREEN_BUFFER_INFO csbi;
 	::GetConsoleScreenBufferInfo(hConsole, &csbi);
-	return ReturnValue(env, sig, args,
-		Value::CreateList(env,
-				Value(csbi.srWindow.Right + 1 - csbi.srWindow.Left),
-				Value(csbi.srWindow.Bottom + 1 - csbi.srWindow.Top)));
+	*pWidth = csbi.srWindow.Right + 1 - csbi.srWindow.Left;
+	*pHeight = csbi.srWindow.Bottom + 1 - csbi.srWindow.Top;
 }
 
-Gura_ImplementFunction(setcolor)
+void SetColor(Environment &env, const Symbol *pSymbolFg,
+			  const Symbol *pSymbolBg, const Expr_Block *pExprBlock)
 {
+	Signal &sig = env.GetSignal();
 	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
 	CONSOLE_SCREEN_BUFFER_INFO csbi;
 	::GetConsoleScreenBufferInfo(hConsole, &csbi);
 	int fg = csbi.wAttributes & 0x000f;
 	int bg = (csbi.wAttributes & 0x00f0) >> 4;
-	if (args.Is_symbol(0) && !SymbolToNumber(sig, args.GetSymbol(0), &fg)) {
-		return Value::Null;
+	if (pSymbolFg != nullptr && !SymbolToNumber(sig, pSymbolFg, &fg)) {
+		return;
 	}
-	if (args.Is_symbol(1) && !SymbolToNumber(sig, args.GetSymbol(1), &bg)) {
-		return Value::Null;
+	if (pSymbolBg != nullptr && !SymbolToNumber(sig, pSymbolBg, &bg)) {
+		return;
 	}
 	::SetConsoleTextAttribute(hConsole, fg + (bg << 4));
-	if (args.IsBlockSpecified()) {
-		SeqPostHandler *pSeqPostHandler = NULL;
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
-		pExprBlock->Exec2(env, sig, pSeqPostHandler);
+	if (pExprBlock != nullptr) {
+		pExprBlock->Exec(env);
 		::SetConsoleTextAttribute(hConsole, csbi.wAttributes);
 	}
-	return Value::Null;
 }
 
-Gura_ImplementFunction(moveto)
+void MoveTo(Environment &env, int x, int y, const Expr_Block *pExprBlock)
 {
 	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
 	CONSOLE_SCREEN_BUFFER_INFO csbi;
 	::GetConsoleScreenBufferInfo(hConsole, &csbi);
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
 	COORD pos = { x, y };
 	::SetConsoleCursorPosition(hConsole, pos);
-	if (args.IsBlockSpecified()) {
-		SeqPostHandler *pSeqPostHandler = NULL;
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
-		pExprBlock->Exec2(env, sig, pSeqPostHandler);
+	if (pExprBlock != nullptr) {
+		pExprBlock->Exec(env);
 		::SetConsoleCursorPosition(hConsole, csbi.dwCursorPosition);
 	}
-	return Value::Null;
 }
 
-Gura_ImplementFunction(waitkey)
+bool CheckKey()
 {
-	bool raiseFlag = args.IsSet(Gura_Symbol(raise));
+	return ::_kbhit() != 0;
+}
+
+int WaitKey(Environment &env, bool raiseFlag)
+{
+	Signal &sig = env.GetSignal();
+	//bool raiseFlag = arg.IsSet(Gura_Symbol(raise));
 	int chRtn = 0;
 	enum {
 		STAT_None, STAT_Special,
@@ -298,8 +393,8 @@ Gura_ImplementFunction(waitkey)
 				chRtn = K_RETURN;
 				break;
 			} else if (raiseFlag && ch == 0x03) {
-				sig.SetSignal(SIGTYPE_Terminate, Value::Null);
-				return Value::Null;
+				sig.SetSignal(SIGTYPE_Terminate, Value::Nil);
+				return 0;
 			} else {
 				chRtn = ch;
 				break;
@@ -341,15 +436,15 @@ Gura_ImplementFunction(waitkey)
 			}
 		}
 	}
-	return Value(chRtn);
+	return chRtn;
 }
 
 #elif defined(GURA_ON_LINUX) || defined(GURA_ON_DARWIN)
-
-Gura_ImplementFunction(clear)
+void Clear(Environment &env, const Symbol *pSymbol)
 {
-	const Symbol *pSymbol = args.Is_symbol(0)? args.GetSymbol(0) : NULL;
-	if (pSymbol == NULL) {
+	Signal &sig = env.GetSignal();
+	//const Symbol *pSymbol = arg.Is_symbol(0)? arg.GetSymbol(0) : nullptr;
+	if (pSymbol == nullptr) {
 		::printf("\033[2J");
 		::printf("\033[H");
 	} else if (pSymbol == Gura_Symbol(line_)) {
@@ -365,29 +460,28 @@ Gura_ImplementFunction(clear)
 		::printf("\033[K");
 	} else {
 		sig.SetError(ERR_ValueError, "invalid symbol %s", pSymbol->GetName());
-		return Value::Null;
 	}
-	return Value::Null;
 }
 
-Gura_ImplementFunction(getwinsize)
+void GetWinSize(Environment &env, size_t *pWidth, size_t *pHeight)
 {
 	struct winsize ws;
 	::ioctl(STDOUT_FILENO, TIOCGWINSZ, &ws);
-	return ReturnValue(env, sig, args,
-		Value::CreateList(env, Value(ws.ws_col), Value(ws.ws_row)));
+	*pWidth = ws.ws_col, *pHeight = ws.ws_row;
 }
 
 StringList g_attrStack;
 
-Gura_ImplementFunction(setcolor)
+void SetColor(Environment &env, const Symbol *pSymbolFg,
+			  const Symbol *pSymbolBg, const Expr_Block *pExprBlock)
 {
+	Signal &sig = env.GetSignal();
 	int fg = 0, bg = 0;
 	String str;
-	if (!args.Is_symbol(0)) {
+	if (pSymbolFg == nullptr) {
 		// nothing to do
-	} else if (!SymbolToNumber(sig, args.GetSymbol(0), &fg)) {
-		return Value::Null;
+	} else if (!SymbolToNumber(sig, pSymbolFg, &fg)) {
+		return;
 	} else {
 		if (fg & 8) {
 			str += "1;";
@@ -397,10 +491,10 @@ Gura_ImplementFunction(setcolor)
 		str += '3';
 		str += ('0' + (fg & 7));
 	}
-	if (!args.Is_symbol(1)) {
+	if (pSymbolBg == nullptr) {
 		// nothing to do
-	} else if (!SymbolToNumber(sig, args.GetSymbol(1), &bg)) {
-		return Value::Null;
+	} else if (!SymbolToNumber(sig, pSymbolBg, &bg)) {
+		return;
 	} else {
 		if (!str.empty()) str += ';';
 		str += '4';
@@ -409,12 +503,9 @@ Gura_ImplementFunction(setcolor)
 	if (!str.empty()) {
 		::printf("\033[%sm", str.c_str());
 	}
-	if (args.IsBlockSpecified()) {
-		SeqPostHandler *pSeqPostHandler = NULL;
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
+	if (pExprBlock != nullptr) {
 		g_attrStack.push_back(str);
-		pExprBlock->Exec2(env, sig, pSeqPostHandler);
+		pExprBlock->Exec(env);
 		if (!g_attrStack.empty()) g_attrStack.pop_back();
 		if (g_attrStack.empty()) {
 			::printf("\033[0m");
@@ -425,30 +516,34 @@ Gura_ImplementFunction(setcolor)
 		if (!g_attrStack.empty()) g_attrStack.pop_back();
 		g_attrStack.push_back(str);
 	}
-	return Value::Null;
 }
 
-Gura_ImplementFunction(moveto)
+void MoveTo(Environment &env, int x, int y, const Expr_Block *pExprBlock)
 {
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
-	if (args.IsBlockSpecified()) {
-		SeqPostHandler *pSeqPostHandler = NULL;
+	//Signal &sig = env.GetSignal();
+	if (pExprBlock == nullptr) {
+		::printf("\033[%d;%dH", y + 1, x + 1);
+	} else {
 		::printf("\033[s");
 		::printf("\033[%d;%dH", y + 1, x + 1);
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
-		pExprBlock->Exec2(env, sig, pSeqPostHandler);
+		pExprBlock->Exec(env);
 		::printf("\033[u");
-	} else {
-		::printf("\033[%d;%dH", y + 1, x + 1);
 	}
-	return Value::Null;
 }
 
-Gura_ImplementFunction(waitkey)
+bool CheckKey()
 {
-	bool raiseFlag = args.IsSet(Gura_Symbol(raise));
+	struct timeval tv = { 0L, 0L };
+	fd_set fds;
+	FD_ZERO(&fds);
+	FD_SET(0, &fds);
+	return ::select(1, &fds, NULL, NULL, &tv) > 0;
+}
+
+int WaitKey(Environment &env, bool raiseFlag)
+{
+	Signal &sig = env.GetSignal();
+	//bool raiseFlag = arg.IsSet(Gura_Symbol(raise));
 	struct termios termios_org, termios_new;
 	::tcgetattr(STDIN_FILENO, &termios_org);
 	termios_new = termios_org;
@@ -470,9 +565,9 @@ Gura_ImplementFunction(waitkey)
 				chRtn = K_BACKSPACE;
 				break;
 			} else if (raiseFlag && ch == 0x03) {
-				sig.SetSignal(SIGTYPE_Terminate, Value::Null);
+				sig.SetSignal(SIGTYPE_Terminate, Value::Nil);
 				::tcsetattr(STDIN_FILENO, TCSANOW, &termios_org);
-				return Value::Null;
+				return 0;
 			} else {
 				chRtn = ch;
 				break;
@@ -537,7 +632,7 @@ Gura_ImplementFunction(waitkey)
 		}
 	}
 	::tcsetattr(STDIN_FILENO, TCSANOW, &termios_org);
-	return Value(chRtn);
+	return chRtn;
 }
 
 #else
@@ -545,8 +640,13 @@ Gura_ImplementFunction(waitkey)
 #endif
 
 //-----------------------------------------------------------------------------
-// Module entry
+// Module Entries
 //-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	// function assignment
@@ -555,6 +655,7 @@ Gura_ModuleEntry()
 	Gura_AssignFunction(setcolor);
 	Gura_AssignFunction(moveto);
 	Gura_AssignFunction(waitkey);
+	Gura_AssignFunction(readkey);
 	// value assignment
 	Gura_AssignValueOf(K_CTRL_A);
 	Gura_AssignValueOf(K_CTRL_B);
@@ -607,7 +708,7 @@ Gura_ModuleTerminate()
 //-----------------------------------------------------------------------------
 // utility function
 //-----------------------------------------------------------------------------
-bool SymbolToNumber(Signal sig, const Symbol *pSymbol, int *pNum)
+bool SymbolToNumber(Signal &sig, const Symbol *pSymbol, int *pNum)
 {
 #if defined(GURA_ON_MSWIN)
 	int num =
