@@ -26,7 +26,7 @@ Gura_BeginModuleBody(curl)
 //-----------------------------------------------------------------------------
 // utility functions
 //-----------------------------------------------------------------------------
-void SetError_Curl(Signal sig, CURLcode code)
+void SetError_Curl(Signal &sig, CURLcode code)
 {
 	sig.SetError(ERR_RuntimeError, "%s", ::curl_easy_strerror(code));
 }
@@ -66,7 +66,7 @@ void FileinfoOwner::Clear()
 //-----------------------------------------------------------------------------
 // Browser
 //-----------------------------------------------------------------------------
-Browser::Browser(Signal sig, FileinfoOwner &fileinfoOwner) :
+Browser::Browser(Signal &sig, FileinfoOwner &fileinfoOwner) :
 									_sig(sig), _fileinfoOwner(fileinfoOwner)
 {
 }
@@ -98,7 +98,7 @@ long Browser::OnChunkEndStub(struct callback_data *data)
 //-----------------------------------------------------------------------------
 // Writer
 //-----------------------------------------------------------------------------
-Writer::Writer(Signal sig, Stream *pStream) : _sig(sig), _pStream(pStream)
+Writer::Writer(Signal &sig, Stream *pStream) : _sig(sig), _pStream(pStream)
 {
 }
 
@@ -117,7 +117,7 @@ size_t Writer::OnWriteStub(char *buffer, size_t size, size_t nitems, void *outst
 //-----------------------------------------------------------------------------
 // Reader
 //-----------------------------------------------------------------------------
-Reader::Reader(Signal sig, Stream *pStream) : _sig(sig), _pStream(pStream)
+Reader::Reader(Signal &sig, Stream *pStream) : _sig(sig), _pStream(pStream)
 {
 }
 
@@ -157,14 +157,14 @@ Gura_DeclareFunction(version)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns a string of the libcurl version.");
 }
 
 Gura_ImplementFunction(version)
 {
 	const char *rtn = ::curl_version();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 // curl.easy_init() {block?}
@@ -173,14 +173,14 @@ Gura_DeclareFunction(easy_init)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Initializes cURL and returns a easy_handle object.");
 }
 
 Gura_ImplementFunction(easy_init)
 {
 	CURL *curl = ::curl_easy_init();
-	return ReturnValue(env, sig, args, Value(new Object_easy_handle(curl)));
+	return ReturnValue(env, arg, Value(new Object_easy_handle(curl)));
 }
 
 // curl.test()
@@ -188,19 +188,20 @@ Gura_DeclareFunction(test)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementFunction(test)
 {
+	Signal &sig = env.GetSignal();
 	CURLcode code;
 	CURL *curl = ::curl_easy_init();
-	if (curl == NULL) return Value::Null;
+	if (curl == nullptr) return Value::Nil;
 	::curl_easy_setopt(curl, CURLOPT_URL, "ftp://ftp.debian.org/debian/*");
 	::curl_easy_setopt(curl, CURLOPT_WILDCARDMATCH, 1L);
-	std::auto_ptr<FileinfoOwner> pFileinfoOwner(new FileinfoOwner());
-	std::auto_ptr<Browser> pBrowser(new Browser(sig, *pFileinfoOwner));
+	std::unique_ptr<FileinfoOwner> pFileinfoOwner(new FileinfoOwner());
+	std::unique_ptr<Browser> pBrowser(new Browser(sig, *pFileinfoOwner));
 	::curl_easy_setopt(curl, CURLOPT_CHUNK_DATA, pBrowser.get());
 	::curl_easy_setopt(curl, CURLOPT_CHUNK_BGN_FUNCTION, Browser::OnChunkBgnStub);
 	::curl_easy_setopt(curl, CURLOPT_CHUNK_END_FUNCTION, Browser::OnChunkEndStub);
@@ -220,12 +221,17 @@ Gura_ImplementFunction(test)
 	}
 	::curl_easy_cleanup(curl);
 	::curl_global_cleanup();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //-----------------------------------------------------------------------------
-// Module entry
+// Module Entries
 //-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	// class realization
@@ -709,14 +715,15 @@ Directory_cURL::~Directory_cURL()
 {
 }
 
-Directory *Directory_cURL::DoNext(Environment &env, Signal sig)
+Directory *Directory_cURL::DoNext(Environment &env)
 {
-	if (_pFileinfoOwner.get() == NULL) {
-		_pFileinfoOwner.reset(DoBrowse(sig));
-		if (sig.IsSignalled()) return NULL;
+	Signal &sig = env.GetSignal();
+	if (_pFileinfoOwner.get() == nullptr) {
+		_pFileinfoOwner.reset(DoBrowse(env));
+		if (sig.IsSignalled()) return nullptr;
 		_ppFileinfo = _pFileinfoOwner->begin();
 	}
-	if (_ppFileinfo == _pFileinfoOwner->end()) return NULL;
+	if (_ppFileinfo == _pFileinfoOwner->end()) return nullptr;
 	Fileinfo *pFileinfo = *_ppFileinfo++;
 	Type type = (pFileinfo->GetFiletype() == CURLFILETYPE_DIRECTORY)?
 												TYPE_Container : TYPE_Item;
@@ -724,9 +731,10 @@ Directory *Directory_cURL::DoNext(Environment &env, Signal sig)
 										pFileinfo->GetFilename(), type);
 }
 
-Stream *Directory_cURL::DoOpenStream(Environment &env, Signal sig, ULong attr)
+Stream *Directory_cURL::DoOpenStream(Environment &env, ULong attr)
 {
-	AutoPtr<StreamFIFO> pStream(new StreamFIFO(env, sig, 65536));
+	Signal &sig = env.GetSignal();
+	AutoPtr<StreamFIFO> pStream(new StreamFIFO(env, 65536));
 	// pThread will automatically be deleted after the thread is done.
 	Thread *pThread = new Thread(sig, GetName(),
 				dynamic_cast<StreamFIFO *>(Stream::Reference(pStream.get())));
@@ -734,15 +742,16 @@ Stream *Directory_cURL::DoOpenStream(Environment &env, Signal sig, ULong attr)
 	return pStream.release();
 }
 
-FileinfoOwner *Directory_cURL::DoBrowse(Signal sig)
+FileinfoOwner *Directory_cURL::DoBrowse(Environment &env)
 {
-	std::auto_ptr<FileinfoOwner> pFileinfoOwner(new FileinfoOwner());
+	Signal &sig = env.GetSignal();
+	std::unique_ptr<FileinfoOwner> pFileinfoOwner(new FileinfoOwner());
 	CURL *curl = ::curl_easy_init();
-	if (curl == NULL) return NULL;
-	String url = OAL::JoinPathName('/', MakePathName(false, NULL).c_str(), "*");
+	if (curl == nullptr) return nullptr;
+	String url = OAL::JoinPathName('/', MakePathName(false, nullptr).c_str(), "*");
 	::curl_easy_setopt(curl, CURLOPT_URL, url.c_str());
 	::curl_easy_setopt(curl, CURLOPT_WILDCARDMATCH, 1L);
-	std::auto_ptr<Browser> pBrowser(new Browser(sig, *pFileinfoOwner));
+	std::unique_ptr<Browser> pBrowser(new Browser(sig, *pFileinfoOwner));
 	::curl_easy_setopt(curl, CURLOPT_CHUNK_DATA, pBrowser.get());
 	::curl_easy_setopt(curl, CURLOPT_CHUNK_BGN_FUNCTION, Browser::OnChunkBgnStub);
 	::curl_easy_setopt(curl, CURLOPT_CHUNK_END_FUNCTION, Browser::OnChunkEndStub);
@@ -751,7 +760,7 @@ FileinfoOwner *Directory_cURL::DoBrowse(Signal sig)
 		SetError_Curl(sig, code);
 		::curl_easy_cleanup(curl);
 		::curl_global_cleanup();
-		return NULL;
+		return nullptr;
 	}
 	::curl_easy_cleanup(curl);
 	::curl_global_cleanup();
@@ -761,10 +770,10 @@ FileinfoOwner *Directory_cURL::DoBrowse(Signal sig)
 void Directory_cURL::Thread::Run()
 {
 	CURL *curl = ::curl_easy_init();
-	if (curl == NULL) return;
+	if (curl == nullptr) return;
 	::curl_easy_setopt(curl, CURLOPT_URL, _name.c_str());
 	::curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
-	std::auto_ptr<Writer> pWriter(new Writer(_sig, Stream::Reference(_pStreamFIFO.get())));
+	std::unique_ptr<Writer> pWriter(new Writer(_sig, Stream::Reference(_pStreamFIFO.get())));
 	::curl_easy_setopt(curl, CURLOPT_WRITEDATA, pWriter.get());
 	::curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, Writer::OnWriteStub);
 	CURLcode code = ::curl_easy_perform(curl);
@@ -776,10 +785,10 @@ void Directory_cURL::Thread::Run()
 //-----------------------------------------------------------------------------
 // PathMgr_cURL implementation
 //-----------------------------------------------------------------------------
-bool PathMgr_cURL::IsResponsible(Environment &env, Signal sig,
+bool PathMgr_cURL::IsResponsible(Environment &env,
 						const Directory *pParent, const char *pathName)
 {
-	return pParent == NULL && (
+	return pParent == nullptr && (
 			StartsWith(pathName, "http:", 0, false) ||
 			StartsWith(pathName, "https:", 0, false) ||
 			StartsWith(pathName, "ftp:", 0, false) ||
@@ -787,7 +796,7 @@ bool PathMgr_cURL::IsResponsible(Environment &env, Signal sig,
 			StartsWith(pathName, "sftp:", 0, false));
 }
 
-Directory *PathMgr_cURL::DoOpenDirectory(Environment &env, Signal sig,
+Directory *PathMgr_cURL::DoOpenDirectory(Environment &env,
 		Directory *pParent, const char **pPathName, NotFoundMode notFoundMode)
 {
 	const char *uri = *pPathName;
@@ -805,47 +814,46 @@ Directory *PathMgr_cURL::DoOpenDirectory(Environment &env, Signal sig,
 //-----------------------------------------------------------------------------
 Object_easy_handle::~Object_easy_handle()
 {
-	if (_curl != NULL) {
+	if (_curl != nullptr) {
 		//::curl_easy_cleanup(_curl);
 	}
 }
 
 Object *Object_easy_handle::Clone() const
 {
-	return NULL;
-}
-
-bool Object_easy_handle::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	//symbols.insert(Gura_UserSymbol(surface));
-	//symbols.insert(Gura_UserSymbol(width));
-	//symbols.insert(Gura_UserSymbol(height));
-	return true;
-}
-
-Value Object_easy_handle::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	//evaluatedFlag = true;
-	//if (pSymbol->IsIdentical(Gura_UserSymbol(surface))) {
-	//	return Value(Object_surface::Reference(_pObjSurface.get()));
-	//}
-	evaluatedFlag = false;
-	return Value::Null;
+	return nullptr;
 }
 
 String Object_easy_handle::ToString(bool exprFlag)
 {
 	String str;
 	str += "<curl.easy_handle:";
-	if (_curl == NULL) {
+	if (_curl == nullptr) {
 		str += "invalid";
 	}
 	str += ">";
 	return str;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// curl.easy_handle#surface
+Gura_DeclareProperty_R(easy_handle, surface)
+{
+	SetPropAttr(VTYPE_any);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(easy_handle, surface)
+{
+	//return Value(Object_surface::Reference(_pObjSurface.get()));
+	return Value::Nil;
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for easy_handle
 // easy_handle operations
@@ -856,14 +864,14 @@ Gura_DeclareMethod(easy_handle, escape)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "string", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, escape)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
-	const String str = args.GetStringSTL(0);
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
+	const String str = arg.GetStringSTL(0);
 	const char *rtn = ::curl_easy_escape(pThis->GetEntity(),
 								str.c_str(), static_cast<int>(str.size()));
 	return Value(rtn);
@@ -875,22 +883,23 @@ Gura_DeclareMethod(easy_handle, getinfo)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "info", VTYPE_number);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, getinfo)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
 	CURLcode code;
-	CURLINFO info = static_cast<CURLINFO>(args.GetInt(0));
-	int infoType = args.GetInt(0) & CURLINFO_TYPEMASK;
+	CURLINFO info = static_cast<CURLINFO>(arg.GetInt(0));
+	int infoType = arg.GetInt(0) & CURLINFO_TYPEMASK;
 	if (infoType == CURLINFO_STRING) {
-		const char *rtn = NULL;
+		const char *rtn = nullptr;
 		code = ::curl_easy_getinfo(pThis->GetEntity(), info, &rtn);
 		if (code != CURLE_OK) {
 			SetError_Curl(sig, code);
-			return Value::Null;
+			return Value::Nil;
 		}
 		return Value(rtn);
 	} else if (infoType == CURLINFO_LONG) {
@@ -898,22 +907,22 @@ Gura_ImplementMethod(easy_handle, getinfo)
 		code = ::curl_easy_getinfo(pThis->GetEntity(), info, &rtn);
 		if (code != CURLE_OK) {
 			SetError_Curl(sig, code);
-			return Value::Null;
+			return Value::Nil;
 		}
-		return Value(rtn);
+		return Value(static_cast<Int32>(rtn));
 	} else if (infoType == CURLINFO_DOUBLE) {
 		double rtn = 0;
 		code = ::curl_easy_getinfo(pThis->GetEntity(), info, &rtn);
 		if (code != CURLE_OK) {
 			SetError_Curl(sig, code);
-			return Value::Null;
+			return Value::Nil;
 		}
 		return Value(rtn);
 	} else if (infoType == CURLINFO_SLIST) {
 		// not implemented yet
 	}
 	sig.SetError(ERR_ValueError, "invalid value for info");
-	return Value::Null;
+	return Value::Nil;
 }
 
 // curl.easy_handle#pause(bitmask:number):void
@@ -922,17 +931,17 @@ Gura_DeclareMethod(easy_handle, pause)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "bitmask", VTYPE_number);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, pause)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
-	int bitmask = args.GetInt(0);
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
+	int bitmask = arg.GetInt(0);
 	CURLcode code = ::curl_easy_pause(pThis->GetEntity(), bitmask);
 	
-	return Value::Null;
+	return Value::Nil;
 }
 
 // curl.easy_handle#perform(stream?:stream:w):void
@@ -941,21 +950,22 @@ Gura_DeclareMethod(easy_handle, perform)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_ZeroOrOnce, FLAG_Write);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, perform)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
-	Stream *pStreamOut = args.Is_stream(0)?
-			&Object_stream::GetObject(args, 0)->GetStream() : env.GetConsole();
-	std::auto_ptr<Writer> pWriter(new Writer(sig, Stream::Reference(pStreamOut)));
+	Signal &sig = env.GetSignal();
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
+	Stream *pStreamOut = arg.Is_stream(0)?
+			&Object_stream::GetObject(arg, 0)->GetStream() : env.GetConsole();
+	std::unique_ptr<Writer> pWriter(new Writer(sig, Stream::Reference(pStreamOut)));
 	::curl_easy_setopt(pThis->GetEntity(), CURLOPT_WRITEDATA, pWriter.get());
 	::curl_easy_setopt(pThis->GetEntity(), CURLOPT_WRITEFUNCTION, Writer::OnWriteStub);
 	CURLcode code = ::curl_easy_perform(pThis->GetEntity());
 	if (code != CURLE_OK) SetError_Curl(sig, code);
-	return Value::Null;
+	return Value::Nil;
 }
 
 // curl.easy_handle#recv(buflen:number)
@@ -964,21 +974,22 @@ Gura_DeclareMethod(easy_handle, recv)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "buflen", VTYPE_number);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, recv)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
-	size_t buflen = args.GetSizeT(0);
-	if (buflen == 0) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
+	size_t buflen = arg.GetSizeT(0);
+	if (buflen == 0) return Value::Nil;
 	AutoPtr<Memory> pMemory(new MemoryHeap(buflen));
 	size_t n = 0;
 	CURLcode code = ::curl_easy_recv(pThis->GetEntity(), pMemory->GetPointer(), buflen, &n);
 	if (code != CURLE_OK) {
 		SetError_Curl(sig, code);
-		return Value::Null;
+		return Value::Nil;
 	}
 	return new Object_binary(env, pMemory->GetPointer(), n);
 }
@@ -988,15 +999,15 @@ Gura_DeclareMethod(easy_handle, reset)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, reset)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
 	::curl_easy_reset(pThis->GetEntity());
-	return Value::Null;
+	return Value::Nil;
 }
 
 // curl.easy_handle#send(buffer:binary)
@@ -1005,19 +1016,20 @@ Gura_DeclareMethod(easy_handle, send)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "buffer", VTYPE_binary);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, send)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
-	const Binary &buffer = args.GetBinary(0);
+	Signal &sig = env.GetSignal();
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
+	const Binary &buffer = arg.GetBinary(0);
 	size_t n = 0;
 	CURLcode code = ::curl_easy_send(pThis->GetEntity(), buffer.data(), buffer.size(), &n);
 	if (code != CURLE_OK) {
 		SetError_Curl(sig, code);
-		return Value::Null;
+		return Value::Nil;
 	}
 	return Value(n);
 }
@@ -1029,33 +1041,34 @@ Gura_DeclareMethod(easy_handle, setopt)
 	DeclareArg(env, "option", VTYPE_number);
 	DeclareArg(env, "arg", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, setopt)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
 	CURLcode code;
-	CURLoption option = static_cast<CURLoption>(args.GetInt(0));
-	if (args.Is_number(1)) {
+	CURLoption option = static_cast<CURLoption>(arg.GetInt(0));
+	if (arg.Is_number(1)) {
 		if (!(option < CURLOPTTYPE_OBJECTPOINT || CURLOPTTYPE_OFF_T <= option)) {
 			sig.SetError(ERR_TypeError, "number cannot be specified for the option");
-			return Value::Null;
+			return Value::Nil;
 		}
-		code = ::curl_easy_setopt(pThis->GetEntity(), option, args.GetInt(1));
-	} else if (args.Is_string(1)) {
+		code = ::curl_easy_setopt(pThis->GetEntity(), option, arg.GetInt(1));
+	} else if (arg.Is_string(1)) {
 		if (!(CURLOPTTYPE_OBJECTPOINT <= option && option < CURLOPTTYPE_FUNCTIONPOINT)) {
 			sig.SetError(ERR_TypeError, "string cannot be specified for the option");
-			return Value::Null;
+			return Value::Nil;
 		}
-		code = ::curl_easy_setopt(pThis->GetEntity(), option, args.GetString(1));
+		code = ::curl_easy_setopt(pThis->GetEntity(), option, arg.GetString(1));
 	} else {
-		Declaration::SetError_InvalidArgument(sig);
-		return Value::Null;
+		Declaration::SetError_InvalidArgument(env);
+		return Value::Nil;
 	}
 	if (code != CURLE_OK) SetError_Curl(sig, code);
-	return Value::Null;
+	return Value::Nil;
 }
 
 // curl.easy_handle#unescape(string:string):void
@@ -1064,14 +1077,14 @@ Gura_DeclareMethod(easy_handle, unescape)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "string", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(easy_handle, unescape)
 {
-	Object_easy_handle *pThis = Object_easy_handle::GetThisObj(args);
-	const String str = args.GetStringSTL(0);
+	Object_easy_handle *pThis = Object_easy_handle::GetObjectThis(arg);
+	const String str = arg.GetStringSTL(0);
 	int outlength = 0;
 	const char *rtn = ::curl_easy_unescape(pThis->GetEntity(),
 					str.c_str(), static_cast<int>(str.size()), &outlength);
@@ -1081,6 +1094,9 @@ Gura_ImplementMethod(easy_handle, unescape)
 // implementation of class easy_handle
 Gura_ImplementUserClass(easy_handle)
 {
+	// Assignment of properties
+	//Gura_AssignProperty(easy_handle, surface);
+	// Assignment of methods
 	Gura_AssignMethod(easy_handle, escape);
 	Gura_AssignMethod(easy_handle, getinfo);
 	Gura_AssignMethod(easy_handle, perform);
