@@ -20,11 +20,6 @@ public:
 			Object(obj), _cmapCache(obj._cmapCache) {}
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline FTC_CMapCache &GetEntity() { return _cmapCache; }
 	inline const FTC_CMapCache &GetEntity() const { return _cmapCache; }
 };
