@@ -23,14 +23,9 @@ public:
 			Object(obj), _matrix(obj._matrix) {}
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline FT_Matrix *GetEntity() { return &_matrix; }
 	inline const FT_Matrix *GetEntity() const { return &_matrix; }
-	bool ConvertFrom(Signal sig, const Gura::Matrix *pMat);
+	bool ConvertFrom(Signal &sig, const ArrayT<Double> *pArrayT);
 };
 
 Gura_EndModuleScope(freetype)
