@@ -19,11 +19,6 @@ public:
 			Object(Gura_UserClass(Outline)), _pObjHolder(pObjHolder), _outline(outline) {}
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline FT_Outline *GetEntity() { return _outline; }
 	inline const FT_Outline *GetEntity() const { return _outline; }
 };
