@@ -13,99 +13,7 @@ Object_font::Object_font(Object_Face *pObjFace, Object_color *pObjColor) :
 
 Object *Object_font::Clone() const
 {
-	return NULL; //new Object_font(*this);
-}
-
-bool Object_font::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_UserSymbol(face));
-	symbols.insert(Gura_UserSymbol(color));
-	symbols.insert(Gura_UserSymbol(mode));
-	symbols.insert(Gura_UserSymbol(strength));
-	symbols.insert(Gura_UserSymbol(slant));
-	symbols.insert(Gura_UserSymbol(rotate));
-	symbols.insert(Gura_UserSymbol(width));
-	symbols.insert(Gura_UserSymbol(height));
-	return true;
-}
-
-Value Object_font::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(face))) {
-		return Value(Object_Face::Reference(_pObjFace.get()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(color))) {
-		return Value(Object_color::Reference(_pObjColor.get()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(mode))) {
-		const Symbol *pSymbol =
-			(_mode == MODE_Blend)? Gura_UserSymbol(blend) :
-			(_mode == MODE_Alpha)? Gura_UserSymbol(alpha) :
-			Gura_UserSymbol(blend);
-		return Value(pSymbol);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(strength))) {
-		return Value(_strength);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(slant))) {
-		return Value(_slant);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(rotate))) {
-		return Value(_rotate.deg);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(width))) {
-		return Value(_width);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(height))) {
-		return Value(_height);
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_font::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(color))) {
-		Value valueCasted;
-		if (!value.CastType(env, sig, VTYPE_color, valueCasted)) {
-			sig.SetError(ERR_ValueError, "value must be color");
-			return Value::Null;
-		}
-		_pObjColor->SetColor(Object_color::GetObject(valueCasted)->GetColor());
-		return Value(Object_color::Reference(_pObjColor.get()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(mode))) {
-		if (!value.MustBe_symbol(sig)) return Value::Null;
-		const Symbol *pSymbolVal = value.GetSymbol();
-		if (pSymbolVal->IsIdentical(Gura_UserSymbol(blend))) {
-			_mode = MODE_Blend;
-		} else if (pSymbolVal->IsIdentical(Gura_UserSymbol(alpha))) {
-			_mode = MODE_Alpha;
-		} else {
-			sig.SetError(ERR_ValueError, "symbol must be `blend or `alpha");
-			return Value::Null;
-		}
-		return Value(pSymbolVal);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(strength))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		SetStrength(value.GetDouble());
-		return Value(_strength);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(slant))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		SetSlant(value.GetDouble());
-		return Value(_slant);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(rotate))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		SetRotate(value.GetDouble());
-		return Value(_rotate.deg);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(width))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		SetWidth(value.GetDouble());
-		return Value(_width);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(height))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		SetHeight(value.GetDouble());
-		return Value(_height);
-	}
-	evaluatedFlag = false;
-	return Value::Null;
+	return nullptr; //new Object_font(*this);
 }
 
 String Object_font::ToString(bool exprFlag)
@@ -128,15 +36,16 @@ void Object_font::ClearDeco()
 	_rotate.cosNum = 1., _rotate.sinNum = 0.;
 }
 
-bool Object_font::CalcSize(Environment &env, Signal sig, const String &str,
+bool Object_font::CalcSize(Environment &env, const String &str,
 					size_t &width, size_t &height, const Function *pFuncDeco)
 {
+	Signal &sig = env.GetSignal();
 	int xShifted = 0, yShifted = 0;
 	String::const_iterator p = str.begin();
 	int xMin = 0, xMax = 0, yMin = 0, yMax = 0;
 	size_t idx = 0;
 	do {
-		unsigned long codeUTF32;
+		UInt32 codeUTF32;
 		p = Gura::NextUTF32(str, p, codeUTF32);
 		if (codeUTF32 == 0x00000000) break;
 		if (LoadAndDecorateChar(env, sig, codeUTF32, idx, pFuncDeco) != 0) continue;
@@ -158,7 +67,7 @@ bool Object_font::CalcSize(Environment &env, Signal sig, const String &str,
 	return true;
 }
 
-bool Object_font::DrawOnImage(Environment &env, Signal sig, Image *pImage,
+bool Object_font::DrawOnImage(Environment &env, Signal &sig, Image *pImage,
 				int x, int y, const String &str, const Function *pFuncDeco)
 {
 	const Color &color = _pObjColor->GetColor();
@@ -169,7 +78,7 @@ bool Object_font::DrawOnImage(Environment &env, Signal sig, Image *pImage,
 	int xShifted = x << 6, yShifted = y << 6;
 	size_t idx = 0;
 	do {
-		unsigned long codeUTF32;
+		UInt32 codeUTF32;
 		p = Gura::NextUTF32(str, p, codeUTF32);
 		if (codeUTF32 == 0x00000000) break;
 		if (LoadAndDecorateChar(env, sig, codeUTF32, idx, pFuncDeco) != 0) continue;
@@ -181,7 +90,7 @@ bool Object_font::DrawOnImage(Environment &env, Signal sig, Image *pImage,
 			int xAdj = xOrg, yAdj = yOrg;
 			int width = bitmap.width;
 			int height = bitmap.rows;
-			if (bitmap.buffer == NULL) {
+			if (bitmap.buffer == nullptr) {
 				// nothing to do
 			} else if (!pImage->AdjustCoord(xAdj, yAdj, width, height)) {
 				// nothing to do
@@ -200,10 +109,10 @@ bool Object_font::DrawOnImage(Environment &env, Signal sig, Image *pImage,
 	return true;
 }
 
-FT_Error Object_font::LoadAndDecorateChar(Environment &env, Signal sig,
-			unsigned long codeUTF32, size_t idx, const Function *pFuncDeco)
+FT_Error Object_font::LoadAndDecorateChar(Environment &env, Signal &sig,
+			UInt32 codeUTF32, size_t idx, const Function *pFuncDeco)
 {
-	bool transformFlag = (pFuncDeco != NULL);
+	bool transformFlag = (pFuncDeco != nullptr);
 	FT_Matrix matrix;	// 16.16 fixed float
 	matrix.xx = 1 << 16;
 	matrix.xy = 0 << 16;
@@ -232,19 +141,14 @@ FT_Error Object_font::LoadAndDecorateChar(Environment &env, Signal sig,
 		if (err != 0) return err;
 	}
 	// FT_Load_Char calls FT_Get_Char_Index and FT_Load_Glypy internally.
-	if (pFuncDeco == NULL) {
+	if (pFuncDeco == nullptr) {
 		FT_Error err = ::FT_Load_Char(GetFace(), codeUTF32,
 					FT_LOAD_DEFAULT | (transformFlag? FT_LOAD_NO_BITMAP : 0));
 		if (err != 0) return err;
 	} else {
-		//ValueList valListArg;
-		//valListArg.reserve(2);
-		//valListArg.push_back(Value(codeUTF32));
-		//valListArg.push_back(Value(idx));
-		AutoPtr<Args> pArgs(new Args());
-		pArgs->AddValue(Value(codeUTF32));
-		pArgs->AddValue(Value(idx));
-		pFuncDeco->Eval(env, sig, *pArgs);
+		AutoPtr<Argument> pArg(new Argument(pFuncDeco));
+		if (!pArg->StoreValue(env, Value(codeUTF32), Value(idx))) return FT_Err_Syntax_Error;
+		pFuncDeco->Eval(env, *pArg);
 	}
 	FT_GlyphSlot glyphSlot = GetFace()->glyph;
 	if (_strength == 0.) {
@@ -300,7 +204,7 @@ void Object_font::DrawMonoOnImage(Image *pImage, int x, int y,
 	unsigned char red = color.GetR();
 	unsigned char green = color.GetG();
 	unsigned char blue = color.GetB();
-	std::auto_ptr<Image::Scanner>
+	std::unique_ptr<Image::Scanner>
 				pScanner(pImage->CreateScanner(x, y, width, height));
 	int bitOffset = xOffset % 8;
 	unsigned char mask = 1 << (7 - bitOffset);
@@ -339,7 +243,7 @@ void Object_font::DrawGrayOnImage(Image *pImage, int x, int y,
 	unsigned long redFg = color.GetR();
 	unsigned long greenFg = color.GetG();
 	unsigned long blueFg = color.GetB();
-	std::auto_ptr<Image::Scanner>
+	std::unique_ptr<Image::Scanner>
 				pScanner(pImage->CreateScanner(x, y, width, height));
 	const unsigned char *pLine = buffer + xOffset + yOffset * pitch;
 	const unsigned char *pPixel = pLine;
@@ -393,6 +297,199 @@ void Object_font::DrawGrayOnImage(Image *pImage, int x, int y,
 	}
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// freetype.font#color
+Gura_DeclareProperty_RW(font, color)
+{
+	SetPropAttr(VTYPE_color);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, color)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(Object_color::Reference(pObjThis->GetObjColor()));
+}
+
+Gura_ImplementPropertySetter(font, color)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	pObjThis->GetObjColor()->SetColor(Object_color::GetObject(value)->GetColor());
+	return Value(Object_color::Reference(pObjThis->GetObjColor()));
+}
+
+// freetype.font#face
+Gura_DeclareProperty_R(font, face)
+{
+	SetPropAttr(VTYPE_Face);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, face)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(Object_Face::Reference(pObjThis->GetObjFace()));
+}
+
+// freetype.font#height
+Gura_DeclareProperty_RW(font, height)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, height)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(pObjThis->GetHeight());
+}
+
+Gura_ImplementPropertySetter(font, height)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	pObjThis->SetHeight(value.GetDouble());
+	return Value(pObjThis->GetHeight());
+}
+
+// freetype.font#mode
+Gura_DeclareProperty_RW(font, mode)
+{
+	SetPropAttr(VTYPE_symbol);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, mode)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	Object_font::Mode mode = pObjThis->GetMode();
+	const Symbol *pSymbol =
+		(mode == Object_font::MODE_Blend)? Gura_UserSymbol(blend) :
+		(mode == Object_font::MODE_Alpha)? Gura_UserSymbol(alpha) :
+		Gura_UserSymbol(blend);
+	return Value(pSymbol);
+}
+
+Gura_ImplementPropertySetter(font, mode)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	const Symbol *pSymbolVal = value.GetSymbol();
+	if (pSymbolVal->IsIdentical(Gura_UserSymbol(blend))) {
+		pObjThis->SetMode(Object_font::MODE_Blend);
+	} else if (pSymbolVal->IsIdentical(Gura_UserSymbol(alpha))) {
+		pObjThis->SetMode(Object_font::MODE_Alpha);
+	} else {
+		env.SetError(ERR_ValueError, "symbol must be `blend or `alpha");
+		return Value::Nil;
+	}
+	return Value(pSymbolVal);
+}
+
+// freetype.font#rotate
+Gura_DeclareProperty_RW(font, rotate)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, rotate)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(pObjThis->GetRotate());
+}
+
+Gura_ImplementPropertySetter(font, rotate)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	pObjThis->SetRotate(value.GetDouble());
+	return Value(pObjThis->GetRotate());
+}
+
+// freetype.font#slant
+Gura_DeclareProperty_RW(font, slant)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, slant)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(pObjThis->GetSlant());
+}
+
+Gura_ImplementPropertySetter(font, slant)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	pObjThis->SetSlant(value.GetDouble());
+	return Value(pObjThis->GetSlant());
+}
+
+// freetype.font#strength
+Gura_DeclareProperty_RW(font, strength)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, strength)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(pObjThis->GetStrength());
+}
+
+Gura_ImplementPropertySetter(font, strength)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	pObjThis->SetStrength(value.GetDouble());
+	return Value(pObjThis->GetStrength());
+}
+
+// freetype.font#width
+Gura_DeclareProperty_RW(font, width)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(font, width)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	return Value(pObjThis->GetWidth());
+}
+
+Gura_ImplementPropertySetter(font, width)
+{
+	Object_font *pObjThis = Object_font::GetObject(valueThis);
+	pObjThis->SetWidth(value.GetDouble());
+	return Value(pObjThis->GetWidth());
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for freetype.font
 //-----------------------------------------------------------------------------
@@ -407,10 +504,10 @@ Gura_DeclareFunction(font)
 
 Gura_ImplementFunction(font)
 {
-	Object_Face *pObjFace = Object_Face::GetObject(args, 0);
+	Object_Face *pObjFace = Object_Face::GetObject(arg, 0);
 	AutoPtr<Object_font> pObjFont(
 		new Object_font(Object_Face::Reference(pObjFace), new Object_color(env)));
-	return ReturnValue(env, sig, args, Value(pObjFont.release()));
+	return ReturnValue(env, arg, Value(pObjFont.release()));
 }
 
 // freetype.font#cleardeco()
@@ -421,9 +518,9 @@ Gura_DeclareMethod(font, cleardeco)
 
 Gura_ImplementMethod(font, cleardeco)
 {
-	Object_font *pThis = Object_font::GetThisObj(args);
+	Object_font *pThis = Object_font::GetObjectThis(arg);
 	pThis->ClearDeco();
-	return args.GetThis();
+	return arg.GetValueThis();
 }
 
 // freetype.font#drawtext(image:image, x:number, y:number, str:string):map:reduce {block?}
@@ -435,23 +532,24 @@ Gura_DeclareMethod(font, drawtext)
 	DeclareArg(env, "y", VTYPE_number);
 	DeclareArg(env, "str", VTYPE_string);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown, "Draws a text on the image.");
+	AddHelp(Gura_Symbol(en), "Draws a text on the image.");
 }
 
 Gura_ImplementMethod(font, drawtext)
 {
-	Object_font *pThis = Object_font::GetThisObj(args);
-	Image *pImage = Object_image::GetObject(args, 0)->GetImage();
-	int x = args.GetInt(1);
-	int y = args.GetInt(2);
-	String str = args.GetStringSTL(3);
-	const Function *pFuncDeco = NULL;
-	if (args.IsBlockSpecified()) {
-		pFuncDeco = args.GetBlockFunc(env, sig, GetSymbolForBlock());
-		if (pFuncDeco == NULL) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_font *pThis = Object_font::GetObjectThis(arg);
+	Image *pImage = Object_image::GetObject(arg, 0)->GetImage();
+	int x = arg.GetInt(1);
+	int y = arg.GetInt(2);
+	String str = arg.GetStringSTL(3);
+	const Function *pFuncDeco = nullptr;
+	if (arg.IsBlockSpecified()) {
+		pFuncDeco = arg.GetBlockFunc(env, GetSymbolForBlock());
+		if (pFuncDeco == nullptr) return Value::Nil;
 	}
-	if (pThis->DrawOnImage(env, sig, pImage, x, y, str, pFuncDeco)) return Value::Null;
-	return args.GetThis();
+	if (pThis->DrawOnImage(env, sig, pImage, x, y, str, pFuncDeco)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // freetype.font#calcsize(str:string):map
@@ -463,11 +561,11 @@ Gura_DeclareMethod(font, calcsize)
 
 Gura_ImplementMethod(font, calcsize)
 {
-	const Function *pFuncDeco = NULL;
-	Object_font *pThis = Object_font::GetThisObj(args);
-	String str = args.GetStringSTL(0);
+	const Function *pFuncDeco = nullptr;
+	Object_font *pThis = Object_font::GetObjectThis(arg);
+	String str = arg.GetStringSTL(0);
 	size_t width, height;
-	if (!pThis->CalcSize(env, sig, str, width, height, pFuncDeco)) return Value::Null;
+	if (!pThis->CalcSize(env, str, width, height, pFuncDeco)) return Value::Nil;
 	return Value::CreateList(env, 
 			Value(static_cast<unsigned int>(width)),
 			Value(static_cast<unsigned int>(height)));
@@ -485,13 +583,13 @@ Gura_DeclareMethod(font, calcbbox)
 // ******************* still buggy
 Gura_ImplementMethod(font, calcbbox)
 {
-	const Function *pFuncDeco = NULL;
-	Object_font *pThis = Object_font::GetThisObj(args);
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
-	String str = args.GetStringSTL(2);
+	const Function *pFuncDeco = nullptr;
+	Object_font *pThis = Object_font::GetObjectThis(arg);
+	int x = arg.GetInt(0);
+	int y = arg.GetInt(1);
+	String str = arg.GetStringSTL(2);
 	size_t width, height;
-	if (!pThis->CalcSize(env, sig, str, width, height, pFuncDeco)) return Value::Null;
+	if (!pThis->CalcSize(env, str, width, height, pFuncDeco)) return Value::Nil;
 	return Value::CreateList(env,
 			Value(x), Value(y - pThis->GetFace()->ascender / 4),
 			Value(width), Value(height));
@@ -500,7 +598,18 @@ Gura_ImplementMethod(font, calcbbox)
 // implementation of class font
 Gura_ImplementUserClass(font)
 {
+	// Assignment of properties
+	Gura_AssignProperty(font, color);
+	Gura_AssignProperty(font, face);
+	Gura_AssignProperty(font, height);
+	Gura_AssignProperty(font, mode);
+	Gura_AssignProperty(font, rotate);
+	Gura_AssignProperty(font, slant);
+	Gura_AssignProperty(font, strength);
+	Gura_AssignProperty(font, width);
+	// Assignment of function
 	Gura_AssignFunction(font);
+	// Assignment of methods
 	Gura_AssignMethod(font, cleardeco);
 	Gura_AssignMethod(font, drawtext);
 	Gura_AssignMethod(font, calcsize);
