@@ -22,15 +22,15 @@ Handler::~Handler()
 	delete _pStreamRec;
 }
 
-bool Handler::OpenFace(Signal sig, int index, FT_Face *aface)
+bool Handler::OpenFace(Signal &sig, int index, FT_Face *aface)
 {
 	::memset(_pStreamRec, 0x00, sizeof(FT_StreamRec));
 	_pStreamRec->descriptor.pointer = this;
 	_pStreamRec->size = 0x7fffffffL;
 	_pStreamRec->pos = 0;
-	_pStreamRec->base = NULL;
+	_pStreamRec->base = nullptr;
 	_pStreamRec->read = ReadStub;
-	_pStreamRec->close = NULL;
+	_pStreamRec->close = nullptr;
 	FT_Open_Args ftargs;
 	::memset(&ftargs, 0x00, sizeof(ftargs));
 	ftargs.flags = FT_OPEN_STREAM;
@@ -71,24 +71,25 @@ Gura_DeclareMethod(image, drawtext)
 	DeclareArg(env, "y", VTYPE_number);
 	DeclareArg(env, "str", VTYPE_string);
 	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(Gura_Symbol(en), Help::FMT_markdown, "Draws a text on the image.");
+	AddHelp(Gura_Symbol(en), "Draws a text on the image.");
 }
 
 Gura_ImplementMethod(image, drawtext)
 {
-	Object_image *pObjImage = Object_image::GetThisObj(args);
-	Object_font *pObjFont = Object_font::GetObject(args, 0);
-	int x = args.GetInt(1);
-	int y = args.GetInt(2);
-	String str = args.GetStringSTL(3);
-	const Function *pFuncDeco = NULL;
-	if (args.IsBlockSpecified()) {
-		pFuncDeco = args.GetBlockFunc(env, sig, GetSymbolForBlock());
-		if (pFuncDeco == NULL) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_image *pObjImage = Object_image::GetObjectThis(arg);
+	Object_font *pObjFont = Object_font::GetObject(arg, 0);
+	int x = arg.GetInt(1);
+	int y = arg.GetInt(2);
+	String str = arg.GetStringSTL(3);
+	const Function *pFuncDeco = nullptr;
+	if (arg.IsBlockSpecified()) {
+		pFuncDeco = arg.GetBlockFunc(env, GetSymbolForBlock());
+		if (pFuncDeco == nullptr) return Value::Nil;
 	}
 	if (pObjFont->DrawOnImage(env, sig, pObjImage->GetImage(),
-								x, y, str, pFuncDeco)) return Value::Null;
-	return args.GetThis();
+								x, y, str, pFuncDeco)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 //-----------------------------------------------------------------------------
@@ -103,20 +104,21 @@ Gura_DeclareFunction(test)
 
 Gura_ImplementFunction(test)
 {
+	Signal &sig = env.GetSignal();
 #if 0
 	FT_Face face;
 	FT_Error err = ::FT_New_Face(g_lib, "arial.ttf", 0, &face);
 	
 	FT_Stream streamFT = new FT_StreamRec;
 	
-	Handler handler(sig, args.GetStream(0));
+	Handler handler(sig, arg.GetStream(0));
 	::memset(streamFT, 0x00, sizeof(*streamFT));
 	streamFT->descriptor.pointer = &handler;
 	streamFT->size = 0x7fffffffL;
 	streamFT->pos = 0;
-	streamFT->base = NULL;
+	streamFT->base = nullptr;
 	streamFT->read = Handler::ReadStub;
-	streamFT->close = NULL;
+	streamFT->close = nullptr;
 	FT_Open_Args ftargs;
 	::memset(&ftargs, 0x00, sizeof(ftargs));
 	ftargs.flags = FT_OPEN_STREAM;
@@ -130,8 +132,8 @@ Gura_ImplementFunction(test)
 	String pathName = GetSysFontPathName();
 	Directory *pDirectoryParent = Directory::OpenDirectory(
 						env, sig, pathName.c_str(), Directory::NF_Signal);
-	Directory *pDirectory = NULL;
-	while ((pDirectory = pDirectoryParent->Next(env, sig)) != NULL) {
+	Directory *pDirectory = nullptr;
+	while ((pDirectory = pDirectoryParent->Next(env)) != nullptr) {
 		if (pDirectory->IsMatchName("*.ttf", true) ||
 								pDirectory->IsMatchName("*.ttc", true)) {
 			FT_Face face;
@@ -147,7 +149,7 @@ Gura_ImplementFunction(test)
 		}
 	}
 #endif
-	return Value::Null;
+	return Value::Nil;
 }
 
 #if 0
@@ -175,24 +177,31 @@ Gura_ImplementFunction(test)
 	//FT_Open_Args args;
 	//err = ::FT_Open_Face(g_lib, &args, face_index, &face);
 	::FT_Done_Face(face);
-	return Value::Null;
+	return Value::Nil;
 #endif
 
 
-// freetype.sysfontpath(name?:string):map
+// freetype.sysfontpath(name:string):map
 Gura_DeclareFunction(sysfontpath)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
-	DeclareArg(env, "name", VTYPE_string, OCCUR_ZeroOrOnce);
+	DeclareArg(env, "name", VTYPE_string);
 }
 
 Gura_ImplementFunction(sysfontpath)
 {
-	const char *name = args.Is_string(0)? args.GetString(0) : "";
-	return Value(OAL::JoinPathName(GetSysFontPathName().c_str(), name));
+	const char *name = arg.GetString(0);
+	return Value(GetSysFontPathName(name));
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	::FT_Init_FreeType(&g_lib);
@@ -604,22 +613,37 @@ Gura_ModuleTerminate()
 // utility functions
 //-----------------------------------------------------------------------------
 #if defined(GURA_ON_MSWIN)
-String GetSysFontPathName()
+String GetSysFontPathName(const char *name)
 {
 	char pathName[MAX_PATH];
-	if (SUCCEEDED(::SHGetFolderPath(NULL, CSIDL_FONTS, NULL, 0, pathName))) {
-		return String(pathName);
+	if (SUCCEEDED(::SHGetFolderPath(nullptr, CSIDL_FONTS, nullptr, 0, pathName))) {
+		return OAL::JoinPathName(pathName, name);
 	}
-	return String("");
+	return String(name);
+}
+#elif defined(GURA_ON_DARWIN)
+String GetSysFontPathName(const char *name)
+{
+	String pathName;
+	pathName = OAL::JoinPathName("/System/Library/Fonts", name);
+	if (OAL::DoesExist(pathName.c_str())) return pathName;
+	pathName = OAL::JoinPathName("/Library/Fonts", name);
+	if (OAL::DoesExist(pathName.c_str())) return pathName;
+	return String(name);
+}
+#elif defined(GURA_ON_LINUX)
+String GetSysFontPathName(const char *name)
+{
+	return String(name);
 }
 #else
-String GetSysFontPathName()
+String GetSysFontPathName(const char *name)
 {
-	return String("");
+	return String(name);
 }
 #endif
 
-void SetError_Freetype(Signal sig, FT_Error err)
+void SetError_Freetype(Signal &sig, FT_Error err)
 {
 	sig.SetError(ERR_RuntimeError, "freetype error");
 }
