@@ -36,84 +36,320 @@ Object *Object_Stat::Clone() const
 	return new Object_Stat(*this);
 }
 
-bool Object_Stat::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_UserSymbol(pathname));
-	symbols.insert(Gura_UserSymbol(dirname));
-	symbols.insert(Gura_UserSymbol(filename));
-	symbols.insert(Gura_UserSymbol(size));
-	symbols.insert(Gura_UserSymbol(uid));
-	symbols.insert(Gura_UserSymbol(gid));
-	symbols.insert(Gura_UserSymbol(atime));
-	symbols.insert(Gura_UserSymbol(mtime));
-	symbols.insert(Gura_UserSymbol(ctime));
-	symbols.insert(Gura_UserSymbol(isdir));
-	symbols.insert(Gura_UserSymbol(ischr));
-	symbols.insert(Gura_UserSymbol(isblk));
-	symbols.insert(Gura_UserSymbol(isreg));
-	symbols.insert(Gura_UserSymbol(isfifo));
-	symbols.insert(Gura_UserSymbol(islnk));
-	symbols.insert(Gura_UserSymbol(issock));
-	return true;
-}
-
-Value Object_Stat::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(pathname))) {
-		return Value(_fileStat.GetPathName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(dirname))) {
-		String dirName;
-		PathMgr::SplitFileName(_fileStat.GetPathName(), &dirName, NULL);
-		return Value(dirName);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(filename))) {
-		String fileName;
-		PathMgr::SplitFileName(_fileStat.GetPathName(), NULL, &fileName);
-		return Value(fileName);
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(size))) {
-		return Value(static_cast<Number>(_fileStat.GetSize()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(uid))) {
-		return Value(static_cast<Number>(_fileStat.GetUid()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(gid))) {
-		return Value(static_cast<Number>(_fileStat.GetGid()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(atime))) {
-		return Value(new Object_datetime(env, _fileStat.GetATime()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(mtime))) {
-		return Value(new Object_datetime(env, _fileStat.GetMTime()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(ctime))) {
-		return Value(new Object_datetime(env, _fileStat.GetCTime()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(isdir))) {
-		return Value(_fileStat.IsDir());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(ischr))) {
-		return Value(_fileStat.IsChr());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(isblk))) {
-		return Value(_fileStat.IsBlk());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(isreg))) {
-		return Value(_fileStat.IsReg());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(isfifo))) {
-		return Value(_fileStat.IsFifo());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(islnk))) {
-		return Value(_fileStat.IsLnk());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(issock))) {
-		return Value(_fileStat.IsSock());
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_Stat::ToString(bool exprFlag)
 {
 	return String("<fs.stat>");
 }
 
+// fs.stat(pathname:string) {block?}
+Gura_DeclareFunction(stat)
+{
+	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
+	DeclareArg(env, "pathname", VTYPE_string, OCCUR_Once);
+	SetClassToConstruct(Gura_UserClass(Stat));
+	DeclareBlock(OCCUR_ZeroOrOnce);
+	AddHelp(
+		Gura_Symbol(en), 
+		"");
+}
+
+Gura_ImplementFunction(stat)
+{
+	Signal &sig = env.GetSignal();
+	const char *pathName = arg.GetString(0);
+	std::unique_ptr<OAL::FileStat> pFileStat(OAL::FileStat::Generate(sig, pathName));
+	if (sig.IsSignalled()) return Value::Nil;
+	return ReturnValue(env, arg, Value(new Object_Stat(*pFileStat)));
+}
+
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// fs.Stat#atime
+Gura_DeclareProperty_R(Stat, atime)
+{
+	SetPropAttr(VTYPE_datetime);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, atime)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(new Object_datetime(env, fileStat.GetATime()));
+}
+
+// fs.Stat#ctime
+Gura_DeclareProperty_R(Stat, ctime)
+{
+	SetPropAttr(VTYPE_datetime);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, ctime)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(new Object_datetime(env, fileStat.GetCTime()));
+}
+
+// fs.Stat#dirname
+Gura_DeclareProperty_R(Stat, dirname)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, dirname)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	String dirName;
+	PathMgr::SplitFileName(fileStat.GetPathName(), &dirName, nullptr);
+	return Value(dirName);
+}
+
+// fs.Stat#filename
+Gura_DeclareProperty_R(Stat, filename)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, filename)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	String fileName;
+	PathMgr::SplitFileName(fileStat.GetPathName(), nullptr, &fileName);
+	return Value(fileName);
+}
+
+// fs.Stat#gid
+Gura_DeclareProperty_R(Stat, gid)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, gid)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(static_cast<Number>(fileStat.GetGid()));
+}
+
+// fs.Stat#isblk
+Gura_DeclareProperty_R(Stat, isblk)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, isblk)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsBlk());
+}
+
+// fs.Stat#ischr
+Gura_DeclareProperty_R(Stat, ischr)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, ischr)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsChr());
+}
+
+// fs.Stat#isdir
+Gura_DeclareProperty_R(Stat, isdir)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, isdir)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsDir());
+}
+
+// fs.Stat#isfifo
+Gura_DeclareProperty_R(Stat, isfifo)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, isfifo)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsFifo());
+}
+
+// fs.Stat#islnk
+Gura_DeclareProperty_R(Stat, islnk)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, islnk)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsLnk());
+}
+
+// fs.Stat#isreg
+Gura_DeclareProperty_R(Stat, isreg)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, isreg)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsReg());
+}
+
+// fs.Stat#issock
+Gura_DeclareProperty_R(Stat, issock)
+{
+	SetPropAttr(VTYPE_boolean);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, issock)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.IsSock());
+}
+
+// fs.Stat#mtime
+Gura_DeclareProperty_R(Stat, mtime)
+{
+	SetPropAttr(VTYPE_datetime);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, mtime)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(new Object_datetime(env, fileStat.GetMTime()));
+}
+
+// fs.Stat#pathname
+Gura_DeclareProperty_R(Stat, pathname)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, pathname)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(fileStat.GetPathName());
+}
+
+// fs.Stat#size
+Gura_DeclareProperty_R(Stat, size)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, size)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(static_cast<Number>(fileStat.GetSize()));
+}
+
+// fs.Stat#uid
+Gura_DeclareProperty_R(Stat, uid)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(Stat, uid)
+{
+	const OAL::FileStat &fileStat = Object_Stat::GetObject(valueThis)->GetFileStat();
+	return Value(static_cast<Number>(fileStat.GetUid()));
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for Object_Stat
 //-----------------------------------------------------------------------------
 // implementation of class Stat
 Gura_ImplementUserClass(Stat)
 {
+	// Assignment of properties
+	Gura_AssignProperty(Stat, atime);
+	Gura_AssignProperty(Stat, ctime);
+	Gura_AssignProperty(Stat, dirname);
+	Gura_AssignProperty(Stat, filename);
+	Gura_AssignProperty(Stat, gid);
+	Gura_AssignProperty(Stat, isblk);
+	Gura_AssignProperty(Stat, ischr);
+	Gura_AssignProperty(Stat, isdir);
+	Gura_AssignProperty(Stat, isfifo);
+	Gura_AssignProperty(Stat, islnk);
+	Gura_AssignProperty(Stat, isreg);
+	Gura_AssignProperty(Stat, issock);
+	Gura_AssignProperty(Stat, mtime);
+	Gura_AssignProperty(Stat, pathname);
+	Gura_AssignProperty(Stat, size);
+	Gura_AssignProperty(Stat, uid);
+	// Assignment of function
+	Gura_AssignFunction(stat);
 }
 
 //-----------------------------------------------------------------------------
@@ -136,27 +372,29 @@ const char *Stream_File::GetIdentifier() const
 
 bool Stream_File::GetAttribute(Attribute &attr)
 {
-	std::auto_ptr<OAL::FileStat> pFileStat(
+	std::unique_ptr<OAL::FileStat> pFileStat(
 					OAL::FileStat::Generate(_sig, _fileName.c_str()));
-	if (pFileStat.get() == NULL) return false;
+	if (pFileStat.get() == nullptr) return false;
 	attr.atime = pFileStat->GetATime();
 	attr.mtime = pFileStat->GetMTime();
 	attr.ctime = pFileStat->GetCTime();
+	attr.uid = pFileStat->GetUid();
+	attr.gid = pFileStat->GetGid();
 	attr.attr = attr.attrMask = pFileStat->GetMode();
 	return true;
 }
 
 #if defined(GURA_ON_MSWIN)
-Stream_File::Stream_File(Environment &env, Signal sig) :
-	Stream(env, sig, ATTR_BwdSeekable), _hFile(INVALID_HANDLE_VALUE), _needCloseFlag(false)
+Stream_File::Stream_File(Environment &env) :
+	Stream(env, ATTR_BwdSeekable), _hFile(INVALID_HANDLE_VALUE), _needCloseFlag(false)
 {
-	_map.hFileMappingObject = NULL;
-	_map.buff = NULL;
+	_map.hFileMappingObject = nullptr;
+	_map.buff = nullptr;
 	_map.bytes = 0;
 	_map.offset = 0;
 }
 
-bool Stream_File::Open(Signal sig, const char *fileName, ULong attr)
+bool Stream_File::Open(Signal &sig, const char *fileName, ULong attr)
 {
 	Close();
 	_attr |= attr;
@@ -174,29 +412,29 @@ bool Stream_File::Open(Signal sig, const char *fileName, ULong attr)
 			OPEN_EXISTING;
 	_hFile = ::CreateFile(OAL::ToNativeString(_fileName.c_str()).c_str(),
 					dwDesiredAccess, dwShareMode,
-					NULL, dwCreationDisposition, FILE_ATTRIBUTE_NORMAL, NULL);
+					nullptr, dwCreationDisposition, FILE_ATTRIBUTE_NORMAL, nullptr);
 	if (_hFile == INVALID_HANDLE_VALUE) {
 		sig.SetError(ERR_IOError, "can't open file '%s'", fileName);
 		return false;
 	}
 	if (IsAppend()) {
-		::SetFilePointer(_hFile, 0, NULL, FILE_END);
+		::SetFilePointer(_hFile, 0, nullptr, FILE_END);
 	}
-	_map.hFileMappingObject = NULL;
-	_map.buff = NULL;
+	_map.hFileMappingObject = nullptr;
+	_map.buff = nullptr;
 	_map.bytes = 0;
 	_map.offset = 0;
 	_needCloseFlag = true;
 	if (dwDesiredAccess == GENERIC_READ) {
 		_map.hFileMappingObject =
-				::CreateFileMapping(_hFile, NULL, PAGE_READONLY, 0, 0, NULL);
-		if (_map.hFileMappingObject == NULL) {
+				::CreateFileMapping(_hFile, nullptr, PAGE_READONLY, 0, 0, nullptr);
+		if (_map.hFileMappingObject == nullptr) {
 			// it seems to open an empty file
 			return true;
 		}
 		_map.buff = reinterpret_cast<UChar *>(
 				::MapViewOfFile(_map.hFileMappingObject, FILE_MAP_READ, 0, 0, 0));
-		_map.bytes = ::GetFileSize(_hFile, NULL);
+		_map.bytes = ::GetFileSize(_hFile, nullptr);
 		_map.offset = 0;
 	}
 	return true;
@@ -239,7 +477,7 @@ bool Stream_File::OpenStderr()
 bool Stream_File::SetAttribute(const Attribute &attr)
 {
 	HANDLE hFileDst = ::CreateFile(_fileName.c_str(),
-			GENERIC_WRITE, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
+			GENERIC_WRITE, 0, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 	if (hFileDst == INVALID_HANDLE_VALUE) return false;
 	FILETIME ftCreate = OAL::ToFILETIME(attr.ctime);
 	FILETIME ftAccess = OAL::ToFILETIME(attr.atime);
@@ -249,11 +487,11 @@ bool Stream_File::SetAttribute(const Attribute &attr)
 	return true;
 }
 
-size_t Stream_File::DoRead(Signal sig, void *buff, size_t bytes)
+size_t Stream_File::DoRead(Signal &sig, void *buff, size_t bytes)
 {
-	if (_map.hFileMappingObject == NULL) {
+	if (_map.hFileMappingObject == nullptr) {
 		DWORD dwBytesRead;
-		::ReadFile(_hFile, buff, static_cast<DWORD>(bytes), &dwBytesRead, NULL);
+		::ReadFile(_hFile, buff, static_cast<DWORD>(bytes), &dwBytesRead, nullptr);
 		return static_cast<size_t>(dwBytesRead);
 	} else {
 		size_t bytesRead = bytes;
@@ -268,21 +506,21 @@ size_t Stream_File::DoRead(Signal sig, void *buff, size_t bytes)
 	}
 }
 
-size_t Stream_File::DoWrite(Signal sig, const void *buff, size_t bytes)
+size_t Stream_File::DoWrite(Signal &sig, const void *buff, size_t bytes)
 {
 	DWORD dwBytesWritten;
-	::WriteFile(_hFile, buff, static_cast<DWORD>(bytes), &dwBytesWritten, NULL);
+	::WriteFile(_hFile, buff, static_cast<DWORD>(bytes), &dwBytesWritten, nullptr);
 	return static_cast<size_t>(dwBytesWritten);
 }
 
-bool Stream_File::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode seekMode)
+bool Stream_File::DoSeek(Signal &sig, long offset, size_t offsetPrev, SeekMode seekMode)
 {
 	if (_hFile == INVALID_HANDLE_VALUE) return true;
-	if (_map.hFileMappingObject == NULL) {
+	if (_map.hFileMappingObject == nullptr) {
 		DWORD dwMoveMethod =
 			(seekMode == SeekSet)? FILE_BEGIN :
 			(seekMode == SeekCur)? FILE_CURRENT : FILE_BEGIN;
-		DWORD dwPtr = ::SetFilePointer(_hFile, offset, NULL, dwMoveMethod);
+		DWORD dwPtr = ::SetFilePointer(_hFile, offset, nullptr, dwMoveMethod);
 		if (dwPtr == INVALID_SET_FILE_POINTER) {
 			sig.SetError(ERR_IOError, "seek error");
 			return false;
@@ -305,21 +543,21 @@ bool Stream_File::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode se
 	return true;
 }
 
-bool Stream_File::DoFlush(Signal sig)
+bool Stream_File::DoFlush(Signal &sig)
 {
 	::FlushFileBuffers(_hFile);
 	return true;
 }
 
-bool Stream_File::DoClose(Signal sig)
+bool Stream_File::DoClose(Signal &sig)
 {
 	if (!_needCloseFlag) return true;
 	if (_hFile != INVALID_HANDLE_VALUE) {
-		if (_map.hFileMappingObject != NULL) {
+		if (_map.hFileMappingObject != nullptr) {
 			::UnmapViewOfFile(_map.buff);
 			::CloseHandle(_map.hFileMappingObject);
-			_map.hFileMappingObject = NULL;
-			_map.buff = NULL;
+			_map.hFileMappingObject = nullptr;
+			_map.buff = nullptr;
 		}
 		::CloseHandle(_hFile);
 		_hFile = INVALID_HANDLE_VALUE;
@@ -332,29 +570,29 @@ bool Stream_File::DoClose(Signal sig)
 size_t Stream_File::DoGetSize()
 {
 	if (_hFile == INVALID_HANDLE_VALUE) return 0;
-	DWORD rtn = ::GetFileSize(_hFile, NULL);
+	DWORD rtn = ::GetFileSize(_hFile, nullptr);
 	if (rtn == 0xffffffff) return InvalidSize;
 	return static_cast<size_t>(rtn);
 }
 
-Object *Stream_File::DoGetStatObj(Signal sig)
+Object *Stream_File::DoGetStatObj(Signal &sig)
 {
 	BY_HANDLE_FILE_INFORMATION attrData;
 	String pathName = OAL::MakeAbsPathName(OAL::FileSeparator, _fileName.c_str());
 	if (::GetFileInformationByHandle(_hFile, &attrData) == 0) {
 		sig.SetError(ERR_IOError, "failed to get file status of %s", pathName.c_str());
-		return NULL;
+		return nullptr;
 	}
 	return new Object_Stat(OAL::FileStat(pathName.c_str(), attrData));
 }
 
 #else // !defined(GURA_ON_MSWIN)
-Stream_File::Stream_File(Environment &env, Signal sig) :
-		Stream(env, sig, ATTR_BwdSeekable), _fp(NULL), _needCloseFlag(false)
+Stream_File::Stream_File(Environment &env) :
+		Stream(env, ATTR_BwdSeekable), _fp(nullptr), _needCloseFlag(false)
 {
 }
 
-bool Stream_File::Open(Signal sig, const char *fileName, ULong attr)
+bool Stream_File::Open(Signal &sig, const char *fileName, ULong attr)
 {
 	Close();
 	_attr |= attr;
@@ -371,7 +609,7 @@ bool Stream_File::Open(Signal sig, const char *fileName, ULong attr)
 	}
 	modeMod[1] = '\0';
 	_fp = ::fopen(OAL::ToNativeString(_fileName.c_str()).c_str(), modeMod);
-	if (_fp == NULL) {
+	if (_fp == nullptr) {
 		sig.SetError(ERR_IOError, "can't open file '%s'", fileName);
 		return false;
 	}
@@ -409,25 +647,25 @@ bool Stream_File::SetAttribute(const Attribute &attr)
 	return false;
 }
 
-size_t Stream_File::DoRead(Signal sig, void *buff, size_t bytes)
+size_t Stream_File::DoRead(Signal &sig, void *buff, size_t bytes)
 {
 	return ::fread(buff, 1, bytes, _fp);
 }
 
-size_t Stream_File::DoWrite(Signal sig, const void *buff, size_t bytes)
+size_t Stream_File::DoWrite(Signal &sig, const void *buff, size_t bytes)
 {
 	return ::fwrite(buff, 1, bytes, _fp);
 }
 
-bool Stream_File::DoFlush(Signal sig)
+bool Stream_File::DoFlush(Signal &sig)
 {
 	::fflush(_fp);
 	return true;
 }
 
-bool Stream_File::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode seekMode)
+bool Stream_File::DoSeek(Signal &sig, long offset, size_t offsetPrev, SeekMode seekMode)
 {
-	if (_fp == NULL) return true;
+	if (_fp == nullptr) return true;
 	int origin =
 		(seekMode == SeekSet)? SEEK_SET :
 		(seekMode == SeekCur)? SEEK_CUR : SEEK_SET;
@@ -438,12 +676,12 @@ bool Stream_File::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode se
 	return true;
 }
 
-bool Stream_File::DoClose(Signal sig)
+bool Stream_File::DoClose(Signal &sig)
 {
 	if (!_needCloseFlag) return true;
-	if (_fp != NULL) {
+	if (_fp != nullptr) {
 		::fclose(_fp);
-		_fp = NULL;
+		_fp = nullptr;
 		_needCloseFlag = false;
 	}
 	return Stream::DoClose(sig);
@@ -451,20 +689,19 @@ bool Stream_File::DoClose(Signal sig)
 
 size_t Stream_File::DoGetSize()
 {
-	if (_fp == NULL) return 0;
+	if (_fp == nullptr) return 0;
 	struct stat stat;
 	if (::fstat(fileno(_fp), &stat) != 0) return InvalidSize;
 	return static_cast<size_t>(stat.st_size);
 }
 
-Object *Stream_File::DoGetStatObj(Signal sig)
+Object *Stream_File::DoGetStatObj(Signal &sig)
 {
-	ULong attr = 0;
 	struct stat stat;
 	String pathName = OAL::MakeAbsPathName(OAL::FileSeparator, _fileName.c_str());
 	if (::fstat(fileno(_fp), &stat) != 0) {
 		sig.SetError(ERR_IOError, "failed to get file status of %s", pathName.c_str());
-		return NULL;
+		return nullptr;
 	}
 	return new Object_Stat(OAL::FileStat(pathName.c_str(), stat));
 }
@@ -487,7 +724,7 @@ Directory_FileSys::~Directory_FileSys()
 	::FindClose(_hFind);
 }
 
-Directory *Directory_FileSys::DoNext(Environment &env, Signal sig)
+Directory *Directory_FileSys::DoNext(Environment &env)
 {
 	WIN32_FIND_DATA findData;
 	if (_hFind == INVALID_HANDLE_VALUE) {
@@ -495,18 +732,18 @@ Directory *Directory_FileSys::DoNext(Environment &env, Signal sig)
 		if (!pathName.empty()) pathName += GetSeparator();
 		pathName += "*.*";
 		_hFind = ::FindFirstFile(OAL::ToNativeString(pathName.c_str()).c_str(), &findData);
-		if (_hFind == INVALID_HANDLE_VALUE) return NULL;
+		if (_hFind == INVALID_HANDLE_VALUE) return nullptr;
 	} else if (!::FindNextFile(_hFind, &findData)) {
 		::FindClose(_hFind);
 		_hFind = INVALID_HANDLE_VALUE;
-		return NULL;
+		return nullptr;
 	}
 	while (::strcmp(findData.cFileName, ".") == 0 ||
 			::strcmp(findData.cFileName, "..") == 0) {
 		if (!::FindNextFile(_hFind, &findData)) {
 			::FindClose(_hFind);
 			_hFind = INVALID_HANDLE_VALUE;
-			return NULL;
+			return nullptr;
 		}
 	}
 	Type type = (findData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)?
@@ -516,14 +753,14 @@ Directory *Directory_FileSys::DoNext(Environment &env, Signal sig)
 							type, new OAL::FileStat(fileName.c_str(), findData));
 }
 
-bool Directory_FileSys::IsExist(Signal sig, const char *pathName)
+bool Directory_FileSys::IsExist(Signal &sig, const char *pathName)
 {
 	WIN32_FILE_ATTRIBUTE_DATA attrData;
 	return ::GetFileAttributesEx(OAL::ToNativeString(pathName).c_str(),
 										GetFileExInfoStandard, &attrData) != 0;
 }
 
-bool Directory_FileSys::IsDir(Signal sig, const char *pathName)
+bool Directory_FileSys::IsDir(Signal &sig, const char *pathName)
 {
 	WIN32_FILE_ATTRIBUTE_DATA attrData;
 	return ::GetFileAttributesEx(OAL::ToNativeString(pathName).c_str(),
@@ -536,46 +773,46 @@ bool Directory_FileSys::IsDir(Signal sig, const char *pathName)
 Directory_FileSys::Directory_FileSys(Directory *pParent, const char *name,
 												Type type, OAL::FileStat *pFileStat) :
 	Directory(pParent, name, type, OAL::FileSeparator),
-	_pDir(NULL), _pFileStat(pFileStat)
+	_pDir(nullptr), _pFileStat(pFileStat)
 {
 }
 
 Directory_FileSys::~Directory_FileSys()
 {
-	if (_pDir != NULL) closedir(_pDir);
+	if (_pDir != nullptr) closedir(_pDir);
 }
 
-Directory *Directory_FileSys::DoNext(Environment &env, Signal sig)
+Directory *Directory_FileSys::DoNext(Environment &env)
 {
-	if (_pDir == NULL) {
+	if (_pDir == nullptr) {
 		String pathName(MakePathName(false));
 		String pathNameEnc = OAL::ToNativeString(pathName.c_str());
 		_pDir = opendir(pathNameEnc.empty()? "." : pathNameEnc.c_str());
-		if (_pDir == NULL) return NULL;
+		if (_pDir == nullptr) return nullptr;
 	}
-	struct dirent *pEnt = NULL;
+	struct dirent *pEnt = nullptr;
 	for (;;) {
 		pEnt = readdir(_pDir);
-		if (pEnt == NULL) {
+		if (pEnt == nullptr) {
 			closedir(_pDir);
-			_pDir = NULL;
-			return NULL;
+			_pDir = nullptr;
+			return nullptr;
 		}
 		if (::strcmp(pEnt->d_name, ".") != 0 &&
 			::strcmp(pEnt->d_name, "..") != 0) break;
 	}
 	Type type = (pEnt->d_type == DT_DIR)? TYPE_Container : TYPE_Item;
 	return new Directory_FileSys(Directory::Reference(this),
-					OAL::FromNativeString(pEnt->d_name).c_str(), type, NULL);
+					OAL::FromNativeString(pEnt->d_name).c_str(), type, nullptr);
 }
 
-bool Directory_FileSys::IsExist(Signal sig, const char *pathName)
+bool Directory_FileSys::IsExist(Signal &sig, const char *pathName)
 {
 	struct stat stat;
 	return ::stat(OAL::ToNativeString(pathName).c_str(), &stat) == 0;
 }
 
-bool Directory_FileSys::IsDir(Signal sig, const char *pathName)
+bool Directory_FileSys::IsDir(Signal &sig, const char *pathName)
 {
 	struct stat stat;
 	return ::stat(OAL::ToNativeString(pathName).c_str(), &stat) == 0 && S_ISDIR(stat.st_mode);
@@ -583,22 +820,23 @@ bool Directory_FileSys::IsDir(Signal sig, const char *pathName)
 
 #endif
 
-Object *Directory_FileSys::DoGetStatObj(Signal sig)
+Object *Directory_FileSys::DoGetStatObj(Signal &sig)
 {
-	if (_pFileStat.get() == NULL) {
+	if (_pFileStat.get() == nullptr) {
 		OAL::FileStat *pFileStat =
 				OAL::FileStat::Generate(sig, MakePathName(false).c_str());
-		if (sig.IsSignalled()) return NULL;
+		if (sig.IsSignalled()) return nullptr;
 		_pFileStat.reset(pFileStat);
 	}
 	return new Object_Stat(*_pFileStat);
 }
 
-Stream *Directory_FileSys::DoOpenStream(Environment &env, Signal sig, ULong attr)
+Stream *Directory_FileSys::DoOpenStream(Environment &env, ULong attr)
 {
-	Stream_File *pStream = new Stream_File(env, sig);
+	Signal &sig = env.GetSignal();
+	Stream_File *pStream = new Stream_File(env);
 	if (!pStream->Open(sig, MakePathName(false).c_str(), attr)) {
-		return NULL;
+		return nullptr;
 	}
 	return pStream;
 }
@@ -606,18 +844,19 @@ Stream *Directory_FileSys::DoOpenStream(Environment &env, Signal sig, ULong attr
 //-----------------------------------------------------------------------------
 // PathMgr_FileSys implementation
 //-----------------------------------------------------------------------------
-bool PathMgr_FileSys::IsResponsible(Environment &env, Signal sig,
+bool PathMgr_FileSys::IsResponsible(Environment &env,
 								const Directory *pParent, const char *pathName)
 {
-	if (pParent != NULL) return false;
+	if (pParent != nullptr) return false;
 	
 	return true;
 }
 
-Directory *PathMgr_FileSys::DoOpenDirectory(Environment &env, Signal sig,
+Directory *PathMgr_FileSys::DoOpenDirectory(Environment &env,
 		Directory *pParent, const char **pPathName, NotFoundMode notFoundMode)
 {
-	Directory *pDirectory = NULL;
+	Signal &sig = env.GetSignal();
+	Directory *pDirectory = nullptr;
 	String field;
 	String pathAccum;
 	const char *p = *pPathName;
@@ -626,7 +865,7 @@ Directory *PathMgr_FileSys::DoOpenDirectory(Environment &env, Signal sig,
 		p++;
 		Directory::Type type = Directory::TYPE_RootContainer;
 		pDirectory = new Directory_FileSys(
-						Directory::Reference(pParent), "", type, NULL);
+						Directory::Reference(pParent), "", type, nullptr);
 		pParent = pDirectory;
 	}
 	for ( ; ; p++) {
@@ -636,23 +875,23 @@ Directory *PathMgr_FileSys::DoOpenDirectory(Environment &env, Signal sig,
 			Directory::Type type = Directory::TYPE_Container;
 			if (!pathAccum.empty()) {
 				bool existFlag = Directory_FileSys::IsExist(sig, pathAccum.c_str());
-				if (sig.IsSignalled()) return NULL;
+				if (sig.IsSignalled()) return nullptr;
 				if (existFlag) {
 					type = Directory_FileSys::IsDir(sig, pathAccum.c_str())?
 								Directory::TYPE_Container : Directory::TYPE_Item;
-					if (sig.IsSignalled()) return NULL;
+					if (sig.IsSignalled()) return nullptr;
 				} else if (notFoundMode == NF_Wouldbe) {
 					type = IsFileSeparator(ch)?
 								Directory::TYPE_Container : Directory::TYPE_Item;
 				} else if (notFoundMode == NF_Signal) {
 					sig.SetError(ERR_IOError, "path not exist '%s'", pathAccum.c_str());
-					return NULL;
+					return nullptr;
 				} else {
-					return NULL;
+					return nullptr;
 				}
 			}
 			pDirectory = new Directory_FileSys(
-					Directory::Reference(pParent), field.c_str(), type, NULL);
+					Directory::Reference(pParent), field.c_str(), type, nullptr);
 			pParent = pDirectory;
 			field.clear();
 			if (type == Directory::TYPE_Item || ch == '\0') break;
@@ -674,30 +913,33 @@ Gura_DeclareFunction(chdir)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "pathname", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"Changes the current working directory.");
+		Gura_Symbol(en),
+		"Changes the current working directory to `pathname`.\n"
+		"\n"
+		"The block would be evaluated if specified, and the working directory would be changed\n"
+		"only during that evaluation period.\n");
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 Gura_ImplementFunction(chdir)
 {
-	if (args.IsBlockSpecified()) {
-		SeqPostHandler *pSeqPostHandler = NULL;
+	Signal &sig = env.GetSignal();
+	if (arg.IsBlockSpecified()) {
 		String pathNameOrg = OAL::GetCurDir();
-		if (!OAL::ChangeCurDir(args.GetString(0))) {
+		if (!OAL::ChangeCurDir(arg.GetString(0))) {
 			sig.SetError(ERR_IOError, "failed to change current directory");
-			return Value::Null;
+			return Value::Nil;
 		}
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
-		Value rtn = pExprBlock->Exec2(env, sig, pSeqPostHandler);
+		const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+		if (sig.IsSignalled()) return Value::Nil;
+		Value rtn = pExprBlock->Exec(env);
 		OAL::ChangeCurDir(pathNameOrg.c_str());
 		return rtn;
-	} else if (!OAL::ChangeCurDir(args.GetString(0))) {
+	} else if (!OAL::ChangeCurDir(arg.GetString(0))) {
 		sig.SetError(ERR_IOError, "failed to change current directory");
-		return Value::Null;
+		return Value::Nil;
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.chmod(mode, pathname:string):map:void:[follow_link]
@@ -708,7 +950,7 @@ Gura_DeclareFunction(chmod)
 	DeclareArg(env, "pathname", VTYPE_string);
 	DeclareAttr(Gura_UserSymbol(follow_link));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Changes the access mode of a file specified by `pathname`.\n"
 		"\n"
 		"There are two formats to specify the mode: one is by a number, and another in a string.\n"
@@ -752,20 +994,21 @@ Gura_DeclareFunction(chmod)
 
 Gura_ImplementFunction(chmod)
 {
+	Signal &sig = env.GetSignal();
 	bool rtn = false;
-	bool followLinkFlag = args.IsSet(Gura_UserSymbol(follow_link));
-	if (args.Is_string(0)) {
-		rtn = OAL::ChangeMode(args.GetString(0), args.GetString(1), followLinkFlag);
-	} else if (args.Is_number(0)) {
-		rtn = OAL::ChangeMode(args.GetInt(0), args.GetString(1), followLinkFlag);
+	bool followLinkFlag = arg.IsSet(Gura_UserSymbol(follow_link));
+	if (arg.Is_string(0)) {
+		rtn = OAL::ChangeMode(arg.GetString(0), arg.GetString(1), followLinkFlag);
+	} else if (arg.Is_number(0)) {
+		rtn = OAL::ChangeMode(arg.GetInt(0), arg.GetString(1), followLinkFlag);
 	} else {
 		sig.SetError(ERR_ValueError, "number or string must be specified as mode");
-		return Value::Null;
+		return Value::Nil;
 	}
 	if (!rtn) {
 		sig.SetError(ERR_IOError, "failed to change access mode");
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.copy(src:string, dst:string):map:void:[overwrite]
@@ -777,7 +1020,7 @@ Gura_DeclareFunction(copy)
 	DeclareAttr(Gura_Symbol(overwrite));
 	//DeclareAttr(Gura_Symbol(follow_link));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Copies a file.\n"
 		"\n"
 		"An argument `src` needs to specify a path name of a file that is to be copied\n"
@@ -791,12 +1034,13 @@ Gura_DeclareFunction(copy)
 
 Gura_ImplementFunction(copy)
 {
-	bool failIfExistsFlag = !args.IsSet(Gura_Symbol(overwrite));
-	bool followLinkFlag = args.IsSet(Gura_UserSymbol(follow_link));
-	if (!OAL::Copy(args.GetString(0), args.GetString(1), failIfExistsFlag, followLinkFlag)) {
-		sig.SetError(ERR_IOError, "failed to copy a file %s", args.GetString(0));
+	Signal &sig = env.GetSignal();
+	bool failIfExistsFlag = !arg.IsSet(Gura_Symbol(overwrite));
+	bool followLinkFlag = arg.IsSet(Gura_UserSymbol(follow_link));
+	if (!OAL::Copy(arg.GetString(0), arg.GetString(1), failIfExistsFlag, followLinkFlag)) {
+		sig.SetError(ERR_IOError, "failed to copy a file %s", arg.GetString(0));
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.cpdir(src:string, dst:string):map:void[:tree]
@@ -807,7 +1051,7 @@ Gura_DeclareFunction(cpdir)
 	DeclareArg(env, "dst", VTYPE_string);
 	DeclareAttr(Gura_UserSymbol(tree));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Copies a directory.\n"
 		"\n"
 		"Arguments `src` and `dst` specify source directory and destination directory respectively.\n"
@@ -817,16 +1061,17 @@ Gura_DeclareFunction(cpdir)
 
 Gura_ImplementFunction(cpdir)
 {
-	const char *dirNameSrc = args.GetString(0);
-	const char *dirNameDst = args.GetString(1);
-	bool rtn = args.IsSet(Gura_UserSymbol(tree))?
+	Signal &sig = env.GetSignal();
+	const char *dirNameSrc = arg.GetString(0);
+	const char *dirNameDst = arg.GetString(1);
+	bool rtn = arg.IsSet(Gura_UserSymbol(tree))?
 				OAL::CopyDirTree(dirNameSrc, dirNameDst) :
 				OAL::CopyDir(dirNameSrc, dirNameDst);
 	if (!rtn) {
 		sig.SetError(ERR_IOError, "failed to copies a directory '%s' to '%s'",
 													dirNameSrc, dirNameDst);
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.getcwd()
@@ -834,7 +1079,7 @@ Gura_DeclareFunction(getcwd)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns the current working directory.");
 }
 
@@ -851,7 +1096,7 @@ Gura_DeclareFunction(mkdir)
 	DeclareArg(env, "pathname", VTYPE_string);
 	DeclareAttr(Gura_UserSymbol(tree));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a directory.\n"
 		"\n"
 		"If `pathname` consists of multiple sub directories and some of them still doesn't exist,\n"
@@ -860,14 +1105,15 @@ Gura_DeclareFunction(mkdir)
 
 Gura_ImplementFunction(mkdir)
 {
-	const char *pathName = args.GetString(0);
-	bool rtn = args.IsSet(Gura_UserSymbol(tree))?
+	Signal &sig = env.GetSignal();
+	const char *pathName = arg.GetString(0);
+	bool rtn = arg.IsSet(Gura_UserSymbol(tree))?
 				OAL::MakeDirTree(pathName) :
 				OAL::MakeDir(pathName);
 	if (!rtn) {
 		sig.SetError(ERR_IOError, "failed to create a directory %s", pathName);
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.remove(pathname:string):map:void
@@ -876,16 +1122,17 @@ Gura_DeclareFunction(remove)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "pathname", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Removes a file from the file system.");
 }
 
 Gura_ImplementFunction(remove)
 {
-	if (!OAL::Remove(args.GetString(0))) {
+	Signal &sig = env.GetSignal();
+	if (!OAL::Remove(arg.GetString(0))) {
 		sig.SetError(ERR_IOError, "failed to remove a file");
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.rename(src:string, dst:string):map:void
@@ -895,16 +1142,17 @@ Gura_DeclareFunction(rename)
 	DeclareArg(env, "src", VTYPE_string);
 	DeclareArg(env, "dst", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Renames a file or directory.");
 }
 
 Gura_ImplementFunction(rename)
 {
-	if (!OAL::Rename(args.GetString(0), args.GetString(1))) {
+	Signal &sig = env.GetSignal();
+	if (!OAL::Rename(arg.GetString(0), arg.GetString(1))) {
 		sig.SetError(ERR_IOError, "failed to rename a file or directory");
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // fs.rmdir(pathname:string):map:void[:tree]
@@ -914,7 +1162,7 @@ Gura_DeclareFunction(rmdir)
 	DeclareArg(env, "pathname", VTYPE_string);
 	DeclareAttr(Gura_UserSymbol(tree));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Removes a directory.\n"
 		"\n"
 		"If the directory contains sub directories, an error occurs.\n"
@@ -923,17 +1171,25 @@ Gura_DeclareFunction(rmdir)
 
 Gura_ImplementFunction(rmdir)
 {
-	const char *pathName = args.GetString(0);
-	bool rtn = args.IsSet(Gura_UserSymbol(tree))?
+	Signal &sig = env.GetSignal();
+	const char *pathName = arg.GetString(0);
+	bool rtn = arg.IsSet(Gura_UserSymbol(tree))?
 				OAL::RemoveDirTree(pathName) :
 				OAL::RemoveDir(pathName);
 	if (!rtn) {
 		sig.SetError(ERR_IOError, "failed to remove a directory %s", pathName);
 	}
-	return Value::Null;
+	return Value::Nil;
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	// symbol realization
@@ -962,19 +1218,19 @@ Gura_ModuleEntry()
 	// assign symbols in sys module
 	Module *pModuleSys = env.GetGlobal()->GetModule_sys();
 	do {
-		Stream_File *pStream = new Stream_File(env, sig);
+		Stream_File *pStream = new Stream_File(env);
 		pStream->OpenStdin();
 		pModuleSys->AssignValue(Gura_Symbol(stdin),
 					Value(new Object_stream(env, pStream)), EXTRA_Public);
 	} while (0);
 	do {
-		Stream_File *pStream = new Stream_File(env, sig);
+		Stream_File *pStream = new Stream_File(env);
 		pStream->OpenStdout();
 		pModuleSys->AssignValue(Gura_Symbol(stdout),
 					Value(new Object_stream(env, pStream)), EXTRA_Public);
 	} while (0);
 	do {
-		Stream_File *pStream = new Stream_File(env, sig);
+		Stream_File *pStream = new Stream_File(env);
 		pStream->OpenStderr();
 		pModuleSys->AssignValue(Gura_Symbol(stderr),
 					Value(new Object_stream(env, pStream)), EXTRA_Public);
