@@ -6,15 +6,13 @@
 
 Gura_BeginModuleBody(glu)
 
-Signal g_sig;
-
 void AssignValues(Environment &env);
 void AssignFunctions(Environment &env);
 
 //-----------------------------------------------------------------------------
 // helper
 //-----------------------------------------------------------------------------
-GLenum GetImageFormat(Signal sig, Image *pImage)
+GLenum GetImageFormat(Environment &env, Image *pImage)
 {
 	GLenum format = 0;
 	Image::Format fmt = pImage->GetFormat();
@@ -22,16 +20,11 @@ GLenum GetImageFormat(Signal sig, Image *pImage)
 		(fmt == Image::FORMAT_RGB)? GL_BGR_EXT :
 		(fmt == Image::FORMAT_RGBA)? GL_BGRA_EXT : 0;
 	if (format == 0) {
-		sig.SetError(ERR_ValueError, "unsupported image type");
+		env.SetError(ERR_ValueError, "unsupported image type");
 	}
 	return format;
 }
 
-void SetError_NotImpFunction(Signal &sig, const char *funcName)
-{
-	sig.SetError(ERR_RuntimeError, "not implemented function %s", funcName);
-}
-
 //-----------------------------------------------------------------------------
 // VertexPackOwner
 //-----------------------------------------------------------------------------
@@ -66,7 +59,7 @@ Object_Quadric::~Object_Quadric()
 
 Object *Object_Quadric::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_Quadric::ToString(bool exprFlag)
@@ -74,23 +67,23 @@ String Object_Quadric::ToString(bool exprFlag)
 	return String("<quadric>");
 }
 
-void Object_Quadric::SetCallback(Signal sig, GLenum which, const Function *func)
+void Object_Quadric::SetCallback(Environment &env, GLenum which, const Function *func)
 {
 	switch (which) {
 	DispatchCallback(gluQuadricCallback, _quad, GLU_ERROR, error)
 	default:
-		sig.SetError(ERR_ValueError, "invalid value for which");
+		env.SetError(ERR_ValueError, "invalid value for which");
 		break;
 	}
 }
 
 void Object_Quadric::_CB_error(GLenum err_no, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value(static_cast<int>(err_no)));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value(static_cast<int>(err_no)))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 // implementation of class Quadric
@@ -150,7 +143,7 @@ Object_Tesselator::~Object_Tesselator()
 
 Object *Object_Tesselator::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_Tesselator::ToString(bool exprFlag)
@@ -158,7 +151,7 @@ String Object_Tesselator::ToString(bool exprFlag)
 	return String("<tesselator>");
 }
 
-void Object_Tesselator::SetCallback(Signal sig, GLenum which, const Function *func)
+void Object_Tesselator::SetCallback(Environment &env, GLenum which, const Function *func)
 {
 	switch (which) {
 	DispatchCallback(gluTessCallback, _tess, GLU_TESS_BEGIN, begin)
@@ -174,151 +167,151 @@ void Object_Tesselator::SetCallback(Signal sig, GLenum which, const Function *fu
 	DispatchCallback(gluTessCallback, _tess, GLU_TESS_EDGE_FLAG_DATA, edge_flag_data)
 	DispatchCallback(gluTessCallback, _tess, GLU_TESS_COMBINE_DATA, combine_data)
 	default:
-		sig.SetError(ERR_ValueError, "invalid value for which");
+		env.SetError(ERR_ValueError, "invalid value for which");
 		break;
 	}
 }
 
 void Object_Tesselator::_CB_begin(GLenum type, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value(static_cast<int>(type)));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value(static_cast<int>(type)))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 
 void Object_Tesselator::_CB_edge_flag(GLboolean flag, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value(flag == GL_TRUE));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value(flag == GL_TRUE))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_vertex(void *vertex_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(reinterpret_cast<VertexPack *>(vertex_data)->GetVertexData());
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, reinterpret_cast<VertexPack *>(vertex_data)->GetVertexData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_end(const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_error(GLenum err_no, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value(err_no));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value(err_no))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_combine(GLdouble coords[3], void *vertex_data[4],
 						GLfloat weight[4], void **outData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Object_Tesselator *pObjTess =
 			reinterpret_cast<VertexPack *>(vertex_data[0])->GetObjTesselator();
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->AddValue(Value::CreateList(env, coords, 3));
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value::CreateList(env, coords, 3))) return;
 	do {
 		Value value;
-		ValueList &valList = value.InitAsList(env, 4);
+		Object_list *pObjList = value.InitAsList(env, 4);
 		for (int i = 0; i < 4; i++) {
-			valList.push_back(reinterpret_cast<VertexPack *>(vertex_data[i])->GetVertexData());
+			pObjList->Add(reinterpret_cast<VertexPack *>(vertex_data[i])->GetVertexData());
 		}
-		pArgs->AddValue(value);
+		if (!pArg->StoreValue(env, value)) return;
 	} while (0);
-	pArgs->AddValue(Value::CreateList(env, weight, 4));
-	Value rtn = pFunc->Eval(env, g_sig, *pArgs);
+	if (!pArg->StoreValue(env, Value::CreateList(env, weight, 4))) return;
+	Value rtn = pFunc->Eval(env, *pArg);
 	*outData = pObjTess->GetPolygonPack()->CreateVertexPack(rtn);
 }
 
 void Object_Tesselator::_CB_begin_data(GLenum type, void *polygon_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value(type),
-		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_edge_flag_data(GLboolean flag, void *polygon_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value(flag == GL_TRUE),
-		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_end_data(void *polygon_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData());
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_vertex_data(void *vertex_data, void *polygon_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		reinterpret_cast<VertexPack *>(vertex_data)->GetVertexData(),
-		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_error_data(GLenum err_no, void *polygon_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value(err_no),
-		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Tesselator::_CB_combine_data(GLdouble coords[3], void *vertex_data[4],
 				 GLfloat weight[4], void **outDatab, void *polygon_data, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Object_Tesselator *pObjTess =
 			reinterpret_cast<VertexPack *>(vertex_data[0])->GetObjTesselator();
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->AddValue(Value::CreateList(env, coords, 3));
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value::CreateList(env, coords, 3))) return;
 	do {
 		Value value;
-		ValueList &valList = value.InitAsList(env, 4);
+		Object_list *pObjList = value.InitAsList(env, 4);
 		for (int i = 0; i < 4; i++) {
-			valList.push_back(reinterpret_cast<VertexPack *>(vertex_data[i])->GetVertexData());
+			pObjList->Add(reinterpret_cast<VertexPack *>(vertex_data[i])->GetVertexData());
 		}
-		pArgs->AddValue(value);
+		if (!pArg->StoreValue(env, value)) return;
 	} while (0);
-	pArgs->AddValue(Value::CreateList(env, weight, 4));
-	pArgs->AddValue(reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData());
-	Value rtn = pFunc->Eval(env, g_sig, *pArgs);
+	if (!pArg->StoreValue(env, Value::CreateList(env, weight, 4))) return;
+	if (!pArg->StoreValue(env, reinterpret_cast<PolygonPack *>(polygon_data)->GetPolygonData())) return;
+	Value rtn = pFunc->Eval(env, *pArg);
 	*outDatab = pObjTess->GetPolygonPack()->CreateVertexPack(rtn);
 }
 
@@ -381,7 +374,7 @@ Object_Nurbs::~Object_Nurbs()
 
 Object *Object_Nurbs::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_Nurbs::ToString(bool exprFlag)
@@ -389,7 +382,7 @@ String Object_Nurbs::ToString(bool exprFlag)
 	return String("<nurbs>");
 }
 
-void Object_Nurbs::SetCallback(Signal sig, GLenum which, const Function *func)
+void Object_Nurbs::SetCallback(Environment &env, GLenum which, const Function *func)
 {
 	switch (which) {
 #if defined(GLU_VERSION_1_3)
@@ -408,141 +401,141 @@ void Object_Nurbs::SetCallback(Signal sig, GLenum which, const Function *func)
 #endif
 	DispatchCallback(gluNurbsCallback, _nurb, GLU_ERROR, error)
 	default:
-		sig.SetError(ERR_ValueError, "invalid value for which");
+		env.SetError(ERR_ValueError, "invalid value for which");
 		break;
 	}
 }
 
 void Object_Nurbs::_CB_begin(GLenum type, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value(type));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value(type))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_vertex(GLfloat *vertex, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value::CreateList(env, vertex, 3));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value::CreateList(env, vertex, 3))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_normal(GLfloat *normal, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value::CreateList(env, normal, 3));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value::CreateList(env, normal, 3))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_color(GLfloat *color, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value::CreateList(env, color, 4));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value::CreateList(env, color, 4))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_texture_coord(GLfloat *tex_coord, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value::CreateList(env, tex_coord, 4)); // 1, 2, 3, 4
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value::CreateList(env, tex_coord, 4))) return; // 1, 2, 3, 4
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_end(const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_begin_data(GLenum type, void *userData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value(type),
-		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_vertex_data(GLfloat *vertex, void *userData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value::CreateList(env, vertex, 3),
-		(userData == NULL)? Value::Null :
-		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		(userData == nullptr)? Value::Nil :
+		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_normal_data(GLfloat *normal, void *userData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value::CreateList(env, normal, 3),
-		(userData == NULL)? Value::Null :
-		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		(userData == nullptr)? Value::Nil :
+		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_color_data(GLfloat *color, void *userData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value::CreateList(env, color, 4),
-		(userData == NULL)? Value::Null :
-		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		(userData == nullptr)? Value::Nil :
+		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_texture_coord_data(GLfloat *tex_coord, void *userData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValues(
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
 		Value::CreateList(env, tex_coord, 3),
-		(userData == NULL)? Value::Null :
-		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData());
-	pFunc->Eval(env, g_sig, *pArgs);
+		(userData == nullptr)? Value::Nil :
+		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_end_data(void *userData, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(
-		(userData == NULL)? Value::Null :
-		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData());
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env,
+		(userData == nullptr)? Value::Nil :
+		reinterpret_cast<Object_Nurbs *>(userData)->GetCallbackData())) return;
+	pFunc->Eval(env, *pArg);
 }
 
 void Object_Nurbs::_CB_error(GLenum err_no, const Function *pFunc)
 {
-	if (pFunc == NULL) return;
+	if (pFunc == nullptr) return;
 	Environment &env = pFunc->GetEnvScope();
-	AutoPtr<Args> pArgs(new Args());
-	pArgs->SetValue(Value(err_no));
-	pFunc->Eval(env, g_sig, *pArgs);
+	AutoPtr<Argument> pArg(new Argument(pFunc));
+	if (!pArg->StoreValue(env, Value(err_no))) return;
+	pFunc->Eval(env, *pArg);
 }
 
 // implementation of class Nurbs
@@ -551,13 +544,17 @@ Gura_ImplementUserClass(Nurbs)
 }
 
 //-----------------------------------------------------------------------------
-// Module entry
+// Module Entries
 //-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
-	g_sig = sig;
 	// class realization
-	Gura_RealizeAndPrepareUserClass(Quadric,		env.LookupClass(VTYPE_object));
+	Gura_RealizeAndPrepareUserClass(Quadric,	env.LookupClass(VTYPE_object));
 	Gura_RealizeAndPrepareUserClass(Tesselator,	env.LookupClass(VTYPE_object));
 	Gura_RealizeAndPrepareUserClass(Nurbs,		env.LookupClass(VTYPE_object));
 	AssignValues(env);
