@@ -581,11 +581,12 @@ Gura_ImplementBinaryOperator(Mul, rational, mpf)
 //-----------------------------------------------------------------------------
 Gura_ImplementBinaryOperator(Div, mpz, mpz)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpz::GetEntity(valueLeft);
 	mpf_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -593,11 +594,12 @@ Gura_ImplementBinaryOperator(Div, mpz, mpz)
 
 Gura_ImplementBinaryOperator(Div, mpz, mpq)
 {
+	Signal &sig = env.GetSignal();
 	mpz_class numLeft = Object_mpz::GetEntity(valueLeft);
 	mpq_class numRight = Object_mpq::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -605,11 +607,12 @@ Gura_ImplementBinaryOperator(Div, mpz, mpq)
 
 Gura_ImplementBinaryOperator(Div, mpz, mpf)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpz::GetEntity(valueLeft);
 	mpf_class numRight = Object_mpf::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -617,11 +620,12 @@ Gura_ImplementBinaryOperator(Div, mpz, mpf)
 
 Gura_ImplementBinaryOperator(Div, mpz, number)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpz::GetEntity(valueLeft);
 	double numRight = valueRight.GetDouble();
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -629,11 +633,12 @@ Gura_ImplementBinaryOperator(Div, mpz, number)
 
 Gura_ImplementBinaryOperator(Div, mpz, rational)
 {
+	Signal &sig = env.GetSignal();
 	mpz_class numLeft = Object_mpz::GetEntity(valueLeft);
 	mpq_class numRight = MpqFromRational(valueRight.GetRational());
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -641,11 +646,12 @@ Gura_ImplementBinaryOperator(Div, mpz, rational)
 
 Gura_ImplementBinaryOperator(Div, mpq, mpz)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = Object_mpq::GetEntity(valueLeft);
 	mpz_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -653,11 +659,12 @@ Gura_ImplementBinaryOperator(Div, mpq, mpz)
 
 Gura_ImplementBinaryOperator(Div, mpq, mpq)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = Object_mpq::GetEntity(valueLeft);
 	mpq_class numRight = Object_mpq::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -665,11 +672,12 @@ Gura_ImplementBinaryOperator(Div, mpq, mpq)
 
 Gura_ImplementBinaryOperator(Div, mpq, mpf)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpq::GetEntity(valueLeft);
 	mpf_class numRight = Object_mpf::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -677,11 +685,12 @@ Gura_ImplementBinaryOperator(Div, mpq, mpf)
 
 Gura_ImplementBinaryOperator(Div, mpq, number)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = Object_mpq::GetEntity(valueLeft);
 	double numRight = valueRight.GetDouble();
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -689,11 +698,12 @@ Gura_ImplementBinaryOperator(Div, mpq, number)
 
 Gura_ImplementBinaryOperator(Div, mpq, rational)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = Object_mpq::GetEntity(valueLeft);
 	mpq_class numRight = MpqFromRational(valueRight.GetRational());
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -701,11 +711,12 @@ Gura_ImplementBinaryOperator(Div, mpq, rational)
 
 Gura_ImplementBinaryOperator(Div, mpf, mpz)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpf::GetEntity(valueLeft);
 	mpf_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -713,11 +724,12 @@ Gura_ImplementBinaryOperator(Div, mpf, mpz)
 
 Gura_ImplementBinaryOperator(Div, mpf, mpq)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpf::GetEntity(valueLeft);
 	mpf_class numRight = Object_mpq::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -725,11 +737,12 @@ Gura_ImplementBinaryOperator(Div, mpf, mpq)
 
 Gura_ImplementBinaryOperator(Div, mpf, mpf)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpf::GetEntity(valueLeft);
 	mpf_class numRight = Object_mpf::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -737,11 +750,12 @@ Gura_ImplementBinaryOperator(Div, mpf, mpf)
 
 Gura_ImplementBinaryOperator(Div, mpf, number)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpf::GetEntity(valueLeft);
 	double numRight = valueRight.GetDouble();
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -749,11 +763,12 @@ Gura_ImplementBinaryOperator(Div, mpf, number)
 
 Gura_ImplementBinaryOperator(Div, mpf, rational)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpf::GetEntity(valueLeft);
 	mpq_class numRight = MpqFromRational(valueRight.GetRational());
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -761,11 +776,12 @@ Gura_ImplementBinaryOperator(Div, mpf, rational)
 
 Gura_ImplementBinaryOperator(Div, number, mpz)
 {
+	Signal &sig = env.GetSignal();
 	double numLeft = valueLeft.GetDouble();
 	mpf_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -773,11 +789,12 @@ Gura_ImplementBinaryOperator(Div, number, mpz)
 
 Gura_ImplementBinaryOperator(Div, number, mpq)
 {
+	Signal &sig = env.GetSignal();
 	double numLeft = valueLeft.GetDouble();
 	mpq_class numRight = Object_mpq::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -785,11 +802,12 @@ Gura_ImplementBinaryOperator(Div, number, mpq)
 
 Gura_ImplementBinaryOperator(Div, number, mpf)
 {
+	Signal &sig = env.GetSignal();
 	double numLeft = valueLeft.GetDouble();
 	mpf_class numRight = Object_mpf::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -797,11 +815,12 @@ Gura_ImplementBinaryOperator(Div, number, mpf)
 
 Gura_ImplementBinaryOperator(Div, rational, mpz)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = MpqFromRational(valueLeft.GetRational());
 	mpz_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -809,11 +828,12 @@ Gura_ImplementBinaryOperator(Div, rational, mpz)
 
 Gura_ImplementBinaryOperator(Div, rational, mpq)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = MpqFromRational(valueLeft.GetRational());
 	mpq_class numRight = Object_mpq::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpq_class numResult = numLeft / numRight;
 	return Value(new Object_mpq(numResult));
@@ -821,11 +841,12 @@ Gura_ImplementBinaryOperator(Div, rational, mpq)
 
 Gura_ImplementBinaryOperator(Div, rational, mpf)
 {
+	Signal &sig = env.GetSignal();
 	mpq_class numLeft = MpqFromRational(valueLeft.GetRational());
 	mpf_class numRight = Object_mpf::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpf_class numResult = numLeft / numRight;
 	return Value(new Object_mpf(numResult));
@@ -836,11 +857,12 @@ Gura_ImplementBinaryOperator(Div, rational, mpf)
 //-----------------------------------------------------------------------------
 Gura_ImplementBinaryOperator(Mod, mpz, mpz)
 {
+	Signal &sig = env.GetSignal();
 	mpz_class numLeft = Object_mpz::GetEntity(valueLeft);
 	mpz_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpz_class numResult = numLeft % numRight;
 	return Value(new Object_mpz(numResult));
@@ -848,11 +870,12 @@ Gura_ImplementBinaryOperator(Mod, mpz, mpz)
 
 Gura_ImplementBinaryOperator(Mod, mpz, number)
 {
+	Signal &sig = env.GetSignal();
 	mpz_class numLeft = Object_mpz::GetEntity(valueLeft);
 	double numRight = valueRight.GetDouble();
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpz_class numResult = numLeft % numRight;
 	return Value(new Object_mpz(numResult));
@@ -860,11 +883,12 @@ Gura_ImplementBinaryOperator(Mod, mpz, number)
 
 Gura_ImplementBinaryOperator(Mod, number, mpz)
 {
+	Signal &sig = env.GetSignal();
 	double numLeft = valueLeft.GetDouble();
 	mpz_class numRight = Object_mpz::GetEntity(valueRight);
 	if (numRight == 0) {
 		Operator::SetError_DivideByZero(sig);
-		return Value::Null;
+		return Value::Nil;
 	}
 	mpz_class numResult = numLeft % numRight;
 	return Value(new Object_mpz(numResult));
@@ -2013,9 +2037,10 @@ Gura_ImplementBinaryOperator(Cmp, mpf, number)
 
 Gura_ImplementBinaryOperator(Cmp, mpf, rational)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = Object_mpf::GetEntity(valueLeft);
 	mpf_class numRight = MpfFromRational(sig, valueRight.GetRational());
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	int numResult = ::mpf_cmp(numLeft.get_mpf_t(), numRight.get_mpf_t());
 	return Value(numResult);
 }
@@ -2062,8 +2087,9 @@ Gura_ImplementBinaryOperator(Cmp, rational, mpq)
 
 Gura_ImplementBinaryOperator(Cmp, rational, mpf)
 {
+	Signal &sig = env.GetSignal();
 	mpf_class numLeft = MpfFromRational(sig, valueLeft.GetRational());
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	mpf_class numRight = Object_mpf::GetEntity(valueRight);
 	int numResult = ::mpf_cmp(numLeft.get_mpf_t(), numRight.get_mpf_t());
 	return Value(numResult);
@@ -2175,7 +2201,7 @@ Gura_ImplementBinaryOperator(Shr, mpz, number)
 //-----------------------------------------------------------------------------
 // unary operator ..
 //-----------------------------------------------------------------------------
-Gura_ImplementUnaryOperatorSuffix(SeqInf, mpz)
+Gura_ImplementUnaryOperator(SeqInf, mpz)
 {
 	mpz_class numBegin = Object_mpz::GetEntity(value);
 	return Value(new Object_iterator(env, new Iterator_GmpSeqInf(numBegin)));
@@ -2470,7 +2496,7 @@ void AssignOperators(Environment &env)
 	// binary operator >>
 	Gura_AssignBinaryOperator(Shr, mpz, number);
 	// unary operator ..
-	Gura_AssignUnaryOperatorSuffix(SeqInf, mpz);
+	Gura_AssignUnaryOperator(SeqInf, mpz);
 	// binary operator ..
 	Gura_AssignBinaryOperator(Seq, mpz, mpz);
 }
