@@ -12,16 +12,18 @@ Gura_BeginModuleScope(jpeg)
 Gura_DeclareUserClass(exif);
 
 class Object_exif : public Object {
+public:
+	struct Strip {
+		bool validFlag;
+		size_t width, height;
+	};
 private:
 	bool _bigendianFlag;
 	AutoPtr<Object_ifd> _pObj0thIFD;
-	AutoPtr<Object_ifd> _pObj1stIFD;				// this may be NULL
-	AutoPtr<Object_binary> _pObjBinaryThumbnail;	// this may be NULL
-	AutoPtr<Object_image> _pObjImageThumbnail;		// this may be NULL
-	struct {
-		bool validFlag;
-		size_t width, height;
-	} _strip;
+	AutoPtr<Object_ifd> _pObj1stIFD;				// this may be nullptr
+	AutoPtr<Object_binary> _pObjBinaryThumbnail;	// this may be nullptr
+	AutoPtr<Object_image> _pObjImageThumbnail;		// this may be nullptr
+	Strip _strip;
 public:
 	Gura_DeclareObjectAccessor(exif)
 public:
@@ -29,13 +31,17 @@ public:
 	virtual ~Object_exif();
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual Value IndexGet(Environment &env, Signal sig, const Value &valueIdx);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-								const SymbolSet &attrs, bool &evaluatedFlag);
+	virtual Value IndexGet(Environment &env, const Value &valueIdx);
+	inline const Strip &GetStrip() const { return _strip; }
+	inline bool GetBigendianFlag() const { return _bigendianFlag; }
 	inline Object_ifd *GetObj0thIFD() { return _pObj0thIFD.get(); }
 	inline Object_ifd *GetObj1stIFD() { return _pObj1stIFD.get(); }
-	static Object_exif *ReadStream(Environment &env, Signal sig, Stream &stream);
+	inline Object_binary *GetObjBinaryThumbnail() { return _pObjBinaryThumbnail.get(); }
+	inline Object_image *GetObjImageThumbnail() { return _pObjImageThumbnail.get(); }
+	inline void SetObjImageThumbnail(Object_image *pObjImageThumbnail) {
+		_pObjImageThumbnail.reset(pObjImageThumbnail);
+	}
+	static Object_exif *ReadStream(Environment &env, Stream &stream);
 };
 
 Gura_EndModuleScope(jpeg)
