@@ -5,8 +5,6 @@
 
 Gura_BeginModuleBody(markdown)
 
-AutoPtr<Function> g_pFunc_Presenter;
-
 //-----------------------------------------------------------------------------
 // Item
 //-----------------------------------------------------------------------------
@@ -68,33 +66,33 @@ const char *Item::GetTypeName() const
 	return "?";
 }
 
-void Item::Print(Signal sig, Stream &stream, int indentLevel) const
+void Item::Print(Signal &sig, Stream &stream, int indentLevel) const
 {
 	for (int i = 0; i < indentLevel; i++) stream.Print(sig, "  ");
 	stream.Print(sig, "<");
 	stream.Print(sig, GetTypeName());
-	if (_pURL.get() != NULL) {
+	if (_pURL.get() != nullptr) {
 		stream.Print(sig, " url='");
 		stream.Print(sig, _pURL->c_str());
 		stream.Print(sig, "'");
 	}
-	if (_pTitle.get() != NULL) {
+	if (_pTitle.get() != nullptr) {
 		stream.Print(sig, " title='");
 		stream.Print(sig, _pTitle->c_str());
 		stream.Print(sig, "'");
 	}
-	if (_pRefId.get() != NULL) {
+	if (_pRefId.get() != nullptr) {
 		stream.Print(sig, " refid='");
 		stream.Print(sig, _pRefId->c_str());
 		stream.Print(sig, "'");
 	}
-	if (_pAttrs.get() != NULL) {
+	if (_pAttrs.get() != nullptr) {
 		stream.Print(sig, " attrs='");
 		stream.Print(sig, _pAttrs->c_str());
 		stream.Print(sig, "'");
 	}
 	stream.Print(sig, ">");
-	if (_pText.get() != NULL) {
+	if (_pText.get() != nullptr) {
 		stream.Print(sig, "'");
 		stream.Print(sig, _pText->c_str());
 		stream.Print(sig, "'");
@@ -111,15 +109,15 @@ void Item::Print(Signal sig, Stream &stream, int indentLevel) const
 //-----------------------------------------------------------------------------
 Item *ItemList::FindByRefId(const char *refId) const
 {
-	if (refId == NULL) return NULL;
+	if (refId == nullptr) return nullptr;
 	foreach_const (ItemList, ppItem, *this) {
 		Item *pItem = *ppItem;
-		if (pItem->GetRefId() != NULL &&
+		if (pItem->GetRefId() != nullptr &&
 					::strcasecmp(pItem->GetRefId(), refId) == 0) {
 			return pItem;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 Item *ItemList::FindByType(Item::Type type) const
@@ -128,10 +126,10 @@ Item *ItemList::FindByType(Item::Type type) const
 		Item *pItem = *ppItem;
 		if (pItem->GetType() == type) return pItem;
 	}
-	return NULL;
+	return nullptr;
 }
 
-void ItemList::Print(Signal sig, Stream &stream, int indentLevel) const
+void ItemList::Print(Signal &sig, Stream &stream, int indentLevel) const
 {
 	foreach_const (ItemList, ppItem, *this) {
 		const Item *pItem = *ppItem;
@@ -218,7 +216,7 @@ Document::Document() : _cntRef(1), _resolvedFlag(false), _decoPrecedingFlag(fals
 	_itemStack.push_back(_pItemRoot.get());
 }
 
-bool Document::ParseStream(Signal sig, SimpleStream &stream)
+bool Document::ParseStream(Signal &sig, SimpleStream &stream)
 {
 	enum {
 		STAT_FirstRowTop,
@@ -391,13 +389,13 @@ bool Document::ParseStream(Signal sig, SimpleStream &stream)
 	return true;
 }
 
-bool Document::ParseString(Signal sig, const char *text)
+bool Document::ParseString(Signal &sig, const char *text)
 {
 	SimpleStream_CStringReader stream(text);
 	return ParseStream(sig, stream);
 }
 
-bool Document::_ParseString(Signal sig, String text)
+bool Document::_ParseString(Signal &sig, String text)
 {
 	foreach (String, p, text) {
 		if (!ParseChar(sig, *p)) return false;
@@ -418,17 +416,17 @@ void Document::ResolveReference()
 		Item *pItemLink = *ppItemLink;
 		const char *refId = pItemLink->GetRefId();
 		Item *pItemRef = _pItemRefereeOwner->FindByRefId(refId);
-		if (pItemRef != NULL) {
+		if (pItemRef != nullptr) {
 			const char *url = pItemRef->GetURL();
 			const char *title = pItemRef->GetTitle();
-			if (url != NULL) pItemLink->SetURL(url);
-			if (title != NULL) pItemLink->SetTitle(title);
+			if (url != nullptr) pItemLink->SetURL(url);
+			if (title != nullptr) pItemLink->SetTitle(title);
 		}
 	}
 	_resolvedFlag = true;
 }
 
-bool Document::ParseChar(Signal sig, char ch)
+bool Document::ParseChar(Signal &sig, char ch)
 {
 	Gura_BeginPushbackRegionEx(char, 16, ch);
 	switch (_stat) {
@@ -454,7 +452,7 @@ bool Document::ParseChar(Signal sig, char ch)
 			_indentLevel += WIDTH_Tab;
 		} else if (_indentLevel >= GetIndentLevelForCodeBlock()) {
 			Gura_PushbackEx(ch);
-			BeginCodeBlock(NULL);
+			BeginCodeBlock(nullptr);
 			_stat = STAT_CodeBlock;
 		} else if (ch == '>') {
 			_indentLevel = -1;
@@ -957,7 +955,7 @@ bool Document::ParseChar(Signal sig, char ch)
 			_stat = STAT_LineTop;
 		} else if (_indentLevel >= GetIndentLevelForCodeBlock()) {
 			Gura_PushbackEx(ch);
-			BeginCodeBlock(NULL);
+			BeginCodeBlock(nullptr);
 			_stat = STAT_CodeBlock;
 		} else if (ch == '*') {
 			UpdateIndentLevelItemBody(_indentLevel);
@@ -1322,7 +1320,7 @@ bool Document::ParseChar(Signal sig, char ch)
 			} else if (IsWithinTag()) {
 				_text += ch;
 			} else {
-				if (EndsWith(_text.c_str(), "  ", false) != NULL) {
+				if (EndsWith(_text.c_str(), "  ", false) != nullptr) {
 					FlushText(Item::TYPE_Text, false, true);
 					Item *pItem = new Item(Item::TYPE_LineBreak);
 					_pItemOwner->push_back(pItem);
@@ -2289,7 +2287,7 @@ void Document::BeginCodeBlock(const char *textInit)
 {
 	FlushItem(Item::TYPE_Paragraph, false, false);
 	for (int i = 0; i < _indentLevel - GetIndentLevelForCodeBlock(); i++) _text += ' ';
-	if (textInit != NULL) _text += textInit;
+	if (textInit != nullptr) _text += textInit;
 	do {
 		Item *pItemParent = _itemStack.back();
 		Item *pItem = new Item(Item::TYPE_CodeBlock, new ItemOwner(), _indentLevel);
@@ -2699,18 +2697,19 @@ bool Document::IsEndTag(const char *text, String &tagName)
 //-----------------------------------------------------------------------------
 Object *Object_document::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_document::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
+bool Object_document::DoDirProp(Environment &env, SymbolSet &symbols)
 {
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
+	Signal &sig = GetSignal();
+	if (!Object::DoDirProp(env, symbols)) return false;
 	symbols.insert(Gura_UserSymbol(refs));
 	symbols.insert(Gura_UserSymbol(root));
 	return true;
 }
 
-Value Object_document::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
+Value Object_document::DoGetProp(Environment &env, const Symbol *pSymbol,
 							const SymbolSet &attrs, bool &evaluatedFlag)
 {
 	evaluatedFlag = true;
@@ -2723,13 +2722,13 @@ Value Object_document::DoGetProp(Environment &env, Signal sig, const Symbol *pSy
 		return Value(new Object_item(_pDocument->GetItemRoot()->Reference()));
 	}
 	evaluatedFlag = false;
-	return Value::Null;
+	return Value::Nil;
 }
 
-Value Object_document::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
+Value Object_document::DoSetProp(Environment &env, const Symbol *pSymbol, const Value &value,
 							const SymbolSet &attrs, bool &evaluatedFlag)
 {
-	return Value::Null;
+	return Value::Nil;
 }
 
 String Object_document::ToString(bool exprFlag)
@@ -2740,6 +2739,35 @@ String Object_document::ToString(bool exprFlag)
 	return rtn;
 }
 
+//-----------------------------------------------------------------------------
+// Constructor for markdown.document
+//-----------------------------------------------------------------------------
+// markdown.document(stream?:stream:r) {block?}
+Gura_DeclareFunction(document)
+{
+	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
+	DeclareArg(env, "stream", VTYPE_stream, OCCUR_ZeroOrOnce, FLAG_Read);
+	SetClassToConstruct(Gura_UserClass(document));
+	DeclareBlock(OCCUR_ZeroOrOnce);
+	AddHelp(
+		Gura_Symbol(en),
+		"Returns an instance of `markdown.document`.\n"
+		"If `stream` is specified, the content of the instance shall be initialized\n"
+		"with the result of parsing the stream.\n"
+	);
+}
+
+Gura_ImplementFunction(document)
+{
+	Signal &sig = env.GetSignal();
+	AutoPtr<Document> pDocument(new Document());
+	if (arg.Is_stream(0)) {
+		if (!pDocument->ParseStream(sig, arg.GetStream(0))) return Value::Nil;
+	}
+	AutoPtr<Object_document> pObj(new Object_document(pDocument.release()));
+	return ReturnValue(env, arg, Value(pObj.release()));
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for markdown.document
 //-----------------------------------------------------------------------------
@@ -2749,15 +2777,16 @@ Gura_DeclareMethod(document, parse)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "str", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Parses a Markdown text in a string.");
 }
 
 Gura_ImplementMethod(document, parse)
 {
-	Document *pDocument = Object_document::GetThisObj(args)->GetDocument();
-	pDocument->ParseString(sig, args.GetString(0));
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Document *pDocument = Object_document::GetObjectThis(arg)->GetDocument();
+	pDocument->ParseString(sig, arg.GetString(0));
+	return Value::Nil;
 }
 
 // markdown.document#read(stream:stream:r):void
@@ -2766,15 +2795,16 @@ Gura_DeclareMethod(document, read)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Read);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Parses a Markdown text from a stream.");
 }
 
 Gura_ImplementMethod(document, read)
 {
-	Document *pDocument = Object_document::GetThisObj(args)->GetDocument();
-	pDocument->ParseStream(sig, args.GetStream(0));
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Document *pDocument = Object_document::GetObjectThis(arg)->GetDocument();
+	pDocument->ParseStream(sig, arg.GetStream(0));
+	return Value::Nil;
 }
 
 //-----------------------------------------------------------------------------
@@ -2782,6 +2812,7 @@ Gura_ImplementMethod(document, read)
 //-----------------------------------------------------------------------------
 Gura_ImplementUserClass(document)
 {
+	Gura_AssignFunction(document);
 	Gura_AssignMethod(document, parse);
 	Gura_AssignMethod(document, read);
 }
@@ -2791,12 +2822,13 @@ Gura_ImplementUserClass(document)
 //-----------------------------------------------------------------------------
 Object *Object_item::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_item::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
+bool Object_item::DoDirProp(Environment &env, SymbolSet &symbols)
 {
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
+	Signal &sig = GetSignal();
+	if (!Object::DoDirProp(env, symbols)) return false;
 	symbols.insert(Gura_UserSymbol(type));
 	symbols.insert(Gura_UserSymbol(text));
 	symbols.insert(Gura_UserSymbol(children));
@@ -2807,7 +2839,7 @@ bool Object_item::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 	return true;
 }
 
-Value Object_item::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
+Value Object_item::DoGetProp(Environment &env, const Symbol *pSymbol,
 							const SymbolSet &attrs, bool &evaluatedFlag)
 {
 	evaluatedFlag = true;
@@ -2815,24 +2847,24 @@ Value Object_item::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol
 		return Value(Symbol::Add(_pItem->GetTypeName()));
 	} else if (pSymbol->IsIdentical(Gura_UserSymbol(text))) {
 		const char *text = _pItem->GetText();
-		if (text == NULL) return Value::Null;
+		if (text == nullptr) return Value::Nil;
 		return Value(text);
 	} else if (pSymbol->IsIdentical(Gura_UserSymbol(children))) {
 		const ItemOwner *pItemOwner = _pItem->GetItemOwner();
-		if (pItemOwner == NULL) return Value::Null;
+		if (pItemOwner == nullptr) return Value::Nil;
 		Iterator *pIterator = new Iterator_item(pItemOwner->Reference());
 		return Value(new Object_iterator(env, pIterator));
 	} else if (pSymbol->IsIdentical(Gura_UserSymbol(url))) {
 		const char *url = _pItem->GetURL();
-		if (url == NULL) return Value::Null;
+		if (url == nullptr) return Value::Nil;
 		return Value(url);
 	} else if (pSymbol->IsIdentical(Gura_UserSymbol(title))) {
 		const char *title = _pItem->GetTitle();
-		if (title == NULL) return Value::Null;
+		if (title == nullptr) return Value::Nil;
 		return Value(title);
 	} else if (pSymbol->IsIdentical(Gura_UserSymbol(attrs))) {
 		const char *attrs = _pItem->GetAttrs();
-		if (attrs == NULL) return Value::Null;
+		if (attrs == nullptr) return Value::Nil;
 		return Value(attrs);
 	} else if (pSymbol->IsIdentical(Gura_UserSymbol(align))) {
 		Align align = _pItem->GetAlign();
@@ -2842,13 +2874,13 @@ Value Object_item::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol
 			(align == ALIGN_Right)? Gura_Symbol(right) : Gura_Symbol(none));
 	}
 	evaluatedFlag = false;
-	return Value::Null;
+	return Value::Nil;
 }
 
-Value Object_item::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
+Value Object_item::DoSetProp(Environment &env, const Symbol *pSymbol, const Value &value,
 							const SymbolSet &attrs, bool &evaluatedFlag)
 {
-	return Value::Null;
+	return Value::Nil;
 }
 
 String Object_item::ToString(bool exprFlag)
@@ -2869,17 +2901,18 @@ Gura_DeclareMethod(item, print)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "indent", VTYPE_number, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Prints structured content of the item.\n"
 		"Argument `indent` specifies an indentation level and is set to zero when omitted.\n");
 }
 
 Gura_ImplementMethod(item, print)
 {
-	Item *pItem = Object_item::GetThisObj(args)->GetItem();
-	int indentLevel = args.Is_number(0)? args.GetInt(0) : 0;
+	Signal &sig = env.GetSignal();
+	Item *pItem = Object_item::GetObjectThis(arg)->GetItem();
+	int indentLevel = arg.Is_number(0)? arg.GetInt(0) : 0;
 	pItem->Print(sig, *env.GetConsole(), indentLevel);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //-----------------------------------------------------------------------------
@@ -2887,68 +2920,20 @@ Gura_ImplementMethod(item, print)
 //-----------------------------------------------------------------------------
 Gura_ImplementUserClass(item)
 {
+	Gura_AssignValue(item, Value(Reference()));
 	Gura_AssignMethod(item, print);
 }
 
-//-----------------------------------------------------------------------------
-// Gura module functions: markdown
-//-----------------------------------------------------------------------------
-// markdown.document(stream?:stream:r) {block?}
-Gura_DeclareFunction(document)
-{
-	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
-	DeclareArg(env, "stream", VTYPE_stream, OCCUR_ZeroOrOnce, FLAG_Read);
-	SetClassToConstruct(Gura_UserClass(document));
-	DeclareBlock(OCCUR_ZeroOrOnce);
-	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"Returns an instance of `markdown.document`.\n"
-		"If `stream` is specified, the content of the instance shall be initialized\n"
-		"with the result of parsing the stream.\n"
-	);
-}
-
-Gura_ImplementFunction(document)
-{
-	AutoPtr<Document> pDocument(new Document());
-	if (args.Is_stream(0)) {
-		if (!pDocument->ParseStream(sig, args.GetStream(0))) return Value::Null;
-	}
-	AutoPtr<Object_document> pObj(new Object_document(pDocument.release()));
-	return ReturnValue(env, sig, args, Value(pObj.release()));
-}
-
-// markdown.setpresenter():void {block}
-Gura_DeclareFunction(setpresenter)
-{
-	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
-	DeclareBlock(OCCUR_Once);
-	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"Sets a presentation procedure that shows helps written in Markdown format.\n"
-		"The procedure is written in the function's block that takes block parameters:\n"
-		"`|title:string, doc:markdown.document|`.\n"
-	);
-}
-
-Gura_ImplementFunction(setpresenter)
-{
-	const Function *pFuncBlock =
-						args.GetBlockFunc(env, sig, GetSymbolForBlock());
-	if (sig.IsSignalled()) return Value::Null;
-	g_pFunc_Presenter.reset(pFuncBlock->Reference());
-	return Value::Null;
-}
-
 //-----------------------------------------------------------------------------
 // Implementation of operators
 //-----------------------------------------------------------------------------
 // operator <<
 Gura_ImplementBinaryOperator(Shl, document, string)
 {
+	Signal &sig = env.GetSignal();
 	Document *pDocument = Object_document::GetObject(valueLeft)->GetDocument();
 	const char *text = valueRight.GetString();
-	if (!pDocument->ParseString(sig, text)) return Value::Null;
+	if (!pDocument->ParseString(sig, text)) return Value::Nil;
 	return valueLeft;
 }
 
@@ -2956,16 +2941,16 @@ Gura_ImplementBinaryOperator(Shl, document, string)
 // Iterator_item
 //-----------------------------------------------------------------------------
 Iterator_item::Iterator_item(ItemOwner *pItemOwner) :
-						Iterator(false), _idxItem(0), _pItemOwner(pItemOwner)
+						Iterator(Finite), _idxItem(0), _pItemOwner(pItemOwner)
 {
 }
 
 Iterator *Iterator_item::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_item::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_item::DoNext(Environment &env, Value &value)
 {
 	if (_idxItem < _pItemOwner->size()) {
 		Item *pItem = (*_pItemOwner)[_idxItem++];
@@ -2988,37 +2973,13 @@ void Iterator_item::GatherFollower(Environment::Frame *pFrame, EnvironmentSet &e
 }
 
 //-----------------------------------------------------------------------------
-// HelpPresenter_markdown
+// Module Entries
 //-----------------------------------------------------------------------------
-bool HelpPresenter_markdown::DoPresent(Environment &env, Signal sig,
-									const char *title, const Help *pHelp) const
+Gura_ModuleValidate()
 {
-	if (g_pFunc_Presenter.IsNull()) {
-		sig.SetError(ERR_FormatError, "presenter function is not registered");
-		return false;
-	}
-	//ValueList valListArg;
-	AutoPtr<Args> pArgs(new Args());
-	if (title == NULL) {
-		pArgs->AddValue(Value::Null);
-	} else {
-		pArgs->AddValue(Value(title));
-	}
-	if (pHelp == NULL) {
-		pArgs->AddValue(Value::Null);
-	} else {
-		AutoPtr<Document> pDocument(new Document());
-		SimpleStream_CStringReader streamSrc(pHelp->GetText());
-		if (!pDocument->ParseStream(sig, streamSrc)) return false;
-		pArgs->AddValue(Value(new Object_document(pDocument->Reference())));
-	}
-	g_pFunc_Presenter->Eval(env, sig, *pArgs);
-	return !sig.IsSignalled();
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-//-----------------------------------------------------------------------------
-// Module entry
-//-----------------------------------------------------------------------------
 Gura_ModuleEntry()
 {
 	// symbol realization
@@ -3034,23 +2995,16 @@ Gura_ModuleEntry()
 	// class realization
 	Gura_RealizeUserClass(document, env.LookupClass(VTYPE_object));
 	Gura_RealizeUserClass(item, env.LookupClass(VTYPE_object));
+	// class preparation
 	Gura_PrepareUserClass(document);
 	Gura_PrepareUserClass(item);
-	// class reference assignment
-	Gura_AssignValue(item, Value(Gura_UserClass(item)->Reference()));
-	// function assignment
-	Gura_AssignFunction(document);
-	Gura_AssignFunction(setpresenter);
 	// operator assignment
 	Gura_AssignBinaryOperator(Shl, document, string);
-	// registoration of HelpPresenter
-	HelpPresenter::Register(env, new HelpPresenter_markdown());
 	return true;
 }
 
 Gura_ModuleTerminate()
 {
-	g_pFunc_Presenter.reset(NULL);
 }
 
 Gura_EndModuleBody(markdown, markdown)
