@@ -35,7 +35,7 @@ void MML::Reset()
 	_timeStampTail		= 0;
 	_chOctaveUp			= '<';
 	_chOctaveDown		= '>';
-	_pMIDIEventLast		= NULL;
+	_pMIDIEventLast		= nullptr;
 }
 
 void MML::UpdateTimeStamp(Track *pTrack)
@@ -46,12 +46,12 @@ void MML::UpdateTimeStamp(Track *pTrack)
 	}
 }
 
-bool MML::ParseStream(Signal sig, Sequence &sequence, SimpleStream &stream)
+bool MML::ParseStream(Signal &sig, Sequence &sequence, SimpleStream &stream)
 {
 	bool rtn = true;
 	TrackOwner &trackOwner = sequence.GetTrackOwner();
 	for (size_t iTrack = 0; ; iTrack++) {
-		Track *pTrack = NULL;
+		Track *pTrack = nullptr;
 		if (iTrack < trackOwner.size()) {
 			pTrack = trackOwner[iTrack];
 		} else {
@@ -72,13 +72,13 @@ bool MML::ParseStream(Signal sig, Sequence &sequence, SimpleStream &stream)
 	return rtn;
 }
 
-bool MML::ParseString(Signal sig, Sequence &sequence, const char *str)
+bool MML::ParseString(Signal &sig, Sequence &sequence, const char *str)
 {
 	SimpleStream_CStringReader stream(str);
 	return ParseStream(sig, sequence, stream);
 }
 
-MML::Result MML::ParseStream(Signal sig, Track *pTrack, SimpleStream &stream)
+MML::Result MML::ParseStream(Signal &sig, Track *pTrack, SimpleStream &stream)
 {
 	Result result = RSLT_None;
 	pTrack->RequestEndOfTrack();
@@ -95,13 +95,13 @@ MML::Result MML::ParseStream(Signal sig, Track *pTrack, SimpleStream &stream)
 	return result;
 }
 
-MML::Result MML::ParseString(Signal sig, Track *pTrack, const char *str)
+MML::Result MML::ParseString(Signal &sig, Track *pTrack, const char *str)
 {
 	SimpleStream_CStringReader stream(str);
 	return ParseStream(sig, pTrack, stream);
 }
 
-MML::Result MML::FeedChar(Signal sig, Track *pTrack, int ch)
+MML::Result MML::FeedChar(Signal &sig, Track *pTrack, int ch)
 {
 	Result result = RSLT_None;
 	if (_stateMachineStack.empty()) {
@@ -455,7 +455,7 @@ MML::Result MML::FeedChar(Signal sig, Track *pTrack, int ch)
 		ULong timeStampTail = _timeStampHead + deltaTime;
 		ULong timeStampGate = _timeStampHead + deltaTime * _gate / MAX_GATE;
 		bool joinedFlag = false;
-		if (_joinFlag && _pMIDIEventLast != NULL) {
+		if (_joinFlag && _pMIDIEventLast != nullptr) {
 			if (_pMIDIEventLast->GetNote() == note) {
 				joinedFlag = true;
 				_pMIDIEventLast->SetTimeStamp(timeStampGate);
