@@ -75,17 +75,17 @@ SoundFont::SoundFont(Stream *pStream) : _pStream(pStream)
 
 void SoundFont::Clear()
 {
-	_INFO.p_ifil.reset(NULL);	// mandatory
-	_INFO.p_isng.reset(NULL);	// mandatory
-	_INFO.p_INAM.reset(NULL);	// mandatory
-	_INFO.p_irom.reset(NULL);	// optional
-	_INFO.p_iver.reset(NULL);	// optional
-	_INFO.p_ICRD.reset(NULL);	// optional
-	_INFO.p_IENG.reset(NULL);	// optional
-	_INFO.p_IPRD.reset(NULL);	// optional
-	_INFO.p_ICOP.reset(NULL);	// optional
-	_INFO.p_ICMT.reset(NULL);	// optional
-	_INFO.p_ISFT.reset(NULL);	// optional
+	_INFO.p_ifil.reset(nullptr);	// mandatory
+	_INFO.p_isng.reset(nullptr);	// mandatory
+	_INFO.p_INAM.reset(nullptr);	// mandatory
+	_INFO.p_irom.reset(nullptr);	// optional
+	_INFO.p_iver.reset(nullptr);	// optional
+	_INFO.p_ICRD.reset(nullptr);	// optional
+	_INFO.p_IENG.reset(nullptr);	// optional
+	_INFO.p_IPRD.reset(nullptr);	// optional
+	_INFO.p_ICOP.reset(nullptr);	// optional
+	_INFO.p_ICMT.reset(nullptr);	// optional
+	_INFO.p_ISFT.reset(nullptr);	// optional
 	_offsetSdta = 0;
 	_pdta.phdrs.Clear();
 	_pdta.pbags.Clear();
@@ -98,7 +98,7 @@ void SoundFont::Clear()
 	_pdta.shdrs.Clear();
 }
 
-bool SoundFont::ReadChunks(Environment &env, Signal sig)
+bool SoundFont::ReadChunks(Environment &env, Signal &sig)
 {
 	ChunkHdr chunkHdr;
 	size_t bytesRead = _pStream->Read(sig, &chunkHdr, ChunkHdr::Size);
@@ -106,8 +106,8 @@ bool SoundFont::ReadChunks(Environment &env, Signal sig)
 		sig.SetError(ERR_FormatError, "invalid SF2 format");
 		return false;
 	}
-	ULong ckID = Gura_UnpackULong(chunkHdr.ckID);
-	ULong ckSize = Gura_UnpackULong(chunkHdr.ckSize);
+	UInt32 ckID = Gura_UnpackUInt32(chunkHdr.ckID);
+	UInt32 ckSize = Gura_UnpackUInt32(chunkHdr.ckSize);
 	if (ckID != CKID_RIFF) {
 		sig.SetError(ERR_FormatError, "can't find RIFF chunk");
 		return false;
@@ -124,8 +124,8 @@ bool SoundFont::ReadChunks(Environment &env, Signal sig)
 	}
 	ckSize -= 4;
 	if (!ReadSubChunk(env, sig, static_cast<size_t>(ckSize))) return false;
-	if (_INFO.p_ifil.get() == NULL ||
-				_INFO.p_isng.get() == NULL || _INFO.p_INAM.get() == NULL) {
+	if (_INFO.p_ifil.get() == nullptr ||
+				_INFO.p_isng.get() == nullptr || _INFO.p_INAM.get() == nullptr) {
 		sig.SetError(ERR_FormatError, "necessary chunk doesn't exist");
 		return false;
 	}
@@ -166,22 +166,22 @@ bool SoundFont::ReadChunks(Environment &env, Signal sig)
 }
 
 const SoundFont::sfPresetHeader *SoundFont::LookupPresetHeader(
-										UShort wPreset, UShort wBank) const
+										UInt16 wPreset, UInt16 wBank) const
 {
 	foreach_const (sfPresetHeaderOwner, ppPresetHeader, _pdta.phdrs) {
 		const sfPresetHeader *pPresetHeader = *ppPresetHeader;
 		if (pPresetHeader->IsMatched(wPreset, wBank)) return pPresetHeader;
 	}
-	return NULL;
+	return nullptr;
 }
 
-SoundFont::Synthesizer *SoundFont::CreateSynthesizer(Signal sig,
-					UShort wPreset, UShort wBank, UChar key, UChar velocity) const
+SoundFont::Synthesizer *SoundFont::CreateSynthesizer(Signal &sig,
+					UInt16 wPreset, UInt16 wBank, UChar key, UChar velocity) const
 {
 	const sfPresetHeader *pPresetHeader = LookupPresetHeader(wPreset, wBank);
-	if (pPresetHeader == NULL) {
+	if (pPresetHeader == nullptr) {
 		sig.SetError(ERR_IndexError, "can't find specified PresetHeader");
-		return NULL;
+		return nullptr;
 	}
 	AutoPtr<Synthesizer> pSynthesizer(new Synthesizer());
 	foreach_const (sfPresetBagOwner, ppPresetBag, pPresetHeader->GetPresetBagOwner()) {
@@ -195,7 +195,7 @@ SoundFont::Synthesizer *SoundFont::CreateSynthesizer(Signal sig,
 			pSynthesizer->GetModOwner().push_back(pMod->Reference());
 		}
 		const sfInst *pInst = pPresetBag->GetInst();
-		if (pInst == NULL) continue;
+		if (pInst == nullptr) continue;
 		foreach_const (sfInstBagOwner, ppInstBag, pInst->GetInstBagOwner()) {
 			const sfInstBag *pInstBag = *ppInstBag;
 			if (!pInstBag->IsMatched(key, velocity)) continue;
@@ -211,13 +211,13 @@ SoundFont::Synthesizer *SoundFont::CreateSynthesizer(Signal sig,
 		}
 	}
 	do {
-		UShort wSampleNdx = pSynthesizer->GetProps().sampleID;
+		UInt16 wSampleNdx = pSynthesizer->GetProps().sampleID;
 		if (static_cast<size_t>(wSampleNdx) >= _pdta.shdrs.size()) {
 			sig.SetError(ERR_FormatError, "invalid index value in sfGen sampleID");
-			return NULL;
+			return nullptr;
 		}
 		sfSample *pSample = _pdta.shdrs[wSampleNdx];
-		if (!pSample->CreateAudio(sig, *_pStream, _offsetSdta)) return NULL;
+		if (!pSample->CreateAudio(sig, *_pStream, _offsetSdta)) return nullptr;
 		pSynthesizer->SetSample(sfSample::Reference(pSample));
 	} while (0);
 	return pSynthesizer.release();
@@ -225,23 +225,23 @@ SoundFont::Synthesizer *SoundFont::CreateSynthesizer(Signal sig,
 
 void SoundFont::Print() const
 {
-	if (_INFO.p_ifil.get() != NULL) {
+	if (_INFO.p_ifil.get() != nullptr) {
 		::printf("ifil ");
 		_INFO.p_ifil->Print(0);
 	}
-	if (_INFO.p_isng.get() != NULL) ::printf("isng \"%s\"\n", _INFO.p_isng->c_str());
-	if (_INFO.p_INAM.get() != NULL) ::printf("INAM \"%s\"\n", _INFO.p_INAM->c_str());
-	if (_INFO.p_irom.get() != NULL) ::printf("irom \"%s\"\n", _INFO.p_irom->c_str());
-	if (_INFO.p_iver.get() != NULL) {
+	if (_INFO.p_isng.get() != nullptr) ::printf("isng \"%s\"\n", _INFO.p_isng->c_str());
+	if (_INFO.p_INAM.get() != nullptr) ::printf("INAM \"%s\"\n", _INFO.p_INAM->c_str());
+	if (_INFO.p_irom.get() != nullptr) ::printf("irom \"%s\"\n", _INFO.p_irom->c_str());
+	if (_INFO.p_iver.get() != nullptr) {
 		::printf("<iver> ");
 		_INFO.p_iver->Print(0);
 	}
-	if (_INFO.p_ICRD.get() != NULL) ::printf("ICRD \"%s\"\n", _INFO.p_ICRD->c_str());
-	if (_INFO.p_IENG.get() != NULL) ::printf("IENG \"%s\"\n", _INFO.p_IENG->c_str());
-	if (_INFO.p_IPRD.get() != NULL) ::printf("IPRD \"%s\"\n", _INFO.p_IPRD->c_str());
-	if (_INFO.p_ICOP.get() != NULL) ::printf("ICOP \"%s\"\n", _INFO.p_ICOP->c_str());
-	if (_INFO.p_ICMT.get() != NULL) ::printf("ICMT \"%s\"\n", _INFO.p_ICMT->c_str());
-	if (_INFO.p_ISFT.get() != NULL) ::printf("ISFT \"%s\"\n", _INFO.p_ISFT->c_str());
+	if (_INFO.p_ICRD.get() != nullptr) ::printf("ICRD \"%s\"\n", _INFO.p_ICRD->c_str());
+	if (_INFO.p_IENG.get() != nullptr) ::printf("IENG \"%s\"\n", _INFO.p_IENG->c_str());
+	if (_INFO.p_IPRD.get() != nullptr) ::printf("IPRD \"%s\"\n", _INFO.p_IPRD->c_str());
+	if (_INFO.p_ICOP.get() != nullptr) ::printf("ICOP \"%s\"\n", _INFO.p_ICOP->c_str());
+	if (_INFO.p_ICMT.get() != nullptr) ::printf("ICMT \"%s\"\n", _INFO.p_ICMT->c_str());
+	if (_INFO.p_ISFT.get() != nullptr) ::printf("ISFT \"%s\"\n", _INFO.p_ISFT->c_str());
 	::printf("phdr[%d] : sfPresetHeader\n", _pdta.phdrs.size());
 	_pdta.phdrs.Print(0);
 }
@@ -252,7 +252,7 @@ const char *SoundFont::SFGeneratorToName(SFGenerator generator)
 	return "unknown";
 }
 
-bool SoundFont::ReadSubChunk(Environment &env, Signal sig, size_t bytes)
+bool SoundFont::ReadSubChunk(Environment &env, Signal &sig, size_t bytes)
 {
 	size_t bytesRest = (bytes + 1) / 2 * 2;
 	while (bytesRest > 0) {
@@ -265,9 +265,9 @@ bool SoundFont::ReadSubChunk(Environment &env, Signal sig, size_t bytes)
 			return false;
 		}
 		bytesRest -= bytesRead;
-		ULong ckID = Gura_UnpackULong(chunkHdr.ckID);
-		ULong ckSize = Gura_UnpackULong(chunkHdr.ckSize);
-		ULong ckSizeAlign = (ckSize + 1) / 2 * 2;
+		UInt32 ckID = Gura_UnpackUInt32(chunkHdr.ckID);
+		UInt32 ckSize = Gura_UnpackUInt32(chunkHdr.ckSize);
+		UInt32 ckSizeAlign = (ckSize + 1) / 2 * 2;
 		switch (ckID) {
 		case CKID_LIST: {
 			char listHdr[4];
@@ -450,7 +450,7 @@ bool SoundFont::ReadSubChunk(Environment &env, Signal sig, size_t bytes)
 	return true;
 }
 
-bool SoundFont::ReadStruct(Environment &env, Signal sig,
+bool SoundFont::ReadStruct(Environment &env, Signal &sig,
 						void *rawData, size_t ckSizeExpect, size_t ckSizeActual)
 {
 	if (ckSizeExpect > ckSizeActual) {
@@ -465,7 +465,7 @@ bool SoundFont::ReadStruct(Environment &env, Signal sig,
 	return true;
 }
 
-bool SoundFont::ReadString(Environment &env, Signal sig,
+bool SoundFont::ReadString(Environment &env, Signal &sig,
 						char *str, size_t ckSizeMax, size_t ckSizeActual)
 {
 	size_t ckSizeAlign = (ckSizeActual + 1) / 2 * 2;
@@ -486,8 +486,8 @@ bool SoundFont::ReadString(Environment &env, Signal sig,
 //-----------------------------------------------------------------------------
 void SoundFont::ChunkHdr::Print(int indentLevel) const
 {
-	ULong ckID = Gura_UnpackULong(ckID);
-	ULong ckSize = Gura_UnpackULong(ckSize);
+	UInt32 ckID = Gura_UnpackUInt32(ckID);
+	UInt32 ckSize = Gura_UnpackUInt32(ckSize);
 	::printf("%*s<%c%c%c%c-ck> %dbytes\n", indentLevel * 2, "",
 			static_cast<UChar>(ckID >> 0),
 			static_cast<UChar>(ckID >> 8),
@@ -507,8 +507,8 @@ SoundFont::sfVersionTag::sfVersionTag() : _cntRef(1),
 }
 
 SoundFont::sfVersionTag::sfVersionTag(const RawData &rawData) : _cntRef(1),
-		_wMajor(Gura_UnpackUShort(rawData.wMajor)),
-		_wMinor(Gura_UnpackUShort(rawData.wMinor))
+		_wMajor(Gura_UnpackUInt16(rawData.wMajor)),
+		_wMinor(Gura_UnpackUInt16(rawData.wMinor))
 {
 }
 
@@ -537,12 +537,12 @@ SoundFont::sfPresetHeader::sfPresetHeader() : _cntRef(1),
 }
 
 SoundFont::sfPresetHeader::sfPresetHeader(const RawData &rawData) : _cntRef(1),
-		_wPreset(Gura_UnpackUShort(rawData.wPreset)),
-		_wBank(Gura_UnpackUShort(rawData.wBank)),
-		_wPresetBagNdx(Gura_UnpackUShort(rawData.wPresetBagNdx)),
-		_dwLibrary(Gura_UnpackULong(rawData.dwLibrary)),
-		_dwGenre(Gura_UnpackULong(rawData.dwGenre)),
-		_dwMorphology(Gura_UnpackULong(rawData.dwMorphology)),
+		_wPreset(Gura_UnpackUInt16(rawData.wPreset)),
+		_wBank(Gura_UnpackUInt16(rawData.wBank)),
+		_wPresetBagNdx(Gura_UnpackUInt16(rawData.wPresetBagNdx)),
+		_dwLibrary(Gura_UnpackUInt32(rawData.dwLibrary)),
+		_dwGenre(Gura_UnpackUInt32(rawData.dwGenre)),
+		_dwMorphology(Gura_UnpackUInt32(rawData.dwMorphology)),
 		_pPresetBagOwner(new sfPresetBagOwner())
 {
 	::memcpy(_achPresetName, rawData.achPresetName, sizeof(_achPresetName));
@@ -562,7 +562,7 @@ void SoundFont::sfPresetHeader::Print(int indentLevel) const
 	GetPresetBagOwner().Print(indentLevel + 1);
 }
 
-bool SoundFont::sfPresetHeader::SetupReference(Signal sig,
+bool SoundFont::sfPresetHeader::SetupReference(Signal &sig,
 							sfPresetHeader *pPresetHeaderNext, const pdta_t &pdta)
 {
 	if (_wPresetBagNdx > pPresetHeaderNext->_wPresetBagNdx ||
@@ -594,8 +594,8 @@ SoundFont::sfPresetBag::sfPresetBag() : _cntRef(1),
 }
 
 SoundFont::sfPresetBag::sfPresetBag(const RawData &rawData) : _cntRef(1),
-		_wGenNdx(Gura_UnpackUShort(rawData.wGenNdx)),
-		_wModNdx(Gura_UnpackUShort(rawData.wModNdx)),
+		_wGenNdx(Gura_UnpackUInt16(rawData.wGenNdx)),
+		_wModNdx(Gura_UnpackUInt16(rawData.wModNdx)),
 		_pGenOwner(new sfGenOwner()),
 		_pModOwner(new sfModOwner())
 {
@@ -609,10 +609,10 @@ void SoundFont::sfPresetBag::Print(int indentLevel) const
 		_wModNdx);
 	GetGenOwner().Print(indentLevel + 1);
 	GetModOwner().Print(indentLevel + 1);
-	if (GetInst() != NULL) GetInst()->Print(indentLevel + 1);
+	if (GetInst() != nullptr) GetInst()->Print(indentLevel + 1);
 }
 
-bool SoundFont::sfPresetBag::SetupReference(Signal sig, sfPresetBag *pPresetBagNext, const pdta_t &pdta)
+bool SoundFont::sfPresetBag::SetupReference(Signal &sig, sfPresetBag *pPresetBagNext, const pdta_t &pdta)
 {
 	if (_wModNdx > pPresetBagNext->_wModNdx ||
 			static_cast<size_t>(_wModNdx) > pdta.pmods.size() ||
@@ -649,7 +649,7 @@ bool SoundFont::sfPresetBag::SetupReference(Signal sig, sfPresetBag *pPresetBagN
 			break;
 		}
 		case GEN_instrument: {
-			UShort wInstNdx = pGen->GetGenAmount();
+			UInt16 wInstNdx = pGen->GetGenAmount();
 			if (static_cast<size_t>(wInstNdx) >= pdta.insts.size()) {
 				sig.SetError(ERR_FormatError, "invalid index value in sfGen instrument");
 				return false;
@@ -681,11 +681,11 @@ SoundFont::sfMod::sfMod() : _cntRef(1),
 }
 
 SoundFont::sfMod::sfMod(const RawData &rawData) : _cntRef(1),
-		_sfModSrcOper(static_cast<SFModulator>(Gura_UnpackUShort(rawData.sfModSrcOper))),
-		_sfModDestOper(static_cast<SFGenerator>(Gura_UnpackUShort(rawData.sfModDestOper))),
-		_modAmount(static_cast<short>(Gura_UnpackUShort(rawData.modAmount))),
-		_sfModAmtSrcOper(static_cast<SFModulator>(Gura_UnpackUShort(rawData.sfModAmtSrcOper))),
-		_sfModTransOper(static_cast<SFTransform>(Gura_UnpackUShort(rawData.sfModTransOper)))
+		_sfModSrcOper(static_cast<SFModulator>(Gura_UnpackUInt16(rawData.sfModSrcOper))),
+		_sfModDestOper(static_cast<SFGenerator>(Gura_UnpackUInt16(rawData.sfModDestOper))),
+		_modAmount(static_cast<short>(Gura_UnpackUInt16(rawData.modAmount))),
+		_sfModAmtSrcOper(static_cast<SFModulator>(Gura_UnpackUInt16(rawData.sfModAmtSrcOper))),
+		_sfModTransOper(static_cast<SFTransform>(Gura_UnpackUInt16(rawData.sfModTransOper)))
 {
 }
 
@@ -711,8 +711,8 @@ SoundFont::sfGen::sfGen() : _cntRef(1),
 }
 
 SoundFont::sfGen::sfGen(const RawData &rawData) : _cntRef(1),
-		_sfGenOper(static_cast<SFGenerator>(Gura_UnpackUShort(rawData.sfGenOper))),
-		_genAmount(Gura_UnpackUShort(rawData.genAmount))
+		_sfGenOper(static_cast<SFGenerator>(Gura_UnpackUInt16(rawData.sfGenOper))),
+		_genAmount(Gura_UnpackUInt16(rawData.genAmount))
 {
 }
 
@@ -736,7 +736,7 @@ SoundFont::sfInst::sfInst() : _cntRef(1),
 }
 
 SoundFont::sfInst::sfInst(const RawData &rawData) : _cntRef(1),
-		_wInstBagNdx(Gura_UnpackUShort(rawData.wInstBagNdx)),
+		_wInstBagNdx(Gura_UnpackUInt16(rawData.wInstBagNdx)),
 		_pInstBagOwner(new sfInstBagOwner())
 {
 	::memcpy(_achInstName, rawData.achInstName, sizeof(_achInstName));
@@ -751,7 +751,7 @@ void SoundFont::sfInst::Print(int indentLevel) const
 	GetInstBagOwner().Print(indentLevel + 1);
 }
 
-bool SoundFont::sfInst::SetupReference(Signal sig, sfInst *pInstNext, const pdta_t &pdta)
+bool SoundFont::sfInst::SetupReference(Signal &sig, sfInst *pInstNext, const pdta_t &pdta)
 {
 	if (_wInstBagNdx > pInstNext->_wInstBagNdx ||
 			static_cast<size_t>(_wInstBagNdx) > pdta.ibags.size() ||
@@ -782,8 +782,8 @@ SoundFont::sfInstBag::sfInstBag() : _cntRef(1),
 }
 
 SoundFont::sfInstBag::sfInstBag(const RawData &rawData) : _cntRef(1),
-		_wInstGenNdx(Gura_UnpackUShort(rawData.wInstGenNdx)),
-		_wInstModNdx(Gura_UnpackUShort(rawData.wInstModNdx)),
+		_wInstGenNdx(Gura_UnpackUInt16(rawData.wInstGenNdx)),
+		_wInstModNdx(Gura_UnpackUInt16(rawData.wInstModNdx)),
 		_pInstGenOwner(new sfGenOwner()),
 		_pInstModOwner(new sfModOwner())
 {
@@ -799,7 +799,7 @@ void SoundFont::sfInstBag::Print(int indentLevel) const
 	GetInstModOwner().Print(indentLevel + 1);
 }
 
-bool SoundFont::sfInstBag::SetupReference(Signal sig,
+bool SoundFont::sfInstBag::SetupReference(Signal &sig,
 								sfInstBag *pInstBagNext, const pdta_t &pdta)
 {
 	if (_wInstModNdx > pInstBagNext->_wInstModNdx ||
@@ -879,20 +879,20 @@ SoundFont::sfSample::sfSample() : _cntRef(1),
 }
 
 SoundFont::sfSample::sfSample(const RawData &rawData) : _cntRef(1),
-		_dwStart(Gura_UnpackULong(rawData.dwStart)),
-		_dwEnd(Gura_UnpackULong(rawData.dwEnd)),
-		_dwStartloop(Gura_UnpackULong(rawData.dwStartloop)),
-		_dwEndloop(Gura_UnpackULong(rawData.dwEndloop)),
-		_dwSampleRate(Gura_UnpackULong(rawData.dwSampleRate)),
+		_dwStart(Gura_UnpackUInt32(rawData.dwStart)),
+		_dwEnd(Gura_UnpackUInt32(rawData.dwEnd)),
+		_dwStartloop(Gura_UnpackUInt32(rawData.dwStartloop)),
+		_dwEndloop(Gura_UnpackUInt32(rawData.dwEndloop)),
+		_dwSampleRate(Gura_UnpackUInt32(rawData.dwSampleRate)),
 		_byOriginalKey(rawData.byOriginalKey),
 		_chCorrection(rawData.chCorrection),
-		_wSampleLink(Gura_UnpackUShort(rawData.wSampleLink)),
-		_sfSampleType(static_cast<SFSampleLink>(Gura_UnpackUShort(rawData.sfSampleType)))
+		_wSampleLink(Gura_UnpackUInt16(rawData.wSampleLink)),
+		_sfSampleType(static_cast<SFSampleLink>(Gura_UnpackUInt16(rawData.sfSampleType)))
 {
 	::memcpy(_achSampleName, rawData.achSampleName, sizeof(_achSampleName));
 }
 
-bool SoundFont::sfSample::CreateAudio(Signal sig, Stream &stream, size_t offsetSdta)
+bool SoundFont::sfSample::CreateAudio(Signal &sig, Stream &stream, size_t offsetSdta)
 {
 	if (!_pAudio.IsNull()) return true;
 	_pAudio.reset(new Audio(Audio::FORMAT_S16LE, 1, _dwSampleRate));
@@ -900,12 +900,12 @@ bool SoundFont::sfSample::CreateAudio(Signal sig, Stream &stream, size_t offsetS
 		sig.SetError(ERR_FormatError, "invalid value in sfSample");
 		return false;
 	}
-	if (!stream.Seek(sig, offsetSdta + _dwStart * 2, Stream::SeekSet)) return NULL;
+	if (!stream.Seek(sig, offsetSdta + _dwStart * 2, Stream::SeekSet)) return false;
 	size_t nSamples = _dwEnd - _dwStart;
 	Audio::Chain *pChain = _pAudio->AllocChain(nSamples);
 	size_t bytesToRead = nSamples * 2;
 	size_t bytesRead = stream.Read(sig, pChain->GetPointer(), bytesToRead);
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return false;
 	if (bytesRead < bytesToRead) {
 		sig.SetError(ERR_FormatError, "invalid format of SoundFont");
 		return false;
@@ -1008,137 +1008,137 @@ void SoundFont::Synthesizer::Props::Reset()
 	endOper						= 0;		// 60
 }
 
-bool SoundFont::Synthesizer::Props::Update(SFGenerator sfGenOper, UShort genAmount)
+bool SoundFont::Synthesizer::Props::Update(SFGenerator sfGenOper, UInt16 genAmount)
 {
 	switch (sfGenOper) {
 	case GEN_startAddrsOffset:				// 0
-		startAddrsOffset = static_cast<UShort>(genAmount);
+		startAddrsOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_endAddrsOffset:				// 1
-		endAddrsOffset = static_cast<UShort>(genAmount);
+		endAddrsOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_startloopAddrsOffset:			// 2
-		startloopAddrsOffset = static_cast<UShort>(genAmount);
+		startloopAddrsOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_endloopAddrsOffset:			// 3
-		endloopAddrsOffset = static_cast<UShort>(genAmount);
+		endloopAddrsOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_startAddrsCoarseOffset:		// 4
-		startAddrsCoarseOffset = static_cast<UShort>(genAmount);
+		startAddrsCoarseOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_modLfoToPitch:					// 5
-		modLfoToPitch = static_cast<Short>(genAmount);
+		modLfoToPitch = static_cast<Int16>(genAmount);
 		break;
 	case GEN_vibLfoToPitch:					// 6
-		vibLfoToPitch = static_cast<Short>(genAmount);
+		vibLfoToPitch = static_cast<Int16>(genAmount);
 		break;
 	case GEN_modEnvToPitch:					// 7
-		modEnvToPitch = static_cast<Short>(genAmount);
+		modEnvToPitch = static_cast<Int16>(genAmount);
 		break;
 	case GEN_initialFilterFc:				// 8
-		initialFilterFc = static_cast<Short>(genAmount);
+		initialFilterFc = static_cast<Int16>(genAmount);
 		break;
 	case GEN_initiflFilterQ:				// 9
-		initiflFilterQ = static_cast<Short>(genAmount);
+		initiflFilterQ = static_cast<Int16>(genAmount);
 		break;
 	case GEN_modLfoToFilterFc:				// 10
-		modLfoToFilterFc = static_cast<Short>(genAmount);
+		modLfoToFilterFc = static_cast<Int16>(genAmount);
 		break;
 	case GEN_modEnvToFilterFc:				// 11
-		modEnvToFilterFc = static_cast<Short>(genAmount);
+		modEnvToFilterFc = static_cast<Int16>(genAmount);
 		break;
 	case GEN_endAddrsCoarseOffset:			// 12
-		endAddrsCoarseOffset = static_cast<UShort>(genAmount);
+		endAddrsCoarseOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_modLfoToVolume:				// 13
-		modLfoToVolume = static_cast<Short>(genAmount);
+		modLfoToVolume = static_cast<Int16>(genAmount);
 		break;
 	case GEN_unnsed1:						// 14
-		unnsed1 = static_cast<UShort>(genAmount);
+		unnsed1 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_chorusEffectsSend:				// 15
-		chorusEffectsSend = static_cast<UShort>(genAmount);
+		chorusEffectsSend = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_reverbEffectsSend:				// 16
-		reverbEffectsSend = static_cast<UShort>(genAmount);
+		reverbEffectsSend = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_pan:							// 17
-		pan = static_cast<Short>(genAmount);
+		pan = static_cast<Int16>(genAmount);
 		break;
 	case GEN_unused2:						// 18
-		unused2 = static_cast<UShort>(genAmount);
+		unused2 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_unused3:						// 19
-		unused3 = static_cast<UShort>(genAmount);
+		unused3 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_unused4:						// 20
-		unused4 = static_cast<UShort>(genAmount);
+		unused4 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_delayModLFO:					// 21
-		delayModLFO = static_cast<Short>(genAmount);
+		delayModLFO = static_cast<Int16>(genAmount);
 		break;
 	case GEN_freqModLFO:					// 22
-		freqModLFO = static_cast<Short>(genAmount);
+		freqModLFO = static_cast<Int16>(genAmount);
 		break;
 	case GEN_delayVibLFO:					// 23
-		delayVibLFO = static_cast<Short>(genAmount);
+		delayVibLFO = static_cast<Int16>(genAmount);
 		break;
 	case GEN_freqVibLFO:					// 24
-		freqVibLFO = static_cast<Short>(genAmount);
+		freqVibLFO = static_cast<Int16>(genAmount);
 		break;
 	case GEN_delayModEnv:					// 25
-		delayModEnv = static_cast<Short>(genAmount);
+		delayModEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_attackModEnv:					// 26
-		attackModEnv = static_cast<Short>(genAmount);
+		attackModEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_holdModEnv:					// 27
-		holdModEnv = static_cast<Short>(genAmount);
+		holdModEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_decayModEnv:					// 28
-		decayModEnv = static_cast<Short>(genAmount);
+		decayModEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_sustainModEnv:					// 29
-		sustainModEnv = static_cast<Short>(genAmount);
+		sustainModEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_releaseModEnv:					// 30
-		releaseModEnv = static_cast<Short>(genAmount);
+		releaseModEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_keynumToModEnvHold:			// 31
-		keynumToModEnvHold = static_cast<Short>(genAmount);
+		keynumToModEnvHold = static_cast<Int16>(genAmount);
 		break;
 	case GEN_keynumToModEnvDecay:			// 32
-		keynumToModEnvDecay = static_cast<Short>(genAmount);
+		keynumToModEnvDecay = static_cast<Int16>(genAmount);
 		break;
 	case GEN_delayVolEnv:					// 33
-		delayVolEnv = static_cast<Short>(genAmount);
+		delayVolEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_attackVolEnv:					// 34
-		attackVolEnv = static_cast<Short>(genAmount);
+		attackVolEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_holdVolEnv:					// 35
-		holdVolEnv = static_cast<Short>(genAmount);
+		holdVolEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_decayVolEnv:					// 36
-		decayVolEnv = static_cast<Short>(genAmount);
+		decayVolEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_sustainVolEnv:					// 37
-		sustainVolEnv = static_cast<Short>(genAmount);
+		sustainVolEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_releaseVolEnv:					// 38
-		releaseVolEnv = static_cast<Short>(genAmount);
+		releaseVolEnv = static_cast<Int16>(genAmount);
 		break;
 	case GEN_keynumToVolEnvHold:			// 39
-		keynumToVolEnvHold = static_cast<Short>(genAmount);
+		keynumToVolEnvHold = static_cast<Int16>(genAmount);
 		break;
 	case GEN_keynumToVolEnvDecay:			// 40
-		keynumToVolEnvDecay = static_cast<Short>(genAmount);
+		keynumToVolEnvDecay = static_cast<Int16>(genAmount);
 		break;
 	case GEN_instrument:					// 41
-		instrument = static_cast<UShort>(genAmount);
+		instrument = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_reserved1:						// 42
-		reserved1 = static_cast<UShort>(genAmount);
+		reserved1 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_keyRange:						// 43
 		keyRange.byLo = static_cast<UChar>(genAmount >> 0);
@@ -1149,52 +1149,52 @@ bool SoundFont::Synthesizer::Props::Update(SFGenerator sfGenOper, UShort genAmou
 		velRange.byHi = static_cast<UChar>(genAmount >> 8);
 		break;
 	case GEN_startloopAddrsCoarseOffset:	// 45
-		startloopAddrsCoarseOffset = static_cast<UShort>(genAmount);
+		startloopAddrsCoarseOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_keynum:						// 46
-		keynum = static_cast<UShort>(genAmount);
+		keynum = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_velocity:						// 47
-		velocity = static_cast<UShort>(genAmount);
+		velocity = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_initialAttenuation:			// 48
-		initialAttenuation = static_cast<UShort>(genAmount);
+		initialAttenuation = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_reserved2:						// 49
-		reserved2 = static_cast<UShort>(genAmount);
+		reserved2 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_endloopAddrsCoarseOffset:		// 50
-		endloopAddrsCoarseOffset = static_cast<UShort>(genAmount);
+		endloopAddrsCoarseOffset = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_coarseTune:					// 51
-		coarseTune = static_cast<Short>(genAmount);
+		coarseTune = static_cast<Int16>(genAmount);
 		break;
 	case GEN_fineTune:						// 52
-		fineTune = static_cast<Short>(genAmount);
+		fineTune = static_cast<Int16>(genAmount);
 		break;
 	case GEN_sampleID:						// 53
-		sampleID = static_cast<UShort>(genAmount);
+		sampleID = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_sampleModes:					// 54
-		sampleModes = static_cast<UShort>(genAmount);
+		sampleModes = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_reserved3:						// 55
-		reserved3 = static_cast<UShort>(genAmount);
+		reserved3 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_scaleTuning:					// 56
-		scaleTuning = static_cast<UShort>(genAmount);
+		scaleTuning = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_exclusiveClass:				// 57
-		exclusiveClass = static_cast<UShort>(genAmount);
+		exclusiveClass = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_overridingRootKey:				// 58
-		overridingRootKey = static_cast<UShort>(genAmount);
+		overridingRootKey = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_unused5:						// 59
-		unused5 = static_cast<UShort>(genAmount);
+		unused5 = static_cast<UInt16>(genAmount);
 		break;
 	case GEN_endOper:						// 60
-		endOper = static_cast<UShort>(genAmount);
+		endOper = static_cast<UInt16>(genAmount);
 		break;
 	default:
 		break;
