@@ -16,7 +16,7 @@ Object_regkey::~Object_regkey()
 
 Object *Object_regkey::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_regkey::ToString(bool exprFlag)
@@ -36,28 +36,29 @@ Gura_DeclareMethod(regkey, createkey)
 	DeclareArg(env, "samDesired", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, createkey)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
-	const char *lpSubKey = args.GetString(0);
-	DWORD dwOptions = args.Is_number(1)? args.GetULong(1) : REG_OPTION_NON_VOLATILE;
-	if (sig.IsSignalled()) return Value::Null;
-	REGSAM samDesired = args.Is_number(2)? args.GetULong(2) : KEY_ALL_ACCESS;
+	const char *lpSubKey = arg.GetString(0);
+	DWORD dwOptions = arg.Is_number(1)? arg.GetULong(1) : REG_OPTION_NON_VOLATILE;
+	if (sig.IsSignalled()) return Value::Nil;
+	REGSAM samDesired = arg.Is_number(2)? arg.GetULong(2) : KEY_ALL_ACCESS;
 	HKEY hKeyResult;
 	DWORD dwDisposition;
 	DWORD dwErrCode = ::RegCreateKeyEx(hKey, OAL::ToNativeString(lpSubKey).c_str(),
-			0, NULL, dwOptions, samDesired, NULL, &hKeyResult, &dwDisposition);
+			0, nullptr, dwOptions, samDesired, nullptr, &hKeyResult, &dwDisposition);
 	if (dwErrCode != ERROR_SUCCESS) {
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value result(new Object_regkey(hKeyResult, true));
-	return ReturnValue(env, sig, args, result);
+	return ReturnValue(env, arg, result);
 }
 
 // mswin.regkey#openkey(subkey:string, samDesired?:number):map {block?}
@@ -68,26 +69,27 @@ Gura_DeclareMethod(regkey, openkey)
 	DeclareArg(env, "samDesired", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, openkey)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
-	const char *lpSubKey = args.GetString(0);
-	if (sig.IsSignalled()) return Value::Null;
-	REGSAM samDesired = args.Is_number(1)? args.GetULong(1) : KEY_ALL_ACCESS;
+	const char *lpSubKey = arg.GetString(0);
+	if (sig.IsSignalled()) return Value::Nil;
+	REGSAM samDesired = arg.Is_number(1)? arg.GetULong(1) : KEY_ALL_ACCESS;
 	HKEY hKeyResult;
 	DWORD dwErrCode = ::RegOpenKeyEx(hKey, OAL::ToNativeString(lpSubKey).c_str(),
 												0, samDesired, &hKeyResult);
 	if (dwErrCode != ERROR_SUCCESS) {
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value result(new Object_regkey(hKeyResult, true));
-	return ReturnValue(env, sig, args, result);
+	return ReturnValue(env, arg, result);
 }
 
 // mswin.regkey#deletekey(subkey:string):map:void
@@ -96,21 +98,22 @@ Gura_DeclareMethod(regkey, deletekey)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "subkey", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, deletekey)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
-	const char *lpSubKey = args.GetString(0);
+	const char *lpSubKey = arg.GetString(0);
 	DWORD dwErrCode = ::RegDeleteKey(hKey, OAL::ToNativeString(lpSubKey).c_str());
 	if (dwErrCode != ERROR_SUCCESS) {
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // mswin.regkey#enumkey(samDesired?:number):[openkey] {block?}
@@ -121,22 +124,22 @@ Gura_DeclareMethod(regkey, enumkey)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	DeclareAttr(Gura_UserSymbol(openkey));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, enumkey)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	REGSAM samDesired = 0;
-	if (!args.IsSet(Gura_UserSymbol(openkey))) {
+	if (!arg.IsSet(Gura_UserSymbol(openkey))) {
 		// nothing to do
 	} else {
-		samDesired = args.Is_number(0)? args.GetULong(0) : KEY_ALL_ACCESS;
+		samDesired = arg.Is_number(0)? arg.GetULong(0) : KEY_ALL_ACCESS;
 	}
 	Iterator *pIterator =
 			new Iterator_RegEnumKey(Object_regkey::Reference(pThis), samDesired);
-	return ReturnIterator(env, sig, args, pIterator);
+	return ReturnIterator(env, arg, pIterator);
 }
 
 // mswin.regkey#setvalue(valueName:string, data:nomap):map
@@ -146,29 +149,30 @@ Gura_DeclareMethod(regkey, setvalue)
 	DeclareArg(env, "valueName", VTYPE_string);
 	DeclareArg(env, "data", VTYPE_any, OCCUR_Once, FLAG_NoMap);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, setvalue)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
-	const char *lpValueName = args.GetString(0);
+	const char *lpValueName = arg.GetString(0);
 	DWORD dwType = 0;
-	BYTE *lpData = NULL;
+	BYTE *lpData = nullptr;
 	DWORD cbData = 0;
-	if (!ValueToRegData(env, sig, args.GetValue(1), &dwType, &lpData, &cbData)) {
-		return Value::Null;
+	if (!ValueToRegData(env, sig, arg.GetValue(1), &dwType, &lpData, &cbData)) {
+		return Value::Nil;
 	}
 	DWORD dwErrCode = ::RegSetValueEx(hKey,
 			OAL::ToNativeString(lpValueName).c_str(), 0, dwType, lpData, cbData);
 	::LocalFree(lpData);
 	if (dwErrCode != ERROR_SUCCESS) {
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // mswin.regkey#deletevalue(valueName:string):map:void
@@ -177,21 +181,22 @@ Gura_DeclareMethod(regkey, deletevalue)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "valueName", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, deletevalue)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
-	const char *lpValueName = args.GetString(0);
+	const char *lpValueName = arg.GetString(0);
 	DWORD dwErrCode = ::RegDeleteValue(hKey, OAL::ToNativeString(lpValueName).c_str());
 	if (dwErrCode != ERROR_SUCCESS) {
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
 // mswin.regkey#queryvalue(valueName?:string):map
@@ -200,32 +205,33 @@ Gura_DeclareMethod(regkey, queryvalue)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "valueName", VTYPE_string, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, queryvalue)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
-	const char *lpValueName = args.Is_string(0)? args.GetString(0) : NULL;
+	const char *lpValueName = arg.Is_string(0)? arg.GetString(0) : nullptr;
 	DWORD dwType;
 	DWORD cbData;
 	DWORD dwErrCode = ::RegQueryValueEx(hKey,
-		(lpValueName == NULL)? NULL : OAL::ToNativeString(lpValueName).c_str(),
-		NULL, &dwType, NULL, &cbData);
+		(lpValueName == nullptr)? nullptr : OAL::ToNativeString(lpValueName).c_str(),
+		nullptr, &dwType, nullptr, &cbData);
 	if (dwErrCode != ERROR_SUCCESS) {
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
 	LPBYTE lpData = reinterpret_cast<LPBYTE>(::LocalAlloc(LMEM_FIXED, cbData));
 	dwErrCode = ::RegQueryValueEx(hKey,
-		(lpValueName == NULL)? NULL : OAL::ToNativeString(lpValueName).c_str(),
-		NULL, &dwType, lpData, &cbData);
+		(lpValueName == nullptr)? nullptr : OAL::ToNativeString(lpValueName).c_str(),
+		nullptr, &dwType, lpData, &cbData);
 	if (dwErrCode != ERROR_SUCCESS) {
 		::LocalFree(lpData);
 		SetError(sig, dwErrCode);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value result = RegDataToValue(env, sig, dwType, lpData, cbData);
 	::LocalFree(lpData);
@@ -238,17 +244,17 @@ Gura_DeclareMethod(regkey, enumvalue)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(regkey, enumvalue)
 {
-	Object_regkey *pThis = Object_regkey::GetThisObj(args);
+	Object_regkey *pThis = Object_regkey::GetObjectThis(arg);
 	HKEY hKey = pThis->GetKey();
 	Iterator *pIterator =
 			new Iterator_RegEnumValue(Object_regkey::Reference(pThis));
-	return ReturnIterator(env, sig, args, pIterator);
+	return ReturnIterator(env, arg, pIterator);
 }
 
 // implementation of class RegKey
@@ -270,17 +276,17 @@ Gura_ImplementUserClass(regkey)
 //-----------------------------------------------------------------------------
 Object_ole::~Object_ole()
 {
-	if (_pDispatch != NULL) {
+	if (_pDispatch != nullptr) {
 		_pDispatch->Release();
 	}
 }
 
 Object *Object_ole::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_ole::Create(Signal sig, const char *progID)
+bool Object_ole::Create(Signal &sig, const char *progID)
 {
 	HRESULT hr;
 	CLSID clsid;
@@ -290,7 +296,7 @@ bool Object_ole::Create(Signal sig, const char *progID)
 		::SysFreeString(progID_W);
 	} while (0);
 	hr = ::CoCreateInstance(clsid,
-					NULL, CLSCTX_INPROC_SERVER | CLSCTX_LOCAL_SERVER,
+					nullptr, CLSCTX_INPROC_SERVER | CLSCTX_LOCAL_SERVER,
 					IID_IDispatch, reinterpret_cast<LPVOID *>(&_pDispatch));
 	if (FAILED(hr)) {
 		SetError(sig, hr);
@@ -299,7 +305,7 @@ bool Object_ole::Create(Signal sig, const char *progID)
 	return true;
 }
 
-bool Object_ole::Connect(Signal sig, const char *progID)
+bool Object_ole::Connect(Signal &sig, const char *progID)
 {
 	HRESULT hr;
 	CLSID clsid;
@@ -308,7 +314,7 @@ bool Object_ole::Connect(Signal sig, const char *progID)
 		::CLSIDFromProgID(progID_W, &clsid);
 		::SysFreeString(progID_W);
 	} while (0);
-	IUnknown *pUnknown = NULL;
+	IUnknown *pUnknown = nullptr;
 	hr = ::GetActiveObject(clsid, 0, &pUnknown);
 	if (FAILED(hr)) {
 		SetError(sig, hr);
@@ -325,13 +331,13 @@ bool Object_ole::Connect(Signal sig, const char *progID)
 	return true;
 }
 
-bool Object_ole::ImportConstant(Environment &env, Signal sig)
+bool Object_ole::ImportConstant(Environment &env, Signal &sig)
 {
 	HRESULT hr;
 	//hr = _pDispatch->GetTypeInfoCount(&cnt); // 0 or 1
-	ITypeLib *pTypeLib = NULL;
+	ITypeLib *pTypeLib = nullptr;
 	do {
-		ITypeInfo *pTypeInfo = NULL;
+		ITypeInfo *pTypeInfo = nullptr;
 		do {
 			hr = _pDispatch->GetTypeInfo(0, LOCALE_SYSTEM_DEFAULT, &pTypeInfo);
 			if (FAILED(hr)) {
@@ -352,7 +358,7 @@ bool Object_ole::ImportConstant(Environment &env, Signal sig)
 	} while (0);
 	long cntTypeInfo = pTypeLib->GetTypeInfoCount();
 	for (long iTypeInfo = 0; iTypeInfo < cntTypeInfo; iTypeInfo++) {
-		ITypeInfo *pTypeInfo = NULL;
+		ITypeInfo *pTypeInfo = nullptr;
 		do {
 			hr = pTypeLib->GetTypeInfo(iTypeInfo, &pTypeInfo);
 			if (FAILED(hr)) {
@@ -363,7 +369,7 @@ bool Object_ole::ImportConstant(Environment &env, Signal sig)
 		} while (0);
 		int cVars = 0;
 		do {
-			TYPEATTR *pTypeAttr = NULL;
+			TYPEATTR *pTypeAttr = nullptr;
 			hr = pTypeInfo->GetTypeAttr(&pTypeAttr);
 			if (FAILED(hr)) {
 				SetError(sig, hr);
@@ -375,14 +381,14 @@ bool Object_ole::ImportConstant(Environment &env, Signal sig)
 			pTypeInfo->ReleaseTypeAttr(pTypeAttr);
 		} while (0);
 		for (int iVar = 0; iVar < cVars; iVar++) {
-			VARDESC *pVarDesc = NULL;
+			VARDESC *pVarDesc = nullptr;
 			hr = pTypeInfo->GetVarDesc(iVar, &pVarDesc);
 			if (FAILED(hr)) continue;
 			if (pVarDesc->varkind != VAR_CONST) {
 				pTypeInfo->ReleaseVarDesc(pVarDesc);
 				continue;
 			}
-			const Symbol *pSymbol = NULL;
+			const Symbol *pSymbol = nullptr;
 			do {
 				OLECHAR *nameOle;
 				unsigned int len;
@@ -391,7 +397,7 @@ bool Object_ole::ImportConstant(Environment &env, Signal sig)
 				pSymbol = Symbol::Add(BSTRToString(nameOle).c_str());
 				::SysFreeString(nameOle);
 			} while (0);
-			if (pSymbol != NULL) {
+			if (pSymbol != nullptr) {
 				Value value;
 				if (!VariantToValue(*this, sig, value, *pVarDesc->lpvarValue)) return false;
 				env.AssignValue(pSymbol, value, EXTRA_Public);
@@ -429,13 +435,13 @@ HRESULT Object_ole::GetDispIDOfNamedArg(
 	return hr;
 }
 
-Iterator *Object_ole::CreateIterator(Signal sig)
+Iterator *Object_ole::CreateIterator(Signal &sig)
 {
 	VARIANT var;
 	HRESULT hr;
 	::VariantInit(&var);
 	do {
-		DISPPARAMS dispParams = { NULL, NULL, 0, 0 };
+		DISPPARAMS dispParams = { nullptr, nullptr, 0, 0 };
 	    EXCEPINFO exceptInfo;
 		unsigned int argErr;
 		::memset(&exceptInfo, 0, sizeof(exceptInfo));
@@ -444,10 +450,10 @@ Iterator *Object_ole::CreateIterator(Signal sig)
 					&dispParams, &var, &exceptInfo, &argErr);
 		if (FAILED(hr)) {
 			sig.SetError(ERR_RuntimeError, "OLE object is not iteratable");
-			return NULL;
+			return nullptr;
 		}
 	} while (0);
-	IEnumVARIANT *pEnum = NULL;
+	IEnumVARIANT *pEnum = nullptr;
 	VARTYPE type = var.vt & VT_TYPEMASK;
 	if (type == VT_UNKNOWN) {
 		IUnknown *pUnknown = (var.vt & VT_BYREF)? *var.ppunkVal : var.punkVal;
@@ -459,25 +465,26 @@ Iterator *Object_ole::CreateIterator(Signal sig)
 										reinterpret_cast<LPVOID *>(&pEnum));
 	} else {
 		sig.SetError(ERR_RuntimeError, "unexpected return value");
-		return NULL;
+		return nullptr;
 	}
 	::VariantClear(&var);
 	if (FAILED(hr)) {
 		SetError(sig, hr);
-		return NULL;
+		return nullptr;
 	}
 	Iterator *pIterator = new IteratorEx(Object_ole::Reference(this), pEnum);
 	return pIterator;
 }
 
-bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
+bool Object_ole::DoDirProp(Environment &env, SymbolSet &symbols)
 {
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
+	Signal &sig = GetSignal();
+	if (!Object::DoDirProp(env, symbols)) return false;
 	HRESULT hr;
 	//hr = _pDispatch->GetTypeInfoCount(&cnt); // 0 or 1
-	ITypeLib *pTypeLib = NULL;
+	ITypeLib *pTypeLib = nullptr;
 	do {
-		ITypeInfo *pTypeInfo = NULL;
+		ITypeInfo *pTypeInfo = nullptr;
 		do {
 			hr = _pDispatch->GetTypeInfo(0, LOCALE_SYSTEM_DEFAULT, &pTypeInfo);
 			if (FAILED(hr)) {
@@ -498,7 +505,7 @@ bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 	} while (0);
 	long cntTypeInfo = pTypeLib->GetTypeInfoCount();
 	for (long iTypeInfo = 0; iTypeInfo < cntTypeInfo; iTypeInfo++) {
-		ITypeInfo *pTypeInfo = NULL;
+		ITypeInfo *pTypeInfo = nullptr;
 		do {
 			hr = pTypeLib->GetTypeInfo(iTypeInfo, &pTypeInfo);
 			if (FAILED(hr)) {
@@ -510,7 +517,7 @@ bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 		int cFuncs = 0;
 		int cVars = 0;
 		do {
-			TYPEATTR *pTypeAttr = NULL;
+			TYPEATTR *pTypeAttr = nullptr;
 			hr = pTypeInfo->GetTypeAttr(&pTypeAttr);
 			if (FAILED(hr)) {
 				SetError(sig, hr);
@@ -523,10 +530,10 @@ bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 			pTypeInfo->ReleaseTypeAttr(pTypeAttr);
 		} while (0);
 		for (int iFunc = 0; iFunc < cFuncs; iFunc++) {
-			FUNCDESC *pFuncDesc = NULL;
+			FUNCDESC *pFuncDesc = nullptr;
 			hr = pTypeInfo->GetFuncDesc(iFunc, &pFuncDesc);
 			if (FAILED(hr)) continue;
-			const Symbol *pSymbol = NULL;
+			const Symbol *pSymbol = nullptr;
 			do {
 				OLECHAR *nameOle;
 				unsigned int len;
@@ -535,15 +542,15 @@ bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 				pSymbol = Symbol::Add(BSTRToString(nameOle).c_str());
 				::SysFreeString(nameOle);
 			} while (0);
-			if (pSymbol != NULL) symbols.insert(pSymbol);
+			if (pSymbol != nullptr) symbols.insert(pSymbol);
 			pTypeInfo->ReleaseFuncDesc(pFuncDesc);
 		}
 #if 0
 		for (int iVar = 0; iVar < cVars; iVar++) {
-			VARDESC *pVarDesc = NULL;
+			VARDESC *pVarDesc = nullptr;
 			hr = pTypeInfo->GetVarDesc(iVar, &pVarDesc);
 			if (FAILED(hr)) continue;
-			const Symbol *pSymbol = NULL;
+			const Symbol *pSymbol = nullptr;
 			do {
 				OLECHAR *nameOle;
 				unsigned int len;
@@ -552,7 +559,7 @@ bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 				pSymbol = Symbol::Add(BSTRToString(nameOle).c_str());
 				::SysFreeString(nameOle);
 			} while (0);
-			if (pSymbol != NULL) symbols.insert(pSymbol);
+			if (pSymbol != nullptr) symbols.insert(pSymbol);
 			pTypeInfo->ReleaseVarDesc(pVarDesc);
 		}
 #endif
@@ -562,26 +569,27 @@ bool Object_ole::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 	return true;
 }
 
-Value Object_ole::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
+Value Object_ole::DoGetProp(Environment &env, const Symbol *pSymbol,
 							const SymbolSet &attrs, bool &evaluatedFlag)
 {
+	Signal &sig = GetSignal();
 	DISPID dispid;
 	do {
 		HRESULT hr = GetDispID(pSymbol->GetName(), dispid);
 		if (FAILED(hr)) {
 			SetError(sig, hr);
-			return Value::Null;
+			return Value::Nil;
 		}
 	} while (0);
 	evaluatedFlag = true;
 	VARIANT var;
 	do {
-		DISPPARAMS dispParams = { NULL, NULL, 0, 0 };
+		DISPPARAMS dispParams = { nullptr, nullptr, 0, 0 };
 		HRESULT hr = _pDispatch->Invoke(dispid, IID_NULL, LOCALE_USER_DEFAULT,
-						DISPATCH_PROPERTYGET, &dispParams, &var, NULL, NULL);
+						DISPATCH_PROPERTYGET, &dispParams, &var, nullptr, nullptr);
 		if (FAILED(hr)) {
 			SetError(sig, hr);
-			return Value::Null;
+			return Value::Nil;
 		}
 	} while (0);
 	Value result;
@@ -590,40 +598,42 @@ Value Object_ole::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
 	return result;
 }
 
-Value Object_ole::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
+Value Object_ole::DoSetProp(Environment &env, const Symbol *pSymbol, const Value &value,
 							const SymbolSet &attrs, bool &evaluatedFlag)
 {
+	Signal &sig = GetSignal();
 	evaluatedFlag = true;
 	DISPID dispid;
 	do {
 		HRESULT hr = GetDispID(pSymbol->GetName(), dispid);
 		if (FAILED(hr)) {
 			SetError(sig, hr);
-			return Value::Null;
+			return Value::Nil;
 		}
 	} while (0);
 	do {
 		VARIANTARG varArgs[1];
 		DISPID dispidNamedArgs[1] = { DISPID_PROPERTYPUT };
-		if (!ValueToVariant(sig, varArgs[0], value)) return Value::Null;
+		if (!ValueToVariant(sig, varArgs[0], value)) return Value::Nil;
 		DISPPARAMS dispParams;
 		dispParams.rgvarg = varArgs;
 		dispParams.rgdispidNamedArgs = dispidNamedArgs;
 		dispParams.cArgs = 1;
 		dispParams.cNamedArgs = 1;
 		HRESULT hr = _pDispatch->Invoke(dispid, IID_NULL, LOCALE_USER_DEFAULT,
-							DISPATCH_PROPERTYPUT, &dispParams, NULL, NULL, NULL);
+							DISPATCH_PROPERTYPUT, &dispParams, nullptr, nullptr, nullptr);
 		::VariantClear(&varArgs[0]);
 		if (FAILED(hr)) {
 			sig.SetError(ERR_RuntimeError, "can't change OLE property %s", pSymbol->GetName());
-			return Value::Null;
+			return Value::Nil;
 		}
 	} while (0);
 	return value;
 }
 
-Callable *Object_ole::GetCallable(Signal sig, const Symbol *pSymbol)
+Callable *Object_ole::GetCallable(const Symbol *pSymbol)
 {
+	Signal &sig = GetSignal();
 	foreach (CallableOLEOwner, ppCallableOLE, _callableOLEOwner) {
 		CallableOLE *pCallableOLE = *ppCallableOLE;
 		if (pCallableOLE->GetSymbol() == pSymbol) return pCallableOLE;
@@ -632,7 +642,7 @@ Callable *Object_ole::GetCallable(Signal sig, const Symbol *pSymbol)
 	HRESULT hr = GetDispID(pSymbol->GetName(), dispid);
 	if (FAILED(hr)) {
 		Object_ole::SetError(sig, hr);
-		return NULL;
+		return nullptr;
 	}
 	CallableOLE *pCallableOLE = new CallableOLE(this, pSymbol, dispid);
 	_callableOLEOwner.push_back(pCallableOLE);
@@ -645,7 +655,7 @@ String Object_ole::ToString(bool exprFlag)
 	rtn += "<mswin.ole:";
 	do {
 		HRESULT hr;
-		ITypeInfo *pTypeInfo = NULL;
+		ITypeInfo *pTypeInfo = nullptr;
 		do {
 			hr = _pDispatch->GetTypeInfo(0, LOCALE_SYSTEM_DEFAULT, &pTypeInfo);
 			if (FAILED(hr)) {
@@ -655,7 +665,7 @@ String Object_ole::ToString(bool exprFlag)
 		} while (0);
 		TYPEKIND typekind;
 		do {
-			TYPEATTR *pTypeAttr = NULL;
+			TYPEATTR *pTypeAttr = nullptr;
 			hr = pTypeInfo->GetTypeAttr(&pTypeAttr);
 			if (FAILED(hr)) {
 				rtn += "*error*>";
@@ -692,20 +702,20 @@ String Object_ole::ToString(bool exprFlag)
 	return rtn;
 }
 
-void Object_ole::SetError(Signal sig, HRESULT hr)
+void Object_ole::SetError(Signal &sig, HRESULT hr)
 {
-	LPWSTR errMsg = NULL;
+	LPWSTR errMsg = nullptr;
 	::FormatMessageW(
 		FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-		NULL, hr, LOCALE_SYSTEM_DEFAULT, reinterpret_cast<LPWSTR>(&errMsg), 0, NULL);
-	if (errMsg == NULL) {
+		nullptr, hr, LOCALE_SYSTEM_DEFAULT, reinterpret_cast<LPWSTR>(&errMsg), 0, nullptr);
+	if (errMsg == nullptr) {
 		sig.SetError(ERR_RuntimeError, "COM error [%08x]", hr);
 	} else {
 		int len = static_cast<int>(::wcslen(errMsg));
 		if (len > 0 && errMsg[len - 1] == '\n') len--;
-		int bytes = ::WideCharToMultiByte(CP_UTF8, 0, errMsg, len, NULL, 0, NULL, NULL);
+		int bytes = ::WideCharToMultiByte(CP_UTF8, 0, errMsg, len, nullptr, 0, nullptr, nullptr);
 		char *pszErrMsg = new char [bytes];
-		::WideCharToMultiByte(CP_UTF8, 0, errMsg, len, pszErrMsg, bytes, NULL, NULL);
+		::WideCharToMultiByte(CP_UTF8, 0, errMsg, len, pszErrMsg, bytes, nullptr, nullptr);
 		pszErrMsg[bytes] = '\0';
 		sig.SetError(ERR_RuntimeError, "COM error [%08x] %s", hr, pszErrMsg);
 		::LocalFree(errMsg);
@@ -715,13 +725,17 @@ void Object_ole::SetError(Signal sig, HRESULT hr)
 //-----------------------------------------------------------------------------
 // Object_ole::CallableOLE
 //-----------------------------------------------------------------------------
-Value Object_ole::CallableOLE::DoCall(Environment &env, Signal sig, Args &argsExpr)
+Value Object_ole::CallableOLE::DoCall(
+	Environment &env, const CallerInfo &callerInfo, ULong flags,
+	const Value &valueThis, const Iterator *pIteratorThis,
+	const TrailCtrlHolder *pTrailCtrlHolder)
 {
+	Signal &sig = env.GetSignal();
 	Value result;
 	HRESULT hr;
-	const ExprList &exprListArg = argsExpr.GetExprListArg();
-	VARIANTARG *varArgs = NULL;
-	DISPID *dispidNamedArgs = NULL;
+	const ExprList &exprListArg = callerInfo.GetExprListArg();
+	VARIANTARG *varArgs = nullptr;
+	DISPID *dispidNamedArgs = nullptr;
 	ValueList valueArgs;
 	ValueList valueArgsNamed;
 	StringList argNames;
@@ -743,13 +757,11 @@ Value Object_ole::CallableOLE::DoCall(Environment &env, Signal sig, Args &argsEx
 						"a key for named argument of OLE must be a string or an identifier");
 				goto error_done;
 			}
-			SeqPostHandler *pSeqPostHandler = NULL;
-			Value value = pExprBinaryOp->GetRight()->Exec2(env, sig, pSeqPostHandler);
+			Value value = pExprBinaryOp->GetRight()->Exec(env);
 			if (sig.IsSignalled()) goto error_done;
 			valueArgsNamed.push_back(value);
 		} else {
-			SeqPostHandler *pSeqPostHandler = NULL;
-			Value value = pExpr->Exec2(env, sig, pSeqPostHandler);
+			Value value = pExpr->Exec(env);
 			if (sig.IsSignalled()) goto error_done;
 			valueArgs.push_back(value);
 		}
@@ -795,8 +807,8 @@ Value Object_ole::CallableOLE::DoCall(Environment &env, Signal sig, Args &argsEx
 	VARIANT varResult;
 	hr = _pObj->GetDispatch()->Invoke(_dispid, IID_NULL, LOCALE_USER_DEFAULT,
 					DISPATCH_METHOD | DISPATCH_PROPERTYGET,
-					&dispParams, &varResult, NULL, NULL);
-	if (varArgs != NULL) {
+					&dispParams, &varResult, nullptr, nullptr);
+	if (varArgs != nullptr) {
 		for (size_t iArg = 0; iArg < cArgs; iArg++) {
 			::VariantClear(&varArgs[iArg]);
 		}
@@ -806,20 +818,20 @@ Value Object_ole::CallableOLE::DoCall(Environment &env, Signal sig, Args &argsEx
 	if (FAILED(hr)) {
 		::VariantClear(&varResult);
 		Object_ole::SetError(sig, hr);
-		return Value::Null;
+		return Value::Nil;
 	}
 	VariantToValue(env, sig, result, varResult);
 	::VariantClear(&varResult);
 	return result;
 error_done:
-	if (varArgs != NULL) {
+	if (varArgs != nullptr) {
 		for (size_t iArg = 0; iArg < cArgs; iArg++) {
 			::VariantClear(&varArgs[iArg]);
 		}
 	}
 	delete[] varArgs;
 	delete[] dispidNamedArgs;
-	return Value::Null;
+	return Value::Nil;
 }
 
 //-----------------------------------------------------------------------------
@@ -849,14 +861,15 @@ Object_ole::IteratorEx::~IteratorEx()
 
 Iterator *Object_ole::IteratorEx::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Object_ole::IteratorEx::DoNext(Environment &env, Signal sig, Value &value)
+bool Object_ole::IteratorEx::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	VARIANT var;
 	::VariantInit(&var);
-	if (_pEnum->Next(1, &var, NULL) != S_OK) return false;
+	if (_pEnum->Next(1, &var, nullptr) != S_OK) return false;
 	VariantToValue(*_pObj, sig, value, var);
 	::VariantClear(&var);
 	return true;
@@ -886,23 +899,24 @@ Gura_ImplementUserClass(ole)
 // Iterator_RegEnumKey implementation
 //-----------------------------------------------------------------------------
 Iterator_RegEnumKey::Iterator_RegEnumKey(Object_regkey *pObjRegKey, REGSAM samDesired) :
-	Iterator(false), _pObjRegKey(pObjRegKey), _samDesired(samDesired), _dwIndex(0)
+	Iterator(Finite), _pObjRegKey(pObjRegKey), _samDesired(samDesired), _dwIndex(0)
 {
 }
 
 Iterator *Iterator_RegEnumKey::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_RegEnumKey::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_RegEnumKey::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	char name[256];
 	FILETIME ftLastWriteTime;
 	HKEY hKey = _pObjRegKey->GetKey();
 	DWORD pcName = ArraySizeOf(name);
 	DWORD dwErrCode = ::RegEnumKeyEx(hKey, _dwIndex, name, &pcName,
-										NULL, NULL, NULL, &ftLastWriteTime);
+										nullptr, nullptr, nullptr, &ftLastWriteTime);
 	if (dwErrCode != ERROR_SUCCESS) {
 		if (dwErrCode != ERROR_NO_MORE_ITEMS) SetError(sig, dwErrCode);
 		return false;
@@ -935,24 +949,25 @@ void Iterator_RegEnumKey::GatherFollower(Environment::Frame *pFrame, Environment
 // Iterator_RegEnumValue implementation
 //-----------------------------------------------------------------------------
 Iterator_RegEnumValue::Iterator_RegEnumValue(Object_regkey *pObjRegKey) :
-	Iterator(false), _pObjRegKey(pObjRegKey), _dwIndex(0)
+	Iterator(Finite), _pObjRegKey(pObjRegKey), _dwIndex(0)
 {
 }
 
 Iterator *Iterator_RegEnumValue::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_RegEnumValue::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_RegEnumValue::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	char valueName[256];
 	DWORD cValueName = ArraySizeOf(valueName);
 	HKEY hKey = _pObjRegKey->GetKey();
 	DWORD dwType;
 	DWORD cbData;
 	DWORD dwErrCode = ::RegEnumValue(hKey, _dwIndex, 
-						valueName, &cValueName, NULL, &dwType, NULL, &cbData);
+						valueName, &cValueName, nullptr, &dwType, nullptr, &cbData);
 	if (dwErrCode != ERROR_SUCCESS) {
 		if (dwErrCode != ERROR_NO_MORE_ITEMS) SetError(sig, dwErrCode);
 		return false;
@@ -960,16 +975,16 @@ bool Iterator_RegEnumValue::DoNext(Environment &env, Signal sig, Value &value)
 	cValueName = ArraySizeOf(valueName);
 	LPBYTE lpData = reinterpret_cast<LPBYTE>(::LocalAlloc(LMEM_FIXED, cbData));
 	dwErrCode = ::RegEnumValue(hKey, _dwIndex, 
-						valueName, &cValueName, NULL, &dwType, lpData, &cbData);
+						valueName, &cValueName, nullptr, &dwType, lpData, &cbData);
 	if (dwErrCode != ERROR_SUCCESS) {
 		::LocalFree(lpData);
 		if (dwErrCode != ERROR_NO_MORE_ITEMS) SetError(sig, dwErrCode);
 		return false;
 	}
-	ValueList &valList = value.InitAsList(env);
+	Object_list *pObjList = value.InitAsList(env);
 	Value valueWk(OAL::FromNativeString(valueName));
-	valList.push_back(valueWk);
-	valList.push_back(RegDataToValue(env, sig, dwType, lpData, cbData));
+	pObjList->Add(valueWk);
+	pObjList->Add(RegDataToValue(env, sig, dwType, lpData, cbData));
 	::LocalFree(lpData);
 	if (sig.IsSignalled()) return false;
 	_dwIndex++;
@@ -998,30 +1013,31 @@ Gura_DeclareFunction(ole)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(ole));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementFunction(ole)
 {
+	Signal &sig = env.GetSignal();
 	AutoPtr<Object_ole> pObj(new Object_ole(env));
-	if (args.IsSet(Gura_UserSymbol(connect))) {
-		if (!pObj->Connect(sig, args.GetString(0))) return Value::Null;
+	if (arg.IsSet(Gura_UserSymbol(connect))) {
+		if (!pObj->Connect(sig, arg.GetString(0))) return Value::Nil;
 	} else {
-		if (!pObj->Create(sig, args.GetString(0))) return Value::Null;
+		if (!pObj->Create(sig, arg.GetString(0))) return Value::Nil;
 	}
-	if (!args.IsSet(Gura_UserSymbol(no_const))) {
+	if (!arg.IsSet(Gura_UserSymbol(no_const))) {
 		pObj->ImportConstant(*pObj, sig);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(pObj.release()));
+	return ReturnValue(env, arg, Value(pObj.release()));
 }
 
 Gura_DeclareFunction(GetACP)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
@@ -1031,6 +1047,14 @@ Gura_ImplementFunction(GetACP)
 	return Value(rtn);
 }
 
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	::CoInitialize(0);
@@ -1106,8 +1130,8 @@ void SetError(Signal &sig, DWORD dwErrCode)
 {
 	LPVOID lpMsgBuf;
 	::FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM |
-		FORMAT_MESSAGE_IGNORE_INSERTS, NULL, dwErrCode,
-		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (LPWSTR)&lpMsgBuf, 0, NULL);
+		FORMAT_MESSAGE_IGNORE_INSERTS, nullptr, dwErrCode,
+		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (LPWSTR)&lpMsgBuf, 0, nullptr);
 	sig.SetError(ERR_SystemError, "Error: %s",
 			BSTRToString(reinterpret_cast<OLECHAR *>(lpMsgBuf)).c_str());
 	::LocalFree(lpMsgBuf);
@@ -1116,8 +1140,8 @@ void SetError(Signal &sig, DWORD dwErrCode)
 OLECHAR *StringToBSTR(const char *psz)
 {
 	// cnt includes null-terminater
-	int cnt = ::MultiByteToWideChar(CP_UTF8, 0, psz, -1, NULL, 0);
-	OLECHAR *bstr = ::SysAllocStringByteLen(NULL, (cnt + 1) * sizeof(OLECHAR));
+	int cnt = ::MultiByteToWideChar(CP_UTF8, 0, psz, -1, nullptr, 0);
+	OLECHAR *bstr = ::SysAllocStringByteLen(nullptr, (cnt + 1) * sizeof(OLECHAR));
 	::MultiByteToWideChar(CP_UTF8, 0, psz, -1, bstr, cnt);
 	bstr[cnt] = 0;
 	return bstr;
@@ -1126,14 +1150,14 @@ OLECHAR *StringToBSTR(const char *psz)
 String BSTRToString(const OLECHAR *bstr)
 {
 	// cnt includes null-terminater
-	int cnt = ::WideCharToMultiByte(CP_UTF8, 0, bstr, -1, NULL, 0, NULL, NULL);
+	int cnt = ::WideCharToMultiByte(CP_UTF8, 0, bstr, -1, nullptr, 0, nullptr, nullptr);
 	char *psz = new char [cnt + 1];
-	::WideCharToMultiByte(CP_UTF8, 0, bstr, -1, psz, cnt, NULL, NULL);
+	::WideCharToMultiByte(CP_UTF8, 0, bstr, -1, psz, cnt, nullptr, nullptr);
 	psz[cnt] = '\0';
 	return String(psz);
 }
 
-bool ValueToVariant(Signal sig, VARIANT &var, const Value &value)
+bool ValueToVariant(Signal &sig, VARIANT &var, const Value &value)
 {
 	//::printf("ValueToVariant(%s %s)\n", value.GetTypeName(), value.ToString().c_str());
 	::VariantInit(&var);
@@ -1187,7 +1211,7 @@ bool ValueToVariant(Signal sig, VARIANT &var, const Value &value)
 	return true;
 }
 
-bool VariantToValue(Environment &env, Signal sig, Value &value, const VARIANT &var)
+bool VariantToValue(Environment &env, Signal &sig, Value &value, const VARIANT &var)
 {
 	VARTYPE type = var.vt & VT_TYPEMASK;
 	if (var.vt & VT_ARRAY) {
@@ -1235,7 +1259,7 @@ bool VariantToValue(Environment &env, Signal sig, Value &value, const VARIANT &v
 	return true;
 }
 
-Value RegDataToValue(Environment &env, Signal sig,
+Value RegDataToValue(Environment &env, Signal &sig,
 								DWORD dwType, LPCBYTE lpData, DWORD cbData)
 {
 	Value result;
@@ -1250,12 +1274,12 @@ Value RegDataToValue(Environment &env, Signal sig,
 	} else if (dwType == REG_LINK) {
 		sig.SetError(ERR_ValueError, "cantnot convert from registry value REG_LINK");
 	} else if (dwType == REG_MULTI_SZ) {
-		ValueList &valList = result.InitAsList(env);
+		Object_list *pObjList = result.InitAsList(env);
 		size_t bytesSum = 0;
 		while (bytesSum + 1 < static_cast<size_t>(cbData)) {
 			Value value(OAL::FromNativeString(
 								reinterpret_cast<const char *>(lpData)));
-			valList.push_back(value);
+			pObjList->Add(value);
 			size_t bytes = ::strlen(reinterpret_cast<const char *>(lpData)) + 1;
 			lpData += bytes;
 			bytesSum += bytes;
@@ -1273,7 +1297,7 @@ Value RegDataToValue(Environment &env, Signal sig,
 	return result;
 }
 
-bool ValueToRegData(Environment &env, Signal sig, const Value &value,
+bool ValueToRegData(Environment &env, Signal &sig, const Value &value,
 								DWORD *pdwType, LPBYTE *lppData, DWORD *pcbData)
 {
 	if (value.Is_number()) {
