@@ -11,7 +11,7 @@ void AssignFunctions(Environment &env);
 
 typedef std::map<GLenum, size_t> ParamInfoDict;
 
-static ParamInfoDict *_pParamInfoDict = NULL;
+static ParamInfoDict *_pParamInfoDict = nullptr;
 
 //-----------------------------------------------------------------------------
 // helper
@@ -19,15 +19,17 @@ static ParamInfoDict *_pParamInfoDict = NULL;
 size_t GetParamCount(GLenum pname)
 {
 	ParamInfoDict::iterator iter = _pParamInfoDict->find(pname);
-	if (iter == _pParamInfoDict->end()) return 16;
+	if (iter == _pParamInfoDict->end()) return 1;
 	return iter->second;
 }
 
-bool CheckParamCount(GLenum pname, size_t n)
+bool CheckArray(Signal &sig, GLenum pname, const Array *pArray)
 {
 	ParamInfoDict::iterator iter = _pParamInfoDict->find(pname);
 	if (iter == _pParamInfoDict->end()) return true;
-	return n == iter->second;
+	if (pArray->HasShape(iter->second)) return true;
+	sig.SetError(ERR_ValueError, "the array must contain %d elements", iter->second);
+	return false;
 }
 
 void PrepareParamInfoDict()
@@ -1377,6 +1379,33 @@ void PrepareParamInfoDict()
 #endif
 #if defined(GL_ZOOM_Y)
 		{ GL_ZOOM_Y,								 1 },
+#endif
+#if defined(GL_BUFFER_ACCESS)
+		{ GL_BUFFER_ACCESS,							 1 },
+#endif
+#if defined(GL_BUFFER_ACCESS_FLAGS)
+		{ GL_BUFFER_ACCESS_FLAGS,					 1 },
+#endif
+#if defined(GL_BUFFER_IMMUTABLE_STORAGE)
+		{ GL_BUFFER_IMMUTABLE_STORAGE,				 1 },
+#endif
+#if defined(GL_BUFFER_MAPPED)
+		{ GL_BUFFER_MAPPED,							 1 },
+#endif
+#if defined(GL_BUFFER_MAP_LENGTH)
+		{ GL_BUFFER_MAP_LENGTH,						 1 },
+#endif
+#if defined(GL_BUFFER_MAP_OFFSET)
+		{ GL_BUFFER_MAP_OFFSET,						 1 },
+#endif
+#if defined(GL_BUFFER_SIZE)
+		{ GL_BUFFER_SIZE,							 1 },
+#endif
+#if defined(GL_BUFFER_STORAGE_FLAGS)
+		{ GL_BUFFER_STORAGE_FLAGS,					 1 },
+#endif
+#if defined(GL_BUFFER_USAGE)
+		{ GL_BUFFER_USAGE,							 1 },
 #endif
 	};
 	for (int i = 0; i < ArraySizeOf(tbl); i++) {
@@ -1384,7 +1413,7 @@ void PrepareParamInfoDict()
 	}
 }
 
-GLenum GetImageFormat(Signal sig, const Image *pImage)
+GLenum GetImageFormat(Environment &env, const Image *pImage)
 {
 	GLenum format = 0;
 	Image::Format fmt = pImage->GetFormat();
@@ -1392,16 +1421,34 @@ GLenum GetImageFormat(Signal sig, const Image *pImage)
 		(fmt == Image::FORMAT_RGB)? GL_BGR_EXT :
 		(fmt == Image::FORMAT_RGBA)? GL_BGRA_EXT : 0;
 	if (format == 0) {
-		sig.SetError(ERR_ValueError, "unsupported image type");
+		env.SetError(ERR_ValueError, "unsupported image type");
 	}
 	return format;
 }
 
-void SetError_NotImpFunction(Signal &sig, const char *funcName)
+void SetError_NotImpFunction(Environment &env, const char *funcName)
 {
-	sig.SetError(ERR_RuntimeError, "not implemented function %s", funcName);
+	env.SetError(ERR_NotImplementedError, "not implemented function %s", funcName);
 }
 
+void SetError_RequiredGLVersion(Environment &env, const char *version)
+{
+	env.SetError(ERR_NotImplementedError, "available in OpenGL %s or later", version);
+}
+
+#if defined(__GLEW_H__)
+bool SetupGLEW(Environment &env)
+{
+	static bool setupFlag = false;
+	if (setupFlag) return true;
+	setupFlag = true;
+	GLenum err = glewInit();
+	if (err == GLEW_OK) return true;
+	env.SetError(ERR_RuntimeError, "%s", glewGetErrorString(err));
+	return false;
+}
+#endif
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for Object_image
 // These method are available after importing opengl module.
@@ -1415,15 +1462,21 @@ Gura_DeclareMethod(image, opengl)
 
 Gura_ImplementMethod(image, opengl)
 {
-	Object_image *pThis = Object_image::GetThisObj(args);
-	if (!pThis->GetImage()->CheckValid(sig)) return Value::Null;
-	if (!DoGLSection(env, sig, args, pThis->GetImage())) return Value::Null;
-	return args.GetThis();
+	Signal &sig = env.GetSignal();
+	Object_image *pThis = Object_image::GetObjectThis(arg);
+	if (!pThis->GetImage()->CheckValid(sig)) return Value::Nil;
+	if (!DoGLSection(env, arg, pThis->GetImage())) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 //-----------------------------------------------------------------------------
-// Gura module functions: opengl
+// Module Entries
 //-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	PrepareParamInfoDict();
@@ -1440,7 +1493,7 @@ Gura_ModuleTerminate()
 //-----------------------------------------------------------------------------
 // utilities
 //-----------------------------------------------------------------------------
-bool DoGLSection(Environment &env, Signal sig, Args &args, Image *pImage)
+bool DoGLSection(Environment &env, Argument &arg, Image *pImage)
 {
 #if GURA_USE_MSWIN_DIB
 	PIXELFORMATDESCRIPTOR pfd = { 
@@ -1449,19 +1502,18 @@ bool DoGLSection(Environment &env, Signal sig, Args &args, Image *pImage)
 		static_cast<BYTE>(pImage->GetBitsPerPixel()), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 		32, 0, 0, PFD_MAIN_PLANE, 0, 0, 0, 0
 	}; 
-	HDC hdc = ::CreateCompatibleDC(NULL);
+	HDC hdc = ::CreateCompatibleDC(nullptr);
 	HBITMAP hBmp = pImage->GetHBITMAP();
 	HBITMAP hBmpOld = reinterpret_cast<HBITMAP>(::SelectObject(hdc, hBmp));
 	int iPixelFormat = ::ChoosePixelFormat(hdc, &pfd);
 	::SetPixelFormat(hdc, iPixelFormat, &pfd);
 	HGLRC hglrc = ::wglCreateContext(hdc);
 	::wglMakeCurrent(hdc, hglrc);
-	const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-	if (!sig.IsSignalled()) {
-		SeqPostHandler *pSeqPostHandler = NULL;
-		pExprBlock->Exec2(env, sig, pSeqPostHandler);
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (!env.IsSignalled()) {
+		pExprBlock->Exec(env);
 	}
-	::wglMakeCurrent(NULL, NULL);
+	::wglMakeCurrent(nullptr, nullptr);
 	::wglDeleteContext(hglrc);
 	::SelectObject(hdc, hBmpOld);
 	::DeleteDC(hdc);
@@ -1474,7 +1526,7 @@ bool DoGLSection(Environment &env, Signal sig, Args &args, Image *pImage)
 	GLsizei height = static_cast<GLsizei>(pImage->GetHeight());
     CGLError errCode = kCGLNoError;
 	GLuint texOut = 0;
-	CGLContextObj ctx = NULL;
+	CGLContextObj ctx = nullptr;
 	CGLContextObj ctxOrg = CGLGetCurrentContext();
 	CGLPixelFormatAttribute attributes[4] = {
 		kCGLPFAAccelerated,
@@ -1482,29 +1534,28 @@ bool DoGLSection(Environment &env, Signal sig, Args &args, Image *pImage)
 		(CGLPixelFormatAttribute)kCGLOGLPVersion_3_2_Core,
 		(CGLPixelFormatAttribute)0
 	};
-	CGLPixelFormatObj pixelFormat = NULL;
+	CGLPixelFormatObj pixelFormat = nullptr;
 	GLint numPixelFormats = 0;
 	errCode = CGLChoosePixelFormat(attributes, &pixelFormat, &numPixelFormats);
-	errCode = CGLCreateContext(pixelFormat, NULL, &ctx);
+	errCode = CGLCreateContext(pixelFormat, nullptr, &ctx);
 	errCode = CGLSetCurrentContext(ctx);
 	glGenTextures(1, &texOut);
 	glBindTexture(GL_TEXTURE_2D, texOut);
-	glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, width, height, 0, GL_RGBA, GL_FLOAT, NULL);
+	glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, width, height, 0, GL_RGBA, GL_FLOAT, nullptr);
 	GLuint frameBuffer = 0;
 	glGenFramebuffers(1, &frameBuffer);
 	glBindFramebuffer(GL_FRAMEBUFFER, frameBuffer);
 	glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, texOut, 0);
 	GLenum status = glCheckFramebufferStatus(GL_FRAMEBUFFER);
 	if (status == GL_FRAMEBUFFER_COMPLETE) {
-		const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-		if (!sig.IsSignalled()) {
-			SeqPostHandler *pSeqPostHandler = NULL;
-			pExprBlock->Exec2(env, sig, pSeqPostHandler);
+		const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+		if (!env.IsSignalled()) {
+			pExprBlock->Exec(env);
 		}
 	}
 	do {
-		GLenum format = GetImageFormat(sig, pImage);
-		if (sig.IsSignalled()) return false;
+		GLenum format = GetImageFormat(env, pImage);
+		if (env.IsSignalled()) return false;
 		glBindTexture(GL_TEXTURE_2D, texOut);
 		glGetTexImage(GL_TEXTURE_2D, 0, format, GL_UNSIGNED_BYTE, pImage->GetBuffer());
 	} while (0);
@@ -1513,24 +1564,22 @@ bool DoGLSection(Environment &env, Signal sig, Args &args, Image *pImage)
 	CGLSetCurrentContext(ctxOrg);
 	CGLDestroyContext(ctx);
 	return true;
-#else
-#if 0
-	int width = static_cast<int>(pImage->GetWidth());
-	int height = static_cast<int>(pImage->GetHeight());
-	GLXFBConfig config;
-	Pixmap pixmap = ::XCreatePixmap(NULL, d, width, height, 32);
-	GLXPixmap xid = ::glXCreatePixmap(NULL, config, pixmap, NULL);
-	GLXContext ctx;
-	::glXMakeCurrent(NULL, xid, ctx);
-	const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-	if (!sig.IsSignalled()) {
-		pExprBlock->Exec2(env, sig);
+#elif defined(GURA_ON_LINUX)
+	GLenum format = (pImage->GetFormat() == Image::FORMAT_RGB)? OSMESA_BGR : OSMESA_BGRA;
+	GLsizei width = static_cast<GLsizei>(pImage->GetWidth());
+	GLsizei height = static_cast<GLsizei>(pImage->GetHeight());
+	OSMesaContext ctx = ::OSMesaCreateContext(format, nullptr);
+	if (!::OSMesaMakeCurrent(ctx, pImage->GetBuffer(), GL_UNSIGNED_BYTE, width, height)) {
+		env.SetError(ERR_RuntimeError, "failed to create OpenGL off-line context");
+		return false;
 	}
-	::glReadPixels(0, 0, width, height, GL_BGRA_EXT,
-									GL_UNSIGNED_BYTE, pImage->GetBuffer());
-#endif
-#endif
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (!env.IsSignalled()) {
+		pExprBlock->Exec(env);
+	}
+	//::OSMesaDestroyContext(ctx);
 	return true;
+#endif
 }
 
 Gura_EndModuleBody(opengl, opengl)
