@@ -9,7 +9,7 @@ Gura_BeginModuleBody(re)
 // IteratorSplit
 //-----------------------------------------------------------------------------
 IteratorSplit::IteratorSplit(Object_pattern *pObjPattern, const String &str, int cntMax) :
-		Iterator(false), _pObjPattern(pObjPattern), _str(str),
+		Iterator(Finite), _pObjPattern(pObjPattern), _str(str),
 		_cnt(cntMax), _idx(0),
 		_len(static_cast<int>(str.size())), _doneFlag(false),
 		_pRegion(::onig_region_new())
@@ -23,11 +23,12 @@ IteratorSplit::~IteratorSplit()
 
 Iterator *IteratorSplit::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool IteratorSplit::DoNext(Environment &env, Signal sig, Value &value)
+bool IteratorSplit::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	const char *str = _str.c_str();
 	if (_doneFlag) return false;
 	if (_cnt == 0) {
@@ -82,7 +83,7 @@ void IteratorSplit::GatherFollower(Environment::Frame *pFrame, EnvironmentSet &e
 // IteratorScan
 //-----------------------------------------------------------------------------
 IteratorScan::IteratorScan(Object_pattern *pObjPattern, const String &str, int pos, int posEnd) :
-		Iterator(false), _pObjPattern(pObjPattern), _str(str),
+		Iterator(Finite), _pObjPattern(pObjPattern), _str(str),
 		_len(static_cast<int>(str.size())), _pRegion(::onig_region_new())
 {
 	_idx = static_cast<int>(CalcCharOffset(str.c_str(), pos));
@@ -96,11 +97,12 @@ IteratorScan::~IteratorScan()
 
 Iterator *IteratorScan::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool IteratorScan::DoNext(Environment &env, Signal sig, Value &value)
+bool IteratorScan::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	if (_idx >= _idxEnd) return false;
 	const char *str = _str.c_str();
 	int rtn = ::onig_search(_pObjPattern->GetRegEx(),
@@ -149,7 +151,7 @@ void IteratorScan::GatherFollower(Environment::Frame *pFrame, EnvironmentSet &en
 // IteratorGrep
 //-----------------------------------------------------------------------------
 IteratorGrep::IteratorGrep(Iterator *pIteratorSrc, Object_pattern *pObjPattern) :
-		Iterator(pIteratorSrc->IsInfinite()),
+		Iterator(pIteratorSrc->GetFiniteness()),
 		_pIteratorSrc(pIteratorSrc), _pObjPattern(pObjPattern)
 {
 }
@@ -159,10 +161,11 @@ Iterator *IteratorGrep::GetSource()
 	return _pIteratorSrc.get();
 }
 
-bool IteratorGrep::DoNext(Environment &env, Signal sig, Value &value)
+bool IteratorGrep::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	const int pos = 0, posEnd = -1;
-	while (_pIteratorSrc->Next(env, sig, value)) {
+	while (_pIteratorSrc->Next(env, value)) {
 		String str = value.ToString(false);
 		if (sig.IsSignalled()) return false;
 		value = DoMatch(env, sig,
@@ -193,16 +196,16 @@ void IteratorGrep::GatherFollower(Environment::Frame *pFrame, EnvironmentSet &en
 // IteratorGroup
 //-----------------------------------------------------------------------------
 IteratorGroup::IteratorGroup(Object_match *pObjMatch) :
-						Iterator(false), _pObjMatch(pObjMatch), _iGroup(1)
+						Iterator(Finite), _pObjMatch(pObjMatch), _iGroup(1)
 {
 }
 
 Iterator *IteratorGroup::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool IteratorGroup::DoNext(Environment &env, Signal sig, Value &value)
+bool IteratorGroup::DoNext(Environment &env, Value &value)
 {
 	const GroupList &groupList = _pObjMatch->GetGroupList();
 	if (_iGroup < groupList.size()) {
@@ -237,41 +240,14 @@ Object *Object_match::Clone() const
 	return new Object_match(*this);
 }
 
-Value Object_match::IndexGet(Environment &env, Signal sig, const Value &valueIdx)
+Value Object_match::IndexGet(Environment &env, const Value &valueIdx)
 {
+	Signal &sig = GetSignal();
 	const Group *pGroup = GetGroup(sig, valueIdx);
-	if (pGroup == NULL) return Value::Null;
+	if (pGroup == nullptr) return Value::Nil;
 	return Value(pGroup->GetString());
 }
 
-bool Object_match::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_Symbol(source));
-	symbols.insert(Gura_Symbol(string));
-	symbols.insert(Gura_Symbol(begin));
-	symbols.insert(Gura_Symbol(end));
-	return true;
-}
-
-Value Object_match::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	const Group &group = _groupList.front();
-	if (pSymbol->IsIdentical(Gura_Symbol(source))) {
-		return Value(GetString());
-	} else if (pSymbol->IsIdentical(Gura_Symbol(string))) {
-		return Value(group.GetString());
-	} else if (pSymbol->IsIdentical(Gura_Symbol(begin))) {
-		return Value(group.GetPosBegin());
-	} else if (pSymbol->IsIdentical(Gura_Symbol(end))) {
-		return Value(group.GetPosEnd());
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_match::ToString(bool exprFlag)
 {
 	String rtn;
@@ -289,25 +265,25 @@ bool Object_match::SetMatchInfo(const char *str,
 {
 	if (pRegion->num_regs == 0) return false;
 	::onig_foreach_name(pRegEx, &ForeachNameCallbackStub, this);
-	_pStrRef.reset(new StringRef(str));
+	_pStrShrd.reset(new StringShared(str));
 	for (int iGroup = 0; iGroup < pRegion->num_regs; iGroup++) {
 		int idxBegin = pRegion->beg[iGroup];
 		int idxEnd = pRegion->end[iGroup];
 		if (idxBegin > idxEnd) return false;
 		int posBegin = static_cast<int>(CalcCharPos(str, idxBegin)) + posOffset;
 		int posEnd = static_cast<int>(CalcCharPos(str, idxEnd)) + posOffset;
-		_groupList.push_back(Group(_pStrRef->Reference(), posBegin, posEnd));
+		_groupList.push_back(Group(_pStrShrd->Reference(), posBegin, posEnd));
 	}
 	return true;
 }
 
-const Group *Object_match::GetGroup(Signal sig, const Value &index) const
+const Group *Object_match::GetGroup(Signal &sig, const Value &index) const
 {
 	if (index.Is_number()) {
 		size_t indexNum = static_cast<size_t>(index.GetNumber());
 		if (indexNum >= _groupList.size()) {
 			sig.SetError(ERR_IndexError, "index is out of range");
-			return NULL;
+			return nullptr;
 		}
 		return &_groupList[indexNum];
 	} else if (index.Is_string()) {
@@ -316,12 +292,12 @@ const Group *Object_match::GetGroup(Signal sig, const Value &index) const
 		if (iter == _groupNameDict.end()) {
 			sig.SetError(ERR_IndexError,
 				"regular expression doesn't have a group named '%s%", name);
-			return NULL;
+			return nullptr;
 		}
 		return &_groupList[iter->second];
 	} else {
 		sig.SetError(ERR_TypeError, "invalid argument type");
-		return NULL;
+		return nullptr;
 	}
 }
 
@@ -341,6 +317,76 @@ int Object_match::ForeachNameCallbackStub(
 					ForeachNameCallback(name, nGroups, idxGroupTbl, pRegEx);
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// re.match#begin
+Gura_DeclareProperty_R(match, begin)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(match, begin)
+{
+	Object_match *pObjThis = Object_match::GetObject(valueThis);
+	const Group &group = pObjThis->GetGroupList().front();
+	return Value(group.GetPosBegin());
+}
+
+// re.match#end
+Gura_DeclareProperty_R(match, end)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(match, end)
+{
+	Object_match *pObjThis = Object_match::GetObject(valueThis);
+	const Group &group = pObjThis->GetGroupList().front();
+	return Value(group.GetPosEnd());
+}
+
+// re.match#source
+Gura_DeclareProperty_R(match, source)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(match, source)
+{
+	Object_match *pObjThis = Object_match::GetObject(valueThis);
+	return Value(pObjThis->GetString());
+}
+
+// re.match#string
+Gura_DeclareProperty_R(match, string)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(match, string)
+{
+	Object_match *pObjThis = Object_match::GetObject(valueThis);
+	const Group &group = pObjThis->GetGroupList().front();
+	return Value(group.GetString());
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for re.match
 //-----------------------------------------------------------------------------
@@ -350,7 +396,7 @@ Gura_DeclareFunction(match)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "pattern", VTYPE_pattern);
 	DeclareArg(env, "str", VTYPE_string);
-	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "endpos", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(match));
@@ -359,11 +405,12 @@ Gura_DeclareFunction(match)
 
 Gura_ImplementFunction(match)
 {
-	regex_t *pRegEx = dynamic_cast<Object_pattern *>(args.GetObject(0))->GetRegEx();
-	Value result = DoMatch(env, sig, pRegEx, args.GetString(1),
-			args.GetInt(2), args.Is_number(3)? args.GetInt(3) : -1);
+	Signal &sig = env.GetSignal();
+	regex_t *pRegEx = dynamic_cast<Object_pattern *>(arg.GetObject(0))->GetRegEx();
+	Value result = DoMatch(env, sig, pRegEx, arg.GetString(1),
+			arg.GetInt(2), arg.Is_number(3)? arg.GetInt(3) : -1);
 	if (result.IsInvalid()) return result;
-	return ReturnValue(env, sig, args, result);
+	return ReturnValue(env, arg, result);
 }
 
 // re.match#group(index):map
@@ -372,7 +419,7 @@ Gura_DeclareMethod(match, group)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "index", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Returns a `re.group` instance that is positioned by the specified index.\n"
 		"\n"
 		"The argument `index` is a value of `number` or `string`.\n"
@@ -383,7 +430,7 @@ Gura_DeclareMethod(match, group)
 		"Below is an example:\n"
 		"\n"
 		"    str = '12:34:56'\n"
-		"    m = str.match(r'(\d\d):(\d\d):(\d\d)')\n"
+		"    m = str.match(r'(\\d\\d):(\\d\\d):(\\d\\d)')\n"
 		"    m.group(0).string // returns the whole region of matching: 12:34:56\n"
 		"    m.group(1).string // returns the 1st group: 12\n"
 		"    m.group(2).string // returns the 2nd group: 34\n"
@@ -395,7 +442,7 @@ Gura_DeclareMethod(match, group)
 		"Below is an example:\n"
 		"\n"
 		"    str = '12:34:56'\n"
-		"    m = str.match(r'(?<hour>\d\d):(?<min>\d\d):(?<sec>\d\d)')\n"
+		"    m = str.match(r'(?<hour>\\d\\d):(?<min>\\d\\d):(?<sec>\\d\\d)')\n"
 		"    m.group('hour').string // returns the group named 'hour': 12\n"
 		"    m.group('min').string  // returns the group named 'min': 34\n"
 		"    m.group('sec').string  // returns the group named 'sec': 56\n");
@@ -403,9 +450,10 @@ Gura_DeclareMethod(match, group)
 
 Gura_ImplementMethod(match, group)
 {
-	Object_match *pThis = Object_match::GetThisObj(args);
-	const Group *pGroup = pThis->GetGroup(sig, args.GetValue(0));
-	if (pGroup == NULL) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_match *pThis = Object_match::GetObjectThis(arg);
+	const Group *pGroup = pThis->GetGroup(sig, arg.GetValue(0));
+	if (pGroup == nullptr) return Value::Nil;
 	return Value(new Object_group(*pGroup));
 }
 
@@ -415,7 +463,7 @@ Gura_DeclareMethod(match, groups)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates an iterator that returns `re.group` instances.\n"
 		"\n"
 		GURA_HELPTEXT_ITERATOR_en());
@@ -423,9 +471,9 @@ Gura_DeclareMethod(match, groups)
 
 Gura_ImplementMethod(match, groups)
 {
-	Object_match *pThis = Object_match::GetThisObj(args);
+	Object_match *pThis = Object_match::GetObjectThis(arg);
 	AutoPtr<Iterator> pIterator(new IteratorGroup(pThis->Reference()));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 //-----------------------------------------------------------------------------
@@ -433,9 +481,16 @@ Gura_ImplementMethod(match, groups)
 //-----------------------------------------------------------------------------
 Gura_ImplementUserClass(match)
 {
-	Gura_AssignFunction(match);
+	// Assignment of properties
+	Gura_AssignProperty(match, begin);
+	Gura_AssignProperty(match, end);
+	Gura_AssignProperty(match, source);
+	Gura_AssignProperty(match, string);
+	// Assignment of methods
 	Gura_AssignMethod(match, group);
 	Gura_AssignMethod(match, groups);
+	// Assignment of function
+	Gura_AssignFunction(match);
 }
 
 //-----------------------------------------------------------------------------
@@ -450,30 +505,6 @@ Object *Object_group::Clone() const
 	return new Object_group(*this);
 }
 
-bool Object_group::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_Symbol(string));
-	symbols.insert(Gura_Symbol(begin));
-	symbols.insert(Gura_Symbol(end));
-	return true;
-}
-
-Value Object_group::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_Symbol(string))) {
-		return Value(_group.GetString());
-	} else if (pSymbol->IsIdentical(Gura_Symbol(begin))) {
-		return Value(_group.GetPosBegin());
-	} else if (pSymbol->IsIdentical(Gura_Symbol(end))) {
-		return Value(_group.GetPosEnd());
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_group::ToString(bool exprFlag)
 {
 	String rtn;
@@ -485,11 +516,67 @@ String Object_group::ToString(bool exprFlag)
 	return rtn;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// re.group#begin
+Gura_DeclareProperty_R(group, begin)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(group, begin)
+{
+	const Group &group = Object_group::GetObject(valueThis)->GetGroup();
+	return Value(group.GetPosBegin());
+}
+
+// re.group#end
+Gura_DeclareProperty_R(group, end)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(group, end)
+{
+	const Group &group = Object_group::GetObject(valueThis)->GetGroup();
+	return Value(group.GetPosEnd());
+}
+
+// re.group#string
+Gura_DeclareProperty_R(group, string)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(group, string)
+{
+	const Group &group = Object_group::GetObject(valueThis)->GetGroup();
+	return Value(group.GetString());
+}
+
 //-----------------------------------------------------------------------------
 // Class implementation for re.group
 //-----------------------------------------------------------------------------
 Gura_ImplementUserClass(group)
 {
+	// Assignment of properties
+	Gura_AssignProperty(group, begin);
+	Gura_AssignProperty(group, end);
+	Gura_AssignProperty(group, string);
+	// Assignment of value
 	Gura_AssignValue(group, Reference());
 }
 
@@ -498,14 +585,14 @@ Gura_ImplementUserClass(group)
 //-----------------------------------------------------------------------------
 Object_pattern::~Object_pattern()
 {
-	if (_pRegEx != NULL) {
+	if (_pRegEx != nullptr) {
 		::onig_free(_pRegEx);
 	}
 }
 
 Object *Object_pattern::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_pattern::ToString(bool exprFlag)
@@ -530,7 +617,7 @@ Gura_DeclareFunction(pattern)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(pattern));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates a `re.pattern` instance from the given pattern string.\n"
 		"\n"
 		"Following attributes would customize some traits of the pattern:\n"
@@ -543,12 +630,13 @@ Gura_DeclareFunction(pattern)
 
 Gura_ImplementFunction(pattern)
 {
+	Signal &sig = env.GetSignal();
 	Object_pattern *pObjPattern = new Object_pattern();
-	if (!pObjPattern->SetPattern(sig, args.GetString(0), args.GetAttrs())) {
+	if (!pObjPattern->SetPattern(sig, arg.GetString(0), arg.GetAttrs())) {
 		delete pObjPattern;
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(pObjPattern));
+	return ReturnValue(env, arg, Value(pObjPattern));
 }
 
 // re.pattern#match(str:string, pos:number => 0, endpos?:number):map {block?}
@@ -556,7 +644,7 @@ Gura_DeclareMethod(pattern, match)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "str", VTYPE_string);
-	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "endpos", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	LinkHelp(env.LookupClass(VTYPE_string), Symbol::Add("match"));
@@ -564,11 +652,12 @@ Gura_DeclareMethod(pattern, match)
 
 Gura_ImplementMethod(pattern, match)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
-	Value result = DoMatch(env, sig, pThis->GetRegEx(), args.GetString(0),
-			args.GetInt(1), args.Is_number(2)? args.GetInt(2) : -1);
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
+	Value result = DoMatch(env, sig, pThis->GetRegEx(), arg.GetString(0),
+			arg.GetInt(1), arg.Is_number(2)? arg.GetInt(2) : -1);
 	if (result.IsInvalid()) return result;
-	return ReturnValue(env, sig, args, result);
+	return ReturnValue(env, arg, result);
 }
 
 // re.pattern#sub(replace, str:string, count?:number):map {block?}
@@ -584,26 +673,27 @@ Gura_DeclareMethod(pattern, sub)
 
 Gura_ImplementMethod(pattern, sub)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
-	int cnt = args.Is_number(2)? static_cast<int>(args.GetNumber(2)) : -1;
+	Signal &sig = env.GetSignal();
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
+	int cnt = arg.Is_number(2)? static_cast<int>(arg.GetNumber(2)) : -1;
 	String result;
-	if (args.Is_string(0)) {
+	if (arg.Is_string(0)) {
 		result = DoSubWithString(env, sig, pThis->GetRegEx(),
-						args.GetString(0), args.GetString(1), cnt);
-	} else if (args.Is_function(0)) {
+						arg.GetString(0), arg.GetString(1), cnt);
+	} else if (arg.Is_function(0)) {
 		result = DoSubWithFunc(env, sig, pThis->GetRegEx(),
-						args.GetFunction(0), args.GetString(1), cnt);
+						arg.GetFunction(0), arg.GetString(1), cnt);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	if (sig.IsSignalled()) return Value::Null;
-	if (!args.IsBlockSpecified()) return Value(result);
+	if (sig.IsSignalled()) return Value::Nil;
+	if (!arg.IsBlockSpecified()) return Value(result);
 	ValueList valListArg;
 	valListArg.reserve(2);
 	valListArg.push_back(Value(result));
-	valListArg.push_back(Value(result != args.GetStringSTL(1)));
-	return ReturnValues(env, sig, args, valListArg);
+	valListArg.push_back(Value(result != arg.GetStringSTL(1)));
+	return ReturnValues(env, arg, valListArg);
 }
 
 // re.pattern#split(str:string, count?:number):map {block?}
@@ -618,12 +708,12 @@ Gura_DeclareMethod(pattern, split)
 
 Gura_ImplementMethod(pattern, split)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	Object_pattern *pObjPattern = Object_pattern::Reference(pThis);
-	String str = args.GetStringSTL(0);
-	int cntMax = args.Is_number(1)? static_cast<int>(args.GetNumber(1)) : -1;
+	String str = arg.GetStringSTL(0);
+	int cntMax = arg.Is_number(1)? static_cast<int>(arg.GetNumber(1)) : -1;
 	AutoPtr<Iterator> pIterator(new IteratorSplit(pObjPattern, str, cntMax));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 // re.pattern#scan(str:string, pos:number => 0, endpos?:number):map {block?}
@@ -631,7 +721,7 @@ Gura_DeclareMethod(pattern, scan)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "str", VTYPE_string);
-	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "endpos", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	LinkHelp(env.LookupClass(VTYPE_string), Symbol::Add("scan"));
@@ -639,12 +729,12 @@ Gura_DeclareMethod(pattern, scan)
 
 Gura_ImplementMethod(pattern, scan)
 {
-	Object_pattern *pThis = Object_pattern::GetThisObj(args);
+	Object_pattern *pThis = Object_pattern::GetObjectThis(arg);
 	Object_pattern *pObjPattern = Object_pattern::Reference(pThis);
-	String str = args.GetStringSTL(0);
-	int posEnd = args.Is_number(2)? args.GetInt(2) : -1;
-	AutoPtr<Iterator> pIterator(new IteratorScan(pObjPattern, str, args.GetInt(1), posEnd));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	String str = arg.GetStringSTL(0);
+	int posEnd = arg.Is_number(2)? arg.GetInt(2) : -1;
+	AutoPtr<Iterator> pIterator(new IteratorScan(pObjPattern, str, arg.GetInt(1), posEnd));
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 //-----------------------------------------------------------------------------
@@ -661,9 +751,10 @@ Gura_ImplementUserClassWithCast(pattern)
 
 Gura_ImplementCastFrom(pattern)
 {
+	Signal &sig = GetSignal();
 	if (value.Is_string()) {
 		Object_pattern *pObjPattern = new Object_pattern();
-		if (!pObjPattern->SetPattern(sig, value.GetString(), SymbolSet::Null)) {
+		if (!pObjPattern->SetPattern(sig, value.GetString(), SymbolSet::Empty)) {
 			delete pObjPattern;
 			return false;
 		}
@@ -686,11 +777,11 @@ Gura_DeclareMethod(string, match)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "pattern", VTYPE_pattern);
-	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "endpos", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Applies a pattern matching to the given string and returns a `re.match` instance\n"
 		"if the matching successes. If not, it would return `nil`.\n"
 		"\n"
@@ -705,12 +796,13 @@ Gura_DeclareMethod(string, match)
 
 Gura_ImplementMethod(string, match)
 {
-	const char *strThis = args.GetThis().GetString();
-	regex_t *pRegEx = dynamic_cast<Object_pattern *>(args.GetObject(0))->GetRegEx();
+	Signal &sig = env.GetSignal();
+	const char *strThis = arg.GetValueThis().GetString();
+	regex_t *pRegEx = dynamic_cast<Object_pattern *>(arg.GetObject(0))->GetRegEx();
 	Value result = DoMatch(env, sig, pRegEx, strThis,
-			args.GetInt(1), args.Is_number(2)? args.GetInt(2) : -1);
+			arg.GetInt(1), arg.Is_number(2)? arg.GetInt(2) : -1);
 	if (result.IsInvalid()) return result;
-	return ReturnValue(env, sig, args, result);
+	return ReturnValue(env, arg, result);
 }
 
 // string#sub(pattern:pattern, replace, count?:number):map {block?}
@@ -722,7 +814,7 @@ Gura_DeclareMethod(string, sub)
 	DeclareArg(env, "count", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Substitutes strings that matches `pattern` with the specified replacer.\n"
 		"\n"
 		"The argument `replace` takes a `string` or `function`.\n"
@@ -741,27 +833,28 @@ Gura_DeclareMethod(string, sub)
 
 Gura_ImplementMethod(string, sub)
 {
-	const char *strThis = args.GetThis().GetString();
-	regex_t *pRegEx = dynamic_cast<Object_pattern *>(args.GetObject(0))->GetRegEx();
-	int cnt = args.Is_number(2)? static_cast<int>(args.GetNumber(2)) : -1;
+	Signal &sig = env.GetSignal();
+	const char *strThis = arg.GetValueThis().GetString();
+	regex_t *pRegEx = dynamic_cast<Object_pattern *>(arg.GetObject(0))->GetRegEx();
+	int cnt = arg.Is_number(2)? static_cast<int>(arg.GetNumber(2)) : -1;
 	String result;
-	if (args.Is_string(1)) {
+	if (arg.Is_string(1)) {
 		result = DoSubWithString(env, sig, pRegEx,
-						args.GetString(1), strThis, cnt);
-	} else if (args.Is_function(1)) {
+						arg.GetString(1), strThis, cnt);
+	} else if (arg.Is_function(1)) {
 		result = DoSubWithFunc(env, sig, pRegEx,
-						args.GetFunction(1), strThis, cnt);
+						arg.GetFunction(1), strThis, cnt);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 1);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 1);
+		return Value::Nil;
 	}
-	if (sig.IsSignalled()) return Value::Null;
-	if (!args.IsBlockSpecified()) return Value(result);
+	if (sig.IsSignalled()) return Value::Nil;
+	if (!arg.IsBlockSpecified()) return Value(result);
 	ValueList valListArg;
 	valListArg.reserve(2);
 	valListArg.push_back(Value(result));
 	valListArg.push_back(Value(result != strThis));
-	return ReturnValues(env, sig, args, valListArg);
+	return ReturnValues(env, arg, valListArg);
 }
 
 // string#splitreg(pattern:pattern, count?:number):map {block?}
@@ -772,7 +865,7 @@ Gura_DeclareMethod(string, splitreg)
 	DeclareArg(env, "count", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates an iterator that splits the source string with the specified pattern.\n"
 		"\n"
 		"The argument `count` specifies the maximum number for splitting.\n"
@@ -783,12 +876,12 @@ Gura_DeclareMethod(string, splitreg)
 
 Gura_ImplementMethod(string, splitreg)
 {
-	const char *strThis = args.GetThis().GetString();
+	const char *strThis = arg.GetValueThis().GetString();
 	Object_pattern *pObjPattern =
-			dynamic_cast<Object_pattern *>(Object::Reference(args.GetObject(0)));
-	int cntMax = args.Is_number(1)? static_cast<int>(args.GetNumber(1)) : -1;
+			dynamic_cast<Object_pattern *>(Object::Reference(arg.GetObject(0)));
+	int cntMax = arg.Is_number(1)? static_cast<int>(arg.GetNumber(1)) : -1;
 	AutoPtr<Iterator> pIterator(new IteratorSplit(pObjPattern, strThis, cntMax));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 // string#scan(pattern:pattern, pos:number => 0, endpos?:number):map {block?}
@@ -796,11 +889,11 @@ Gura_DeclareMethod(string, scan)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "pattern", VTYPE_pattern);
-	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "endpos", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Creates an iterator that returns strings that match the specified pattern.\n"
 		"\n"
 		"The argument `pos` specifies the starting position for matching process.\n"
@@ -814,12 +907,12 @@ Gura_DeclareMethod(string, scan)
 
 Gura_ImplementMethod(string, scan)
 {
-	const char *strThis = args.GetThis().GetString();
+	const char *strThis = arg.GetValueThis().GetString();
 	Object_pattern *pObjPattern =
-			dynamic_cast<Object_pattern *>(Object::Reference(args.GetObject(0)));
-	int posEnd = args.Is_number(2)? args.GetInt(2) : -1;
-	AutoPtr<Iterator> pIterator(new IteratorScan(pObjPattern, strThis, args.GetInt(1), posEnd));
-	return ReturnIterator(env, sig, args, pIterator.release());
+			dynamic_cast<Object_pattern *>(Object::Reference(arg.GetObject(0)));
+	int posEnd = arg.Is_number(2)? arg.GetInt(2) : -1;
+	AutoPtr<Iterator> pIterator(new IteratorScan(pObjPattern, strThis, arg.GetInt(1), posEnd));
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 //-----------------------------------------------------------------------------
@@ -832,19 +925,20 @@ Gura_DeclareMethod(list, grep)
 	DeclareArg(env, "pattern", VTYPE_pattern);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(list, grep)
 {
-	Object_list *pThis = Object_list::GetThisObj(args);
-	Object_pattern *pObjPattern = Object_pattern::GetObject(args, 0);
+	Signal &sig = env.GetSignal();
+	Object_list *pThis = Object_list::GetObjectThis(arg);
+	Object_pattern *pObjPattern = Object_pattern::GetObject(arg, 0);
 	AutoPtr<Iterator> pIteratorSrc(pThis->CreateIterator(sig));
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	AutoPtr<Iterator> pIterator(new IteratorGrep(pIteratorSrc.release(),
 									Object_pattern::Reference(pObjPattern)));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 // iterator#grep(pattern:pattern) {block?}
@@ -854,19 +948,20 @@ Gura_DeclareMethod(iterator, grep)
 	DeclareArg(env, "pattern", VTYPE_pattern);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(iterator, grep)
 {
-	Object_iterator *pThis = Object_iterator::GetThisObj(args);
-	Object_pattern *pObjPattern = Object_pattern::GetObject(args, 0);
+	Signal &sig = env.GetSignal();
+	Object_iterator *pThis = Object_iterator::GetObjectThis(arg);
+	Object_pattern *pObjPattern = Object_pattern::GetObject(arg, 0);
 	AutoPtr<Iterator> pIteratorSrc(pThis->GetIterator()->Clone());
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	AutoPtr<Iterator> pIterator(new IteratorGrep(pIteratorSrc.release(),
 									Object_pattern::Reference(pObjPattern)));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 //-----------------------------------------------------------------------------
@@ -886,26 +981,27 @@ Gura_DeclareFunction(sub)
 
 Gura_ImplementFunction(sub)
 {
-	regex_t *pRegEx = dynamic_cast<Object_pattern *>(args.GetObject(0))->GetRegEx();
-	int cnt = args.Is_number(3)? static_cast<int>(args.GetNumber(3)) : -1;
+	Signal &sig = env.GetSignal();
+	regex_t *pRegEx = dynamic_cast<Object_pattern *>(arg.GetObject(0))->GetRegEx();
+	int cnt = arg.Is_number(3)? static_cast<int>(arg.GetNumber(3)) : -1;
 	String result;
-	if (args.Is_string(1)) {
+	if (arg.Is_string(1)) {
 		result = DoSubWithString(env, sig, pRegEx,
-						args.GetString(1), args.GetString(2), cnt);
-	} else if (args.Is_function(1)) {
+						arg.GetString(1), arg.GetString(2), cnt);
+	} else if (arg.Is_function(1)) {
 		result = DoSubWithFunc(env, sig, pRegEx,
-						args.GetFunction(1), args.GetString(2), cnt);
+						arg.GetFunction(1), arg.GetString(2), cnt);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 1);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 1);
+		return Value::Nil;
 	}
-	if (sig.IsSignalled()) return Value::Null;
-	if (!args.IsBlockSpecified()) return Value(result);
+	if (sig.IsSignalled()) return Value::Nil;
+	if (!arg.IsBlockSpecified()) return Value(result);
 	ValueList valListArg;
 	valListArg.reserve(2);
 	valListArg.push_back(Value(result));
-	valListArg.push_back(Value(result != args.GetStringSTL(2)));
-	return ReturnValues(env, sig, args, valListArg);
+	valListArg.push_back(Value(result != arg.GetStringSTL(2)));
+	return ReturnValues(env, arg, valListArg);
 }
 
 // re.split(pattern:pattern, str:string, count?:number):map {block?}
@@ -922,11 +1018,11 @@ Gura_DeclareFunction(split)
 Gura_ImplementFunction(split)
 {
 	Object_pattern *pObjPattern =
-			dynamic_cast<Object_pattern *>(Object::Reference(args.GetObject(0)));
-	String str = args.GetStringSTL(1);
-	int cntMax = args.Is_number(2)? static_cast<int>(args.GetNumber(2)) : -1;
+			dynamic_cast<Object_pattern *>(Object::Reference(arg.GetObject(0)));
+	String str = arg.GetStringSTL(1);
+	int cntMax = arg.Is_number(2)? static_cast<int>(arg.GetNumber(2)) : -1;
 	AutoPtr<Iterator> pIterator(new IteratorSplit(pObjPattern, str, cntMax));
-	return ReturnIterator(env, sig, args, pIterator.release());
+	return ReturnIterator(env, arg, pIterator.release());
 }
 
 // re.scan(pattern:pattern, str:string, pos:number => 0, endpos?:number):map {block?}
@@ -935,7 +1031,7 @@ Gura_DeclareFunction(scan)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "pattern", VTYPE_pattern);
 	DeclareArg(env, "str", VTYPE_string);
-	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, new Expr_Value(0));
+	DeclareArg(env, "pos", VTYPE_number, OCCUR_Once, FLAG_None, 0, new Expr_Value(0));
 	DeclareArg(env, "endpos", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	LinkHelp(env.LookupClass(VTYPE_string), Symbol::Add("scan"));
@@ -944,14 +1040,21 @@ Gura_DeclareFunction(scan)
 Gura_ImplementFunction(scan)
 {
 	Object_pattern *pObjPattern =
-			dynamic_cast<Object_pattern *>(Object::Reference(args.GetObject(0)));
-	String str = args.GetStringSTL(1);
-	int posEnd = args.Is_number(3)? args.GetInt(3) : -1;
-	AutoPtr<Iterator> pIterator(new IteratorScan(pObjPattern, str, args.GetInt(2), posEnd));
-	return ReturnIterator(env, sig, args, pIterator.release());
+			dynamic_cast<Object_pattern *>(Object::Reference(arg.GetObject(0)));
+	String str = arg.GetStringSTL(1);
+	int posEnd = arg.Is_number(3)? arg.GetInt(3) : -1;
+	AutoPtr<Iterator> pIterator(new IteratorScan(pObjPattern, str, arg.GetInt(2), posEnd));
+	return ReturnIterator(env, arg, pIterator.release());
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	// symbol realization
@@ -989,10 +1092,10 @@ Gura_ModuleTerminate()
 //-----------------------------------------------------------------------------
 // Utilities
 //-----------------------------------------------------------------------------
-regex_t *CreateRegEx(Signal sig, const char *pattern, const SymbolSet &attrs)
+regex_t *CreateRegEx(Signal &sig, const char *pattern, const SymbolSet &attrs)
 {
 	// ::onig_end() call may be necessary when module is destroyed
-	regex_t *pRegEx = NULL;
+	regex_t *pRegEx = nullptr;
 	OnigOptionType option = ONIG_OPTION_CAPTURE_GROUP;
 	OnigEncoding enc = ONIG_ENCODING_UTF8;
 	OnigErrorInfo errInfo;
@@ -1009,12 +1112,12 @@ regex_t *CreateRegEx(Signal sig, const char *pattern, const SymbolSet &attrs)
 				option, enc, ONIG_SYNTAX_DEFAULT, &errInfo);
 	if (rtn != ONIG_NORMAL) {
 		SetError_OnigurumaError(sig, rtn);
-		return NULL;
+		return nullptr;
 	}
 	return pRegEx;
 }
 
-Value DoMatch(Environment &env, Signal sig, regex_t *pRegEx,
+Value DoMatch(Environment &env, Signal &sig, regex_t *pRegEx,
 										const char *str, int pos, int posEnd)
 {
 	Value result;
@@ -1045,7 +1148,7 @@ Value DoMatch(Environment &env, Signal sig, regex_t *pRegEx,
 	return result;
 }
 
-String DoSubWithString(Environment &env, Signal sig, regex_t *pRegEx,
+String DoSubWithString(Environment &env, Signal &sig, regex_t *pRegEx,
 							const char *replace, const char *str, int cnt)
 {
 	enum Stat { STAT_Start, STAT_Escape };
@@ -1106,7 +1209,7 @@ error_done:
 	return "";
 }
 
-String DoSubWithFunc(Environment &env, Signal sig, regex_t *pRegEx,
+String DoSubWithFunc(Environment &env, Signal &sig, regex_t *pRegEx,
 						const Function *pFunc, const char *str, int cnt)
 {
 	enum Stat { STAT_Start, STAT_Escape };
@@ -1128,11 +1231,9 @@ String DoSubWithFunc(Environment &env, Signal sig, regex_t *pRegEx,
 				delete pObj;
 				goto error_done;
 			}
-			//Value value(pObj);
-			//ValueList valListArg(value);
-			AutoPtr<Args> pArgs(new Args());
-			pArgs->AddValue(Value(pObj));
-			Value resultFunc = pFunc->Eval(env, sig, *pArgs);
+			AutoPtr<Argument> pArg(new Argument(pFunc));
+			if (!pArg->StoreValue(env, Value(pObj))) goto error_done;
+			Value resultFunc = pFunc->Eval(env, *pArg);
 			if (sig.IsSignalled()) goto error_done;
 			result += String(str + idx, rtn - idx);
 			result += resultFunc.ToString(false);
@@ -1153,14 +1254,14 @@ error_done:
 	return "";
 }
 
-void SetError_OnigurumaError(Signal sig, int errCode)
+void SetError_OnigurumaError(Signal &sig, int errCode)
 {
 	char errMsg[ONIG_MAX_ERROR_MESSAGE_LEN];
 	::onig_error_code_to_str(reinterpret_cast<OnigUChar *>(errMsg), errCode);
 	sig.SetError(ERR_ValueError, "oniguruma: %s", errMsg);
 }
 
-void SetError_FailInOniguruma(Signal sig)
+void SetError_FailInOniguruma(Signal &sig)
 {
 	sig.SetError(ERR_SystemError,
 				"something's wrong in the process of Oniguruma library");
