@@ -14,7 +14,7 @@ Object_Event::~Object_Event()
 
 Object *Object_Event::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_Event::ToString(bool exprFlag)
@@ -183,9 +183,10 @@ String Object_Event::ToString(bool exprFlag)
 	return str;
 }
 
-bool Object_Event::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
+bool Object_Event::DoDirProp(Environment &env, SymbolSet &symbols)
 {
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
+	Signal &sig = GetSignal();
+	if (!Object::DoDirProp(env, symbols)) return false;
 	symbols.insert(Gura_UserSymbol(type));
 	if (_event.type == SDL_QUIT) {
 		symbols.insert(Gura_UserSymbol(timestamp));
@@ -347,7 +348,7 @@ bool Object_Event::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
 	return true;
 }
 
-Value Object_Event::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
+Value Object_Event::DoGetProp(Environment &env, const Symbol *pSymbol,
 						const SymbolSet &attrs, bool &evaluatedFlag)
 {
 	evaluatedFlag = true;
@@ -667,7 +668,7 @@ Value Object_Event::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbo
 		}
 	}
 	evaluatedFlag = false;
-	return Value::Null;
+	return Value::Nil;
 }
 
 const char *GetEventTypeName(Uint32 type)
@@ -748,6 +749,7 @@ const char *GetWindowEventName(Uint8 event)
 // implementation of class Event
 Gura_ImplementUserClass(Event)
 {
+	// Assignment of value
 	Gura_AssignValue(Event, Value(Reference()));
 }
 
