@@ -12,7 +12,7 @@ Object_GameController::~Object_GameController()
 
 Object *Object_GameController::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_GameController::ToString(bool exprFlag)
@@ -20,26 +20,6 @@ String Object_GameController::ToString(bool exprFlag)
 	return String("<sdl2.GameController>");
 }
 
-bool Object_GameController::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	return true;
-}
-
-Value Object_GameController::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							  const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_GameController::DoSetProp(Environment &env, Signal sig,
-							  const Symbol *pSymbol, const Value &value,
-							  const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 //-----------------------------------------------------------------------------
 // Gura interfaces for GameController
 //-----------------------------------------------------------------------------
