@@ -11,7 +11,7 @@ Object_GameControllerButtonBind::~Object_GameControllerButtonBind()
 
 Object *Object_GameControllerButtonBind::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_GameControllerButtonBind::ToString(bool exprFlag)
@@ -19,26 +19,6 @@ String Object_GameControllerButtonBind::ToString(bool exprFlag)
 	return String("<sdl2.GameControllerButtonBind>");
 }
 
-bool Object_GameControllerButtonBind::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	return true;
-}
-
-Value Object_GameControllerButtonBind::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							  const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_GameControllerButtonBind::DoSetProp(Environment &env, Signal sig,
-							  const Symbol *pSymbol, const Value &value,
-							  const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 //-----------------------------------------------------------------------------
 // Gura interfaces for GameControllerButtonBind
 //-----------------------------------------------------------------------------
