@@ -19,9 +19,6 @@ public:
 	virtual ~Object_PixelFormat();
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline SDL_PixelFormat *GetEntity() { return _pPixelFormat; }
 };
 
