@@ -19,13 +19,6 @@ public:
 	virtual ~Object_Rect();
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig,
-							const Symbol *pSymbol, const SymbolSet &attrs,
-							bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig,
-							const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline SDL_Rect *GetEntity() { return &_rect; }
 };
 
