@@ -15,15 +15,12 @@ private:
 public:
 	Gura_DeclareObjectAccessor(Surface)
 public:
-	inline Object_Surface(SDL_Surface *pSurface, Image *pImage = NULL) :
+	inline Object_Surface(SDL_Surface *pSurface, Image *pImage = nullptr) :
 		Object(Gura_UserClass(Surface)), _pSurface(pSurface), _pImage(pImage) {}
 	virtual ~Object_Surface();
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
-	static Object_Surface *CreateSurfaceFromImage(Signal sig, Image *pImage);
+	static Object_Surface *CreateSurfaceFromImage(Signal &sig, Image *pImage);
 	inline SDL_Surface *GetEntity() { return _pSurface; }
 };
 
