@@ -21,12 +21,6 @@ public:
 	virtual ~Object_Wav();
 	virtual Object *Clone() const;
 	virtual String ToString(bool exprFlag);
-	virtual bool DoDirProp(Environment &env, Signal sig, SymbolSet &symbols);
-	virtual Value DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag);
-	virtual Value DoSetProp(Environment &env, Signal sig,
-							const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag);
 	inline SDL_AudioSpec *GetSpec() { return &_spec; }
 	inline const SDL_AudioSpec *GetSpec() const { return &_spec; }
 	inline Uint8 *GetBuffer() { return _buffer; }
