@@ -7,14 +7,14 @@ Gura_DeclareMethod(Window, CreateRenderer)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(Window, CreateRenderer)
 {
 	//::SDL_CreateRenderer();
-	return Value::Null;
+	return Value::Nil;
 }
 
 // SDL_GL_CreateContext
@@ -29,7 +29,7 @@ Object_Window::~Object_Window()
 
 Object *Object_Window::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_Window::ToString(bool exprFlag)
@@ -37,26 +37,6 @@ String Object_Window::ToString(bool exprFlag)
 	return String("<sdl2.Window>");
 }
 
-bool Object_Window::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	return true;
-}
-
-Value Object_Window::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							  const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_Window::DoSetProp(Environment &env, Signal sig,
-							  const Symbol *pSymbol, const Value &value,
-							  const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 //-----------------------------------------------------------------------------
 // Gura interfaces for Window
 //-----------------------------------------------------------------------------
