@@ -34,8 +34,13 @@ Gura_AssignValue(K_##name, Value(SDLK_##name))
 Gura_BeginModuleBody(sdl2)
 
 //-----------------------------------------------------------------------------
-// Module entry
+// Module Entries
 //-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 void AssignValues(Environment &env);
 void AssignFunctions(Environment &env);
 
@@ -836,16 +841,6 @@ void SetError_SDL(Signal &sig)
 	}
 }
 
-void SetError_NotImpFunction(Signal &sig, const char *funcName)
-{
-	sig.SetError(ERR_RuntimeError, "not implemented function %s", funcName);
-}
-
-void SetError_NotImpMethod(Signal &sig, const char *className, const char *methodName)
-{
-	sig.SetError(ERR_RuntimeError, "not implemented method %s#methodName", className, methodName);
-}
-
 Gura_EndModuleBody(sdl2, sdl2)
 
 Gura_RegisterModule(sdl2)
