@@ -82,7 +82,7 @@ void Header::Initialize()
 	SetDevMinor(0);
 }
 
-bool Header::SetRawHeader(Signal sig, const star_header &rawHdr)
+bool Header::SetRawHeader(Signal &sig, const star_header &rawHdr)
 {
 	_name[sizeof(_name) - 1] = '\0';
 	_linkname[sizeof(_linkname) - 1] = '\0';
@@ -125,17 +125,17 @@ bool Header::SetRawHeader(Signal sig, const star_header &rawHdr)
 	return true;
 }
 
-void Header::ComposeHeaderBlock(void *memBlock)
+void Header::ComposeHeaderBlock(void *memBlock) const
 {
 	star_header &rawHdr = *reinterpret_cast<star_header *>(memBlock);
 	::memset(memBlock, 0x00, BLOCKSIZE);
 	::memcpy(rawHdr.name,		_name, sizeof(rawHdr.name));
-	::sprintf(rawHdr.mode,		"%06o ", _mode);
-	::sprintf(rawHdr.uid,		"%06o ", _uid);
-	::sprintf(rawHdr.gid,		"%06o ", _gid);
-	::sprintf(rawHdr.size,		"%11o", _size);
+	::sprintf(rawHdr.mode,		"%06lo ", _mode);
+	::sprintf(rawHdr.uid,		"%06lo ", _uid);
+	::sprintf(rawHdr.gid,		"%06lo ", _gid);
+	::sprintf(rawHdr.size,		"%11lo", _size);
 	rawHdr.size[11] = ' ';
-	::sprintf(rawHdr.mtime,		"%11o", _mtime.GetUnixTime());
+	::sprintf(rawHdr.mtime,		"%11lo", _mtime.GetUnixTime());
 	rawHdr.mtime[11] = ' ';
 	::memset(rawHdr.chksum,		' ', 8);
 	rawHdr.typeflag = _typeflag;
@@ -154,7 +154,7 @@ void Header::ComposeHeaderBlock(void *memBlock)
 	ULong chksum = 0;
 	UChar *p = reinterpret_cast<UChar *>(&rawHdr);
 	for (int i = 0; i < BLOCKSIZE; i++, p++) chksum += *p;
-	::sprintf(rawHdr.chksum,	"%6o ", chksum);
+	::sprintf(rawHdr.chksum,	"%6lo ", chksum);
 }
 
 //-----------------------------------------------------------------------------
@@ -171,7 +171,7 @@ Object_reader::~Object_reader()
 
 Object *Object_reader::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_reader::ToString(bool exprFlag)
@@ -187,15 +187,16 @@ String Object_reader::ToString(bool exprFlag)
 	return str;
 }
 
-bool Object_reader::Open(Environment &env, Signal sig,
+bool Object_reader::Open(Environment &env,
 						Stream *pStreamSrc, CompressionType compressionType)
 {
-	_pStreamSrc.reset(DecorateReaderStream(env, sig,
+	Signal &sig = env.GetSignal();
+	_pStreamSrc.reset(DecorateReaderStream(env,
 				pStreamSrc, pStreamSrc->GetIdentifier(), compressionType));
 	return !sig.IsSignalled();
 }
 
-Header *Object_reader::NextHeader(Signal sig)
+Header *Object_reader::NextHeader(Signal &sig)
 {
 	return ReadHeader(sig, _pStreamSrc.get(), _pMemoryBlock->GetPointer());
 }
@@ -209,15 +210,15 @@ Gura_DeclareMethod(reader, entries)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
-		"");
+		Gura_Symbol(en), 
+		"Creates an iterator that returns stream instances for each entry in the tar file.");
 }
 
 Gura_ImplementMethod(reader, entries)
 {
-	Object_reader *pThis = Object_reader::GetThisObj(args);
+	Object_reader *pThis = Object_reader::GetObjectThis(arg);
 	Iterator *pIterator = new Iterator_Entry(Object_reader::Reference(pThis));
-	return ReturnIterator(env, sig, args, pIterator);
+	return ReturnIterator(env, arg, pIterator);
 }
 
 // implementation of class reader
@@ -229,7 +230,7 @@ Gura_ImplementUserClass(reader)
 //-----------------------------------------------------------------------------
 // Implementation of Object_writer
 //-----------------------------------------------------------------------------
-Object_writer::Object_writer(Signal sig) : Object(Gura_UserClass(writer)),
+Object_writer::Object_writer(Signal &sig) : Object(Gura_UserClass(writer)),
 					_sig(sig), _pMemoryBlock(new MemoryHeap(BLOCKSIZE))
 {
 }
@@ -242,14 +243,14 @@ Object_writer::~Object_writer()
 bool Object_writer::Open(Environment &env,
 						Stream *pStreamDst, CompressionType compressionType)
 {
-	_pStreamDst.reset(DecorateWriterStream(env, _sig,
+	_pStreamDst.reset(DecorateWriterStream(env,
 				pStreamDst, pStreamDst->GetIdentifier(), compressionType));
 	return !_sig.IsSignalled();
 }
 
 Object *Object_writer::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_writer::ToString(bool exprFlag)
@@ -265,7 +266,7 @@ String Object_writer::ToString(bool exprFlag)
 	return str;
 }
 
-bool Object_writer::Add(Stream &streamSrc, const char *fileName)
+bool Object_writer::Add(Stream &streamSrc, const Header &hdr)
 {
 	if (_pStreamDst.IsNull()) {
 		_sig.SetError(ERR_IOError, "invalid tar writer");
@@ -276,31 +277,6 @@ bool Object_writer::Add(Stream &streamSrc, const char *fileName)
 										BLOCKSIZE * BLOCKSIZE - bytesBody;
 	AutoPtr<Memory> pMemory(new MemoryHeap(32768));
 	void *buff = pMemory->GetPointer();
-	Header hdr;
-	hdr.SetName(fileName);
-	hdr.SetLinkName("");
-	hdr.SetUName("root");
-	hdr.SetGName("");
-	hdr.SetUid(0);
-	hdr.SetGid(0);
-	hdr.SetSize(streamSrc.GetSize());
-	Stream::Attribute attr;
-	if (streamSrc.GetAttribute(attr)) {
-		hdr.SetMode(0100000 | (attr.attr & 0777));
-		hdr.SetMTime(attr.mtime);
-		hdr.SetATime(attr.atime);
-		hdr.SetCTime(attr.ctime);
-	} else {
-		hdr.SetMode(0100666);
-		DateTime dt = OAL::GetCurDateTime(false);
-		hdr.SetMTime(dt);
-		hdr.SetATime(dt);
-		hdr.SetCTime(dt);
-	}
-	hdr.SetChksum(0);
-	hdr.SetTypeFlag(0x00);
-	hdr.SetDevMajor(0);
-	hdr.SetDevMinor(0);
 	hdr.ComposeHeaderBlock(buff);
 	_pStreamDst->Write(_sig, buff, BLOCKSIZE);
 	if (_sig.IsSignalled()) return false;
@@ -326,7 +302,7 @@ bool Object_writer::Close()
 	::memset(buff, 0x00, bytesTerminator);
 	_pStreamDst->Write(_sig, buff, bytesTerminator);
 	if (_sig.IsSignalled()) return false;
-	_pStreamDst.reset(NULL);
+	_pStreamDst.reset(nullptr);
 	return true;
 }
 
@@ -340,26 +316,63 @@ Gura_DeclareMethod(writer, add)
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Read);
 	DeclareArg(env, "filename", VTYPE_string, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
-		"");
+		Gura_Symbol(en), 
+		"Adds an entry to the tar archive with a content from `stream` and a name of `filename`.\n"
+		"\n"
+		"If the argument `filename` is omitted, an identifier associated with the `stream`\n"
+		"would be used as the entry name.\n");
 }
 
 Gura_ImplementMethod(writer, add)
 {
-	Object_writer *pThis = Object_writer::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_writer *pThis = Object_writer::GetObjectThis(arg);
+	Stream &streamSrc = arg.GetStream(0);
 	String fileName;
-	if (args.Is_string(1)) {
-		fileName = args.GetString(1);
+	if (arg.Is_string(1)) {
+		fileName = arg.GetString(1);
 	} else {
-		const char *identifier = args.GetStream(0).GetIdentifier();
-		if (identifier == NULL) {
+		const char *identifier = arg.GetStream(0).GetIdentifier();
+		if (identifier == nullptr) {
 			sig.SetError(ERR_ValueError, "stream doesn't have an identifier");
-			return Value::Null;
+			return Value::Nil;
 		}
-		PathMgr::SplitFileName(identifier, NULL, &fileName);
+		PathMgr::SplitFileName(identifier, nullptr, &fileName);
 	}
-	if (!pThis->Add(args.GetStream(0), fileName.c_str())) return Value::Null;
-	return args.GetThis();
+	Header hdr;
+	hdr.SetName(fileName.c_str());
+	hdr.SetLinkName("");
+	hdr.SetSize(streamSrc.GetSize());
+	Stream::Attribute attr;
+	if (streamSrc.GetAttribute(attr)) {
+		char buff[80];
+		hdr.SetMode(0100000 | (attr.attr & 0777));
+		hdr.SetMTime(attr.mtime);
+		hdr.SetATime(attr.atime);
+		hdr.SetCTime(attr.ctime);
+		hdr.SetUid(attr.uid);
+		hdr.SetGid(attr.gid);
+		::sprintf(buff, "%d", attr.uid);
+		hdr.SetUName(buff);
+		::sprintf(buff, "%d", attr.gid);
+		hdr.SetGName(buff);
+	} else {
+		hdr.SetMode(0100666);
+		DateTime dt = OAL::GetCurDateTime(false);
+		hdr.SetMTime(dt);
+		hdr.SetATime(dt);
+		hdr.SetCTime(dt);
+		hdr.SetUid(0);
+		hdr.SetGid(0);
+		hdr.SetUName("0");
+		hdr.SetGName("0");
+	}
+	hdr.SetChksum(0);
+	hdr.SetTypeFlag(0x00);
+	hdr.SetDevMajor(0);
+	hdr.SetDevMinor(0);
+	if (!pThis->Add(streamSrc, hdr)) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // tar.writer#close():reduce
@@ -367,15 +380,15 @@ Gura_DeclareMethod(writer, close)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Reduce, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
-		"");
+		Gura_Symbol(en), 
+		"Flushes all the unfinished writing processes and invalidates the `tar.writer` instance.");
 }
 
 Gura_ImplementMethod(writer, close)
 {
-	Object_writer *pThis = Object_writer::GetThisObj(args);
-	if (!pThis->Close()) return Value::Null;
-	return args.GetThis();
+	Object_writer *pThis = Object_writer::GetObjectThis(arg);
+	if (!pThis->Close()) return Value::Nil;
+	return arg.GetValueThis();
 }
 
 // implementation of class writer
@@ -389,26 +402,26 @@ Gura_ImplementUserClass(writer)
 // Iterator_Entry implementation
 //-----------------------------------------------------------------------------
 Iterator_Entry::Iterator_Entry(Object_reader *pObjReader) :
-			Iterator(false), _pObjReader(pObjReader), _offsetNext(InvalidSize)
+			Iterator(Finite), _pObjReader(pObjReader), _offsetNext(InvalidSize)
 {
 }
 
 Iterator *Iterator_Entry::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_Entry::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_Entry::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	Stream *pStreamSrc = _pObjReader->GetStreamSrc();
 	if (_offsetNext != InvalidSize) {
 		pStreamSrc->Seek(sig, _offsetNext, Stream::SeekSet);
 	}
-	std::auto_ptr<Header> pHdr(_pObjReader->NextHeader(sig));
-	if (pHdr.get() == NULL) return false;
+	std::unique_ptr<Header> pHdr(_pObjReader->NextHeader(sig));
+	if (pHdr.get() == nullptr) return false;
 	_offsetNext = pStreamSrc->Tell() + pHdr->CalcBlocks() * BLOCKSIZE;
-	Stream *pStreamEntry = new Stream_Entry(env, sig,
-								Stream::Reference(pStreamSrc), *pHdr);
+	Stream *pStreamEntry = new Stream_Entry(env, Stream::Reference(pStreamSrc), *pHdr);
 	value = Value(new Object_stream(env, pStreamEntry));
 	return true;
 }
@@ -436,69 +449,6 @@ Object *Object_stat::Clone() const
 	return new Object_stat(*this);
 }
 
-bool Object_stat::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_UserSymbol(name));
-	symbols.insert(Gura_UserSymbol(filename));
-	symbols.insert(Gura_UserSymbol(linkname));
-	symbols.insert(Gura_UserSymbol(uname));
-	symbols.insert(Gura_UserSymbol(gname));
-	symbols.insert(Gura_UserSymbol(mode));
-	symbols.insert(Gura_UserSymbol(uid));
-	symbols.insert(Gura_UserSymbol(gid));
-	symbols.insert(Gura_UserSymbol(size));
-	symbols.insert(Gura_UserSymbol(mtime));
-	symbols.insert(Gura_UserSymbol(atime));
-	symbols.insert(Gura_UserSymbol(ctime));
-	symbols.insert(Gura_UserSymbol(chksum));
-	symbols.insert(Gura_UserSymbol(typeflag));
-	symbols.insert(Gura_UserSymbol(devmajor));
-	symbols.insert(Gura_UserSymbol(devminor));
-	return true;
-}
-
-Value Object_stat::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-						const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(name))) {
-		return Value(_hdr.GetName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(filename))) {
-		return Value(_hdr.GetName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(linkname))) {
-		return Value(_hdr.GetLinkName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(uname))) {
-		return Value(_hdr.GetUName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(gname))) {
-		return Value(_hdr.GetGName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(mode))) {
-		return Value(_hdr.GetMode());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(uid))) {
-		return Value(_hdr.GetUid());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(gid))) {
-		return Value(_hdr.GetGid());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(size))) {
-		return Value(_hdr.GetSize());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(mtime))) {
-		return Value(new Object_datetime(env, _hdr.GetMTime()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(atime))) {
-		return Value(new Object_datetime(env, _hdr.GetATime()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(ctime))) {
-		return Value(new Object_datetime(env, _hdr.GetCTime()));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(chksum))) {
-		return Value(_hdr.GetChksum());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(typeflag))) {
-		return Value(_hdr.GetTypeFlag());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(devmajor))) {
-		return Value(_hdr.GetDevMajor());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(devminor))) {
-		return Value(_hdr.GetDevMinor());
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_stat::ToString(bool exprFlag)
 {
 	String str;
@@ -508,19 +458,295 @@ String Object_stat::ToString(bool exprFlag)
 	return str;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// tar.stat#atime
+Gura_DeclareProperty_R(stat, atime)
+{
+	SetPropAttr(VTYPE_datetime);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, atime)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(new Object_datetime(env, hdr.GetATime()));
+}
+
+// tar.stat#chksum
+Gura_DeclareProperty_R(stat, chksum)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, chksum)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetChksum());
+}
+
+// tar.stat#ctime
+Gura_DeclareProperty_R(stat, ctime)
+{
+	SetPropAttr(VTYPE_datetime);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, ctime)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(new Object_datetime(env, hdr.GetCTime()));
+}
+
+// tar.stat#devmajor
+Gura_DeclareProperty_R(stat, devmajor)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, devmajor)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetDevMajor());
+}
+
+// tar.stat#devminor
+Gura_DeclareProperty_R(stat, devminor)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, devminor)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetDevMinor());
+}
+
+// tar.stat#filename
+Gura_DeclareProperty_R(stat, filename)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, filename)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetName());
+}
+
+// tar.stat#gid
+Gura_DeclareProperty_R(stat, gid)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, gid)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetGid());
+}
+
+// tar.stat#gname
+Gura_DeclareProperty_R(stat, gname)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, gname)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetGName());
+}
+
+// tar.stat#linkname
+Gura_DeclareProperty_R(stat, linkname)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, linkname)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetLinkName());
+}
+
+// tar.stat#mode
+Gura_DeclareProperty_R(stat, mode)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, mode)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetMode());
+}
+
+// tar.stat#mtime
+Gura_DeclareProperty_R(stat, mtime)
+{
+	SetPropAttr(VTYPE_datetime);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, mtime)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(new Object_datetime(env, hdr.GetMTime()));
+}
+
+// tar.stat#name
+Gura_DeclareProperty_R(stat, name)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, name)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetName());
+}
+
+// tar.stat#size
+Gura_DeclareProperty_R(stat, size)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, size)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetSize());
+}
+
+// tar.stat#typeflag
+Gura_DeclareProperty_R(stat, typeflag)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, typeflag)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetTypeFlag());
+}
+
+// tar.stat#uid
+Gura_DeclareProperty_R(stat, uid)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, uid)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetUid());
+}
+
+// tar.stat#uname
+Gura_DeclareProperty_R(stat, uname)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(stat, uname)
+{
+	const Header &hdr = Object_stat::GetObject(valueThis)->GetHeader();
+	return Value(hdr.GetUName());
+}
+
 //-----------------------------------------------------------------------------
 // Interfaces of tar.stat
 //-----------------------------------------------------------------------------
 // implementation of class stat
 Gura_ImplementUserClass(stat)
 {
+	// Assignment of properties
+	Gura_AssignProperty(stat, atime);
+	Gura_AssignProperty(stat, chksum);
+	Gura_AssignProperty(stat, ctime);
+	Gura_AssignProperty(stat, devmajor);
+	Gura_AssignProperty(stat, devminor);
+	Gura_AssignProperty(stat, filename);
+	Gura_AssignProperty(stat, gid);
+	Gura_AssignProperty(stat, gname);
+	Gura_AssignProperty(stat, linkname);
+	Gura_AssignProperty(stat, mode);
+	Gura_AssignProperty(stat, mtime);
+	Gura_AssignProperty(stat, name);
+	Gura_AssignProperty(stat, size);
+	Gura_AssignProperty(stat, typeflag);
+	Gura_AssignProperty(stat, uid);
+	Gura_AssignProperty(stat, uname);
 }
 
 //-----------------------------------------------------------------------------
 // Stream_Entry implementation
 //-----------------------------------------------------------------------------
-Stream_Entry::Stream_Entry(Environment &env, Signal sig, Stream *pStreamSrc, const Header &hdr) :
-		Stream(env, sig, ATTR_Readable), _pStreamSrc(pStreamSrc),
+Stream_Entry::Stream_Entry(Environment &env, Stream *pStreamSrc, const Header &hdr) :
+		Stream(env, ATTR_Readable), _pStreamSrc(pStreamSrc),
 		_hdr(hdr), _name(hdr.GetName()), _offsetTop(pStreamSrc->Tell())
 {
 }
@@ -552,14 +778,14 @@ bool Stream_Entry::SetAttribute(const Attribute &attr)
 	return false;
 }
 
-bool Stream_Entry::FlushRead(Signal sig)
+bool Stream_Entry::FlushRead(Signal &sig)
 {
 	Stream &streamSrc = GetSource();
 	size_t offset = _offsetTop + _hdr.CalcBlocks() * BLOCKSIZE;
 	return streamSrc.Seek(sig, offset, Stream::SeekSet);
 }
 
-size_t Stream_Entry::DoRead(Signal sig, void *buff, size_t bytes)
+size_t Stream_Entry::DoRead(Signal &sig, void *buff, size_t bytes)
 {
 	Stream &streamSrc = GetSource();
 	size_t bytesRest = _hdr.GetSize() - (streamSrc.Tell() - _offsetTop);
@@ -567,7 +793,7 @@ size_t Stream_Entry::DoRead(Signal sig, void *buff, size_t bytes)
 	return streamSrc.Read(sig, buff, bytes);
 }
 
-bool Stream_Entry::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode seekMode)
+bool Stream_Entry::DoSeek(Signal &sig, long offset, size_t offsetPrev, SeekMode seekMode)
 {
 	Stream &streamSrc = GetSource();
 	if (seekMode == SeekSet) {
@@ -578,19 +804,19 @@ bool Stream_Entry::DoSeek(Signal sig, long offset, size_t offsetPrev, SeekMode s
 	return false;
 }
 
-size_t Stream_Entry::DoWrite(Signal sig, const void *buff, size_t len)
+size_t Stream_Entry::DoWrite(Signal &sig, const void *buff, size_t len)
 {
 	return 0;
 }
 
-bool Stream_Entry::DoFlush(Signal sig)
+bool Stream_Entry::DoFlush(Signal &sig)
 {
 	return false;
 }
 
-bool Stream_Entry::DoClose(Signal sig)
+bool Stream_Entry::DoClose(Signal &sig)
 {
-	_pStreamSrc.reset(NULL);
+	_pStreamSrc.reset(nullptr);
 	return Stream::DoClose(sig);
 }
 
@@ -599,7 +825,7 @@ size_t Stream_Entry::DoGetSize()
 	return _hdr.GetSize();
 }
 
-Object *Stream_Entry::DoGetStatObj(Signal sig)
+Object *Stream_Entry::DoGetStatObj(Signal &sig)
 {
 	return new Object_stat(_hdr);
 }
@@ -618,33 +844,34 @@ Directory_TAR::~Directory_TAR()
 {
 }
 
-Directory *Directory_TAR::DoNext(Environment &env, Signal sig)
+Directory *Directory_TAR::DoNext(Environment &env)
 {
 	return _pRecord->Next(this);
 }
 
-Stream *Directory_TAR::DoOpenStream(Environment &env, Signal sig, ULong attr)
+Stream *Directory_TAR::DoOpenStream(Environment &env, ULong attr)
 {
+	Signal &sig = env.GetSignal();
 	Directory *pDirectory = this;
-	for ( ; pDirectory != NULL && !pDirectory->IsBoundaryContainer();
+	for ( ; pDirectory != nullptr && !pDirectory->IsBoundaryContainer();
 										pDirectory = pDirectory->GetParent()) ;
-	if (pDirectory != NULL) pDirectory = pDirectory->GetParent();
-	if (pDirectory == NULL) {
+	if (pDirectory != nullptr) pDirectory = pDirectory->GetParent();
+	if (pDirectory == nullptr) {
 		sig.SetError(ERR_IOError, "failed to open a stream");
-		return NULL;
+		return nullptr;
 	}
-	AutoPtr<Stream> pStreamSrc(pDirectory->DoOpenStream(env, sig, attr));
+	AutoPtr<Stream> pStreamSrc(pDirectory->DoOpenStream(env, attr));
 	if (IsGZippedTar(pDirectory->GetName())) {
 		ZLib::GZHeader hdr;
-		if (!hdr.Read(sig, *pStreamSrc)) return NULL;
+		if (!hdr.Read(sig, *pStreamSrc)) return nullptr;
 		AutoPtr<ZLib::Stream_Inflater> pStreamInflater(
-				new ZLib::Stream_Inflater(env, sig, pStreamSrc.release(), InvalidSize));
-		if (!pStreamInflater->Initialize(sig, -MAX_WBITS)) return NULL;
+			new ZLib::Stream_Inflater(env, pStreamSrc.release(), InvalidSize));
+		if (!pStreamInflater->Initialize(sig, -MAX_WBITS)) return nullptr;
 		pStreamSrc.reset(pStreamInflater.release());
 	} else if (IsBZippedTar(pDirectory->GetName())) {
 		AutoPtr<BZLib::Stream_Decompressor> pStreamDecompressor(
-				new BZLib::Stream_Decompressor(env, sig, pStreamSrc.release(), InvalidSize));
-		if (!pStreamDecompressor->Initialize(sig, 0, 0)) return NULL;
+			new BZLib::Stream_Decompressor(env, pStreamSrc.release(), InvalidSize));
+		if (!pStreamDecompressor->Initialize(sig, 0, 0)) return nullptr;
 		pStreamSrc.reset(pStreamDecompressor.release());
 	}
 	//::printf("%s: %08x\n", pDirectory->GetName(), _pRecord->GetOffset());
@@ -652,12 +879,12 @@ Stream *Directory_TAR::DoOpenStream(Environment &env, Signal sig, ULong attr)
 	const Header *pHdr = _pRecord->GetHeader();
 	if (!pStreamSrc->Seek(sig,
 				static_cast<long>(pHdr->GetOffset()), Stream::SeekSet)) {
-		return NULL;
+		return nullptr;
 	}
-	return new Stream_Entry(env, sig, pStreamSrc.release(), *pHdr);
+	return new Stream_Entry(env, pStreamSrc.release(), *pHdr);
 }
 
-Object *Directory_TAR::DoGetStatObj(Signal sig)
+Object *Directory_TAR::DoGetStatObj(Signal &sig)
 {
 	return new Object_stat(*_pRecord->GetHeader());
 }
@@ -681,35 +908,36 @@ Directory *Record_TAR::DoGenerateDirectory(Directory *pParent, Directory::Type t
 //-----------------------------------------------------------------------------
 // PathMgr_TAR implementation
 //-----------------------------------------------------------------------------
-bool PathMgr_TAR::IsResponsible(Environment &env, Signal sig,
+bool PathMgr_TAR::IsResponsible(Environment &env,
 						const Directory *pParent, const char *pathName)
 {
-	return pParent != NULL && !pParent->IsContainer() &&
+	return pParent != nullptr && !pParent->IsContainer() &&
 			(EndsWith(pParent->GetName(), ".tar", true) ||
 										IsGZippedTar(pParent->GetName()));
 }
 
-Directory *PathMgr_TAR::DoOpenDirectory(Environment &env, Signal sig,
+Directory *PathMgr_TAR::DoOpenDirectory(Environment &env,
 		Directory *pParent, const char **pPathName, NotFoundMode notFoundMode)
 {
-	AutoPtr<Stream> pStream(pParent->DoOpenStream(env, sig, Stream::ATTR_Readable));
-	if (sig.IsSignalled()) return NULL;
-	pStream.reset(DecorateReaderStream(env, sig,
+	Signal &sig = env.GetSignal();
+	AutoPtr<Stream> pStream(pParent->DoOpenStream(env, Stream::ATTR_Readable));
+	if (sig.IsSignalled()) return nullptr;
+	pStream.reset(DecorateReaderStream(env,
 					pStream.release(), pParent->GetName(), COMPRESS_Auto));
-	if (sig.IsSignalled()) return NULL;
+	if (sig.IsSignalled()) return nullptr;
 	AutoPtr<Memory> pMemory(new MemoryHeap(BLOCKSIZE));
 	void *buffBlock = pMemory->GetPointer();
 	AutoPtr<DirBuilder::Structure> pStructure(new DirBuilder::Structure());
-	pStructure->SetRoot(new Record_TAR(pStructure.get(), NULL, "", true));
+	pStructure->SetRoot(new Record_TAR(pStructure.get(), nullptr, "", true));
 	for (;;) {
-		std::auto_ptr<Header> pHdr(ReadHeader(sig, pStream.get(), buffBlock));
-		if (sig.IsSignalled()) return NULL;
-		if (pHdr.get() == NULL) break;
+		std::unique_ptr<Header> pHdr(ReadHeader(sig, pStream.get(), buffBlock));
+		if (sig.IsSignalled()) return nullptr;
+		if (pHdr.get() == nullptr) break;
 		Record_TAR *pRecord =
 				dynamic_cast<Record_TAR *>(pStructure->AddRecord(pHdr->GetName()));
 		size_t offset = pHdr->CalcBlocks() * BLOCKSIZE;
 		pRecord->SetHeader(pHdr.release());
-		if (!pStream->Seek(sig, offset, Stream::SeekCur)) return NULL;
+		if (!pStream->Seek(sig, offset, Stream::SeekCur)) return nullptr;
 	}
 	Directory *pDirectory = pStructure->GenerateDirectory(sig,
 											pParent, pPathName, notFoundMode);
@@ -729,24 +957,33 @@ Gura_DeclareFunction(reader)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(reader));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
-		"");
+		Gura_Symbol(en), 
+		"Reads a tar file from `stream` and returns a `tar.reader` instance\n"
+		"that is to be used to read contents from the archive.\n"
+		"\n"
+		"The argument `compression` specifies the compression format of the tar file\n"
+		"and takes one of the following symbols:\n"
+		"\n"
+		"- `` `auto`` .. determins the format from a suffix name of the stream.\n"
+		"- `` `gzip`` .. gzip format\n"
+		"- `` `bzip2`` .. bzip2 format\n");
 }
 
 Gura_ImplementFunction(reader)
 {
-	Stream &streamSrc = args.GetStream(0);
-	CompressionType compressionType = args.Is_symbol(1)?
-				SymbolToCompressionType(args.GetSymbol(1)) : COMPRESS_Auto;
+	Signal &sig = env.GetSignal();
+	Stream &streamSrc = arg.GetStream(0);
+	CompressionType compressionType = arg.Is_symbol(1)?
+				SymbolToCompressionType(arg.GetSymbol(1)) : COMPRESS_Auto;
 	if (compressionType == COMPRESS_Invalid) {
 		sig.SetError(ERR_ValueError, "invalid compression symbol");
-		return Value::Null;
+		return Value::Nil;
 	}
 	AutoPtr<Object_reader> pObj(new Object_reader());
-	if (!pObj->Open(env, sig, streamSrc.Reference(), compressionType)) {
-		return Value::Null;
+	if (!pObj->Open(env, streamSrc.Reference(), compressionType)) {
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(pObj.release()));
+	return ReturnValue(env, arg, Value(pObj.release()));
 }
 
 // tar.writer(stream:stream:w, compression?:symbol) {block?}
@@ -758,24 +995,33 @@ Gura_DeclareFunction(writer)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(writer));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
-		"");
+		Gura_Symbol(en), 
+		"Creates a tar file on `stream` and returns a `tar.writer` instance\n"
+		"that is to be used to write contents to the archive.\n"
+		"\n"
+		"The argument `compression` specifies the compression format of the tar file\n"
+		"and takes one of the following symbols:\n"
+		"\n"
+		"- `` `auto`` .. determins the format from a suffix name of the stream.\n"
+		"- `` `gzip`` .. gzip format\n"
+		"- `` `bzip2`` .. bzip2 format\n");
 }
 
 Gura_ImplementFunction(writer)
 {
-	Stream &streamDst = args.GetStream(0);
-	CompressionType compressionType = args.Is_symbol(1)?
-				SymbolToCompressionType(args.GetSymbol(1)) : COMPRESS_Auto;
+	Signal &sig = env.GetSignal();
+	Stream &streamDst = arg.GetStream(0);
+	CompressionType compressionType = arg.Is_symbol(1)?
+				SymbolToCompressionType(arg.GetSymbol(1)) : COMPRESS_Auto;
 	if (compressionType == COMPRESS_Invalid) {
 		sig.SetError(ERR_ValueError, "invalid compression symbol");
-		return Value::Null;
+		return Value::Nil;
 	}
 	AutoPtr<Object_writer> pObj(new Object_writer(sig));
 	if (!pObj->Open(env, streamDst.Reference(), compressionType)) {
-		return Value::Null;
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(pObj.release()));
+	return ReturnValue(env, arg, Value(pObj.release()));
 }
 
 // tar.test(stream:stream:r)
@@ -784,36 +1030,27 @@ Gura_DeclareFunction(test)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Read);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementFunction(test)
 {
-	Stream &stream = args.GetStream(0);
-	return Value::Null;
+	Stream &stream = arg.GetStream(0);
+	return Value::Nil;
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	// symbol realization
-	Gura_RealizeUserSymbol(name);
-	Gura_RealizeUserSymbol(filename);
-	Gura_RealizeUserSymbol(linkname);
-	Gura_RealizeUserSymbol(uname);
-	Gura_RealizeUserSymbol(gname);
-	Gura_RealizeUserSymbol(mode);
-	Gura_RealizeUserSymbol(uid);
-	Gura_RealizeUserSymbol(gid);
-	Gura_RealizeUserSymbol(size);
-	Gura_RealizeUserSymbol(mtime);
-	Gura_RealizeUserSymbol(atime);
-	Gura_RealizeUserSymbol(ctime);
-	Gura_RealizeUserSymbol(chksum);
-	Gura_RealizeUserSymbol(typeflag);
-	Gura_RealizeUserSymbol(devmajor);
-	Gura_RealizeUserSymbol(devminor);
 	Gura_RealizeUserSymbol(none);
 	Gura_RealizeUserSymbol(gzip);
 	Gura_RealizeUserSymbol(bzip2);
@@ -822,31 +1059,18 @@ Gura_ModuleEntry()
 	Gura_RealizeAndPrepareUserClass(reader, env.LookupClass(VTYPE_object));
 	Gura_RealizeAndPrepareUserClass(writer, env.LookupClass(VTYPE_object));
 	Gura_RealizeAndPrepareUserClass(stat, env.LookupClass(VTYPE_object));
-#if 0
-const char REGTYPE			= '0';		// regular file
-const char AREGTYPE			= '\0';		// regular file
-const char LNKTYPE			= '1';		// link
-const char SYMTYPE			= '2';		// reserved
-const char CHRTYPE			= '3';		// character special
-const char BLKTYPE			= '4';		// block special
-const char DIRTYPE			= '5';		// directory
-const char FIFOTYPE			= '6';		// FIFO special
-const char CONTTYPE			= '7';		// reserved
-const char XHDTYPE			= 'x';		// Extended header referring to the next file in the archive
-const char XGLTYPE			= 'g';		// Global extended header
-#endif
 	// value assignment
-	Gura_AssignValue(REGTYPE,	Value(REGTYPE));
-	Gura_AssignValue(AREGTYPE,	Value(AREGTYPE));
-	Gura_AssignValue(LNKTYPE,	Value(LNKTYPE));
-	Gura_AssignValue(SYMTYPE,	Value(SYMTYPE));
-	Gura_AssignValue(CHRTYPE,	Value(CHRTYPE));
-	Gura_AssignValue(BLKTYPE,	Value(BLKTYPE));
-	Gura_AssignValue(DIRTYPE,	Value(DIRTYPE));
-	Gura_AssignValue(FIFOTYPE,	Value(FIFOTYPE));
-	Gura_AssignValue(CONTTYPE,	Value(CONTTYPE));
-	Gura_AssignValue(XHDTYPE,	Value(XHDTYPE));
-	Gura_AssignValue(XGLTYPE,	Value(XGLTYPE));
+	Gura_AssignValue(REGTYPE,	Value(REGTYPE));	// regular file
+	Gura_AssignValue(AREGTYPE,	Value(AREGTYPE));	// regular file
+	Gura_AssignValue(LNKTYPE,	Value(LNKTYPE));	// link
+	Gura_AssignValue(SYMTYPE,	Value(SYMTYPE));	// reserved
+	Gura_AssignValue(CHRTYPE,	Value(CHRTYPE));	// character special
+	Gura_AssignValue(BLKTYPE,	Value(BLKTYPE));	// block special
+	Gura_AssignValue(DIRTYPE,	Value(DIRTYPE));	// directory
+	Gura_AssignValue(FIFOTYPE,	Value(FIFOTYPE));	// FIFO special
+	Gura_AssignValue(CONTTYPE,	Value(CONTTYPE));	// reserved
+	Gura_AssignValue(XHDTYPE,	Value(XHDTYPE));	// Extended header referring to the next file in the archive
+	Gura_AssignValue(XGLTYPE,	Value(XGLTYPE));	// Global extended header
 	// function assignment
 	Gura_AssignFunction(reader);
 	Gura_AssignFunction(writer);
@@ -877,15 +1101,15 @@ CompressionType SymbolToCompressionType(const Symbol *pSymbol)
 	}
 }
 
-Header *ReadHeader(Signal sig, Stream *pStream, void *buffBlock)
+Header *ReadHeader(Signal &sig, Stream *pStream, void *buffBlock)
 {
 	int nTerminator = 0;
 	for (;;) {
 		size_t bytesRead = pStream->Read(sig, buffBlock, BLOCKSIZE);
-		if (sig.IsSignalled()) return NULL;
+		if (sig.IsSignalled()) return nullptr;
 		if (bytesRead < BLOCKSIZE) {
 			sig.SetError(ERR_FormatError, "failed to read a block");
-			return NULL;
+			return nullptr;
 		}
 		bool zeroBlockFlag = true;
 		ULong *p = reinterpret_cast<ULong *>(buffBlock);
@@ -897,21 +1121,22 @@ Header *ReadHeader(Signal sig, Stream *pStream, void *buffBlock)
 		}
 		if (!zeroBlockFlag) break;
 		nTerminator++;
-		if (nTerminator == 2) return NULL;
+		if (nTerminator == 2) return nullptr;
 	}
 	star_header &hdr = *reinterpret_cast<star_header *>(buffBlock);
-	std::auto_ptr<Header> pHdr(new Header());
+	std::unique_ptr<Header> pHdr(new Header());
 	pHdr->SetOffset(pStream->Tell());
-	if (!pHdr->SetRawHeader(sig, hdr)) return NULL;
+	if (!pHdr->SetRawHeader(sig, hdr)) return nullptr;
 	return pHdr.release();
 }
 
-Stream *DecorateReaderStream(Environment &env, Signal sig, Stream *pStreamSrc,
+Stream *DecorateReaderStream(Environment &env, Stream *pStreamSrc,
 							const char *name, CompressionType compressionType)
 {
+	Signal &sig = env.GetSignal();
 	if (compressionType != COMPRESS_Auto) {
 		// nothing to do
-	} else if (name == NULL) {
+	} else if (name == nullptr) {
 		compressionType = COMPRESS_None;
 	} else if (IsGZippedTar(name)) {
 		compressionType = COMPRESS_GZip;
@@ -922,27 +1147,28 @@ Stream *DecorateReaderStream(Environment &env, Signal sig, Stream *pStreamSrc,
 	}
 	if (compressionType == COMPRESS_GZip) {
 		ZLib::GZHeader hdr;
-		if (!hdr.Read(sig, *pStreamSrc)) return NULL;
+		if (!hdr.Read(sig, *pStreamSrc)) return nullptr;
 		AutoPtr<ZLib::Stream_Inflater> pStreamInflater(
-					new ZLib::Stream_Inflater(env, sig, pStreamSrc, InvalidSize));
-		if (!pStreamInflater->Initialize(sig, -MAX_WBITS)) return NULL;
+			new ZLib::Stream_Inflater(env, pStreamSrc, InvalidSize));
+		if (!pStreamInflater->Initialize(sig, -MAX_WBITS)) return nullptr;
 		pStreamSrc = pStreamInflater.release();
 	} else if (compressionType == COMPRESS_BZip2) {
 		AutoPtr<BZLib::Stream_Decompressor> pStreamDecompressor(
-					new BZLib::Stream_Decompressor(env, sig, pStreamSrc, InvalidSize));
+			new BZLib::Stream_Decompressor(env, pStreamSrc, InvalidSize));
 		int verbosity = 0, small = 0;
-		if (!pStreamDecompressor->Initialize(sig, verbosity, small)) return NULL;
+		if (!pStreamDecompressor->Initialize(sig, verbosity, small)) return nullptr;
 		pStreamSrc = pStreamDecompressor.release();
 	}
 	return pStreamSrc;
 }
 
-Stream *DecorateWriterStream(Environment &env, Signal sig, Stream *pStreamDst,
+Stream *DecorateWriterStream(Environment &env, Stream *pStreamDst,
 							const char *name, CompressionType compressionType)
 {
+	Signal &sig = env.GetSignal();
 	if (compressionType != COMPRESS_Auto) {
 		// nothing to do
-	} else if (name == NULL) {
+	} else if (name == nullptr) {
 		compressionType = COMPRESS_None;
 	} else if (IsGZippedTar(name)) {
 		compressionType = COMPRESS_GZip;
@@ -954,22 +1180,22 @@ Stream *DecorateWriterStream(Environment &env, Signal sig, Stream *pStreamDst,
 	if (compressionType == COMPRESS_GZip) {
 		int windowBits = 31;
 		AutoPtr<ZLib::Stream_Deflater> pStreamDeflater(
-					new ZLib::Stream_Deflater(env, sig, pStreamDst));
+			new ZLib::Stream_Deflater(env, pStreamDst));
 		if (!pStreamDeflater->Initialize(sig, Z_DEFAULT_COMPRESSION,
-							windowBits, 8, Z_DEFAULT_STRATEGY)) return NULL;
+							windowBits, 8, Z_DEFAULT_STRATEGY)) return nullptr;
 		pStreamDst = pStreamDeflater.release();
 	} else if (compressionType == COMPRESS_BZip2) {
 		AutoPtr<BZLib::Stream_Compressor> pStreamCompressor(
-					new BZLib::Stream_Compressor(env, sig, pStreamDst));
+			new BZLib::Stream_Compressor(env, pStreamDst));
 		int blockSize100k = 9, verbosity = 0, workFactor = 0;
 		if (!pStreamCompressor->Initialize(sig,
-							blockSize100k, verbosity, workFactor)) return NULL;
+							blockSize100k, verbosity, workFactor)) return nullptr;
 		pStreamDst = pStreamCompressor.release();
 	}
 	return pStreamDst;
 }
 
-ULong OctetToULong(Signal sig, const char *octet, size_t len)
+ULong OctetToULong(Signal &sig, const char *octet, size_t len)
 {
 	ULong num = 0;
 	for (const char *p = octet; len > 0; len--, p++) {
