@@ -33,7 +33,7 @@ Object_interp::~Object_interp()
 
 Object *Object_interp::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_interp::ToString(bool exprFlag)
@@ -41,7 +41,7 @@ String Object_interp::ToString(bool exprFlag)
 	return String("<tcl.interp>");
 }
 
-Tcl_Obj *Object_interp::ConvToTclObj(Environment &env, Signal sig, const Value &value)
+Tcl_Obj *Object_interp::ConvToTclObj(Environment &env, Signal &sig, const Value &value)
 {
 	if (value.IsInvalid()) {
 		return ::Tcl_NewStringObj("", 0);
@@ -69,7 +69,7 @@ Tcl_Obj *Object_interp::ConvToTclObj(Environment &env, Signal sig, const Value &
 		return ::Tcl_NewStringObj(str, static_cast<int>(::strlen(str)));
 	} else if (value.Is_function()) {
 		Handler *pHandler = new Handler(Object_interp::Reference(this),
-				Object_function::Reference(Object_function::GetObject(value)), sig);
+				Object_function::Reference(Object_function::GetObject(value)));
 		String cmdName = NewCommandName();
 		::Tcl_CreateCommand(_interp, cmdName.c_str(), CommandProc,
 											pHandler, CommandDeleteProc);
@@ -83,11 +83,11 @@ Tcl_Obj *Object_interp::ConvToTclObj(Environment &env, Signal sig, const Value &
 		Object *pObj = value.GetObject();
 		const Function *pFunc =
 					pObj->LookupFunction(Gura_UserSymbol(__tclname__), ENVREF_Escalate);
-		if (pFunc != NULL) {
-			Value valueThis(pObj, VFLAG_NoOwner); // reference to self
-			AutoPtr<Args> pArgs(new Args());
-			pArgs->SetThis(valueThis);
-			Value result = pFunc->Eval(*pObj, sig, *pArgs);
+		if (pFunc != nullptr) {
+			Value valueThis(pObj, VFLAG_NoFundOwner); // reference to self
+			AutoPtr<Argument> pArg(new Argument(pFunc));
+			pArg->SetValueThis(valueThis);
+			Value result = pFunc->Eval(*pObj, *pArg);
 			if (!sig.IsSignalled()) {
 				return ConvToTclObj(env, sig, result);
 			}
@@ -97,10 +97,10 @@ Tcl_Obj *Object_interp::ConvToTclObj(Environment &env, Signal sig, const Value &
 	return ::Tcl_NewStringObj(str.c_str(), static_cast<int>(str.size()));
 }
 
-Value Object_interp::ConvFromTclObj(Environment &env, Signal sig, Tcl_Obj *objPtr)
+Value Object_interp::ConvFromTclObj(Environment &env, Signal &sig, Tcl_Obj *objPtr)
 {
 	Tcl_ObjType *typePtr = objPtr->typePtr;
-	if (typePtr == NULL) {
+	if (typePtr == nullptr) {
 		return Value(objPtr->bytes, objPtr->length);
 	} else if (typePtr == ObjType_boolean) {
 		int value;
@@ -122,13 +122,13 @@ Value Object_interp::ConvFromTclObj(Environment &env, Signal sig, Tcl_Obj *objPt
 		int length;
 		::Tcl_ListObjLength(_interp, objPtr, &length);
 		Value result;
-		ValueList &valList = result.InitAsList(env);
-		valList.reserve(length);
+		Object_list *pObjList = result.InitAsList(env);
+		pObjList->Reserve(length);
 		for (int i = 0; i < length; i++) {
 			Tcl_Obj *objElemPtr;
 			::Tcl_ListObjIndex(_interp, objPtr, i, &objElemPtr);
-			valList.push_back(ConvFromTclObj(env, sig, objElemPtr));
-			if (sig.IsSignalled()) return Value::Null;
+			pObjList->Add(ConvFromTclObj(env, sig, objElemPtr));
+			if (sig.IsSignalled()) return Value::Nil;
 		}
 		return result;
 	} else if (typePtr == ObjType_string) {
@@ -139,7 +139,7 @@ Value Object_interp::ConvFromTclObj(Environment &env, Signal sig, Tcl_Obj *objPt
 	return Value(objPtr->bytes, objPtr->length);
 }
 
-Tcl_Obj **Object_interp::CreateTclObjArray(Environment &env, Signal sig,
+Tcl_Obj **Object_interp::CreateTclObjArray(Environment &env, Signal &sig,
 										const ValueList &valList, int *pObjc)
 {
 	*pObjc = static_cast<int>(valList.size());
@@ -149,7 +149,7 @@ Tcl_Obj **Object_interp::CreateTclObjArray(Environment &env, Signal sig,
 		objv[i++] = ConvToTclObj(env, sig, *pValue);
 		if (sig.IsSignalled()) {
 			DeleteTclObjArray(i - 1, objv);
-			return NULL;
+			return nullptr;
 		}
 	}
 	return objv;
@@ -163,20 +163,21 @@ void Object_interp::DeleteTclObjArray(int objc, Tcl_Obj **objv)
 	delete[] objv;
 }
 
-Value Object_interp::TclEval(Environment &env, Signal sig, const ValueList &valList)
+Value Object_interp::TclEval(Environment &env, const ValueList &valList)
 {
+	Signal &sig = env.GetSignal();
 	int objc;
 	Tcl_Obj **objv = CreateTclObjArray(env, sig, valList, &objc);
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	int rtn = ::Tcl_EvalObjv(_interp, objc, objv, TCL_EVAL_DIRECT | TCL_EVAL_GLOBAL);
 	if (rtn != TCL_OK) {
 		sig.SetError(ERR_RuntimeError, "%s\n", ::Tcl_GetStringResult(_interp));
 		delete[] objv;
-		return Value::Null;
+		return Value::Nil;
 	}
 	delete[] objv;
 	Tcl_Obj *obj = ::Tcl_GetObjResult(_interp);
-	if (obj == NULL) return Value::Null;
+	if (obj == nullptr) return Value::Nil;
 	Value result = ConvFromTclObj(env, sig, obj);
 	return result;
 }
@@ -200,7 +201,7 @@ String Object_interp::NewVariableName()
 void Object_interp::ExitMainLoop()
 {
 	//Tk_Window tkwin = ::Tk_MainWindow(_interp);
-	//if (tkwin != NULL) ::Tk_DestroyWindow(tkwin);
+	//if (tkwin != nullptr) ::Tk_DestroyWindow(tkwin);
 	::longjmp(g_jmpenv, 1);
 }
 
@@ -210,7 +211,7 @@ int Object_interp::CommandProc(ClientData clientData,
 	Handler *pHandler = reinterpret_cast<Handler *>(clientData);
 	Object_interp *pObjInterp = pHandler->GetInterpObj();
 	Environment &env = *pObjInterp;
-	Signal &sig = pHandler->GetSignal();
+	Signal &sig = env.GetSignal();
 	if (argc > 0) {
 		// skip the first argument
 		argc--, argv++;
@@ -243,7 +244,7 @@ int Object_interp::TclThreadProc(Tcl_Event *ev, int flags)
 	pEventPack->objRtn = ::Tcl_GetObjResult(pEventPack->interp);
 	Tcl_IncrRefCount(pEventPack->objRtn);
 	Object_interp::DeleteTclObjArray(pEventPack->objc, pEventPack->objv);
-	pEventPack->objv = NULL;
+	pEventPack->objv = nullptr;
 	// wake up calling thread
 	Tcl_MutexLock(&g_mutex);
 	Tcl_ConditionNotify(pEventPack->pCond);
@@ -251,25 +252,25 @@ int Object_interp::TclThreadProc(Tcl_Event *ev, int flags)
 	return 1;
 }
 
-Value Object_interp::InvokeTclThread(Environment &env, Signal sig,
+Value Object_interp::InvokeTclThread(Environment &env, Signal &sig,
 												const ValueList &valListArg)
 {
-	Tcl_Condition cond = NULL;
+	Tcl_Condition cond = nullptr;
 	EventPack *pEventPack =
 			reinterpret_cast<EventPack *>(::ckalloc(sizeof(EventPack)));
 	pEventPack->ev.proc = TclThreadProc;
 	pEventPack->interp = _interp;
 	pEventPack->objv = CreateTclObjArray(env, sig, valListArg, &pEventPack->objc);
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	pEventPack->rtn = TCL_OK;
-	pEventPack->objRtn = NULL;
+	pEventPack->objRtn = nullptr;
 	pEventPack->pCond = &cond;
 	do {
 		Tcl_MutexLock(g_mutex);
 		::Tcl_ThreadQueueEvent(_thread_id,
 					reinterpret_cast<Tcl_Event *>(pEventPack), TCL_QUEUE_TAIL);
 		::Tcl_ThreadAlert(_thread_id);
-		Tcl_ConditionWait(&cond, g_mutex, NULL);
+		Tcl_ConditionWait(&cond, g_mutex, nullptr);
 		Tcl_MutexUnlock(g_mutex);
 	} while (0);
 	Tcl_ConditionFinalize(&cond);
@@ -278,7 +279,7 @@ Value Object_interp::InvokeTclThread(Environment &env, Signal sig,
 		const char *str = ::Tcl_GetStringFromObj(pEventPack->objRtn, &length);
 		Tcl_DecrRefCount(pEventPack->objRtn);
 		sig.SetError(ERR_RuntimeError, "%s\n", str);
-		return Value::Null;
+		return Value::Nil;
 	}
 	Value result = ConvFromTclObj(env, sig, pEventPack->objRtn);
 	Tcl_DecrRefCount(pEventPack->objRtn);
@@ -294,16 +295,16 @@ Gura_DeclareMethod(interp, command)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "func", VTYPE_function);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(interp, command)
 {
-	Object_interp *pThis = Object_interp::GetThisObj(args);
+	Object_interp *pThis = Object_interp::GetObjectThis(arg);
 	Tcl_Interp *interp = pThis->GetInterp();
 	Handler *pHandler = new Handler(Object_interp::Reference(pThis),
-			Object_function::Reference(Object_function::GetObject(args, 0)), sig);
+			Object_function::Reference(Object_function::GetObject(arg, 0)));
 	String cmdName = pThis->NewCommandName();
 	::Tcl_CreateCommand(interp, cmdName.c_str(), Object_interp::CommandProc,
 									pHandler, Object_interp::CommandDeleteProc);
@@ -316,21 +317,23 @@ Gura_DeclareMethod(interp, eval)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "objs", VTYPE_any, OCCUR_OnceOrMore);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(interp, eval)
 {
-	Object_interp *pThis = Object_interp::GetThisObj(args);
-	return pThis->TclEval(env, sig, args.GetList(0));
+	Signal &sig = env.GetSignal();
+	Object_interp *pThis = Object_interp::GetObjectThis(arg);
+	return pThis->TclEval(env, arg.GetList(0));
 }
 
 #if 0
 Gura_ImplementMethod(interp, eval)
 {
-	Object_interp *pThis = Object_interp::GetThisObj(args);
-	return pThis->InvokeTclThread(env, sig, args.GetList(0));
+	Signal &sig = env.GetSignal();
+	Object_interp *pThis = Object_interp::GetObjectThis(arg);
+	return pThis->InvokeTclThread(env, sig, arg.GetList(0));
 }
 #endif
 
@@ -340,18 +343,19 @@ Gura_DeclareMethod(interp, evalscript)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "script", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(interp, evalscript)
 {
-	Object_interp *pThis = Object_interp::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_interp *pThis = Object_interp::GetObjectThis(arg);
 	Tcl_Interp *interp = pThis->GetInterp();
-	int rtn = ::Tcl_Eval(interp, args.GetString(0));
+	int rtn = ::Tcl_Eval(interp, arg.GetString(0));
 	if (rtn != TCL_OK) {
 		sig.SetError(ERR_RuntimeError, "%s\n", ::Tcl_GetStringResult(interp));
-		return Value::Null;
+		return Value::Nil;
 	}
 	return pThis->ConvFromTclObj(env, sig, ::Tcl_GetObjResult(interp));
 }
@@ -361,13 +365,13 @@ Gura_DeclareMethod(interp, timer)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(interp, timer)
 {
-	Object_interp *pThis = Object_interp::GetThisObj(args);
+	Object_interp *pThis = Object_interp::GetObjectThis(arg);
 	Object_interp *pObjInterp = Object_interp::Reference(pThis);
 	Object_timer *pObjTimer = new Object_timer(pObjInterp);
 	return Value(pObjTimer);
@@ -380,23 +384,24 @@ Gura_DeclareMethod(interp, variable)
 	DeclareArg(env, "value", VTYPE_any, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "varName", VTYPE_string, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(interp, variable)
 {
-	Object_interp *pThis = Object_interp::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_interp *pThis = Object_interp::GetObjectThis(arg);
 	Object_interp *pObjInterp = Object_interp::Reference(pThis);
 	String varName;
-	if (args.Is_string(1)) {
-		varName = args.GetString(1);
+	if (arg.Is_string(1)) {
+		varName = arg.GetString(1);
 	} else {
 		varName = pObjInterp->NewVariableName();
 	}
 	Object_variable *pObjVariable = new Object_variable(pObjInterp, varName.c_str());
-	if (args.IsValid(0)) {
-		if (!pObjVariable->Set(env, sig, args.GetValue(0))) return Value::Null;
+	if (arg.IsValid(0)) {
+		if (!pObjVariable->Set(env, sig, arg.GetValue(0))) return Value::Nil;
 	}
 	return Value(pObjVariable);
 }
@@ -422,10 +427,11 @@ Value Handler::Eval(ValueList &valListArg)
 {
 	Function *pFunc = _pObjFunc->GetFunction();
 	Environment &env = pFunc->GetEnvScope();
-	Value result = _pObjFunc->Eval(env, _sig, valListArg);
-	if (_sig.IsSignalled()) {
+	Signal &sig = env.GetSignal();
+	Value result = _pObjFunc->Eval(env, valListArg);
+	if (sig.IsSignalled()) {
 		_pObjInterp->ExitMainLoop();
-		return Value::Null;
+		return Value::Nil;
 	}
 	return result;
 }
@@ -434,6 +440,7 @@ Value Handler::Eval(int argc, const char *argv[])
 {
 	Function *pFunc = _pObjFunc->GetFunction();
 	Environment &env = pFunc->GetEnvScope();
+	Signal &sig = env.GetSignal();
 	ValueList valListArg;
 	//argc = ChooseMin(argc, static_cast<int>(pFunc->GetDeclList().size()));
 	if (argc > 0) {
@@ -442,10 +449,10 @@ Value Handler::Eval(int argc, const char *argv[])
 			valListArg.push_back(Value(argv[i]));
 		}
 	}
-	Value result = _pObjFunc->Eval(env, _sig, valListArg);
-	if (_sig.IsSignalled()) {
+	Value result = _pObjFunc->Eval(env, valListArg);
+	if (sig.IsSignalled()) {
 		_pObjInterp->ExitMainLoop();
-		return Value::Null;
+		return Value::Nil;
 	}
 	return result;
 }
@@ -476,21 +483,23 @@ String Object_variable::ToString(bool exprFlag)
 	return str;
 }
 
-bool Object_variable::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
+bool Object_variable::DoDirProp(Environment &env, SymbolSet &symbols)
 {
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
+	Signal &sig = GetSignal();
+	if (!Object::DoDirProp(env, symbols)) return false;
 	symbols.insert(Gura_Symbol(boolean));
 	symbols.insert(Gura_Symbol(string));
 	symbols.insert(Gura_Symbol(number));
 	return true;
 }
 
-Value Object_variable::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
+Value Object_variable::DoGetProp(Environment &env, const Symbol *pSymbol,
 						const SymbolSet &attrs, bool &evaluatedFlag)
 {
+	Signal &sig = GetSignal();
 	if (pSymbol->IsIdentical(Gura_Symbol(boolean))) {
 		Value value = Get(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		if (value.Is_string()) {
 			if (*value.GetString() == '\0') {
 				value = Value(false);
@@ -509,17 +518,17 @@ Value Object_variable::DoGetProp(Environment &env, Signal sig, const Symbol *pSy
 		return value;
 	} else if (pSymbol->IsIdentical(Gura_Symbol(string))) {
 		Value value = Get(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		if (!value.Is_string()) {
 			String str = value.ToString(false);
-			if (sig.IsSignalled()) return Value::Null;
+			if (sig.IsSignalled()) return Value::Nil;
 			value = Value(str);
 		}
 		evaluatedFlag = true;
 		return value;
 	} else if (pSymbol->IsIdentical(Gura_Symbol(number))) {
 		Value value = Get(env, sig);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		if (!value.Is_number()) {
 			bool successFlag;
 			Number num = value.ToNumber(true, successFlag);
@@ -528,42 +537,43 @@ Value Object_variable::DoGetProp(Environment &env, Signal sig, const Symbol *pSy
 		evaluatedFlag = true;
 		return value;
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
-Value Object_variable::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
+Value Object_variable::DoSetProp(Environment &env, const Symbol *pSymbol, const Value &value,
 						const SymbolSet &attrs, bool &evaluatedFlag)
 {
+	Signal &sig = GetSignal();
 	if (pSymbol->IsIdentical(Gura_Symbol(boolean))) {
 		Set(env, sig, value);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		evaluatedFlag = true;
 		return value;
 	} else if (pSymbol->IsIdentical(Gura_Symbol(string))) {
 		Set(env, sig, value);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		evaluatedFlag = true;
 		return value;
 	} else if (pSymbol->IsIdentical(Gura_Symbol(number))) {
 		Set(env, sig, value);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		evaluatedFlag = true;
 		return value;
 	}
-	return Value::Null;
+	return Value::Nil;
 }
 
-bool Object_variable::Set(Environment &env, Signal sig, const Value &value)
+bool Object_variable::Set(Environment &env, Signal &sig, const Value &value)
 {
 	ValueList valList(Value("set"), Value(GetVarName()), value);
-	_pObjInterp->TclEval(env, sig, valList);
+	_pObjInterp->TclEval(env, valList);
 	return !sig.IsSignalled();
 }
 
-Value Object_variable::Get(Environment &env, Signal sig)
+Value Object_variable::Get(Environment &env, Signal &sig)
 {
 	ValueList valList(Value("set"), Value(GetVarName()));
-	return _pObjInterp->TclEval(env, sig, valList);
+	return _pObjInterp->TclEval(env, valList);
 }
 
 //-----------------------------------------------------------------------------
@@ -591,7 +601,7 @@ Object_timer::~Object_timer()
 
 Object *Object_timer::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_timer::ToString(bool exprFlag)
@@ -602,7 +612,7 @@ String Object_timer::ToString(bool exprFlag)
 	return str;
 }
 
-void Object_timer::Start(Signal sig, const Function *pFunc,
+void Object_timer::Start(Signal &sig, const Function *pFunc,
 									int msec, int msecCont, int cnt)
 {
 	Environment &env = *this;
@@ -613,7 +623,7 @@ void Object_timer::Start(Signal sig, const Function *pFunc,
 	Object::Reference(this);
 	_token = ::Tcl_CreateTimerHandler(msec, TimerProcStub, this);
 	Object_function *pObjFunc = new Object_function(env, Function::Reference(pFunc));
-	_pHandler.reset(new Handler(Object_interp::Reference(_pObjInterp.get()), pObjFunc, sig));
+	_pHandler.reset(new Handler(Object_interp::Reference(_pObjInterp.get()), pObjFunc));
 }
 
 void Object_timer::Cancel()
@@ -626,7 +636,7 @@ bool Object_timer::TimerProc()
 {
 	ValueList valListArg;
 	valListArg.reserve(1);
-	valListArg.push_back(Value(this, VFLAG_NoOwner));
+	valListArg.push_back(Value(this, VFLAG_NoFundOwner));
 	_pHandler->Eval(valListArg);
 	_idx++;
 	if (_contFlag && _idx != _cnt) {
@@ -654,16 +664,16 @@ Gura_DeclareMethod(timer, cancel)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(timer, cancel)
 {
-	Object_timer *pThis = Object_timer::GetThisObj(args);
+	Object_timer *pThis = Object_timer::GetObjectThis(arg);
 	pThis->Cancel();
 	Object::Delete(pThis);
-	return Value::Null;
+	return Value::Nil;
 }
 
 // tcl.timer#start(msec:number, msecCont?:number, count?:number):reduce {block}
@@ -675,20 +685,21 @@ Gura_DeclareMethod(timer, start)
 	DeclareArg(env, "count", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_Once);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementMethod(timer, start)
 {
-	Object_timer *pThis = Object_timer::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_timer *pThis = Object_timer::GetObjectThis(arg);
 	const Function *pFuncBlock =
-					args.GetBlockFunc(env, sig, GetSymbolForBlock());
-	int msec = args.GetInt(0);
-	int msecCont = args.Is_number(1)? args.GetInt(1) : msec;
-	int cnt = args.Is_number(2)? args.GetInt(2) : -1;
+					arg.GetBlockFunc(env, GetSymbolForBlock());
+	int msec = arg.GetInt(0);
+	int msecCont = arg.Is_number(1)? arg.GetInt(1) : msec;
+	int cnt = arg.Is_number(2)? arg.GetInt(2) : -1;
 	pThis->Start(sig, pFuncBlock, msec, msecCont, cnt);
-	return args.GetThis();
+	return arg.GetValueThis();
 }
 
 // implementation of class timer
@@ -709,26 +720,27 @@ Gura_DeclareMethodAlias(image, read_tcl, "read@tcl")
 	DeclareArg(env, "interp", VTYPE_interp);
 	DeclareArg(env, "imageName", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Reads an image data from TCL image object.");
 }
 
 Gura_ImplementMethod(image, read_tcl)
 {
-	Object_image *pThis = Object_image::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_image *pThis = Object_image::GetObjectThis(arg);
 	Image *pImage = pThis->GetImage();
-	if (!pImage->CheckEmpty(sig)) return Value::Null;
-	Object_interp *pObjInterp = reinterpret_cast<Object_interp *>(args.GetObject(0));
+	if (!pImage->CheckEmpty(sig)) return Value::Nil;
+	Object_interp *pObjInterp = reinterpret_cast<Object_interp *>(arg.GetObject(0));
 	Tcl_Interp *interp = pObjInterp->GetInterp();
-	const char *imageName = args.GetString(1);
+	const char *imageName = arg.GetString(1);
 	Tk_PhotoHandle handle = ::Tk_FindPhoto(interp, imageName);
-	if (handle == NULL) {
+	if (handle == nullptr) {
 		sig.SetError(ERR_ValueError, "invalid image name %s", imageName);
-		return Value::Null;
+		return Value::Nil;
 	}
 	int width, height;
 	::Tk_PhotoGetSize(handle, &width, &height);
-	if (!pImage->AllocBuffer(sig, width, height, 0xff)) return Value::Null;
+	if (!pImage->AllocBuffer(sig, width, height, 0xff)) return Value::Nil;
 	Tk_PhotoImageBlock photoImageBlock;
 	photoImageBlock.pixelPtr = reinterpret_cast<unsigned char *>(pImage->GetBuffer());
 	photoImageBlock.width = width;
@@ -740,7 +752,7 @@ Gura_ImplementMethod(image, read_tcl)
 	photoImageBlock.offset[2] = Image::OffsetB;
 	photoImageBlock.offset[3] = Image::OffsetA;
 	::Tk_PhotoGetImage(handle, &photoImageBlock);
-	return args.GetThis();
+	return arg.GetValueThis();
 }
 
 // image#write@tcl(interp:tcl.interp, imageName:string):reduce
@@ -750,22 +762,23 @@ Gura_DeclareMethodAlias(image, write_tcl, "write@tcl")
 	DeclareArg(env, "interp", VTYPE_interp);
 	DeclareArg(env, "imageName", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"Writes an image data to TCL image object.");
 }
 
 Gura_ImplementMethod(image, write_tcl)
 {
-	Object_image *pThis = Object_image::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_image *pThis = Object_image::GetObjectThis(arg);
 	Image *pImage = pThis->GetImage();
-	if (!pImage->CheckValid(sig)) return Value::Null;
-	Object_interp *pObjInterp = reinterpret_cast<Object_interp *>(args.GetObject(0));
+	if (!pImage->CheckValid(sig)) return Value::Nil;
+	Object_interp *pObjInterp = reinterpret_cast<Object_interp *>(arg.GetObject(0));
 	Tcl_Interp *interp = pObjInterp->GetInterp();
-	const char *imageName = args.GetString(1);
+	const char *imageName = arg.GetString(1);
 	Tk_PhotoHandle handle = ::Tk_FindPhoto(interp, imageName);
-	if (handle == NULL) {
+	if (handle == nullptr) {
 		sig.SetError(ERR_ValueError, "invalid image name %s", imageName);
-		return Value::Null;
+		return Value::Nil;
 	}
 	int width = static_cast<int>(pImage->GetWidth());
 	int height = static_cast<int>(pImage->GetHeight());
@@ -781,7 +794,7 @@ Gura_ImplementMethod(image, write_tcl)
 	photoImageBlock.offset[3] = Image::OffsetA;
 	::Tk_PhotoPutBlock(interp, handle, &photoImageBlock,
 							0, 0, width, height, TK_PHOTO_COMPOSITE_SET);
-	return args.GetThis();
+	return arg.GetValueThis();
 }
 
 //-----------------------------------------------------------------------------
@@ -793,22 +806,23 @@ Gura_DeclareFunction(interp)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	SetClassToConstruct(Gura_UserClass(interp));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementFunction(interp)
 {
+	Signal &sig = env.GetSignal();
 	Tcl_Interp *interp = ::Tcl_CreateInterp();
 	if (::Tcl_Init(interp) != TCL_OK) {
 		sig.SetError(ERR_RuntimeError, "%s\n", ::Tcl_GetStringResult(interp));
 		::Tcl_DeleteInterp(interp);
-		return Value::Null;
+		return Value::Nil;
 	}
 	if (::Tk_Init(interp) != TCL_OK) {
 		sig.SetError(ERR_RuntimeError, "%s\n", ::Tcl_GetStringResult(interp));
 		::Tcl_DeleteInterp(interp);
-		return Value::Null;
+		return Value::Nil;
 	}
 	return Value(new Object_interp(interp));
 }
@@ -818,18 +832,25 @@ Gura_DeclareFunction(Tk_MainLoop)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown, 
+		Gura_Symbol(en), 
 		"");
 }
 
 Gura_ImplementFunction(Tk_MainLoop)
 {
-	if (::setjmp(g_jmpenv)) return Value::Null;
+	if (::setjmp(g_jmpenv)) return Value::Nil;
 	::Tk_MainLoop();
-	return Value::Null;
+	return Value::Nil;
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	// symbol realization
