@@ -31,10 +31,10 @@ Gura_DeclarePrivUserSymbol(Select);
 //----------------------------------------------------------------------------
 class wx_Accessible: public wxAccessible, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Accessible *_pObj;
 public:
-	inline wx_Accessible(wxWindow* win) : wxAccessible(win), _sig(NULL), _pObj(NULL) {}
+	inline wx_Accessible(wxWindow* win) : wxAccessible(win), _pObj(nullptr) {}
 	//virtual wxAccStatus DoDefaultAction(int childId);
 	//virtual wxAccStatus GetChild(int childId, wxAccessible** child);
 	//virtual wxAccStatus GetChildCount(int* childCount);
@@ -55,8 +55,8 @@ public:
 	//virtual static void NotifyEvent(int eventType, wxWindow* window, wxAccObject objectType, int objectType);
 	//virtual wxAccStatus Select(int childId, wxAccSelectionFlags selectFlags);
 	~wx_Accessible();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Accessible *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Accessible *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -64,12 +64,12 @@ public:
 
 wx_Accessible::~wx_Accessible()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Accessible::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -85,19 +85,20 @@ Gura_DeclareFunction(Accessible)
 
 Gura_ImplementFunction(Accessible)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *win = (wxWindow *)(NULL);
-	if (args.IsValid(0)) win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *win = (wxWindow *)(nullptr);
+	if (arg.IsValid(0)) win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wx_Accessible *pEntity = new wx_Accessible(win);
-	Object_wx_Accessible *pObj = Object_wx_Accessible::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Accessible *pObj = Object_wx_Accessible::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Accessible(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Accessible, DoDefaultAction)
@@ -109,11 +110,12 @@ Gura_DeclareMethod(wx_Accessible, DoDefaultAction)
 
 Gura_ImplementMethod(wx_Accessible, DoDefaultAction)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
 	wxAccStatus rtn = pThis->GetEntity()->DoDefaultAction(childId);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetChild)
@@ -126,12 +128,13 @@ Gura_DeclareMethod(wx_Accessible, GetChild)
 
 Gura_ImplementMethod(wx_Accessible, GetChild)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxAccessible *child = Object_wx_Accessible::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxAccessible *child = Object_wx_Accessible::GetObject(arg, 1)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->GetChild(childId, *child);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetChildCount)
@@ -143,11 +146,12 @@ Gura_DeclareMethod(wx_Accessible, GetChildCount)
 
 Gura_ImplementMethod(wx_Accessible, GetChildCount)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childCount = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childCount = arg.GetInt(0);
 	wxAccStatus rtn = pThis->GetEntity()->GetChildCount(childCount);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetDefaultAction)
@@ -160,12 +164,13 @@ Gura_DeclareMethod(wx_Accessible, GetDefaultAction)
 
 Gura_ImplementMethod(wx_Accessible, GetDefaultAction)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxString actionName = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxString actionName = wxString::FromUTF8(arg.GetString(1));
 	wxAccStatus rtn = pThis->GetEntity()->GetDefaultAction(childId, actionName);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetDescription)
@@ -178,12 +183,13 @@ Gura_DeclareMethod(wx_Accessible, GetDescription)
 
 Gura_ImplementMethod(wx_Accessible, GetDescription)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxString description = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxString description = wxString::FromUTF8(arg.GetString(1));
 	wxAccStatus rtn = pThis->GetEntity()->GetDescription(childId, description);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetFocus)
@@ -196,12 +202,13 @@ Gura_DeclareMethod(wx_Accessible, GetFocus)
 
 Gura_ImplementMethod(wx_Accessible, GetFocus)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxAccessible *child = Object_wx_Accessible::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxAccessible *child = Object_wx_Accessible::GetObject(arg, 1)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->GetFocus(childId, *child);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetHelpText)
@@ -214,12 +221,13 @@ Gura_DeclareMethod(wx_Accessible, GetHelpText)
 
 Gura_ImplementMethod(wx_Accessible, GetHelpText)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxString helpText = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxString helpText = wxString::FromUTF8(arg.GetString(1));
 	wxAccStatus rtn = pThis->GetEntity()->GetHelpText(childId, helpText);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetKeyboardShortcut)
@@ -232,12 +240,13 @@ Gura_DeclareMethod(wx_Accessible, GetKeyboardShortcut)
 
 Gura_ImplementMethod(wx_Accessible, GetKeyboardShortcut)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxString shortcut = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxString shortcut = wxString::FromUTF8(arg.GetString(1));
 	wxAccStatus rtn = pThis->GetEntity()->GetKeyboardShortcut(childId, shortcut);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetLocation)
@@ -250,12 +259,13 @@ Gura_DeclareMethod(wx_Accessible, GetLocation)
 
 Gura_ImplementMethod(wx_Accessible, GetLocation)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
-	int elementId = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
+	int elementId = arg.GetInt(1);
 	wxAccStatus rtn = pThis->GetEntity()->GetLocation(*rect, elementId);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetName)
@@ -268,12 +278,13 @@ Gura_DeclareMethod(wx_Accessible, GetName)
 
 Gura_ImplementMethod(wx_Accessible, GetName)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxString name = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxString name = wxString::FromUTF8(arg.GetString(1));
 	wxAccStatus rtn = pThis->GetEntity()->GetName(childId, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetParent)
@@ -285,11 +296,12 @@ Gura_DeclareMethod(wx_Accessible, GetParent)
 
 Gura_ImplementMethod(wx_Accessible, GetParent)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxAccessible *parent = Object_wx_Accessible::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxAccessible *parent = Object_wx_Accessible::GetObject(arg, 0)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->GetParent(*parent);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetRole)
@@ -302,12 +314,13 @@ Gura_DeclareMethod(wx_Accessible, GetRole)
 
 Gura_ImplementMethod(wx_Accessible, GetRole)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxAccRole *role = Object_wx_AccRole::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxAccRole *role = Object_wx_AccRole::GetObject(arg, 1)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->GetRole(childId, role);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetSelections)
@@ -319,11 +332,12 @@ Gura_DeclareMethod(wx_Accessible, GetSelections)
 
 Gura_ImplementMethod(wx_Accessible, GetSelections)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxVariant *selections = Object_wx_Variant::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxVariant *selections = Object_wx_Variant::GetObject(arg, 0)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->GetSelections(selections);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetState)
@@ -336,12 +350,13 @@ Gura_DeclareMethod(wx_Accessible, GetState)
 
 Gura_ImplementMethod(wx_Accessible, GetState)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	long state = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	long state = arg.GetLong(1);
 	wxAccStatus rtn = pThis->GetEntity()->GetState(childId, state);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetValue)
@@ -354,12 +369,13 @@ Gura_DeclareMethod(wx_Accessible, GetValue)
 
 Gura_ImplementMethod(wx_Accessible, GetValue)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxString strValue = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxString strValue = wxString::FromUTF8(arg.GetString(1));
 	wxAccStatus rtn = pThis->GetEntity()->GetValue(childId, strValue);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, GetWindow)
@@ -370,10 +386,11 @@ Gura_DeclareMethod(wx_Accessible, GetWindow)
 
 Gura_ImplementMethod(wx_Accessible, GetWindow)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Accessible, HitTest)
@@ -387,13 +404,14 @@ Gura_DeclareMethod(wx_Accessible, HitTest)
 
 Gura_ImplementMethod(wx_Accessible, HitTest)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	int childId = args.GetInt(1);
-	wxAccessible *childObject = Object_wx_Accessible::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	int childId = arg.GetInt(1);
+	wxAccessible *childObject = Object_wx_Accessible::GetObject(arg, 2)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->HitTest(*pt, childId, *childObject);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, Navigate)
@@ -408,14 +426,15 @@ Gura_DeclareMethod(wx_Accessible, Navigate)
 
 Gura_ImplementMethod(wx_Accessible, Navigate)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxNavDir *navDir = Object_wx_NavDir::GetObject(args, 0)->GetEntity();
-	int fromId = args.GetInt(1);
-	int toId = args.GetInt(2);
-	wxAccessible *toObject = Object_wx_Accessible::GetObject(args, 3)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxNavDir *navDir = Object_wx_NavDir::GetObject(arg, 0)->GetEntity();
+	int fromId = arg.GetInt(1);
+	int toId = arg.GetInt(2);
+	wxAccessible *toObject = Object_wx_Accessible::GetObject(arg, 3)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->Navigate(*navDir, fromId, toId, *toObject);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, NotifyEvent)
@@ -429,14 +448,15 @@ Gura_DeclareMethod(wx_Accessible, NotifyEvent)
 
 Gura_ImplementMethod(wx_Accessible, NotifyEvent)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int eventType = args.GetInt(0);
-	wxWindow *window = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxAccObject *objectType = Object_wx_AccObject::GetObject(args, 2)->GetEntity();
-	int objectType = args.GetInt(3);
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int eventType = arg.GetInt(0);
+	wxWindow *window = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxAccObject *objectType = Object_wx_AccObject::GetObject(arg, 2)->GetEntity();
+	int objectType = arg.GetInt(3);
 	pThis->GetEntity()->NotifyEvent(eventType, window, *objectType, objectType);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Accessible, Select)
@@ -449,12 +469,13 @@ Gura_DeclareMethod(wx_Accessible, Select)
 
 Gura_ImplementMethod(wx_Accessible, Select)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int childId = args.GetInt(0);
-	wxAccSelectionFlags *selectFlags = Object_wx_AccSelectionFlags::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int childId = arg.GetInt(0);
+	wxAccSelectionFlags *selectFlags = Object_wx_AccSelectionFlags::GetObject(arg, 1)->GetEntity();
 	wxAccStatus rtn = pThis->GetEntity()->Select(childId, *selectFlags);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AccStatus(new wxAccStatus(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Accessible, SetWindow)
@@ -465,11 +486,12 @@ Gura_DeclareMethod(wx_Accessible, SetWindow)
 
 Gura_ImplementMethod(wx_Accessible, SetWindow)
 {
-	Object_wx_Accessible *pThis = Object_wx_Accessible::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Accessible *pThis = Object_wx_Accessible::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetWindow(window);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -481,13 +503,13 @@ Object_wx_Accessible::~Object_wx_Accessible()
 
 Object *Object_wx_Accessible::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Accessible::ToString(bool exprFlag)
 {
 	String rtn("<wx.Accessible:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -547,7 +569,7 @@ Gura_ImplementUserInheritableClass(wx_Accessible)
 
 Gura_ImplementDescendantCreator(wx_Accessible)
 {
-	return new Object_wx_Accessible((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Accessible((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
