@@ -20,17 +20,17 @@ Gura_DeclarePrivUserSymbol(OnUnhandledException);
 Gura_DeclarePrivUserSymbol(Pending);
 Gura_DeclarePrivUserSymbol(HandleEvent);
 
-static Environment *_pEnv = NULL;
+static Environment *_pEnv = nullptr;
 
 //----------------------------------------------------------------------------
 // Class derivation
 //----------------------------------------------------------------------------
 class wx_App: public wxApp, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	AutoPtr<Object_wx_App> _pObj;
 public:
-	inline wx_App() : wxApp(), _sig(NULL), _pObj(NULL) {}
+	inline wx_App() : wxApp(), _pObj(nullptr) {}
 	//virtual wxLog* CreateLogTarget();
 	//virtual wxAppTraits * CreateTraits();
 	//virtual void Dispatch();
@@ -45,8 +45,8 @@ public:
 	//virtual bool Pending();
 	virtual void HandleEvent(wxEvtHandler *handler, wxEventFunction func, wxEvent& event);
 	~wx_App();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_App *pObj) {
-		_sig = sig, _pObj.reset(Object_wx_App::Reference(pObj));
+	inline void AssocWithGura(Object_wx_App *pObj) {
+		_pObj.reset(Object_wx_App::Reference(pObj));
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -72,38 +72,38 @@ bool wx_App::OnInit()
 	SetWxReadyFlag(true);
 	InitializeObjects(*_pEnv);
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnInit);
-	if (pFunc == NULL) return wxApp::OnInit();
+	if (pFunc == nullptr) return wxApp::OnInit();
 	Environment &env = *_pObj;
 	ValueList valList;
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valList);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valList);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 int wx_App::OnExit()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnExit);
-	if (pFunc == NULL) return wxApp::OnExit();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_number)) return 0;
+	if (pFunc == nullptr) return wxApp::OnExit();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_number)) return 0;
 	return rtn.GetInt();
 }
 
 void wx_App::OnUnhandledException()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnUnhandledException);
-	if (pFunc == NULL) {
+	if (pFunc == nullptr) {
 		wxApp::OnUnhandledException();
 		return;
 	}
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	CheckMethodResult(_sig);
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	CheckMethodResult(_pObj->GetSignal());
 }
 
 void wx_App::HandleEvent(wxEvtHandler *handler, wxEventFunction func, wxEvent& event)
 {
 	wxApp::HandleEvent(handler, func, event);
-	if (_sig.IsSignalled()) {
+	if (_pObj->GetSignal().IsSignalled()) {
 		const_cast<wx_App *>(this)->ExitMainLoop();
 	}
 }
@@ -120,17 +120,18 @@ Gura_DeclareFunction(App)
 
 Gura_ImplementFunction(App)
 {
-	//if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	//if (!CheckWxReady(sig)) return Value::Nil;
 	wx_App *pEntity = new wx_App();
-	Object_wx_App *pObj = Object_wx_App::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_App *pObj = Object_wx_App::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_App(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_App, CreateLogTarget)
@@ -141,14 +142,15 @@ Gura_DeclareMethod(wx_App, CreateLogTarget)
 
 Gura_ImplementMethod(wx_App, CreateLogTarget)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxLog *rtn = (wxLog *)pThis->GetEntity()->CreateLogTarget();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Log(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Log(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, CreateTraits)
@@ -159,14 +161,15 @@ Gura_DeclareMethod(wx_App, CreateTraits)
 
 Gura_ImplementMethod(wx_App, CreateTraits)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxAppTraits *rtn = (wxAppTraits *)pThis->GetEntity()->CreateTraits();
-	return ReturnValue(env, sig, args, Value(new Object_wx_AppTraits(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_AppTraits(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, Dispatch)
@@ -176,10 +179,11 @@ Gura_DeclareMethod(wx_App, Dispatch)
 
 Gura_ImplementMethod(wx_App, Dispatch)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Dispatch();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, ExitMainLoop)
@@ -189,10 +193,11 @@ Gura_DeclareMethod(wx_App, ExitMainLoop)
 
 Gura_ImplementMethod(wx_App, ExitMainLoop)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ExitMainLoop();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, FilterEvent)
@@ -204,11 +209,12 @@ Gura_DeclareMethod(wx_App, FilterEvent)
 
 Gura_ImplementMethod(wx_App, FilterEvent)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvent *event = Object_wx_Event::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvent *event = Object_wx_Event::GetObject(arg, 0)->GetEntity();
 	int rtn = pThis->GetEntity()->FilterEvent(*event);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, GetAppName)
@@ -219,10 +225,11 @@ Gura_DeclareMethod(wx_App, GetAppName)
 
 Gura_ImplementMethod(wx_App, GetAppName)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetAppName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_App, GetClassName)
@@ -233,10 +240,11 @@ Gura_DeclareMethod(wx_App, GetClassName)
 
 Gura_ImplementMethod(wx_App, GetClassName)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetClassName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_App, GetExitOnFrameDelete)
@@ -247,10 +255,11 @@ Gura_DeclareMethod(wx_App, GetExitOnFrameDelete)
 
 Gura_ImplementMethod(wx_App, GetExitOnFrameDelete)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetExitOnFrameDelete();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_App, GetInstance)
@@ -261,13 +270,14 @@ Gura_DeclareClassMethod(wx_App, GetInstance)
 
 Gura_ImplementClassMethod(wx_App, GetInstance)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxAppConsole *rtn = (wxAppConsole *)wxApp::GetInstance();
 	wxApp *rtnEx = wxDynamicCast(rtn, wxApp);
-	if (rtnEx != NULL) {
-		return ReturnValue(env, sig, args, Value(new Object_wx_App(rtnEx, NULL, OwnerFalse)));
+	if (rtnEx != nullptr) {
+		return ReturnValue(env, arg, Value(new Object_wx_App(rtnEx, nullptr, OwnerFalse)));
 	}
-	return ReturnValue(env, sig, args, Value(new Object_wx_AppConsole(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_AppConsole(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_App, GetTopWindow)
@@ -278,12 +288,13 @@ Gura_DeclareMethod(wx_App, GetTopWindow)
 
 Gura_ImplementMethod(wx_App, GetTopWindow)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetTopWindow();
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_Window(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_Window(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_App, GetTraits)
@@ -294,12 +305,13 @@ Gura_DeclareMethod(wx_App, GetTraits)
 
 Gura_ImplementMethod(wx_App, GetTraits)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxAppTraits *rtn = (wxAppTraits *)pThis->GetEntity()->GetTraits();
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_AppTraits(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_AppTraits(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_App, GetUseBestVisual)
@@ -310,10 +322,11 @@ Gura_DeclareMethod(wx_App, GetUseBestVisual)
 
 Gura_ImplementMethod(wx_App, GetUseBestVisual)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetUseBestVisual();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, GetVendorName)
@@ -324,10 +337,11 @@ Gura_DeclareMethod(wx_App, GetVendorName)
 
 Gura_ImplementMethod(wx_App, GetVendorName)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetVendorName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_App, IsActive)
@@ -338,10 +352,11 @@ Gura_DeclareMethod(wx_App, IsActive)
 
 Gura_ImplementMethod(wx_App, IsActive)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsActive();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_App, IsMainLoopRunning)
@@ -352,9 +367,10 @@ Gura_DeclareClassMethod(wx_App, IsMainLoopRunning)
 
 Gura_ImplementClassMethod(wx_App, IsMainLoopRunning)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	bool rtn = wxApp::IsMainLoopRunning();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, MainLoop)
@@ -365,13 +381,14 @@ Gura_DeclareMethod(wx_App, MainLoop)
 
 Gura_ImplementMethod(wx_App, MainLoop)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxApp::SetInstance(pThis->GetEntity());
 	int argc = 0;
-	char *argv[1] = { NULL };
+	char *argv[1] = { nullptr };
 	::wxEntry(argc, argv);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, OnActivate)
@@ -384,15 +401,16 @@ Gura_DeclareMethod(wx_App, OnActivate)
 
 Gura_ImplementMethod(wx_App, OnActivate)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxActivateEvent *event = Object_wx_ActivateEvent::GetObject(args, 0)->GetEntity();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxActivateEvent *event = Object_wx_ActivateEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->wxApp::OnActivate(*event);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, OnCharHook)
@@ -405,15 +423,16 @@ Gura_DeclareMethod(wx_App, OnCharHook)
 
 Gura_ImplementMethod(wx_App, OnCharHook)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxKeyEvent *event = Object_wx_KeyEvent::GetObject(args, 0)->GetEntity();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxKeyEvent *event = Object_wx_KeyEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->wxApp::OnCharHook(*event);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, OnAssertFailure)
@@ -430,19 +449,20 @@ Gura_DeclareMethod(wx_App, OnAssertFailure)
 
 Gura_ImplementMethod(wx_App, OnAssertFailure)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxChar *file = static_cast<wxChar>(args.GetInt(0));
-	int line = args.GetInt(1);
-	wxChar *func = static_cast<wxChar>(args.GetInt(2));
-	wxChar *cond = static_cast<wxChar>(args.GetInt(3));
-	wxChar *msg = static_cast<wxChar>(args.GetInt(4));
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxChar *file = static_cast<wxChar>(arg.GetInt(0));
+	int line = arg.GetInt(1);
+	wxChar *func = static_cast<wxChar>(arg.GetInt(2));
+	wxChar *cond = static_cast<wxChar>(arg.GetInt(3));
+	wxChar *msg = static_cast<wxChar>(arg.GetInt(4));
 	pThis->GetEntity()->wxApp::OnAssertFailure(*file, line, *func, *cond, *msg);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, OnCmdLineError)
@@ -454,11 +474,12 @@ Gura_DeclareMethod(wx_App, OnCmdLineError)
 
 Gura_ImplementMethod(wx_App, OnCmdLineError)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->wxApp::OnCmdLineError(*parser);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnCmdLineHelp)
@@ -470,11 +491,12 @@ Gura_DeclareMethod(wx_App, OnCmdLineHelp)
 
 Gura_ImplementMethod(wx_App, OnCmdLineHelp)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->wxApp::OnCmdLineHelp(*parser);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnCmdLineParsed)
@@ -486,11 +508,12 @@ Gura_DeclareMethod(wx_App, OnCmdLineParsed)
 
 Gura_ImplementMethod(wx_App, OnCmdLineParsed)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->wxApp::OnCmdLineParsed(*parser);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnExceptionInMainLoop)
@@ -501,10 +524,11 @@ Gura_DeclareMethod(wx_App, OnExceptionInMainLoop)
 
 Gura_ImplementMethod(wx_App, OnExceptionInMainLoop)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->wxApp::OnExceptionInMainLoop();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnExit)
@@ -515,10 +539,11 @@ Gura_DeclareMethod(wx_App, OnExit)
 
 Gura_ImplementMethod(wx_App, OnExit)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->wxApp::OnExit();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnFatalException)
@@ -528,10 +553,11 @@ Gura_DeclareMethod(wx_App, OnFatalException)
 
 Gura_ImplementMethod(wx_App, OnFatalException)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->wxApp::OnFatalException();
-	return Value::Null;
+	return Value::Nil;
 }
 
 #if 0
@@ -543,11 +569,12 @@ Gura_DeclareMethod(wx_App, OnIdle)
 
 Gura_ImplementMethod(wx_App, OnIdle)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIdleEvent *event = Object_wx_IdleEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIdleEvent *event = Object_wx_IdleEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->wxApp::OnIdle(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 #endif
 
@@ -559,15 +586,16 @@ Gura_DeclareMethod(wx_App, OnEndSession)
 
 Gura_ImplementMethod(wx_App, OnEndSession)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCloseEvent *event = Object_wx_CloseEvent::GetObject(args, 0)->GetEntity();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCloseEvent *event = Object_wx_CloseEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnEndSession(*event);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -579,10 +607,11 @@ Gura_DeclareMethod(wx_App, OnInit)
 
 Gura_ImplementMethod(wx_App, OnInit)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->wxApp::OnInit();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnInitCmdLine)
@@ -593,11 +622,12 @@ Gura_DeclareMethod(wx_App, OnInitCmdLine)
 
 Gura_ImplementMethod(wx_App, OnInitCmdLine)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCmdLineParser *parser = Object_wx_CmdLineParser::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->wxApp::OnInitCmdLine(*parser);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, OnRun)
@@ -608,10 +638,11 @@ Gura_DeclareMethod(wx_App, OnRun)
 
 Gura_ImplementMethod(wx_App, OnRun)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->wxApp::OnRun();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_App, OnUnhandledException)
@@ -621,10 +652,11 @@ Gura_DeclareMethod(wx_App, OnUnhandledException)
 
 Gura_ImplementMethod(wx_App, OnUnhandledException)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->wxApp::OnUnhandledException();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, ProcessMessage)
@@ -637,14 +669,15 @@ Gura_DeclareMethod(wx_App, ProcessMessage)
 
 Gura_ImplementMethod(wx_App, ProcessMessage)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ProcessMessage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, Pending)
@@ -655,10 +688,11 @@ Gura_DeclareMethod(wx_App, Pending)
 
 Gura_ImplementMethod(wx_App, Pending)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->wxApp::Pending();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 #if 0
@@ -672,12 +706,13 @@ Gura_DeclareMethod(wx_App, SendIdleEvents)
 
 Gura_ImplementMethod(wx_App, SendIdleEvents)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxIdleEvent *event = Object_wx_IdleEvent::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxIdleEvent *event = Object_wx_IdleEvent::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->SendIdleEvents(win, *event);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 #endif
 
@@ -689,11 +724,12 @@ Gura_DeclareMethod(wx_App, SetAppName)
 
 Gura_ImplementMethod(wx_App, SetAppName)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetAppName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, SetClassName)
@@ -704,11 +740,12 @@ Gura_DeclareMethod(wx_App, SetClassName)
 
 Gura_ImplementMethod(wx_App, SetClassName)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetClassName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, SetExitOnFrameDelete)
@@ -719,11 +756,12 @@ Gura_DeclareMethod(wx_App, SetExitOnFrameDelete)
 
 Gura_ImplementMethod(wx_App, SetExitOnFrameDelete)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetExitOnFrameDelete(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_App, SetInstance)
@@ -734,10 +772,11 @@ Gura_DeclareClassMethod(wx_App, SetInstance)
 
 Gura_ImplementClassMethod(wx_App, SetInstance)
 {
-	//if (!CheckWxReady(sig)) return Value::Null;
-	wxAppConsole *app = Object_wx_AppConsole::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	//if (!CheckWxReady(sig)) return Value::Nil;
+	wxAppConsole *app = Object_wx_AppConsole::GetObject(arg, 0)->GetEntity();
 	wxApp::SetInstance(app);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, SetTopWindow)
@@ -748,11 +787,12 @@ Gura_DeclareMethod(wx_App, SetTopWindow)
 
 Gura_ImplementMethod(wx_App, SetTopWindow)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetTopWindow(window);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, SetVendorName)
@@ -763,11 +803,12 @@ Gura_DeclareMethod(wx_App, SetVendorName)
 
 Gura_ImplementMethod(wx_App, SetVendorName)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetVendorName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, SetUseBestVisual)
@@ -779,13 +820,14 @@ Gura_DeclareMethod(wx_App, SetUseBestVisual)
 
 Gura_ImplementMethod(wx_App, SetUseBestVisual)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	bool forceTrueColour = false;
-	if (args.IsValid(1)) forceTrueColour = args.GetBoolean(1);
+	if (arg.IsValid(1)) forceTrueColour = arg.GetBoolean(1);
 	pThis->GetEntity()->SetUseBestVisual(flag, forceTrueColour);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, HandleEvent)
@@ -800,17 +842,18 @@ Gura_DeclareMethod(wx_App, HandleEvent)
 
 Gura_ImplementMethod(wx_App, HandleEvent)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvtHandler **handler = Object_wx_EvtHandler::GetObject(args, 0)->GetEntity();
-	wxEventFunction *func = Object_wx_EventFunction::GetObject(args, 1)->GetEntity();
-	wxEvent *event = Object_wx_Event::GetObject(args, 2)->GetEntity();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvtHandler **handler = Object_wx_EvtHandler::GetObject(arg, 0)->GetEntity();
+	wxEventFunction *func = Object_wx_EventFunction::GetObject(arg, 1)->GetEntity();
+	wxEvent *event = Object_wx_Event::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->wxApp::HandleEvent(**handler, *func, *event);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_App, Yield)
@@ -822,12 +865,13 @@ Gura_DeclareMethod(wx_App, Yield)
 
 Gura_ImplementMethod(wx_App, Yield)
 {
-	Object_wx_App *pThis = Object_wx_App::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_App *pThis = Object_wx_App::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool onlyIfNeeded = false;
-	if (args.IsValid(0)) onlyIfNeeded = args.GetBoolean(0);
+	if (arg.IsValid(0)) onlyIfNeeded = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Yield(onlyIfNeeded);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -839,13 +883,13 @@ Object_wx_App::~Object_wx_App()
 
 Object *Object_wx_App::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_App::ToString(bool exprFlag)
 {
 	String rtn("<wx.App:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -922,7 +966,7 @@ Gura_ImplementUserInheritableClass(wx_App)
 
 Gura_ImplementDescendantCreator(wx_App)
 {
-	return new Object_wx_App((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_App((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
