@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Array: public wxArray, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Array *_pObj;
 public:
-	inline wx_Array() : wxArray(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Array(const wxArray& array) : wxArray(array), _sig(NULL), _pObj(NULL) {}
+	inline wx_Array() : wxArray(), _pObj(nullptr) {}
+	inline wx_Array(const wxArray& array) : wxArray(array), _pObj(nullptr) {}
 	~wx_Array();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Array *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Array *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_Array::~wx_Array()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Array::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -44,10 +44,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_ARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_EXPORTED_ARRAY)
@@ -57,10 +58,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_EXPORTED_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_EXPORTED_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_EXPORTED_ARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_USER_EXPORTED_ARRAY)
@@ -70,10 +72,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_USER_EXPORTED_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_USER_EXPORTED_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_USER_EXPORTED_ARRAY(, , );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_SORTED_ARRAY)
@@ -83,10 +86,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_SORTED_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_SORTED_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_SORTED_ARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_SORTED_EXPORTED_ARRAY)
@@ -96,10 +100,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_SORTED_EXPORTED_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_SORTED_EXPORTED_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_SORTED_EXPORTED_ARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_SORTED_USER_EXPORTED_ARRAY)
@@ -109,10 +114,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_SORTED_USER_EXPORTED_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_SORTED_USER_EXPORTED_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_SORTED_USER_EXPORTED_ARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DECLARE_OBJARRAY)
@@ -122,10 +128,11 @@ Gura_DeclareMethod(wx_Array, WX_DECLARE_OBJARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DECLARE_OBJARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DECLARE_OBJARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DECLARE_EXPORTED_OBJARRAY)
@@ -135,10 +142,11 @@ Gura_DeclareMethod(wx_Array, WX_DECLARE_EXPORTED_OBJARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DECLARE_EXPORTED_OBJARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DECLARE_EXPORTED_OBJARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DECLARE_USER_EXPORTED_OBJARRAY)
@@ -148,10 +156,11 @@ Gura_DeclareMethod(wx_Array, WX_DECLARE_USER_EXPORTED_OBJARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DECLARE_USER_EXPORTED_OBJARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DECLARE_USER_EXPORTED_OBJARRAY(, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_OBJARRAY)
@@ -161,10 +170,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_OBJARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_OBJARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_OBJARRAY();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_EXPORTED_OBJARRAY)
@@ -174,10 +184,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_EXPORTED_OBJARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_EXPORTED_OBJARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_EXPORTED_OBJARRAY();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_DEFINE_USER_EXPORTED_OBJARRAY)
@@ -187,10 +198,11 @@ Gura_DeclareMethod(wx_Array, WX_DEFINE_USER_EXPORTED_OBJARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_DEFINE_USER_EXPORTED_OBJARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->WX_DEFINE_USER_EXPORTED_OBJARRAY();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_APPEND_ARRAY)
@@ -202,12 +214,13 @@ Gura_DeclareMethod(wx_Array, WX_APPEND_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_APPEND_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxArray *array = Object_wx_Array::GetObject(args, 0)->GetEntity();
-	wxArray *other = Object_wx_Array::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxArray *array = Object_wx_Array::GetObject(arg, 0)->GetEntity();
+	wxArray *other = Object_wx_Array::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->WX_APPEND_ARRAY(*array, *other);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_PREPEND_ARRAY)
@@ -219,12 +232,13 @@ Gura_DeclareMethod(wx_Array, WX_PREPEND_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_PREPEND_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxArray *array = Object_wx_Array::GetObject(args, 0)->GetEntity();
-	wxArray *other = Object_wx_Array::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxArray *array = Object_wx_Array::GetObject(arg, 0)->GetEntity();
+	wxArray *other = Object_wx_Array::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->WX_PREPEND_ARRAY(*array, *other);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, WX_CLEAR_ARRAY)
@@ -235,11 +249,12 @@ Gura_DeclareMethod(wx_Array, WX_CLEAR_ARRAY)
 
 Gura_ImplementMethod(wx_Array, WX_CLEAR_ARRAY)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxArray *array = Object_wx_Array::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxArray *array = Object_wx_Array::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->WX_CLEAR_ARRAY(*array);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(ArrayEmpty)
@@ -251,17 +266,18 @@ Gura_DeclareFunction(ArrayEmpty)
 
 Gura_ImplementFunction(ArrayEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Array *pEntity = new wx_Array();
-	Object_wx_Array *pObj = Object_wx_Array::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Array *pObj = Object_wx_Array::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Array(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Array, wxObjArray)
@@ -271,10 +287,11 @@ Gura_DeclareMethod(wx_Array, wxObjArray)
 
 Gura_ImplementMethod(wx_Array, wxObjArray)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->wxObjArray();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, wxSortedArray)
@@ -285,11 +302,12 @@ Gura_DeclareMethod(wx_Array, wxSortedArray)
 
 Gura_ImplementMethod(wx_Array, wxSortedArray)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int compareFunction = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int compareFunction = arg.GetInt(0);
 	pThis->GetEntity()->wxSortedArray(compareFunction);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(Array)
@@ -302,18 +320,19 @@ Gura_DeclareFunction(Array)
 
 Gura_ImplementFunction(Array)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxArray *array = Object_wx_Array::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxArray *array = Object_wx_Array::GetObject(arg, 0)->GetEntity();
 	wx_Array *pEntity = new wx_Array(*array);
-	Object_wx_Array *pObj = Object_wx_Array::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Array *pObj = Object_wx_Array::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Array(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Array, wxSortedArray_1)
@@ -324,11 +343,12 @@ Gura_DeclareMethod(wx_Array, wxSortedArray_1)
 
 Gura_ImplementMethod(wx_Array, wxSortedArray_1)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSortedArray *array = Object_wx_SortedArray::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSortedArray *array = Object_wx_SortedArray::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->wxSortedArray(*array);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, wxObjArray_1)
@@ -339,11 +359,12 @@ Gura_DeclareMethod(wx_Array, wxObjArray_1)
 
 Gura_ImplementMethod(wx_Array, wxObjArray_1)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxObjArray *array = Object_wx_ObjArray::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxObjArray *array = Object_wx_ObjArray::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->wxObjArray(*array);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Add)
@@ -354,12 +375,13 @@ Gura_DeclareMethod(wx_Array, Add)
 
 Gura_ImplementMethod(wx_Array, Add)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t copies = 1;
-	if (args.IsValid(1)) copies = args.GetSizeT(1);
+	if (arg.IsValid(1)) copies = arg.GetSizeT(1);
 	pThis->GetEntity()->Add(, copies);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Add_1)
@@ -369,10 +391,11 @@ Gura_DeclareMethod(wx_Array, Add_1)
 
 Gura_ImplementMethod(wx_Array, Add_1)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Add();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Add_2)
@@ -383,12 +406,13 @@ Gura_DeclareMethod(wx_Array, Add_2)
 
 Gura_ImplementMethod(wx_Array, Add_2)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t copies = 1;
-	if (args.IsValid(1)) copies = args.GetSizeT(1);
+	if (arg.IsValid(1)) copies = arg.GetSizeT(1);
 	pThis->GetEntity()->Add(, copies);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Alloc)
@@ -399,11 +423,12 @@ Gura_DeclareMethod(wx_Array, Alloc)
 
 Gura_ImplementMethod(wx_Array, Alloc)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t count = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t count = arg.GetSizeT(0);
 	pThis->GetEntity()->Alloc(count);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Clear)
@@ -413,10 +438,11 @@ Gura_DeclareMethod(wx_Array, Clear)
 
 Gura_ImplementMethod(wx_Array, Clear)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Count)
@@ -427,10 +453,11 @@ Gura_DeclareMethod(wx_Array, Count)
 
 Gura_ImplementMethod(wx_Array, Count)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->Count();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Array, Detach)
@@ -442,9 +469,10 @@ Gura_DeclareMethod(wx_Array, Detach)
 
 Gura_ImplementMethod(wx_Array, Detach)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t index = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t index = arg.GetSizeT(0);
 }
 
 Gura_DeclareMethod(wx_Array, Empty)
@@ -454,10 +482,11 @@ Gura_DeclareMethod(wx_Array, Empty)
 
 Gura_ImplementMethod(wx_Array, Empty)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Empty();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, GetCount)
@@ -468,10 +497,11 @@ Gura_DeclareMethod(wx_Array, GetCount)
 
 Gura_ImplementMethod(wx_Array, GetCount)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Array, Index)
@@ -483,12 +513,13 @@ Gura_DeclareMethod(wx_Array, Index)
 
 Gura_ImplementMethod(wx_Array, Index)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool searchFromEnd = false;
-	if (args.IsValid(1)) searchFromEnd = args.GetBoolean(1);
+	if (arg.IsValid(1)) searchFromEnd = arg.GetBoolean(1);
 	int rtn = pThis->GetEntity()->Index(, searchFromEnd);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Array, Index_1)
@@ -499,10 +530,11 @@ Gura_DeclareMethod(wx_Array, Index_1)
 
 Gura_ImplementMethod(wx_Array, Index_1)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->Index();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Array, Insert)
@@ -514,13 +546,14 @@ Gura_DeclareMethod(wx_Array, Insert)
 
 Gura_ImplementMethod(wx_Array, Insert)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(1);
 	size_t copies = 1;
-	if (args.IsValid(2)) copies = args.GetSizeT(2);
+	if (arg.IsValid(2)) copies = arg.GetSizeT(2);
 	pThis->GetEntity()->Insert(, n, copies);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Insert_1)
@@ -531,11 +564,12 @@ Gura_DeclareMethod(wx_Array, Insert_1)
 
 Gura_ImplementMethod(wx_Array, Insert_1)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(1);
 	pThis->GetEntity()->Insert(, n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Insert_2)
@@ -547,13 +581,14 @@ Gura_DeclareMethod(wx_Array, Insert_2)
 
 Gura_ImplementMethod(wx_Array, Insert_2)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(1);
 	size_t copies = 1;
-	if (args.IsValid(2)) copies = args.GetSizeT(2);
+	if (arg.IsValid(2)) copies = arg.GetSizeT(2);
 	pThis->GetEntity()->Insert(, n, copies);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, IsEmpty)
@@ -564,10 +599,11 @@ Gura_DeclareMethod(wx_Array, IsEmpty)
 
 Gura_ImplementMethod(wx_Array, IsEmpty)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsEmpty();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Array, Item)
@@ -579,9 +615,10 @@ Gura_DeclareMethod(wx_Array, Item)
 
 Gura_ImplementMethod(wx_Array, Item)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t index = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t index = arg.GetSizeT(0);
 }
 
 Gura_DeclareMethod(wx_Array, Last)
@@ -592,8 +629,9 @@ Gura_DeclareMethod(wx_Array, Last)
 
 Gura_ImplementMethod(wx_Array, Last)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Remove)
@@ -603,10 +641,11 @@ Gura_DeclareMethod(wx_Array, Remove)
 
 Gura_ImplementMethod(wx_Array, Remove)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Remove();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, RemoveAt)
@@ -618,13 +657,14 @@ Gura_DeclareMethod(wx_Array, RemoveAt)
 
 Gura_ImplementMethod(wx_Array, RemoveAt)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t index = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t index = arg.GetSizeT(0);
 	size_t count = 1;
-	if (args.IsValid(1)) count = args.GetSizeT(1);
+	if (arg.IsValid(1)) count = arg.GetSizeT(1);
 	pThis->GetEntity()->RemoveAt(index, count);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, SetCount)
@@ -635,11 +675,12 @@ Gura_DeclareMethod(wx_Array, SetCount)
 
 Gura_ImplementMethod(wx_Array, SetCount)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t count = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t count = arg.GetSizeT(0);
 	pThis->GetEntity()->SetCount(count, );
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Shrink)
@@ -649,10 +690,11 @@ Gura_DeclareMethod(wx_Array, Shrink)
 
 Gura_ImplementMethod(wx_Array, Shrink)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Shrink();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Array, Sort)
@@ -662,10 +704,11 @@ Gura_DeclareMethod(wx_Array, Sort)
 
 Gura_ImplementMethod(wx_Array, Sort)
 {
-	Object_wx_Array *pThis = Object_wx_Array::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Array *pThis = Object_wx_Array::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Sort();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -673,20 +716,20 @@ Gura_ImplementMethod(wx_Array, Sort)
 //----------------------------------------------------------------------------
 Object_wx_Array::~Object_wx_Array()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_Array::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Array::ToString(bool exprFlag)
 {
 	String rtn("<wx.Array:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -748,7 +791,7 @@ Gura_ImplementUserInheritableClass(wx_Array)
 
 Gura_ImplementDescendantCreator(wx_Array)
 {
-	return new Object_wx_Array((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Array((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
