@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_AuiManager: public wxAuiManager, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_AuiManager *_pObj;
 public:
-	inline wx_AuiManager(wxWindow* managed_wnd, unsigned int flags) : wxAuiManager(managed_wnd, flags), _sig(NULL), _pObj(NULL) {}
+	inline wx_AuiManager(wxWindow* managed_wnd, unsigned int flags) : wxAuiManager(managed_wnd, flags), _pObj(nullptr) {}
 	~wx_AuiManager();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_AuiManager *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_AuiManager *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_AuiManager::~wx_AuiManager()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_AuiManager::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,21 +47,22 @@ Gura_DeclareFunction(AuiManager)
 
 Gura_ImplementFunction(AuiManager)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *managed_wnd = (wxWindow *)(NULL);
-	if (args.IsValid(0)) managed_wnd = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *managed_wnd = (wxWindow *)(nullptr);
+	if (arg.IsValid(0)) managed_wnd = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	unsigned flags = wxAUI_MGR_DEFAULT;
-	if (args.IsValid(1)) flags = args.GetInt(1);
+	if (arg.IsValid(1)) flags = arg.GetInt(1);
 	wx_AuiManager *pEntity = new wx_AuiManager(managed_wnd, flags);
-	Object_wx_AuiManager *pObj = Object_wx_AuiManager::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_AuiManager *pObj = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_AuiManager(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_AuiManager, AddPane)
@@ -74,12 +75,13 @@ Gura_DeclareMethod(wx_AuiManager, AddPane)
 
 Gura_ImplementMethod(wx_AuiManager, AddPane)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxAuiPaneInfo *pane_info = Object_wx_AuiPaneInfo::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxAuiPaneInfo *pane_info = Object_wx_AuiPaneInfo::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddPane(window, *pane_info);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, AddPane_1)
@@ -93,15 +95,16 @@ Gura_DeclareMethod(wx_AuiManager, AddPane_1)
 
 Gura_ImplementMethod(wx_AuiManager, AddPane_1)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	int direction = wxLEFT;
-	if (args.IsValid(1)) direction = args.GetInt(1);
+	if (arg.IsValid(1)) direction = arg.GetInt(1);
 	wxString caption = wxEmptyString;
-	if (args.IsValid(2)) caption = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) caption = wxString::FromUTF8(arg.GetString(2));
 	bool rtn = pThis->GetEntity()->AddPane(window, direction, caption);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, AddPane_2)
@@ -115,13 +118,14 @@ Gura_DeclareMethod(wx_AuiManager, AddPane_2)
 
 Gura_ImplementMethod(wx_AuiManager, AddPane_2)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxAuiPaneInfo *pane_info = Object_wx_AuiPaneInfo::GetObject(args, 1)->GetEntity();
-	wxPoint *drop_pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxAuiPaneInfo *pane_info = Object_wx_AuiPaneInfo::GetObject(arg, 1)->GetEntity();
+	wxPoint *drop_pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddPane(window, *pane_info, *drop_pos);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, DetachPane)
@@ -133,11 +137,12 @@ Gura_DeclareMethod(wx_AuiManager, DetachPane)
 
 Gura_ImplementMethod(wx_AuiManager, DetachPane)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->DetachPane(window);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetAllPanes)
@@ -148,14 +153,15 @@ Gura_DeclareMethod(wx_AuiManager, GetAllPanes)
 
 Gura_ImplementMethod(wx_AuiManager, GetAllPanes)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxAuiPaneInfoArray &rtn = pThis->GetEntity()->GetAllPanes();
-	return ReturnValue(env, sig, args, Value(new Object_wx_AuiPaneInfoArray(new wxAuiPaneInfoArray(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AuiPaneInfoArray(new wxAuiPaneInfoArray(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetArtProvider)
@@ -166,10 +172,11 @@ Gura_DeclareMethod(wx_AuiManager, GetArtProvider)
 
 Gura_ImplementMethod(wx_AuiManager, GetArtProvider)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxAuiDockArt *rtn = (wxAuiDockArt *)pThis->GetEntity()->GetArtProvider();
-	return ReturnValue(env, sig, args, Value(new Object_wx_AuiDockArt(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_AuiDockArt(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetDockSizeConstraint)
@@ -183,16 +190,17 @@ Gura_DeclareMethod(wx_AuiManager, GetDockSizeConstraint)
 
 Gura_ImplementMethod(wx_AuiManager, GetDockSizeConstraint)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	double widthpct = args.GetDouble(0);
-	double heightpct = args.GetDouble(1);
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	double widthpct = arg.GetDouble(0);
+	double heightpct = arg.GetDouble(1);
 	pThis->GetEntity()->GetDockSizeConstraint(widthpct, heightpct);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetFlags)
@@ -203,10 +211,11 @@ Gura_DeclareMethod(wx_AuiManager, GetFlags)
 
 Gura_ImplementMethod(wx_AuiManager, GetFlags)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	unsigned rtn = pThis->GetEntity()->GetFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetManagedWindow)
@@ -217,10 +226,11 @@ Gura_DeclareMethod(wx_AuiManager, GetManagedWindow)
 
 Gura_ImplementMethod(wx_AuiManager, GetManagedWindow)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetManagedWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareClassMethod(wx_AuiManager, GetManager)
@@ -232,10 +242,11 @@ Gura_DeclareClassMethod(wx_AuiManager, GetManager)
 
 Gura_ImplementClassMethod(wx_AuiManager, GetManager)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxAuiManager *rtn = (wxAuiManager *)wxAuiManager::GetManager(window);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AuiManager(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_AuiManager(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetPane)
@@ -247,11 +258,12 @@ Gura_DeclareMethod(wx_AuiManager, GetPane)
 
 Gura_ImplementMethod(wx_AuiManager, GetPane)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxAuiPaneInfo &rtn = pThis->GetEntity()->GetPane(window);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AuiPaneInfo(new wxAuiPaneInfo(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AuiPaneInfo(new wxAuiPaneInfo(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_AuiManager, GetPane_1)
@@ -263,11 +275,12 @@ Gura_DeclareMethod(wx_AuiManager, GetPane_1)
 
 Gura_ImplementMethod(wx_AuiManager, GetPane_1)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxAuiPaneInfo &rtn = pThis->GetEntity()->GetPane(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_AuiPaneInfo(new wxAuiPaneInfo(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_AuiPaneInfo(new wxAuiPaneInfo(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_AuiManager, HideHint)
@@ -277,10 +290,11 @@ Gura_DeclareMethod(wx_AuiManager, HideHint)
 
 Gura_ImplementMethod(wx_AuiManager, HideHint)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->HideHint();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, InsertPane)
@@ -294,14 +308,15 @@ Gura_DeclareMethod(wx_AuiManager, InsertPane)
 
 Gura_ImplementMethod(wx_AuiManager, InsertPane)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxAuiPaneInfo *insert_location = Object_wx_AuiPaneInfo::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxAuiPaneInfo *insert_location = Object_wx_AuiPaneInfo::GetObject(arg, 1)->GetEntity();
 	int insert_level = wxAUI_INSERT_PANE;
-	if (args.IsValid(2)) insert_level = args.GetInt(2);
+	if (arg.IsValid(2)) insert_level = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->InsertPane(window, *insert_location, insert_level);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, LoadPaneInfo)
@@ -313,12 +328,13 @@ Gura_DeclareMethod(wx_AuiManager, LoadPaneInfo)
 
 Gura_ImplementMethod(wx_AuiManager, LoadPaneInfo)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString pane_part = wxString::FromUTF8(args.GetString(0));
-	wxAuiPaneInfo *pane = Object_wx_AuiPaneInfo::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString pane_part = wxString::FromUTF8(arg.GetString(0));
+	wxAuiPaneInfo *pane = Object_wx_AuiPaneInfo::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->LoadPaneInfo(pane_part, *pane);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, LoadPerspective)
@@ -331,13 +347,14 @@ Gura_DeclareMethod(wx_AuiManager, LoadPerspective)
 
 Gura_ImplementMethod(wx_AuiManager, LoadPerspective)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString perspective = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString perspective = wxString::FromUTF8(arg.GetString(0));
 	bool update = true;
-	if (args.IsValid(1)) update = args.GetBoolean(1);
+	if (arg.IsValid(1)) update = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->LoadPerspective(perspective, update);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiManager, ProcessDockResult)
@@ -352,16 +369,17 @@ Gura_DeclareMethod(wx_AuiManager, ProcessDockResult)
 
 Gura_ImplementMethod(wx_AuiManager, ProcessDockResult)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxAuiPaneInfo *target = Object_wx_AuiPaneInfo::GetObject(args, 0)->GetEntity();
-	wxAuiPaneInfo *new_pos = Object_wx_AuiPaneInfo::GetObject(args, 1)->GetEntity();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxAuiPaneInfo *target = Object_wx_AuiPaneInfo::GetObject(arg, 0)->GetEntity();
+	wxAuiPaneInfo *new_pos = Object_wx_AuiPaneInfo::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->ProcessDockResult(*target, *new_pos);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, SavePaneInfo)
@@ -373,11 +391,12 @@ Gura_DeclareMethod(wx_AuiManager, SavePaneInfo)
 
 Gura_ImplementMethod(wx_AuiManager, SavePaneInfo)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxAuiPaneInfo *pane = Object_wx_AuiPaneInfo::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxAuiPaneInfo *pane = Object_wx_AuiPaneInfo::GetObject(arg, 0)->GetEntity();
 	wxString rtn = pThis->GetEntity()->SavePaneInfo(*pane);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_AuiManager, SavePerspective)
@@ -388,10 +407,11 @@ Gura_DeclareMethod(wx_AuiManager, SavePerspective)
 
 Gura_ImplementMethod(wx_AuiManager, SavePerspective)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->SavePerspective();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_AuiManager, SetArtProvider)
@@ -402,11 +422,12 @@ Gura_DeclareMethod(wx_AuiManager, SetArtProvider)
 
 Gura_ImplementMethod(wx_AuiManager, SetArtProvider)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxAuiDockArt *art_provider = Object_wx_AuiDockArt::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxAuiDockArt *art_provider = Object_wx_AuiDockArt::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetArtProvider(art_provider);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, SetDockSizeConstraint)
@@ -418,12 +439,13 @@ Gura_DeclareMethod(wx_AuiManager, SetDockSizeConstraint)
 
 Gura_ImplementMethod(wx_AuiManager, SetDockSizeConstraint)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	double widthpct = args.GetDouble(0);
-	double heightpct = args.GetDouble(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	double widthpct = arg.GetDouble(0);
+	double heightpct = arg.GetDouble(1);
 	pThis->GetEntity()->SetDockSizeConstraint(widthpct, heightpct);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, SetFlags)
@@ -434,11 +456,12 @@ Gura_DeclareMethod(wx_AuiManager, SetFlags)
 
 Gura_ImplementMethod(wx_AuiManager, SetFlags)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned flags = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned flags = arg.GetInt(0);
 	pThis->GetEntity()->SetFlags(flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, SetManagedWindow)
@@ -449,11 +472,12 @@ Gura_DeclareMethod(wx_AuiManager, SetManagedWindow)
 
 Gura_ImplementMethod(wx_AuiManager, SetManagedWindow)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *managed_wnd = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *managed_wnd = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetManagedWindow(managed_wnd);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, ShowHint)
@@ -464,11 +488,12 @@ Gura_DeclareMethod(wx_AuiManager, ShowHint)
 
 Gura_ImplementMethod(wx_AuiManager, ShowHint)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->ShowHint(*rect);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, UnInit)
@@ -478,10 +503,11 @@ Gura_DeclareMethod(wx_AuiManager, UnInit)
 
 Gura_ImplementMethod(wx_AuiManager, UnInit)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->UnInit();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiManager, Update)
@@ -491,10 +517,11 @@ Gura_DeclareMethod(wx_AuiManager, Update)
 
 Gura_ImplementMethod(wx_AuiManager, Update)
 {
-	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiManager *pThis = Object_wx_AuiManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Update();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -506,13 +533,13 @@ Object_wx_AuiManager::~Object_wx_AuiManager()
 
 Object *Object_wx_AuiManager::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_AuiManager::ToString(bool exprFlag)
 {
 	String rtn("<wx.AuiManager:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -558,7 +585,7 @@ Gura_ImplementUserInheritableClass(wx_AuiManager)
 
 Gura_ImplementDescendantCreator(wx_AuiManager)
 {
-	return new Object_wx_AuiManager((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_AuiManager((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
