@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_AuiNotebook: public wxAuiNotebook, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_AuiNotebook *_pObj;
 public:
-	inline wx_AuiNotebook() : wxAuiNotebook(), _sig(NULL), _pObj(NULL) {}
-	inline wx_AuiNotebook(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style) : wxAuiNotebook(parent, id, pos, size, style), _sig(NULL), _pObj(NULL) {}
+	inline wx_AuiNotebook() : wxAuiNotebook(), _pObj(nullptr) {}
+	inline wx_AuiNotebook(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style) : wxAuiNotebook(parent, id, pos, size, style), _pObj(nullptr) {}
 	~wx_AuiNotebook();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_AuiNotebook *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_AuiNotebook *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_AuiNotebook::~wx_AuiNotebook()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_AuiNotebook::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(AuiNotebookEmpty)
 
 Gura_ImplementFunction(AuiNotebookEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_AuiNotebook *pEntity = new wx_AuiNotebook();
-	Object_wx_AuiNotebook *pObj = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_AuiNotebook *pObj = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_AuiNotebook(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(AuiNotebook)
@@ -73,26 +74,27 @@ Gura_DeclareFunction(AuiNotebook)
 
 Gura_ImplementFunction(AuiNotebook)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = wxAUI_NB_DEFAULT_STYLE;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wx_AuiNotebook *pEntity = new wx_AuiNotebook(parent, id, *pos, *size, style);
-	Object_wx_AuiNotebook *pObj = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_AuiNotebook *pObj = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_AuiNotebook(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, AddPage)
@@ -107,16 +109,17 @@ Gura_DeclareMethod(wx_AuiNotebook, AddPage)
 
 Gura_ImplementMethod(wx_AuiNotebook, AddPage)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *page = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString caption = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *page = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString caption = wxString::FromUTF8(arg.GetString(1));
 	bool select = false;
-	if (args.IsValid(2)) select = args.GetBoolean(2);
+	if (arg.IsValid(2)) select = arg.GetBoolean(2);
 	wxBitmap *bitmap = (wxBitmap *)(&wxNullBitmap);
-	if (args.IsValid(3)) bitmap = Object_wx_Bitmap::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) bitmap = Object_wx_Bitmap::GetObject(arg, 3)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddPage(page, caption, select, *bitmap);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, AdvanceSelection)
@@ -127,12 +130,13 @@ Gura_DeclareMethod(wx_AuiNotebook, AdvanceSelection)
 
 Gura_ImplementMethod(wx_AuiNotebook, AdvanceSelection)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool forward = true;
-	if (args.IsValid(0)) forward = args.GetBoolean(0);
+	if (arg.IsValid(0)) forward = arg.GetBoolean(0);
 	pThis->GetEntity()->AdvanceSelection(forward);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, Create)
@@ -148,19 +152,20 @@ Gura_DeclareMethod(wx_AuiNotebook, Create)
 
 Gura_ImplementMethod(wx_AuiNotebook, Create)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	bool rtn = pThis->GetEntity()->Create(parent, id, *pos, *size, style);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, DeletePage)
@@ -172,11 +177,12 @@ Gura_DeclareMethod(wx_AuiNotebook, DeletePage)
 
 Gura_ImplementMethod(wx_AuiNotebook, DeletePage)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->DeletePage(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetArtProvider)
@@ -187,10 +193,11 @@ Gura_DeclareMethod(wx_AuiNotebook, GetArtProvider)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetArtProvider)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxAuiTabArt *rtn = (wxAuiTabArt *)pThis->GetEntity()->GetArtProvider();
-	return ReturnValue(env, sig, args, Value(new Object_wx_AuiTabArt(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_AuiTabArt(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetHeightForPageHeight)
@@ -202,11 +209,12 @@ Gura_DeclareMethod(wx_AuiNotebook, GetHeightForPageHeight)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetHeightForPageHeight)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pageHeight = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pageHeight = arg.GetInt(0);
 	int rtn = pThis->GetEntity()->GetHeightForPageHeight(pageHeight);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetPage)
@@ -218,11 +226,12 @@ Gura_DeclareMethod(wx_AuiNotebook, GetPage)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetPage)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page_idx = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page_idx = arg.GetSizeT(0);
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetPage(page_idx);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetPageBitmap)
@@ -234,11 +243,12 @@ Gura_DeclareMethod(wx_AuiNotebook, GetPageBitmap)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetPageBitmap)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	wxBitmap rtn = pThis->GetEntity()->GetPageBitmap(page);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetPageCount)
@@ -249,10 +259,11 @@ Gura_DeclareMethod(wx_AuiNotebook, GetPageCount)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetPageCount)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetPageCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetPageIndex)
@@ -264,11 +275,12 @@ Gura_DeclareMethod(wx_AuiNotebook, GetPageIndex)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetPageIndex)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *page_wnd = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *page_wnd = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	int rtn = pThis->GetEntity()->GetPageIndex(page_wnd);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetPageText)
@@ -280,11 +292,12 @@ Gura_DeclareMethod(wx_AuiNotebook, GetPageText)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetPageText)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	wxString rtn = pThis->GetEntity()->GetPageText(page);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetSelection)
@@ -295,10 +308,11 @@ Gura_DeclareMethod(wx_AuiNotebook, GetSelection)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetSelection)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, GetTabCtrlHeight)
@@ -309,10 +323,11 @@ Gura_DeclareMethod(wx_AuiNotebook, GetTabCtrlHeight)
 
 Gura_ImplementMethod(wx_AuiNotebook, GetTabCtrlHeight)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetTabCtrlHeight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, InsertPage)
@@ -328,17 +343,18 @@ Gura_DeclareMethod(wx_AuiNotebook, InsertPage)
 
 Gura_ImplementMethod(wx_AuiNotebook, InsertPage)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page_idx = args.GetSizeT(0);
-	wxWindow *page = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString caption = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page_idx = arg.GetSizeT(0);
+	wxWindow *page = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString caption = wxString::FromUTF8(arg.GetString(2));
 	bool select = false;
-	if (args.IsValid(3)) select = args.GetBoolean(3);
+	if (arg.IsValid(3)) select = arg.GetBoolean(3);
 	wxBitmap *bitmap = (wxBitmap *)(&wxNullBitmap);
-	if (args.IsValid(4)) bitmap = Object_wx_Bitmap::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) bitmap = Object_wx_Bitmap::GetObject(arg, 4)->GetEntity();
 	bool rtn = pThis->GetEntity()->InsertPage(page_idx, page, caption, select, *bitmap);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, RemovePage)
@@ -350,11 +366,12 @@ Gura_DeclareMethod(wx_AuiNotebook, RemovePage)
 
 Gura_ImplementMethod(wx_AuiNotebook, RemovePage)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->RemovePage(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetArtProvider)
@@ -365,11 +382,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetArtProvider)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetArtProvider)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxAuiTabArt *art = Object_wx_AuiTabArt::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxAuiTabArt *art = Object_wx_AuiTabArt::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetArtProvider(art);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetFont)
@@ -381,11 +399,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetFont)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetFont)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->SetFont(*font);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetNormalFont)
@@ -396,11 +415,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetNormalFont)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetNormalFont)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetNormalFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetSelectedFont)
@@ -411,11 +431,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetSelectedFont)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetSelectedFont)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetSelectedFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetMeasuringFont)
@@ -426,11 +447,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetMeasuringFont)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetMeasuringFont)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMeasuringFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetPageBitmap)
@@ -443,12 +465,13 @@ Gura_DeclareMethod(wx_AuiNotebook, SetPageBitmap)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetPageBitmap)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	wxBitmap *bitmap = Object_wx_Bitmap::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	wxBitmap *bitmap = Object_wx_Bitmap::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->SetPageBitmap(page, *bitmap);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetPageText)
@@ -461,12 +484,13 @@ Gura_DeclareMethod(wx_AuiNotebook, SetPageText)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetPageText)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->SetPageText(page, text);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetSelection)
@@ -478,11 +502,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetSelection)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetSelection)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t new_page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t new_page = arg.GetSizeT(0);
 	size_t rtn = pThis->GetEntity()->SetSelection(new_page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetTabCtrlHeight)
@@ -493,11 +518,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetTabCtrlHeight)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetTabCtrlHeight)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int height = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int height = arg.GetInt(0);
 	pThis->GetEntity()->SetTabCtrlHeight(height);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, SetUniformBitmapSize)
@@ -508,11 +534,12 @@ Gura_DeclareMethod(wx_AuiNotebook, SetUniformBitmapSize)
 
 Gura_ImplementMethod(wx_AuiNotebook, SetUniformBitmapSize)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetUniformBitmapSize(*size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, Split)
@@ -524,12 +551,13 @@ Gura_DeclareMethod(wx_AuiNotebook, Split)
 
 Gura_ImplementMethod(wx_AuiNotebook, Split)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	int direction = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	int direction = arg.GetInt(1);
 	pThis->GetEntity()->Split(page, direction);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_AuiNotebook, ShowWindowMenu)
@@ -540,10 +568,11 @@ Gura_DeclareMethod(wx_AuiNotebook, ShowWindowMenu)
 
 Gura_ImplementMethod(wx_AuiNotebook, ShowWindowMenu)
 {
-	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_AuiNotebook *pThis = Object_wx_AuiNotebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ShowWindowMenu();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -555,13 +584,13 @@ Object_wx_AuiNotebook::~Object_wx_AuiNotebook()
 
 Object *Object_wx_AuiNotebook::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_AuiNotebook::ToString(bool exprFlag)
 {
 	String rtn("<wx.AuiNotebook:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -609,7 +638,7 @@ Gura_ImplementUserInheritableClass(wx_AuiNotebook)
 
 Gura_ImplementDescendantCreator(wx_AuiNotebook)
 {
-	return new Object_wx_AuiNotebook((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_AuiNotebook((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
