@@ -14,23 +14,23 @@ Gura_DeclarePrivUserSymbol(Create_1);
 //----------------------------------------------------------------------------
 class wx_Bitmap : public wxBitmap, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Bitmap *_pObj;
 public:
-	inline wx_Bitmap() : wxBitmap(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(const wxBitmap& bitmap) : wxBitmap(bitmap), _sig(NULL), _pObj(NULL) {}
-	//inline wx_Bitmap(const void* data, int type, int width, int height, int depth) : wxBitmap(data, type, width, height, depth), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(const char bits[], int width, int height, int depth) : wxBitmap(bits, width, height, depth), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(int width, int height, int depth) : wxBitmap(width, height, depth), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(const char* const* bits) : wxBitmap(bits), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(const wxString& name, wxBitmapType type) : wxBitmap(name, type), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(const wxImage& img, int depth) : wxBitmap(img, depth), _sig(NULL), _pObj(NULL) {}
-	inline wx_Bitmap(const wxIcon& icon) : wxBitmap(icon), _sig(NULL), _pObj(NULL) {}
+	inline wx_Bitmap() : wxBitmap(), _pObj(nullptr) {}
+	inline wx_Bitmap(const wxBitmap& bitmap) : wxBitmap(bitmap), _pObj(nullptr) {}
+	//inline wx_Bitmap(const void* data, int type, int width, int height, int depth) : wxBitmap(data, type, width, height, depth), _pObj(nullptr) {}
+	inline wx_Bitmap(const char bits[], int width, int height, int depth) : wxBitmap(bits, width, height, depth), _pObj(nullptr) {}
+	inline wx_Bitmap(int width, int height, int depth) : wxBitmap(width, height, depth), _pObj(nullptr) {}
+	inline wx_Bitmap(const char* const* bits) : wxBitmap(bits), _pObj(nullptr) {}
+	inline wx_Bitmap(const wxString& name, wxBitmapType type) : wxBitmap(name, type), _pObj(nullptr) {}
+	inline wx_Bitmap(const wxImage& img, int depth) : wxBitmap(img, depth), _pObj(nullptr) {}
+	inline wx_Bitmap(const wxIcon& icon) : wxBitmap(icon), _pObj(nullptr) {}
 	//virtual bool Create(int width, int height, int depth);
 	//virtual bool Create(const void* data, int type, int width, int height, int depth);
 	~wx_Bitmap();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Bitmap *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Bitmap *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -38,12 +38,12 @@ public:
 
 wx_Bitmap::~wx_Bitmap()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Bitmap::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -58,17 +58,18 @@ Gura_DeclareFunction(EmptyBitmap)
 
 Gura_ImplementFunction(EmptyBitmap)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Bitmap *pEntity = new wx_Bitmap();
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Bitmap)
@@ -81,51 +82,53 @@ Gura_DeclareFunction(Bitmap)
 
 Gura_ImplementFunction(Bitmap)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	Object_image *pObjImage = Object_image::GetObject(args, 0);
-	std::auto_ptr<wxImage> pImage(new wxImage(
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	Object_image *pObjImage = Object_image::GetObject(arg, 0);
+	std::unique_ptr<wxImage> pImage(new wxImage(
 		pObjImage->GetImage()->GetWidth(), pObjImage->GetImage()->GetHeight(), false));
 	ConvertToWxImage(pObjImage->GetImage(), pImage.get());
 	wx_Bitmap *pEntity = new wx_Bitmap(*pImage, -1);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(BitmapFromXPMData)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	SetClassToConstruct(Gura_UserClass(wx_Bitmap));
-	DeclareArg(env, "bits", VTYPE_string, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "bits", VTYPE_string, OCCUR_Once, FLAG_ListVar);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 Gura_ImplementFunction(BitmapFromXPMData)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	const char **bits = new const char *[args.GetList(0).size()];
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	const char **bits = new const char *[arg.GetList(0).size()];
 	size_t i = 0;
-	foreach_const (ValueList, pValue, args.GetList(0)) {
+	foreach_const (ValueList, pValue, arg.GetList(0)) {
 		const Value &value = *pValue;
 		bits[i++] = value.GetString();
 	}
 	wx_Bitmap *pEntity = new wx_Bitmap(bits);
 	delete[] bits;
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Bitmap_1)
@@ -144,27 +147,28 @@ Gura_DeclareFunction(Bitmap_1)
 
 Gura_ImplementFunction(Bitmap_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	int data = args.GetInt(0);
-	int type = args.GetInt(1);
-	int width = args.GetInt(2);
-	int height = args.GetInt(3);
+	int data = arg.GetInt(0);
+	int type = arg.GetInt(1);
+	int width = arg.GetInt(2);
+	int height = arg.GetInt(3);
 	int depth = -1;
-	if (args.IsValid(4)) depth = args.GetInt(4);
+	if (arg.IsValid(4)) depth = arg.GetInt(4);
 	wx_Bitmap *pEntity = new wx_Bitmap(data, type, width, height, depth);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(BitmapFromBits)
@@ -180,22 +184,23 @@ Gura_DeclareFunction(BitmapFromBits)
 
 Gura_ImplementFunction(BitmapFromBits)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	const char *bits = args.GetBinary(0).data();
-	int width = args.GetInt(1);
-	int height = args.GetInt(2);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	const char *bits = arg.GetBinary(0).data();
+	int width = arg.GetInt(1);
+	int height = arg.GetInt(2);
 	int depth = 1;
-	if (args.IsValid(3)) depth = args.GetInt(3);
+	if (arg.IsValid(3)) depth = arg.GetInt(3);
 	wx_Bitmap *pEntity = new wx_Bitmap(bits, width, height, depth);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(BitmapWH)
@@ -210,21 +215,22 @@ Gura_DeclareFunction(BitmapWH)
 
 Gura_ImplementFunction(BitmapWH)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int width = args.GetInt(0);
-	int height = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
+	int height = arg.GetInt(1);
 	int depth = -1;
-	if (args.IsValid(2)) depth = args.GetInt(2);
+	if (arg.IsValid(2)) depth = arg.GetInt(2);
 	wx_Bitmap *pEntity = new wx_Bitmap(width, height, depth);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(BitmapFromFile)
@@ -238,19 +244,20 @@ Gura_DeclareFunction(BitmapFromFile)
 
 Gura_ImplementFunction(BitmapFromFile)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxBitmapType type = static_cast<wxBitmapType>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxBitmapType type = static_cast<wxBitmapType>(arg.GetInt(1));
 	wx_Bitmap *pEntity = new wx_Bitmap(name, type);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(BitmapFromIcon)
@@ -263,18 +270,19 @@ Gura_DeclareFunction(BitmapFromIcon)
 
 Gura_ImplementFunction(BitmapFromIcon)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxIcon *icon = Object_wx_Icon::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxIcon *icon = Object_wx_Icon::GetObject(arg, 0)->GetEntity();
 	wx_Bitmap *pEntity = new wx_Bitmap(*icon);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(BitmapFromImage)
@@ -288,20 +296,21 @@ Gura_DeclareFunction(BitmapFromImage)
 
 Gura_ImplementFunction(BitmapFromImage)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxImage *img = Object_wx_Image::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxImage *img = Object_wx_Image::GetObject(arg, 0)->GetEntity();
 	int depth = -1;
-	if (args.IsValid(1)) depth = args.GetInt(1);
+	if (arg.IsValid(1)) depth = arg.GetInt(1);
 	wx_Bitmap *pEntity = new wx_Bitmap(*img, depth);
-	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Bitmap *pObj = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Bitmap(pEntity, pEntity, OwnerTrue);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerTrue);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, AddHandler)
@@ -312,10 +321,11 @@ Gura_DeclareClassMethod(wx_Bitmap, AddHandler)
 
 Gura_ImplementClassMethod(wx_Bitmap, AddHandler)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxBitmapHandler *handler = Object_wx_BitmapHandler::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxBitmapHandler *handler = Object_wx_BitmapHandler::GetObject(arg, 0)->GetEntity();
 	wxBitmap::AddHandler(handler);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, CleanUpHandlers)
@@ -325,9 +335,10 @@ Gura_DeclareClassMethod(wx_Bitmap, CleanUpHandlers)
 
 Gura_ImplementClassMethod(wx_Bitmap, CleanUpHandlers)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxBitmap::CleanUpHandlers();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, ConvertToImage)
@@ -338,10 +349,11 @@ Gura_DeclareMethod(wx_Bitmap, ConvertToImage)
 
 Gura_ImplementMethod(wx_Bitmap, ConvertToImage)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxImage rtn = pThis->GetEntity()->ConvertToImage();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Image(new wxImage(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Image(new wxImage(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Bitmap, CopyFromIcon)
@@ -353,11 +365,12 @@ Gura_DeclareMethod(wx_Bitmap, CopyFromIcon)
 
 Gura_ImplementMethod(wx_Bitmap, CopyFromIcon)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIcon *icon = Object_wx_Icon::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIcon *icon = Object_wx_Icon::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->CopyFromIcon(*icon);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, Create)
@@ -371,14 +384,15 @@ Gura_DeclareMethod(wx_Bitmap, Create)
 
 Gura_ImplementMethod(wx_Bitmap, Create)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
-	int height = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
+	int height = arg.GetInt(1);
 	int depth = -1;
-	if (args.IsValid(2)) depth = args.GetInt(2);
+	if (arg.IsValid(2)) depth = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->Create(width, height, depth);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, Create_1)
@@ -396,20 +410,21 @@ Gura_DeclareMethod(wx_Bitmap, Create_1)
 
 Gura_ImplementMethod(wx_Bitmap, Create_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int data = args.GetInt(0);
-	int type = args.GetInt(1);
-	int width = args.GetInt(2);
-	int height = args.GetInt(3);
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int data = arg.GetInt(0);
+	int type = arg.GetInt(1);
+	int width = arg.GetInt(2);
+	int height = arg.GetInt(3);
 	int depth = -1;
-	if (args.IsValid(4)) depth = args.GetInt(4);
+	if (arg.IsValid(4)) depth = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->Create(data, type, width, height, depth);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, FindHandler)
@@ -421,10 +436,11 @@ Gura_DeclareClassMethod(wx_Bitmap, FindHandler)
 
 Gura_ImplementClassMethod(wx_Bitmap, FindHandler)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxBitmapHandler *rtn = (wxBitmapHandler *)wxBitmap::FindHandler(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_BitmapHandler(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_BitmapHandler(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, FindHandler_1)
@@ -437,11 +453,12 @@ Gura_DeclareClassMethod(wx_Bitmap, FindHandler_1)
 
 Gura_ImplementClassMethod(wx_Bitmap, FindHandler_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString extension = wxString::FromUTF8(args.GetString(0));
-	wxBitmapType bitmapType = static_cast<wxBitmapType>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString extension = wxString::FromUTF8(arg.GetString(0));
+	wxBitmapType bitmapType = static_cast<wxBitmapType>(arg.GetInt(1));
 	wxBitmapHandler *rtn = (wxBitmapHandler *)wxBitmap::FindHandler(extension, bitmapType);
-	return ReturnValue(env, sig, args, Value(new Object_wx_BitmapHandler(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_BitmapHandler(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, FindHandler_2)
@@ -453,10 +470,11 @@ Gura_DeclareClassMethod(wx_Bitmap, FindHandler_2)
 
 Gura_ImplementClassMethod(wx_Bitmap, FindHandler_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxBitmapType bitmapType = static_cast<wxBitmapType>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxBitmapType bitmapType = static_cast<wxBitmapType>(arg.GetInt(0));
 	wxBitmapHandler *rtn = (wxBitmapHandler *)wxBitmap::FindHandler(bitmapType);
-	return ReturnValue(env, sig, args, Value(new Object_wx_BitmapHandler(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_BitmapHandler(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Bitmap, GetDepth)
@@ -467,10 +485,11 @@ Gura_DeclareMethod(wx_Bitmap, GetDepth)
 
 Gura_ImplementMethod(wx_Bitmap, GetDepth)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetDepth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, GetHandlers)
@@ -481,9 +500,10 @@ Gura_DeclareClassMethod(wx_Bitmap, GetHandlers)
 
 Gura_ImplementClassMethod(wx_Bitmap, GetHandlers)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxList &rtn = wxBitmap::GetHandlers();
-	return ReturnValue(env, sig, args, Value(new Object_wx_List(new wxList(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_List(new wxList(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Bitmap, GetHeight)
@@ -494,10 +514,11 @@ Gura_DeclareMethod(wx_Bitmap, GetHeight)
 
 Gura_ImplementMethod(wx_Bitmap, GetHeight)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetHeight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, GetPalette)
@@ -508,10 +529,11 @@ Gura_DeclareMethod(wx_Bitmap, GetPalette)
 
 Gura_ImplementMethod(wx_Bitmap, GetPalette)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPalette *rtn = (wxPalette *)pThis->GetEntity()->GetPalette();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Palette(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Palette(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Bitmap, GetMask)
@@ -522,10 +544,11 @@ Gura_DeclareMethod(wx_Bitmap, GetMask)
 
 Gura_ImplementMethod(wx_Bitmap, GetMask)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMask *rtn = (wxMask *)pThis->GetEntity()->GetMask();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Mask(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Mask(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Bitmap, GetWidth)
@@ -536,10 +559,11 @@ Gura_DeclareMethod(wx_Bitmap, GetWidth)
 
 Gura_ImplementMethod(wx_Bitmap, GetWidth)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWidth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, GetSubBitmap)
@@ -551,11 +575,12 @@ Gura_DeclareMethod(wx_Bitmap, GetSubBitmap)
 
 Gura_ImplementMethod(wx_Bitmap, GetSubBitmap)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wxBitmap rtn = pThis->GetEntity()->GetSubBitmap(*rect);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, InitStandardHandlers)
@@ -565,9 +590,10 @@ Gura_DeclareClassMethod(wx_Bitmap, InitStandardHandlers)
 
 Gura_ImplementClassMethod(wx_Bitmap, InitStandardHandlers)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxBitmap::InitStandardHandlers();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, InsertHandler)
@@ -578,10 +604,11 @@ Gura_DeclareClassMethod(wx_Bitmap, InsertHandler)
 
 Gura_ImplementClassMethod(wx_Bitmap, InsertHandler)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxBitmapHandler *handler = Object_wx_BitmapHandler::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxBitmapHandler *handler = Object_wx_BitmapHandler::GetObject(arg, 0)->GetEntity();
 	wxBitmap::InsertHandler(handler);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, LoadFile)
@@ -594,12 +621,13 @@ Gura_DeclareMethod(wx_Bitmap, LoadFile)
 
 Gura_ImplementMethod(wx_Bitmap, LoadFile)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxBitmapType type = static_cast<wxBitmapType>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxBitmapType type = static_cast<wxBitmapType>(arg.GetInt(1));
 	bool rtn = pThis->GetEntity()->LoadFile(name, type);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, IsOk)
@@ -610,10 +638,11 @@ Gura_DeclareMethod(wx_Bitmap, IsOk)
 
 Gura_ImplementMethod(wx_Bitmap, IsOk)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Bitmap, RemoveHandler)
@@ -625,10 +654,11 @@ Gura_DeclareClassMethod(wx_Bitmap, RemoveHandler)
 
 Gura_ImplementClassMethod(wx_Bitmap, RemoveHandler)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = wxBitmap::RemoveHandler(name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, SaveFile)
@@ -642,14 +672,15 @@ Gura_DeclareMethod(wx_Bitmap, SaveFile)
 
 Gura_ImplementMethod(wx_Bitmap, SaveFile)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxBitmapType type = static_cast<wxBitmapType>(args.GetInt(1));
-	wxPalette *palette = (wxPalette *)(NULL);
-	if (args.IsValid(2)) palette = Object_wx_Palette::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxBitmapType type = static_cast<wxBitmapType>(arg.GetInt(1));
+	wxPalette *palette = (wxPalette *)(nullptr);
+	if (arg.IsValid(2)) palette = Object_wx_Palette::GetObject(arg, 2)->GetEntity();
 	bool rtn = pThis->GetEntity()->SaveFile(name, type, palette);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Bitmap, SetDepth)
@@ -660,11 +691,12 @@ Gura_DeclareMethod(wx_Bitmap, SetDepth)
 
 Gura_ImplementMethod(wx_Bitmap, SetDepth)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int depth = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int depth = arg.GetInt(0);
 	pThis->GetEntity()->SetDepth(depth);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, SetHeight)
@@ -675,11 +707,12 @@ Gura_DeclareMethod(wx_Bitmap, SetHeight)
 
 Gura_ImplementMethod(wx_Bitmap, SetHeight)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int height = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int height = arg.GetInt(0);
 	pThis->GetEntity()->SetHeight(height);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, SetMask)
@@ -690,11 +723,12 @@ Gura_DeclareMethod(wx_Bitmap, SetMask)
 
 Gura_ImplementMethod(wx_Bitmap, SetMask)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMask *mask = Object_wx_Mask::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMask *mask = Object_wx_Mask::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMask(mask);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, SetOk)
@@ -707,15 +741,16 @@ Gura_DeclareMethod(wx_Bitmap, SetOk)
 
 Gura_ImplementMethod(wx_Bitmap, SetOk)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int isOk = args.GetInt(0);
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int isOk = arg.GetInt(0);
 	pThis->GetEntity()->SetOk(isOk);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, SetPalette)
@@ -726,11 +761,12 @@ Gura_DeclareMethod(wx_Bitmap, SetPalette)
 
 Gura_ImplementMethod(wx_Bitmap, SetPalette)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPalette *palette = Object_wx_Palette::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPalette *palette = Object_wx_Palette::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPalette(*palette);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Bitmap, SetWidth)
@@ -741,11 +777,12 @@ Gura_DeclareMethod(wx_Bitmap, SetWidth)
 
 Gura_ImplementMethod(wx_Bitmap, SetWidth)
 {
-	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Bitmap *pThis = Object_wx_Bitmap::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
 	pThis->GetEntity()->SetWidth(width);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -757,13 +794,13 @@ Object_wx_Bitmap::~Object_wx_Bitmap()
 
 Object *Object_wx_Bitmap::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Bitmap::ToString(bool exprFlag)
 {
 	String rtn("<wx.Bitmap:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -822,19 +859,19 @@ Gura_ImplementUserInheritableClassWithCast(wx_Bitmap)
 
 Gura_ImplementDescendantCreator(wx_Bitmap)
 {
-	return new Object_wx_Bitmap((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Bitmap((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_ImplementCastFrom(wx_Bitmap)
 {
 	if (!value.Is_image()) return false;
 	Object_image *pObjImage = Object_image::GetObject(value);
-	std::auto_ptr<wxImage> pImage(new wxImage(
+	std::unique_ptr<wxImage> pImage(new wxImage(
 		pObjImage->GetImage()->GetWidth(), pObjImage->GetImage()->GetHeight(), false));
 	ConvertToWxImage(pObjImage->GetImage(), pImage.get());
 	wx_Bitmap *pBitmap = new wx_Bitmap(*pImage, -1);
 	Object_wx_Bitmap *pObj = new Object_wx_Bitmap(pBitmap, pBitmap, OwnerTrue);
-	pBitmap->AssocWithGura(sig, pObj);
+	pBitmap->AssocWithGura(pObj);
 	value = Value(pObj);
 	return true;
 }
