@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_CalendarCtrl: public wxCalendarCtrl, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_CalendarCtrl *_pObj;
 public:
-	inline wx_CalendarCtrl() : wxCalendarCtrl(), _sig(NULL), _pObj(NULL) {}
-	inline wx_CalendarCtrl(wxWindow* parent, wxWindowID id, const wxDateTime& date, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxCalendarCtrl(parent, id, date, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_CalendarCtrl() : wxCalendarCtrl(), _pObj(nullptr) {}
+	inline wx_CalendarCtrl(wxWindow* parent, wxWindowID id, const wxDateTime& date, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxCalendarCtrl(parent, id, date, pos, size, style, name), _pObj(nullptr) {}
 	~wx_CalendarCtrl();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_CalendarCtrl *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_CalendarCtrl *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_CalendarCtrl::~wx_CalendarCtrl()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_CalendarCtrl::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(CalendarCtrlEmpty)
 
 Gura_ImplementFunction(CalendarCtrlEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_CalendarCtrl *pEntity = new wx_CalendarCtrl();
-	Object_wx_CalendarCtrl *pObj = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CalendarCtrl *pObj = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CalendarCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(CalendarCtrl)
@@ -75,29 +76,30 @@ Gura_DeclareFunction(CalendarCtrl)
 
 Gura_ImplementFunction(CalendarCtrl)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxDateTime *date = (wxDateTime *)(&wxDefaultDateTime);
-	if (args.IsValid(2)) date = Object_wx_DateTime::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) date = Object_wx_DateTime::GetObject(arg, 2)->GetEntity();
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = wxCAL_SHOW_HOLIDAYS;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString name = wxCalendarNameStr;
-	if (args.IsValid(6)) name = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) name = wxString::FromUTF8(arg.GetString(6));
 	wx_CalendarCtrl *pEntity = new wx_CalendarCtrl(parent, id, *date, *pos, *size, style, name);
-	Object_wx_CalendarCtrl *pObj = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CalendarCtrl *pObj = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CalendarCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, Create)
@@ -115,22 +117,23 @@ Gura_DeclareMethod(wx_CalendarCtrl, Create)
 
 Gura_ImplementMethod(wx_CalendarCtrl, Create)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxDateTime *date = (wxDateTime *)(&wxDefaultDateTime);
-	if (args.IsValid(2)) date = Object_wx_DateTime::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) date = Object_wx_DateTime::GetObject(arg, 2)->GetEntity();
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = wxCAL_SHOW_HOLIDAYS;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString name = wxCalendarNameStr;
-	if (args.IsValid(6)) name = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) name = wxString::FromUTF8(arg.GetString(6));
 	bool rtn = pThis->GetEntity()->Create(parent, id, *date, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, SetDate)
@@ -141,11 +144,12 @@ Gura_DeclareMethod(wx_CalendarCtrl, SetDate)
 
 Gura_ImplementMethod(wx_CalendarCtrl, SetDate)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDateTime *date = Object_wx_DateTime::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDateTime *date = Object_wx_DateTime::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetDate(*date);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetDate)
@@ -156,10 +160,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetDate)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetDate)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxDateTime &rtn = pThis->GetEntity()->GetDate();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DateTime(new wxDateTime(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_DateTime(new wxDateTime(rtn), nullptr, OwnerTrue)));
 }
 
 #if 0
@@ -171,12 +176,13 @@ Gura_DeclareMethod(wx_CalendarCtrl, EnableYearChange)
 
 Gura_ImplementMethod(wx_CalendarCtrl, EnableYearChange)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableYearChange(enable);
-	return Value::Null;
+	return Value::Nil;
 }
 #endif
 
@@ -188,12 +194,13 @@ Gura_DeclareMethod(wx_CalendarCtrl, EnableMonthChange)
 
 Gura_ImplementMethod(wx_CalendarCtrl, EnableMonthChange)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableMonthChange(enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, EnableHolidayDisplay)
@@ -204,12 +211,13 @@ Gura_DeclareMethod(wx_CalendarCtrl, EnableHolidayDisplay)
 
 Gura_ImplementMethod(wx_CalendarCtrl, EnableHolidayDisplay)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool display = true;
-	if (args.IsValid(0)) display = args.GetBoolean(0);
+	if (arg.IsValid(0)) display = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableHolidayDisplay(display);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, SetHeaderColours)
@@ -221,12 +229,13 @@ Gura_DeclareMethod(wx_CalendarCtrl, SetHeaderColours)
 
 Gura_ImplementMethod(wx_CalendarCtrl, SetHeaderColours)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colFg = Object_wx_Colour::GetObject(args, 0)->GetEntity();
-	wxColour *colBg = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colFg = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
+	wxColour *colBg = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetHeaderColours(*colFg, *colBg);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetHeaderColourFg)
@@ -237,10 +246,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetHeaderColourFg)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetHeaderColourFg)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetHeaderColourFg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetHeaderColourBg)
@@ -251,10 +261,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetHeaderColourBg)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetHeaderColourBg)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetHeaderColourBg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, SetHighlightColours)
@@ -266,12 +277,13 @@ Gura_DeclareMethod(wx_CalendarCtrl, SetHighlightColours)
 
 Gura_ImplementMethod(wx_CalendarCtrl, SetHighlightColours)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colFg = Object_wx_Colour::GetObject(args, 0)->GetEntity();
-	wxColour *colBg = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colFg = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
+	wxColour *colBg = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetHighlightColours(*colFg, *colBg);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetHighlightColourFg)
@@ -282,10 +294,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetHighlightColourFg)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetHighlightColourFg)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetHighlightColourFg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetHighlightColourBg)
@@ -296,10 +309,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetHighlightColourBg)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetHighlightColourBg)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetHighlightColourBg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, SetHolidayColours)
@@ -311,12 +325,13 @@ Gura_DeclareMethod(wx_CalendarCtrl, SetHolidayColours)
 
 Gura_ImplementMethod(wx_CalendarCtrl, SetHolidayColours)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colFg = Object_wx_Colour::GetObject(args, 0)->GetEntity();
-	wxColour *colBg = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colFg = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
+	wxColour *colBg = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetHolidayColours(*colFg, *colBg);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetHolidayColourFg)
@@ -327,10 +342,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetHolidayColourFg)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetHolidayColourFg)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetHolidayColourFg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetHolidayColourBg)
@@ -341,10 +357,11 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetHolidayColourBg)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetHolidayColourBg)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetHolidayColourBg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, GetAttr)
@@ -356,11 +373,12 @@ Gura_DeclareMethod(wx_CalendarCtrl, GetAttr)
 
 Gura_ImplementMethod(wx_CalendarCtrl, GetAttr)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t day = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t day = arg.GetSizeT(0);
 	wxCalendarDateAttr *rtn = (wxCalendarDateAttr *)pThis->GetEntity()->GetAttr(day);
-	return ReturnValue(env, sig, args, Value(new Object_wx_CalendarDateAttr(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_CalendarDateAttr(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, SetAttr)
@@ -372,14 +390,15 @@ Gura_DeclareMethod(wx_CalendarCtrl, SetAttr)
 
 Gura_ImplementMethod(wx_CalendarCtrl, SetAttr)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t day = args.GetSizeT(0);
-	wxCalendarDateAttr *attr = Object_wx_CalendarDateAttr::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t day = arg.GetSizeT(0);
+	wxCalendarDateAttr *attr = Object_wx_CalendarDateAttr::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetAttr(day, new wxCalendarDateAttr(attr->GetTextColour(),
 							attr->GetBackgroundColour(), attr->GetBorderColour(),
 							attr->GetFont(), attr->GetBorder()));
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, SetHoliday)
@@ -390,11 +409,12 @@ Gura_DeclareMethod(wx_CalendarCtrl, SetHoliday)
 
 Gura_ImplementMethod(wx_CalendarCtrl, SetHoliday)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t day = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t day = arg.GetSizeT(0);
 	pThis->GetEntity()->SetHoliday(day);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, ResetAttr)
@@ -405,11 +425,12 @@ Gura_DeclareMethod(wx_CalendarCtrl, ResetAttr)
 
 Gura_ImplementMethod(wx_CalendarCtrl, ResetAttr)
 {
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t day = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t day = arg.GetSizeT(0);
 	pThis->GetEntity()->ResetAttr(day);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CalendarCtrl, HitTest)
@@ -425,19 +446,20 @@ Gura_DeclareMethod(wx_CalendarCtrl, HitTest)
 
 Gura_ImplementMethod(wx_CalendarCtrl, HitTest)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pos = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxDateTime *date = (wxDateTime *)(NULL);
-	if (args.IsValid(1)) date = Object_wx_DateTime::GetObject(args, 1)->GetEntity();
-	wxDateTime *wd = (wxDateTime *)(&NULL);
-	if (args.IsValid(2)) wd = Object_wx_DateTime::GetObject(args, 2)->GetEntity();
+	Object_wx_CalendarCtrl *pThis = Object_wx_CalendarCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxDateTime *date = (wxDateTime *)(nullptr);
+	if (arg.IsValid(1)) date = Object_wx_DateTime::GetObject(arg, 1)->GetEntity();
+	wxDateTime *wd = (wxDateTime *)(&nullptr);
+	if (arg.IsValid(2)) wd = Object_wx_DateTime::GetObject(arg, 2)->GetEntity();
 	wxCalendarHitTestResult rtn = pThis->GetEntity()->HitTest(*pos, date, *wd);
-	return ReturnValue(env, sig, args, Value(new Object_wx_CalendarHitTestResult(new wxCalendarHitTestResult(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_CalendarHitTestResult(new wxCalendarHitTestResult(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -449,13 +471,13 @@ Object_wx_CalendarCtrl::~Object_wx_CalendarCtrl()
 
 Object *Object_wx_CalendarCtrl::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_CalendarCtrl::ToString(bool exprFlag)
 {
 	String rtn("<wx.CalendarCtrl:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -497,7 +519,7 @@ Gura_ImplementUserInheritableClass(wx_CalendarCtrl)
 
 Gura_ImplementDescendantCreator(wx_CalendarCtrl)
 {
-	return new Object_wx_CalendarCtrl((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_CalendarCtrl((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
