@@ -11,19 +11,19 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_CmdLineParser: public wxCmdLineParser, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_CmdLineParser *_pObj;
 public:
-	//inline wx_CmdLineParser() : wxCmdLineParser(), _sig(NULL), _pObj(NULL) {}
-	//inline wx_CmdLineParser(int argc, char** argv) : wxCmdLineParser(argc, argv), _sig(NULL), _pObj(NULL) {}
-	//inline wx_CmdLineParser(int argc, wchar_t** argv) : wxCmdLineParser(argc, argv), _sig(NULL), _pObj(NULL) {}
-	//inline wx_CmdLineParser(const wxString& cmdline) : wxCmdLineParser(cmdline), _sig(NULL), _pObj(NULL) {}
-	//inline wx_CmdLineParser(const wxCmdLineEntryDesc* desc) : wxCmdLineParser(desc), _sig(NULL), _pObj(NULL) {}
-	//inline wx_CmdLineParser(const wxCmdLineEntryDesc* desc, int argc, char** argv) : wxCmdLineParser(desc, argc, argv), _sig(NULL), _pObj(NULL) {}
-	//inline wx_CmdLineParser(const wxCmdLineEntryDesc* desc, const wxString& cmdline) : wxCmdLineParser(desc, cmdline), _sig(NULL), _pObj(NULL) {}
+	//inline wx_CmdLineParser() : wxCmdLineParser(), _pObj(nullptr) {}
+	//inline wx_CmdLineParser(int argc, char** argv) : wxCmdLineParser(argc, argv), _pObj(nullptr) {}
+	//inline wx_CmdLineParser(int argc, wchar_t** argv) : wxCmdLineParser(argc, argv), _pObj(nullptr) {}
+	//inline wx_CmdLineParser(const wxString& cmdline) : wxCmdLineParser(cmdline), _pObj(nullptr) {}
+	//inline wx_CmdLineParser(const wxCmdLineEntryDesc* desc) : wxCmdLineParser(desc), _pObj(nullptr) {}
+	//inline wx_CmdLineParser(const wxCmdLineEntryDesc* desc, int argc, char** argv) : wxCmdLineParser(desc, argc, argv), _pObj(nullptr) {}
+	//inline wx_CmdLineParser(const wxCmdLineEntryDesc* desc, const wxString& cmdline) : wxCmdLineParser(desc, cmdline), _pObj(nullptr) {}
 	~wx_CmdLineParser();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_CmdLineParser *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_CmdLineParser *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -31,12 +31,12 @@ public:
 
 wx_CmdLineParser::~wx_CmdLineParser()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_CmdLineParser::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -53,21 +53,22 @@ Gura_DeclareFunction(CmdLineParserEmpty)
 
 Gura_ImplementFunction(CmdLineParserEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser();
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(CmdLineParser)
@@ -83,23 +84,24 @@ Gura_DeclareFunction(CmdLineParser)
 
 Gura_ImplementFunction(CmdLineParser)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	int argc = args.GetInt(0);
-	char argv = args.GetChar(1);
+	int argc = arg.GetInt(0);
+	char argv = arg.GetChar(1);
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser(argc, argv);
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(CmdLineParser_1)
@@ -115,23 +117,24 @@ Gura_DeclareFunction(CmdLineParser_1)
 
 Gura_ImplementFunction(CmdLineParser_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	int argc = args.GetInt(0);
-	wchar_t argv = static_cast<wchar_t>(args.GetUShort(1));
+	int argc = arg.GetInt(0);
+	wchar_t argv = static_cast<wchar_t>(arg.GetUShort(1));
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser(argc, argv);
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(CmdLineParser_2)
@@ -146,22 +149,23 @@ Gura_DeclareFunction(CmdLineParser_2)
 
 Gura_ImplementFunction(CmdLineParser_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxString cmdline = wxString::FromUTF8(args.GetString(0));
+	wxString cmdline = wxString::FromUTF8(arg.GetString(0));
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser(cmdline);
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(CmdLineParser_3)
@@ -176,22 +180,23 @@ Gura_DeclareFunction(CmdLineParser_3)
 
 Gura_ImplementFunction(CmdLineParser_3)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(args, 0)->GetEntity();
+	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(arg, 0)->GetEntity();
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser(desc);
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(CmdLineParser_4)
@@ -208,24 +213,25 @@ Gura_DeclareFunction(CmdLineParser_4)
 
 Gura_ImplementFunction(CmdLineParser_4)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(args, 0)->GetEntity();
-	int argc = args.GetInt(1);
-	char argv = args.GetChar(2);
+	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(arg, 0)->GetEntity();
+	int argc = arg.GetInt(1);
+	char argv = arg.GetChar(2);
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser(desc, argc, argv);
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(CmdLineParser_5)
@@ -241,23 +247,24 @@ Gura_DeclareFunction(CmdLineParser_5)
 
 Gura_ImplementFunction(CmdLineParser_5)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(args, 0)->GetEntity();
-	wxString cmdline = wxString::FromUTF8(args.GetString(1));
+	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(arg, 0)->GetEntity();
+	wxString cmdline = wxString::FromUTF8(arg.GetString(1));
 	wx_CmdLineParser *pEntity = new wx_CmdLineParser(desc, cmdline);
-	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_CmdLineParser *pObj = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_CmdLineParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_CmdLineParser, ConvertStringToArgs)
@@ -271,14 +278,15 @@ Gura_DeclareClassMethod(wx_CmdLineParser, ConvertStringToArgs)
 
 Gura_ImplementClassMethod(wx_CmdLineParser, ConvertStringToArgs)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxChar *cmdline = static_cast<wxChar>(args.GetInt(0));
+	wxChar *cmdline = static_cast<wxChar>(arg.GetInt(0));
 	wxArrayString rtn = wxCmdLineParser::ConvertStringToArgs(*cmdline);
-	return ReturnValue(env, sig, args, ArrayStringToValue(env, rtn));
+	return ReturnValue(env, arg, ArrayStringToValue(env, rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, SetCmdLine)
@@ -292,16 +300,17 @@ Gura_DeclareMethod(wx_CmdLineParser, SetCmdLine)
 
 Gura_ImplementMethod(wx_CmdLineParser, SetCmdLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int argc = args.GetInt(0);
-	char argv = args.GetChar(1);
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int argc = arg.GetInt(0);
+	char argv = arg.GetChar(1);
 	pThis->GetEntity()->SetCmdLine(argc, argv);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, SetCmdLine_1)
@@ -315,16 +324,17 @@ Gura_DeclareMethod(wx_CmdLineParser, SetCmdLine_1)
 
 Gura_ImplementMethod(wx_CmdLineParser, SetCmdLine_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int argc = args.GetInt(0);
-	wchar_t argv = static_cast<wchar_t>(args.GetUShort(1));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int argc = arg.GetInt(0);
+	wchar_t argv = static_cast<wchar_t>(arg.GetUShort(1));
 	pThis->GetEntity()->SetCmdLine(argc, argv);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, SetCmdLine_2)
@@ -337,15 +347,16 @@ Gura_DeclareMethod(wx_CmdLineParser, SetCmdLine_2)
 
 Gura_ImplementMethod(wx_CmdLineParser, SetCmdLine_2)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString cmdline = wxString::FromUTF8(args.GetString(0));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString cmdline = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetCmdLine(cmdline);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, SetSwitchChars)
@@ -358,15 +369,16 @@ Gura_DeclareMethod(wx_CmdLineParser, SetSwitchChars)
 
 Gura_ImplementMethod(wx_CmdLineParser, SetSwitchChars)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString switchChars = wxString::FromUTF8(args.GetString(0));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString switchChars = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetSwitchChars(switchChars);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, EnableLongOptions)
@@ -379,16 +391,17 @@ Gura_DeclareMethod(wx_CmdLineParser, EnableLongOptions)
 
 Gura_ImplementMethod(wx_CmdLineParser, EnableLongOptions)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableLongOptions(enable);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, DisableLongOptions)
@@ -398,14 +411,15 @@ Gura_DeclareMethod(wx_CmdLineParser, DisableLongOptions)
 
 Gura_ImplementMethod(wx_CmdLineParser, DisableLongOptions)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DisableLongOptions();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, AreLongOptionsEnabled)
@@ -416,14 +430,15 @@ Gura_DeclareMethod(wx_CmdLineParser, AreLongOptionsEnabled)
 
 Gura_ImplementMethod(wx_CmdLineParser, AreLongOptionsEnabled)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->AreLongOptionsEnabled();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, SetLogo)
@@ -436,15 +451,16 @@ Gura_DeclareMethod(wx_CmdLineParser, SetLogo)
 
 Gura_ImplementMethod(wx_CmdLineParser, SetLogo)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString logo = wxString::FromUTF8(args.GetString(0));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString logo = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetLogo(logo);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, SetDesc)
@@ -457,15 +473,16 @@ Gura_DeclareMethod(wx_CmdLineParser, SetDesc)
 
 Gura_ImplementMethod(wx_CmdLineParser, SetDesc)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(args, 0)->GetEntity();
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCmdLineEntryDesc *desc = Object_wx_CmdLineEntryDesc::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetDesc(desc);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, AddSwitch)
@@ -481,21 +498,22 @@ Gura_DeclareMethod(wx_CmdLineParser, AddSwitch)
 
 Gura_ImplementMethod(wx_CmdLineParser, AddSwitch)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxString lng = wxEmptyString;
-	if (args.IsValid(1)) lng = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) lng = wxString::FromUTF8(arg.GetString(1));
 	wxString desc = wxEmptyString;
-	if (args.IsValid(2)) desc = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) desc = wxString::FromUTF8(arg.GetString(2));
 	int flags = 0;
-	if (args.IsValid(3)) flags = args.GetInt(3);
+	if (arg.IsValid(3)) flags = arg.GetInt(3);
 	pThis->GetEntity()->AddSwitch(name, lng, desc, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, AddOption)
@@ -512,23 +530,24 @@ Gura_DeclareMethod(wx_CmdLineParser, AddOption)
 
 Gura_ImplementMethod(wx_CmdLineParser, AddOption)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxString lng = wxEmptyString;
-	if (args.IsValid(1)) lng = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) lng = wxString::FromUTF8(arg.GetString(1));
 	wxString desc = wxEmptyString;
-	if (args.IsValid(2)) desc = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) desc = wxString::FromUTF8(arg.GetString(2));
 	wxCmdLineParamType type = wxCMD_LINE_VAL_STRING;
-	if (args.IsValid(3)) type = static_cast<wxCmdLineParamType>(args.GetInt(3));
+	if (arg.IsValid(3)) type = static_cast<wxCmdLineParamType>(arg.GetInt(3));
 	int flags = 0;
-	if (args.IsValid(4)) flags = args.GetInt(4);
+	if (arg.IsValid(4)) flags = arg.GetInt(4);
 	pThis->GetEntity()->AddOption(name, lng, desc, type, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, AddParam)
@@ -543,20 +562,21 @@ Gura_DeclareMethod(wx_CmdLineParser, AddParam)
 
 Gura_ImplementMethod(wx_CmdLineParser, AddParam)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString desc = wxEmptyString;
-	if (args.IsValid(0)) desc = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) desc = wxString::FromUTF8(arg.GetString(0));
 	wxCmdLineParamType type = wxCMD_LINE_VAL_STRING;
-	if (args.IsValid(1)) type = static_cast<wxCmdLineParamType>(args.GetInt(1));
+	if (arg.IsValid(1)) type = static_cast<wxCmdLineParamType>(arg.GetInt(1));
 	int flags = 0;
-	if (args.IsValid(2)) flags = args.GetInt(2);
+	if (arg.IsValid(2)) flags = arg.GetInt(2);
 	pThis->GetEntity()->AddParam(desc, type, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, Parse)
@@ -570,16 +590,17 @@ Gura_DeclareMethod(wx_CmdLineParser, Parse)
 
 Gura_ImplementMethod(wx_CmdLineParser, Parse)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool giveUsage = true;
-	if (args.IsValid(0)) giveUsage = args.GetBoolean(0);
+	if (arg.IsValid(0)) giveUsage = arg.GetBoolean(0);
 	int rtn = pThis->GetEntity()->Parse(giveUsage);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, Usage)
@@ -589,14 +610,15 @@ Gura_DeclareMethod(wx_CmdLineParser, Usage)
 
 Gura_ImplementMethod(wx_CmdLineParser, Usage)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Usage();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, Found)
@@ -608,11 +630,12 @@ Gura_DeclareMethod(wx_CmdLineParser, Found)
 
 Gura_ImplementMethod(wx_CmdLineParser, Found)
 {
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Found(name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, Found_1)
@@ -627,16 +650,17 @@ Gura_DeclareMethod(wx_CmdLineParser, Found_1)
 
 Gura_ImplementMethod(wx_CmdLineParser, Found_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxString value = wxString::FromUTF8(args.GetString(1));
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxString value = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->Found(name, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, Found_2)
@@ -651,16 +675,17 @@ Gura_DeclareMethod(wx_CmdLineParser, Found_2)
 
 Gura_ImplementMethod(wx_CmdLineParser, Found_2)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	long value = args.GetLong(1);
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	long value = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->Found(name, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, Found_3)
@@ -673,12 +698,13 @@ Gura_DeclareMethod(wx_CmdLineParser, Found_3)
 
 Gura_ImplementMethod(wx_CmdLineParser, Found_3)
 {
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxDateTime *value = Object_wx_DateTime::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxDateTime *value = Object_wx_DateTime::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->Found(name, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, GetParamCount)
@@ -689,10 +715,11 @@ Gura_DeclareMethod(wx_CmdLineParser, GetParamCount)
 
 Gura_ImplementMethod(wx_CmdLineParser, GetParamCount)
 {
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetParamCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_CmdLineParser, GetParam)
@@ -704,12 +731,13 @@ Gura_DeclareMethod(wx_CmdLineParser, GetParam)
 
 Gura_ImplementMethod(wx_CmdLineParser, GetParam)
 {
-	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_CmdLineParser *pThis = Object_wx_CmdLineParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t n = 0u;
-	if (args.IsValid(0)) n = args.GetSizeT(0);
+	if (arg.IsValid(0)) n = arg.GetSizeT(0);
 	wxString rtn = pThis->GetEntity()->GetParam(n);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 //----------------------------------------------------------------------------
@@ -717,20 +745,20 @@ Gura_ImplementMethod(wx_CmdLineParser, GetParam)
 //----------------------------------------------------------------------------
 Object_wx_CmdLineParser::~Object_wx_CmdLineParser()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_CmdLineParser::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_CmdLineParser::ToString(bool exprFlag)
 {
 	String rtn("<wx.CmdLineParser:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -777,7 +805,7 @@ Gura_ImplementUserInheritableClass(wx_CmdLineParser)
 
 Gura_ImplementDescendantCreator(wx_CmdLineParser)
 {
-	return new Object_wx_CmdLineParser((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_CmdLineParser((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
