@@ -13,16 +13,16 @@ Gura_DeclarePrivUserSymbol(GetLastPosition);
 //----------------------------------------------------------------------------
 class wx_ComboBox: public wxComboBox, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_ComboBox *_pObj;
 public:
-	inline wx_ComboBox() : wxComboBox(), _sig(NULL), _pObj(NULL) {}
-	//inline wx_ComboBox(wxWindow* parent, wxWindowID id, const wxString& value, const wxPoint& pos, const wxSize& size, int n, const wxString choices[], long style, const wxValidator& validator, const wxString& name) : wxComboBox(parent, id, value, pos, size, n, choices[], style, validator, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_ComboBox(wxWindow* parent, wxWindowID id, const wxString& value, const wxPoint& pos, const wxSize& size, const wxArrayString& choices, long style, const wxValidator& validator, const wxString& name) : wxComboBox(parent, id, value, pos, size, choices, style, validator, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_ComboBox() : wxComboBox(), _pObj(nullptr) {}
+	//inline wx_ComboBox(wxWindow* parent, wxWindowID id, const wxString& value, const wxPoint& pos, const wxSize& size, int n, const wxString choices[], long style, const wxValidator& validator, const wxString& name) : wxComboBox(parent, id, value, pos, size, n, choices[], style, validator, name), _pObj(nullptr) {}
+	inline wx_ComboBox(wxWindow* parent, wxWindowID id, const wxString& value, const wxPoint& pos, const wxSize& size, const wxArrayString& choices, long style, const wxValidator& validator, const wxString& name) : wxComboBox(parent, id, value, pos, size, choices, style, validator, name), _pObj(nullptr) {}
 	//virtual wxTextPos GetLastPosition();
 	~wx_ComboBox();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_ComboBox *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_ComboBox *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -30,12 +30,12 @@ public:
 
 wx_ComboBox::~wx_ComboBox()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_ComboBox::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -50,17 +50,18 @@ Gura_DeclareFunction(ComboBoxEmpty)
 
 Gura_ImplementFunction(ComboBoxEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_ComboBox *pEntity = new wx_ComboBox();
-	Object_wx_ComboBox *pObj = Object_wx_ComboBox::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ComboBox *pObj = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ComboBox(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(ComboBox)
@@ -72,7 +73,7 @@ Gura_DeclareFunction(ComboBox)
 	DeclareArg(env, "value", VTYPE_string, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "pos", VTYPE_wx_Point, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "size", VTYPE_wx_Size, OCCUR_ZeroOrOnce);
-	DeclareArg(env, "choices", VTYPE_string, OCCUR_ZeroOrOnce, FLAG_List);
+	DeclareArg(env, "choices", VTYPE_string, OCCUR_ZeroOrOnce, FLAG_ListVar);
 	DeclareArg(env, "style", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "validator", VTYPE_wx_Validator, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "name", VTYPE_string, OCCUR_ZeroOrOnce);
@@ -81,37 +82,38 @@ Gura_DeclareFunction(ComboBox)
 
 Gura_ImplementFunction(ComboBox)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString value = wxEmptyString;
-	if (args.IsValid(2)) value = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) value = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
-	std::auto_ptr<wxArrayString> choices;
-	if (args.IsValid(5)) {
-		choices.reset(CreateArrayString(args.GetList(5)));
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
+	std::unique_ptr<wxArrayString> choices;
+	if (arg.IsValid(5)) {
+		choices.reset(CreateArrayString(arg.GetList(5)));
 	} else {
 		choices.reset(new wxArrayString());
 	}
 	long style = 0;
-	if (args.IsValid(6)) style = args.GetLong(6);
+	if (arg.IsValid(6)) style = arg.GetLong(6);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(7)) validator = Object_wx_Validator::GetObject(args, 7)->GetEntity();
+	if (arg.IsValid(7)) validator = Object_wx_Validator::GetObject(arg, 7)->GetEntity();
 	wxString name = wxT("comboBox");
-	if (args.IsValid(8)) name = wxString::FromUTF8(args.GetString(8));
+	if (arg.IsValid(8)) name = wxString::FromUTF8(arg.GetString(8));
 	wx_ComboBox *pEntity = new wx_ComboBox(parent, id, value, *pos, *size, *choices, style, *validator, name);
-	Object_wx_ComboBox *pObj = Object_wx_ComboBox::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ComboBox *pObj = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ComboBox(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_ComboBox, Create)
@@ -122,7 +124,7 @@ Gura_DeclareMethod(wx_ComboBox, Create)
 	DeclareArg(env, "value", VTYPE_string, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "pos", VTYPE_wx_Point, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "size", VTYPE_wx_Size, OCCUR_ZeroOrOnce);
-	DeclareArg(env, "choices", VTYPE_string, OCCUR_ZeroOrOnce, FLAG_List);
+	DeclareArg(env, "choices", VTYPE_string, OCCUR_ZeroOrOnce, FLAG_ListVar);
 	DeclareArg(env, "style", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "validator", VTYPE_wx_Validator, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "name", VTYPE_string, OCCUR_ZeroOrOnce);
@@ -131,30 +133,31 @@ Gura_DeclareMethod(wx_ComboBox, Create)
 
 Gura_ImplementMethod(wx_ComboBox, Create)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString value = wxEmptyString;
-	if (args.IsValid(2)) value = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) value = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
-	std::auto_ptr<wxArrayString> choices;
-	if (args.IsValid(5)) {
-		choices.reset(CreateArrayString(args.GetList(5)));
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
+	std::unique_ptr<wxArrayString> choices;
+	if (arg.IsValid(5)) {
+		choices.reset(CreateArrayString(arg.GetList(5)));
 	} else {
 		choices.reset(new wxArrayString());
 	}
 	long style = 0;
-	if (args.IsValid(6)) style = args.GetLong(6);
+	if (arg.IsValid(6)) style = arg.GetLong(6);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(7)) validator = Object_wx_Validator::GetObject(args, 7)->GetEntity();
+	if (arg.IsValid(7)) validator = Object_wx_Validator::GetObject(arg, 7)->GetEntity();
 	wxString name = wxT("comboBox");
-	if (args.IsValid(8)) name = wxString::FromUTF8(args.GetString(8));
+	if (arg.IsValid(8)) name = wxString::FromUTF8(arg.GetString(8));
 	bool rtn = pThis->GetEntity()->Create(parent, id, value, *pos, *size, *choices, style, *validator, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, CanCopy)
@@ -165,10 +168,11 @@ Gura_DeclareMethod(wx_ComboBox, CanCopy)
 
 Gura_ImplementMethod(wx_ComboBox, CanCopy)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanCopy();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, CanCut)
@@ -179,10 +183,11 @@ Gura_DeclareMethod(wx_ComboBox, CanCut)
 
 Gura_ImplementMethod(wx_ComboBox, CanCut)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanCut();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, CanPaste)
@@ -193,10 +198,11 @@ Gura_DeclareMethod(wx_ComboBox, CanPaste)
 
 Gura_ImplementMethod(wx_ComboBox, CanPaste)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanPaste();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, CanRedo)
@@ -207,10 +213,11 @@ Gura_DeclareMethod(wx_ComboBox, CanRedo)
 
 Gura_ImplementMethod(wx_ComboBox, CanRedo)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanRedo();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, CanUndo)
@@ -221,10 +228,11 @@ Gura_DeclareMethod(wx_ComboBox, CanUndo)
 
 Gura_ImplementMethod(wx_ComboBox, CanUndo)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanUndo();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, Copy)
@@ -234,10 +242,11 @@ Gura_DeclareMethod(wx_ComboBox, Copy)
 
 Gura_ImplementMethod(wx_ComboBox, Copy)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Copy();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Cut)
@@ -247,10 +256,11 @@ Gura_DeclareMethod(wx_ComboBox, Cut)
 
 Gura_ImplementMethod(wx_ComboBox, Cut)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Cut();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetCurrentSelection)
@@ -261,10 +271,11 @@ Gura_DeclareMethod(wx_ComboBox, GetCurrentSelection)
 
 Gura_ImplementMethod(wx_ComboBox, GetCurrentSelection)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetCurrentSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetInsertionPoint)
@@ -275,10 +286,11 @@ Gura_DeclareMethod(wx_ComboBox, GetInsertionPoint)
 
 Gura_ImplementMethod(wx_ComboBox, GetInsertionPoint)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetInsertionPoint();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetLastPosition)
@@ -289,10 +301,11 @@ Gura_DeclareMethod(wx_ComboBox, GetLastPosition)
 
 Gura_ImplementMethod(wx_ComboBox, GetLastPosition)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTextPos rtn = pThis->GetEntity()->GetLastPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetMark)
@@ -303,12 +316,13 @@ Gura_DeclareMethod(wx_ComboBox, GetMark)
 
 Gura_ImplementMethod(wx_ComboBox, GetMark)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long from;
 	long to;
 	pThis->GetEntity()->GetSelection(&from, &to);
-	return ReturnValue(env, sig, args, Value::CreateList(env, from, to));
+	return ReturnValue(env, arg, Value::CreateList(env, from, to));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetValue)
@@ -319,10 +333,11 @@ Gura_DeclareMethod(wx_ComboBox, GetValue)
 
 Gura_ImplementMethod(wx_ComboBox, GetValue)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetValue();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ComboBox, Paste)
@@ -332,10 +347,11 @@ Gura_DeclareMethod(wx_ComboBox, Paste)
 
 Gura_ImplementMethod(wx_ComboBox, Paste)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Paste();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Redo)
@@ -345,10 +361,11 @@ Gura_DeclareMethod(wx_ComboBox, Redo)
 
 Gura_ImplementMethod(wx_ComboBox, Redo)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Redo();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Replace)
@@ -361,13 +378,14 @@ Gura_DeclareMethod(wx_ComboBox, Replace)
 
 Gura_ImplementMethod(wx_ComboBox, Replace)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long from = args.GetLong(0);
-	long to = args.GetLong(1);
-	wxString text = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long from = arg.GetLong(0);
+	long to = arg.GetLong(1);
+	wxString text = wxString::FromUTF8(arg.GetString(2));
 	pThis->GetEntity()->Replace(from, to, text);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Remove)
@@ -379,12 +397,13 @@ Gura_DeclareMethod(wx_ComboBox, Remove)
 
 Gura_ImplementMethod(wx_ComboBox, Remove)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long from = args.GetLong(0);
-	long to = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long from = arg.GetLong(0);
+	long to = arg.GetLong(1);
 	pThis->GetEntity()->Remove(from, to);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetInsertionPoint)
@@ -395,11 +414,12 @@ Gura_DeclareMethod(wx_ComboBox, SetInsertionPoint)
 
 Gura_ImplementMethod(wx_ComboBox, SetInsertionPoint)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long pos = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long pos = arg.GetLong(0);
 	pThis->GetEntity()->SetInsertionPoint(pos);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetInsertionPointEnd)
@@ -409,10 +429,11 @@ Gura_DeclareMethod(wx_ComboBox, SetInsertionPointEnd)
 
 Gura_ImplementMethod(wx_ComboBox, SetInsertionPointEnd)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->SetInsertionPointEnd();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetMark)
@@ -424,12 +445,13 @@ Gura_DeclareMethod(wx_ComboBox, SetMark)
 
 Gura_ImplementMethod(wx_ComboBox, SetMark)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long from = args.GetLong(0);
-	long to = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long from = arg.GetLong(0);
+	long to = arg.GetLong(1);
 	pThis->GetEntity()->SetSelection(from, to);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetValue)
@@ -440,11 +462,12 @@ Gura_DeclareMethod(wx_ComboBox, SetValue)
 
 Gura_ImplementMethod(wx_ComboBox, SetValue)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetValue(text);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Undo)
@@ -454,10 +477,11 @@ Gura_DeclareMethod(wx_ComboBox, Undo)
 
 Gura_ImplementMethod(wx_ComboBox, Undo)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Undo();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Append)
@@ -470,17 +494,18 @@ Gura_DeclareMethod(wx_ComboBox, Append)
 
 Gura_ImplementMethod(wx_ComboBox, Append)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString item = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString item = wxString::FromUTF8(arg.GetString(0));
 	int rtn = 0;
-	if (args.IsValid(1)) {
-		wx_ClientData *clientData = Object_wx_ClientData::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) {
+		wx_ClientData *clientData = Object_wx_ClientData::GetObject(arg, 1)->GetEntity();
 		rtn = pThis->GetEntity()->Append(item, new wx_ClientData(*clientData));
 	} else {
 		rtn = pThis->GetEntity()->Append(item);
 	}
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, Clear)
@@ -490,10 +515,11 @@ Gura_DeclareMethod(wx_ComboBox, Clear)
 
 Gura_ImplementMethod(wx_ComboBox, Clear)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, Delete)
@@ -504,11 +530,12 @@ Gura_DeclareMethod(wx_ComboBox, Delete)
 
 Gura_ImplementMethod(wx_ComboBox, Delete)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	pThis->GetEntity()->Delete(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, FindString)
@@ -521,13 +548,14 @@ Gura_DeclareMethod(wx_ComboBox, FindString)
 
 Gura_ImplementMethod(wx_ComboBox, FindString)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString string = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString string = wxString::FromUTF8(arg.GetString(0));
 	bool caseSensitive = false;
-	if (args.IsValid(1)) caseSensitive = args.GetBoolean(1);
+	if (arg.IsValid(1)) caseSensitive = arg.GetBoolean(1);
 	int rtn = pThis->GetEntity()->FindString(string, caseSensitive);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetClientData)
@@ -538,11 +566,12 @@ Gura_DeclareMethod(wx_ComboBox, GetClientData)
 
 Gura_ImplementMethod(wx_ComboBox, GetClientData)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	pThis->GetEntity()->GetClientData(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetClientObject)
@@ -554,12 +583,13 @@ Gura_DeclareMethod(wx_ComboBox, GetClientObject)
 
 Gura_ImplementMethod(wx_ComboBox, GetClientObject)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	wx_ClientData *rtn = dynamic_cast<wx_ClientData *>(pThis->GetEntity()->GetClientObject(n));
-	if (rtn == NULL) return Value::Null;
-	return ReturnValue(env, sig, args, Value(new Object_wx_ClientData(rtn, NULL, OwnerFalse)));
+	if (rtn == nullptr) return Value::Nil;
+	return ReturnValue(env, arg, Value(new Object_wx_ClientData(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetCount)
@@ -570,10 +600,11 @@ Gura_DeclareMethod(wx_ComboBox, GetCount)
 
 Gura_ImplementMethod(wx_ComboBox, GetCount)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	unsigned rtn = pThis->GetEntity()->GetCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetSelection)
@@ -584,10 +615,11 @@ Gura_DeclareMethod(wx_ComboBox, GetSelection)
 
 Gura_ImplementMethod(wx_ComboBox, GetSelection)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetString)
@@ -599,11 +631,12 @@ Gura_DeclareMethod(wx_ComboBox, GetString)
 
 Gura_ImplementMethod(wx_ComboBox, GetString)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetString(n);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetStrings)
@@ -614,10 +647,11 @@ Gura_DeclareMethod(wx_ComboBox, GetStrings)
 
 Gura_ImplementMethod(wx_ComboBox, GetStrings)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxArrayString rtn = pThis->GetEntity()->GetStrings();
-	return ReturnValue(env, sig, args, ArrayStringToValue(env, rtn));
+	return ReturnValue(env, arg, ArrayStringToValue(env, rtn));
 }
 
 Gura_DeclareMethod(wx_ComboBox, GetStringSelection)
@@ -628,10 +662,11 @@ Gura_DeclareMethod(wx_ComboBox, GetStringSelection)
 
 Gura_ImplementMethod(wx_ComboBox, GetStringSelection)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetStringSelection();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ComboBox, Insert)
@@ -645,18 +680,19 @@ Gura_DeclareMethod(wx_ComboBox, Insert)
 
 Gura_ImplementMethod(wx_ComboBox, Insert)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString item = wxString::FromUTF8(args.GetString(0));
-	unsigned pos = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString item = wxString::FromUTF8(arg.GetString(0));
+	unsigned pos = arg.GetInt(1);
 	int rtn = 0;
-	if (args.IsValid(2)) {
-		wx_ClientData *clientData = Object_wx_ClientData::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) {
+		wx_ClientData *clientData = Object_wx_ClientData::GetObject(arg, 2)->GetEntity();
 		rtn = pThis->GetEntity()->Insert(item, pos, new wx_ClientData(clientData));
 	} else {
 		rtn = pThis->GetEntity()->Insert(item, pos);
 	}
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 #if 0
@@ -668,10 +704,11 @@ Gura_DeclareMethod(wx_ComboBox, IsEmpty)
 
 Gura_ImplementMethod(wx_ComboBox, IsEmpty)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsEmpty();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 #endif
 
@@ -683,11 +720,12 @@ Gura_DeclareMethod(wx_ComboBox, Select)
 
 Gura_ImplementMethod(wx_ComboBox, Select)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->Select(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetClientObject)
@@ -699,12 +737,13 @@ Gura_DeclareMethod(wx_ComboBox, SetClientObject)
 
 Gura_ImplementMethod(wx_ComboBox, SetClientObject)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
-	wx_ClientData *data = Object_wx_ClientData::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
+	wx_ClientData *data = Object_wx_ClientData::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetClientObject(n, new wx_ClientData(*data));
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetSelection)
@@ -715,11 +754,12 @@ Gura_DeclareMethod(wx_ComboBox, SetSelection)
 
 Gura_ImplementMethod(wx_ComboBox, SetSelection)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->SetSelection(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetString)
@@ -731,12 +771,13 @@ Gura_DeclareMethod(wx_ComboBox, SetString)
 
 Gura_ImplementMethod(wx_ComboBox, SetString)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
-	wxString string = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
+	wxString string = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetString(n, string);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboBox, SetStringSelection)
@@ -748,11 +789,12 @@ Gura_DeclareMethod(wx_ComboBox, SetStringSelection)
 
 Gura_ImplementMethod(wx_ComboBox, SetStringSelection)
 {
-	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString string = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboBox *pThis = Object_wx_ComboBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString string = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->SetStringSelection(string);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -764,13 +806,13 @@ Object_wx_ComboBox::~Object_wx_ComboBox()
 
 Object *Object_wx_ComboBox::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_ComboBox::ToString(bool exprFlag)
 {
 	String rtn("<wx.ComboBox:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -834,7 +876,7 @@ Gura_ImplementUserInheritableClass(wx_ComboBox)
 
 Gura_ImplementDescendantCreator(wx_ComboBox)
 {
-	return new Object_wx_ComboBox((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_ComboBox((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
