@@ -14,16 +14,16 @@ Gura_DeclarePrivUserSymbol(DoShowPopup);
 //----------------------------------------------------------------------------
 class wx_ComboCtrl: public wxComboCtrl, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_ComboCtrl *_pObj;
 public:
-	inline wx_ComboCtrl() : wxComboCtrl(), _sig(NULL), _pObj(NULL) {}
-	inline wx_ComboCtrl(wxWindow* parent, wxWindowID id, const wxString& value, const wxPoint& pos, const wxSize& size, long style, const wxValidator& validator, const wxString& name) : wxComboCtrl(parent, id, value, pos, size, style, validator, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_ComboCtrl() : wxComboCtrl(), _pObj(nullptr) {}
+	inline wx_ComboCtrl(wxWindow* parent, wxWindowID id, const wxString& value, const wxPoint& pos, const wxSize& size, long style, const wxValidator& validator, const wxString& name) : wxComboCtrl(parent, id, value, pos, size, style, validator, name), _pObj(nullptr) {}
 	//virtual bool AnimateShow(const wxRect& rect, int flags);
 	//virtual void DoShowPopup(const wxRect& rect, int flags);
 	~wx_ComboCtrl();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_ComboCtrl *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_ComboCtrl *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -42,12 +42,12 @@ public:
 
 wx_ComboCtrl::~wx_ComboCtrl()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_ComboCtrl::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -62,17 +62,18 @@ Gura_DeclareFunction(ComboCtrlEmpty)
 
 Gura_ImplementFunction(ComboCtrlEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_ComboCtrl *pEntity = new wx_ComboCtrl();
-	Object_wx_ComboCtrl *pObj = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ComboCtrl *pObj = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ComboCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(ComboCtrl)
@@ -92,31 +93,32 @@ Gura_DeclareFunction(ComboCtrl)
 
 Gura_ImplementFunction(ComboCtrl)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString value = wxT("");
-	if (args.IsValid(2)) value = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) value = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = 0;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(6)) validator = Object_wx_Validator::GetObject(args, 6)->GetEntity();
+	if (arg.IsValid(6)) validator = Object_wx_Validator::GetObject(arg, 6)->GetEntity();
 	wxString name = wxT("comboCtrl");
-	if (args.IsValid(7)) name = wxString::FromUTF8(args.GetString(7));
+	if (arg.IsValid(7)) name = wxString::FromUTF8(arg.GetString(7));
 	wx_ComboCtrl *pEntity = new wx_ComboCtrl(parent, id, value, *pos, *size, style, *validator, name);
-	Object_wx_ComboCtrl *pObj = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ComboCtrl *pObj = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ComboCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, AnimateShow)
@@ -129,12 +131,13 @@ Gura_DeclareMethod(wx_ComboCtrl, AnimateShow)
 
 Gura_ImplementMethod(wx_ComboCtrl, AnimateShow)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
-	int flags = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
+	int flags = arg.GetInt(1);
 	bool rtn = dynamic_cast<wx_ComboCtrl *>(pThis->GetEntity())->_AnimateShow(*rect, flags);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Create)
@@ -153,24 +156,25 @@ Gura_DeclareMethod(wx_ComboCtrl, Create)
 
 Gura_ImplementMethod(wx_ComboCtrl, Create)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString value = wxT("");
-	if (args.IsValid(2)) value = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) value = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = 0;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(6)) validator = Object_wx_Validator::GetObject(args, 6)->GetEntity();
+	if (arg.IsValid(6)) validator = Object_wx_Validator::GetObject(arg, 6)->GetEntity();
 	wxString name = wxT("comboCtrl");
-	if (args.IsValid(7)) name = wxString::FromUTF8(args.GetString(7));
+	if (arg.IsValid(7)) name = wxString::FromUTF8(arg.GetString(7));
 	bool rtn = pThis->GetEntity()->Create(parent, id, value, *pos, *size, style, *validator, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Copy)
@@ -180,10 +184,11 @@ Gura_DeclareMethod(wx_ComboCtrl, Copy)
 
 Gura_ImplementMethod(wx_ComboCtrl, Copy)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Copy();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Cut)
@@ -193,10 +198,11 @@ Gura_DeclareMethod(wx_ComboCtrl, Cut)
 
 Gura_ImplementMethod(wx_ComboCtrl, Cut)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Cut();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, DoSetPopupControl)
@@ -207,11 +213,12 @@ Gura_DeclareMethod(wx_ComboCtrl, DoSetPopupControl)
 
 Gura_ImplementMethod(wx_ComboCtrl, DoSetPopupControl)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxComboPopup *popup = Object_wx_ComboPopup::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxComboPopup *popup = Object_wx_ComboPopup::GetObject(arg, 0)->GetEntity();
 	dynamic_cast<wx_ComboCtrl *>(pThis->GetEntity())->_DoSetPopupControl(popup);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, DoShowPopup)
@@ -223,12 +230,13 @@ Gura_DeclareMethod(wx_ComboCtrl, DoShowPopup)
 
 Gura_ImplementMethod(wx_ComboCtrl, DoShowPopup)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
-	int flags = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
+	int flags = arg.GetInt(1);
 	dynamic_cast<wx_ComboCtrl *>(pThis->GetEntity())->_DoShowPopup(*rect, flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, EnablePopupAnimation)
@@ -239,12 +247,13 @@ Gura_DeclareMethod(wx_ComboCtrl, EnablePopupAnimation)
 
 Gura_ImplementMethod(wx_ComboCtrl, EnablePopupAnimation)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	pThis->GetEntity()->EnablePopupAnimation(enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetBitmapDisabled)
@@ -255,10 +264,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetBitmapDisabled)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetBitmapDisabled)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxBitmap &rtn = pThis->GetEntity()->GetBitmapDisabled();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetBitmapHover)
@@ -269,10 +279,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetBitmapHover)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetBitmapHover)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxBitmap &rtn = pThis->GetEntity()->GetBitmapHover();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetBitmapNormal)
@@ -283,10 +294,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetBitmapNormal)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetBitmapNormal)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxBitmap &rtn = pThis->GetEntity()->GetBitmapNormal();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetBitmapPressed)
@@ -297,10 +309,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetBitmapPressed)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetBitmapPressed)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxBitmap &rtn = pThis->GetEntity()->GetBitmapPressed();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetButtonSize)
@@ -311,10 +324,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetButtonSize)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetButtonSize)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetButtonSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetCustomPaintWidth)
@@ -325,10 +339,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetCustomPaintWidth)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetCustomPaintWidth)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetCustomPaintWidth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_ComboCtrl, GetFeatures)
@@ -339,9 +354,10 @@ Gura_DeclareClassMethod(wx_ComboCtrl, GetFeatures)
 
 Gura_ImplementClassMethod(wx_ComboCtrl, GetFeatures)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	int rtn = wxComboCtrl::GetFeatures();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetInsertionPoint)
@@ -352,10 +368,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetInsertionPoint)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetInsertionPoint)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetInsertionPoint();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, IsPopupWindowState)
@@ -367,11 +384,12 @@ Gura_DeclareMethod(wx_ComboCtrl, IsPopupWindowState)
 
 Gura_ImplementMethod(wx_ComboCtrl, IsPopupWindowState)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int state = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int state = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsPopupWindowState(state);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetLastPosition)
@@ -382,10 +400,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetLastPosition)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetLastPosition)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetLastPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetPopupControl)
@@ -396,10 +415,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetPopupControl)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetPopupControl)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxComboPopup *rtn = (wxComboPopup *)pThis->GetEntity()->GetPopupControl();
-	return ReturnValue(env, sig, args, Value(new Object_wx_ComboPopup(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ComboPopup(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetPopupWindow)
@@ -410,10 +430,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetPopupWindow)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetPopupWindow)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetPopupWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetTextCtrl)
@@ -424,10 +445,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetTextCtrl)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetTextCtrl)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTextCtrl *rtn = (wxTextCtrl *)pThis->GetEntity()->GetTextCtrl();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextCtrl(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextCtrl(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetTextIndent)
@@ -438,10 +460,15 @@ Gura_DeclareMethod(wx_ComboCtrl, GetTextIndent)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetTextIndent)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxCoord rtn = pThis->GetEntity()->GetTextIndent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetTextRect)
@@ -452,10 +479,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetTextRect)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetTextRect)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxRect &rtn = pThis->GetEntity()->GetTextRect();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, GetValue)
@@ -466,10 +494,11 @@ Gura_DeclareMethod(wx_ComboCtrl, GetValue)
 
 Gura_ImplementMethod(wx_ComboCtrl, GetValue)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetValue();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, HidePopup)
@@ -479,10 +508,11 @@ Gura_DeclareMethod(wx_ComboCtrl, HidePopup)
 
 Gura_ImplementMethod(wx_ComboCtrl, HidePopup)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->HidePopup();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, IsPopupShown)
@@ -493,10 +523,11 @@ Gura_DeclareMethod(wx_ComboCtrl, IsPopupShown)
 
 Gura_ImplementMethod(wx_ComboCtrl, IsPopupShown)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsPopupShown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, OnButtonClick)
@@ -506,10 +537,11 @@ Gura_DeclareMethod(wx_ComboCtrl, OnButtonClick)
 
 Gura_ImplementMethod(wx_ComboCtrl, OnButtonClick)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnButtonClick();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Paste)
@@ -519,10 +551,11 @@ Gura_DeclareMethod(wx_ComboCtrl, Paste)
 
 Gura_ImplementMethod(wx_ComboCtrl, Paste)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Paste();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Remove)
@@ -534,12 +567,13 @@ Gura_DeclareMethod(wx_ComboCtrl, Remove)
 
 Gura_ImplementMethod(wx_ComboCtrl, Remove)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long from = args.GetLong(0);
-	long to = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long from = arg.GetLong(0);
+	long to = arg.GetLong(1);
 	pThis->GetEntity()->Remove(from, to);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Replace)
@@ -552,13 +586,14 @@ Gura_DeclareMethod(wx_ComboCtrl, Replace)
 
 Gura_ImplementMethod(wx_ComboCtrl, Replace)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long from = args.GetLong(0);
-	long to = args.GetLong(1);
-	wxString value = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long from = arg.GetLong(0);
+	long to = arg.GetLong(1);
+	wxString value = wxString::FromUTF8(arg.GetString(2));
 	pThis->GetEntity()->Replace(from, to, value);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetButtonBitmaps)
@@ -573,19 +608,20 @@ Gura_DeclareMethod(wx_ComboCtrl, SetButtonBitmaps)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetButtonBitmaps)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *bmpNormal = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *bmpNormal = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
 	bool pushButtonBg = false;
-	if (args.IsValid(1)) pushButtonBg = args.GetBoolean(1);
+	if (arg.IsValid(1)) pushButtonBg = arg.GetBoolean(1);
 	wxBitmap *bmpPressed = (wxBitmap *)(&wxNullBitmap);
-	if (args.IsValid(2)) bmpPressed = Object_wx_Bitmap::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) bmpPressed = Object_wx_Bitmap::GetObject(arg, 2)->GetEntity();
 	wxBitmap *bmpHover = (wxBitmap *)(&wxNullBitmap);
-	if (args.IsValid(3)) bmpHover = Object_wx_Bitmap::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) bmpHover = Object_wx_Bitmap::GetObject(arg, 3)->GetEntity();
 	wxBitmap *bmpDisabled = (wxBitmap *)(&wxNullBitmap);
-	if (args.IsValid(4)) bmpDisabled = Object_wx_Bitmap::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) bmpDisabled = Object_wx_Bitmap::GetObject(arg, 4)->GetEntity();
 	pThis->GetEntity()->SetButtonBitmaps(*bmpNormal, pushButtonBg, *bmpPressed, *bmpHover, *bmpDisabled);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetButtonPosition)
@@ -599,18 +635,19 @@ Gura_DeclareMethod(wx_ComboCtrl, SetButtonPosition)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetButtonPosition)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int width = -1;
-	if (args.IsValid(0)) width = args.GetInt(0);
+	if (arg.IsValid(0)) width = arg.GetInt(0);
 	int height = -1;
-	if (args.IsValid(1)) height = args.GetInt(1);
+	if (arg.IsValid(1)) height = arg.GetInt(1);
 	int side = wxRIGHT;
-	if (args.IsValid(2)) side = args.GetInt(2);
+	if (arg.IsValid(2)) side = arg.GetInt(2);
 	int spacingX = 0;
-	if (args.IsValid(3)) spacingX = args.GetInt(3);
+	if (arg.IsValid(3)) spacingX = arg.GetInt(3);
 	pThis->GetEntity()->SetButtonPosition(width, height, side, spacingX);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetCustomPaintWidth)
@@ -621,11 +658,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetCustomPaintWidth)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetCustomPaintWidth)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
 	pThis->GetEntity()->SetCustomPaintWidth(width);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetInsertionPoint)
@@ -636,11 +674,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetInsertionPoint)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetInsertionPoint)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long pos = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long pos = arg.GetLong(0);
 	pThis->GetEntity()->SetInsertionPoint(pos);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetInsertionPointEnd)
@@ -650,10 +689,11 @@ Gura_DeclareMethod(wx_ComboCtrl, SetInsertionPointEnd)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetInsertionPointEnd)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->SetInsertionPointEnd();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetPopupAnchor)
@@ -664,11 +704,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetPopupAnchor)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetPopupAnchor)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int anchorSide = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int anchorSide = arg.GetInt(0);
 	pThis->GetEntity()->SetPopupAnchor(anchorSide);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetPopupControl)
@@ -679,11 +720,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetPopupControl)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetPopupControl)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxComboPopup *popup = Object_wx_ComboPopup::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxComboPopup *popup = Object_wx_ComboPopup::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPopupControl(popup);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetPopupExtents)
@@ -695,12 +737,13 @@ Gura_DeclareMethod(wx_ComboCtrl, SetPopupExtents)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetPopupExtents)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int extLeft = args.GetInt(0);
-	int extRight = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int extLeft = arg.GetInt(0);
+	int extRight = arg.GetInt(1);
 	pThis->GetEntity()->SetPopupExtents(extLeft, extRight);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetPopupMaxHeight)
@@ -711,11 +754,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetPopupMaxHeight)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetPopupMaxHeight)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int height = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int height = arg.GetInt(0);
 	pThis->GetEntity()->SetPopupMaxHeight(height);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetPopupMinWidth)
@@ -726,11 +770,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetPopupMinWidth)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetPopupMinWidth)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
 	pThis->GetEntity()->SetPopupMinWidth(width);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetSelection)
@@ -742,12 +787,13 @@ Gura_DeclareMethod(wx_ComboCtrl, SetSelection)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetSelection)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long from = args.GetLong(0);
-	long to = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long from = arg.GetLong(0);
+	long to = arg.GetLong(1);
 	pThis->GetEntity()->SetSelection(from, to);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetText)
@@ -758,11 +804,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetText)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetText)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString value = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString value = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetText(value);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetTextIndent)
@@ -773,11 +820,16 @@ Gura_DeclareMethod(wx_ComboCtrl, SetTextIndent)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetTextIndent)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int indent = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int indent = arg.GetInt(0);
 	pThis->GetEntity()->SetTextIndent(indent);
-	return Value::Null;
+	return Value::Nil;
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetValue)
@@ -788,11 +840,12 @@ Gura_DeclareMethod(wx_ComboCtrl, SetValue)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetValue)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString value = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString value = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetValue(value);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, SetValueWithEvent)
@@ -804,13 +857,14 @@ Gura_DeclareMethod(wx_ComboCtrl, SetValueWithEvent)
 
 Gura_ImplementMethod(wx_ComboCtrl, SetValueWithEvent)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString value = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString value = wxString::FromUTF8(arg.GetString(0));
 	bool withEvent = true;
-	if (args.IsValid(1)) withEvent = args.GetBoolean(1);
+	if (arg.IsValid(1)) withEvent = arg.GetBoolean(1);
 	pThis->GetEntity()->SetValueWithEvent(value, withEvent);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, ShowPopup)
@@ -820,10 +874,11 @@ Gura_DeclareMethod(wx_ComboCtrl, ShowPopup)
 
 Gura_ImplementMethod(wx_ComboCtrl, ShowPopup)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ShowPopup();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, Undo)
@@ -833,10 +888,11 @@ Gura_DeclareMethod(wx_ComboCtrl, Undo)
 
 Gura_ImplementMethod(wx_ComboCtrl, Undo)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Undo();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ComboCtrl, UseAltPopupWindow)
@@ -847,12 +903,13 @@ Gura_DeclareMethod(wx_ComboCtrl, UseAltPopupWindow)
 
 Gura_ImplementMethod(wx_ComboCtrl, UseAltPopupWindow)
 {
-	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ComboCtrl *pThis = Object_wx_ComboCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	pThis->GetEntity()->UseAltPopupWindow(enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -864,13 +921,13 @@ Object_wx_ComboCtrl::~Object_wx_ComboCtrl()
 
 Object *Object_wx_ComboCtrl::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_ComboCtrl::ToString(bool exprFlag)
 {
 	String rtn("<wx.ComboCtrl:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -940,7 +997,7 @@ Gura_ImplementUserInheritableClass(wx_ComboCtrl)
 
 Gura_ImplementDescendantCreator(wx_ComboCtrl)
 {
-	return new Object_wx_ComboCtrl((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_ComboCtrl((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
