@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_ConfigBase: public wxConfigBase, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_ConfigBase *_pObj;
 public:
-	//inline wx_ConfigBase(const wxString& appName, const wxString& vendorName, const wxString& localFilename, const wxString& globalFilename, long style, wxMBConv& conv) : wxConfigBase(appName, vendorName, localFilename, globalFilename, style, conv), _sig(NULL), _pObj(NULL) {}
+	//inline wx_ConfigBase(const wxString& appName, const wxString& vendorName, const wxString& localFilename, const wxString& globalFilename, long style, wxMBConv& conv) : wxConfigBase(appName, vendorName, localFilename, globalFilename, style, conv), _pObj(nullptr) {}
 	~wx_ConfigBase();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_ConfigBase *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_ConfigBase *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_ConfigBase::~wx_ConfigBase()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_ConfigBase::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -53,33 +53,34 @@ Gura_DeclareFunction(ConfigBase)
 
 Gura_ImplementFunction(ConfigBase)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxString appName = wxEmptyString;
-	if (args.IsValid(0)) appName = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) appName = wxString::FromUTF8(arg.GetString(0));
 	wxString vendorName = wxEmptyString;
-	if (args.IsValid(1)) vendorName = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) vendorName = wxString::FromUTF8(arg.GetString(1));
 	wxString localFilename = wxEmptyString;
-	if (args.IsValid(2)) localFilename = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) localFilename = wxString::FromUTF8(arg.GetString(2));
 	wxString globalFilename = wxEmptyString;
-	if (args.IsValid(3)) globalFilename = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) globalFilename = wxString::FromUTF8(arg.GetString(3));
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxMBConv *conv = (wxMBConv *)(&wxConvUTF8);
-	if (args.IsValid(5)) conv = Object_wx_MBConv::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(5)) conv = Object_wx_MBConv::GetObject(arg, 5)->GetEntity();
 	wx_ConfigBase *pEntity = new wx_ConfigBase(appName, vendorName, localFilename, globalFilename, style, *conv);
-	Object_wx_ConfigBase *pObj = Object_wx_ConfigBase::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ConfigBase *pObj = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ConfigBase(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_ConfigBase, Create)
@@ -90,9 +91,10 @@ Gura_DeclareClassMethod(wx_ConfigBase, Create)
 
 Gura_ImplementClassMethod(wx_ConfigBase, Create)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxConfigBase *rtn = (wxConfigBase *)wxConfigBase::Create();
-	return ReturnValue(env, sig, args, Value(new Object_wx_ConfigBase(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ConfigBase(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, DontCreateOnDemand)
@@ -102,10 +104,11 @@ Gura_DeclareMethod(wx_ConfigBase, DontCreateOnDemand)
 
 Gura_ImplementMethod(wx_ConfigBase, DontCreateOnDemand)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DontCreateOnDemand();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, DeleteAll)
@@ -116,10 +119,11 @@ Gura_DeclareMethod(wx_ConfigBase, DeleteAll)
 
 Gura_ImplementMethod(wx_ConfigBase, DeleteAll)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DeleteAll();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, DeleteEntry)
@@ -132,13 +136,14 @@ Gura_DeclareMethod(wx_ConfigBase, DeleteEntry)
 
 Gura_ImplementMethod(wx_ConfigBase, DeleteEntry)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
 	bool bDeleteGroupIfEmpty = true;
-	if (args.IsValid(1)) bDeleteGroupIfEmpty = args.GetBoolean(1);
+	if (arg.IsValid(1)) bDeleteGroupIfEmpty = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->DeleteEntry(key, bDeleteGroupIfEmpty);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, DeleteGroup)
@@ -150,11 +155,12 @@ Gura_DeclareMethod(wx_ConfigBase, DeleteGroup)
 
 Gura_ImplementMethod(wx_ConfigBase, DeleteGroup)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->DeleteGroup(key);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Exists)
@@ -166,11 +172,12 @@ Gura_DeclareMethod(wx_ConfigBase, Exists)
 
 Gura_ImplementMethod(wx_ConfigBase, Exists)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strName = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strName = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Exists(strName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Flush)
@@ -182,12 +189,13 @@ Gura_DeclareMethod(wx_ConfigBase, Flush)
 
 Gura_ImplementMethod(wx_ConfigBase, Flush)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bCurrentOnly = false;
-	if (args.IsValid(0)) bCurrentOnly = args.GetBoolean(0);
+	if (arg.IsValid(0)) bCurrentOnly = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Flush(bCurrentOnly);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_ConfigBase, Get)
@@ -199,11 +207,12 @@ Gura_DeclareClassMethod(wx_ConfigBase, Get)
 
 Gura_ImplementClassMethod(wx_ConfigBase, Get)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	bool CreateOnDemand = true;
-	if (args.IsValid(0)) CreateOnDemand = args.GetBoolean(0);
+	if (arg.IsValid(0)) CreateOnDemand = arg.GetBoolean(0);
 	wxConfigBase *rtn = (wxConfigBase *)wxConfigBase::Get(CreateOnDemand);
-	return ReturnValue(env, sig, args, Value(new Object_wx_ConfigBase(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ConfigBase(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetAppName)
@@ -214,10 +223,11 @@ Gura_DeclareMethod(wx_ConfigBase, GetAppName)
 
 Gura_ImplementMethod(wx_ConfigBase, GetAppName)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetAppName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetEntryType)
@@ -229,9 +239,10 @@ Gura_DeclareMethod(wx_ConfigBase, GetEntryType)
 
 Gura_ImplementMethod(wx_ConfigBase, GetEntryType)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetFirstGroup)
@@ -244,12 +255,13 @@ Gura_DeclareMethod(wx_ConfigBase, GetFirstGroup)
 
 Gura_ImplementMethod(wx_ConfigBase, GetFirstGroup)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str = wxString::FromUTF8(args.GetString(0));
-	long index = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str = wxString::FromUTF8(arg.GetString(0));
+	long index = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetFirstGroup(str, index);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetFirstEntry)
@@ -262,12 +274,13 @@ Gura_DeclareMethod(wx_ConfigBase, GetFirstEntry)
 
 Gura_ImplementMethod(wx_ConfigBase, GetFirstEntry)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str = wxString::FromUTF8(args.GetString(0));
-	long index = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str = wxString::FromUTF8(arg.GetString(0));
+	long index = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetFirstEntry(str, index);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetNextGroup)
@@ -280,12 +293,13 @@ Gura_DeclareMethod(wx_ConfigBase, GetNextGroup)
 
 Gura_ImplementMethod(wx_ConfigBase, GetNextGroup)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str = wxString::FromUTF8(args.GetString(0));
-	long index = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str = wxString::FromUTF8(arg.GetString(0));
+	long index = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetNextGroup(str, index);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetNextEntry)
@@ -298,12 +312,13 @@ Gura_DeclareMethod(wx_ConfigBase, GetNextEntry)
 
 Gura_ImplementMethod(wx_ConfigBase, GetNextEntry)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str = wxString::FromUTF8(args.GetString(0));
-	long index = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str = wxString::FromUTF8(arg.GetString(0));
+	long index = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetNextEntry(str, index);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetNumberOfEntries)
@@ -315,10 +330,11 @@ Gura_DeclareMethod(wx_ConfigBase, GetNumberOfEntries)
 
 Gura_ImplementMethod(wx_ConfigBase, GetNumberOfEntries)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bRecursive = false;
-	if (args.IsValid(0)) bRecursive = args.GetBoolean(0);
+	if (arg.IsValid(0)) bRecursive = arg.GetBoolean(0);
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetNumberOfGroups)
@@ -330,10 +346,11 @@ Gura_DeclareMethod(wx_ConfigBase, GetNumberOfGroups)
 
 Gura_ImplementMethod(wx_ConfigBase, GetNumberOfGroups)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bRecursive = false;
-	if (args.IsValid(0)) bRecursive = args.GetBoolean(0);
+	if (arg.IsValid(0)) bRecursive = arg.GetBoolean(0);
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetPath)
@@ -344,10 +361,11 @@ Gura_DeclareMethod(wx_ConfigBase, GetPath)
 
 Gura_ImplementMethod(wx_ConfigBase, GetPath)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetPath();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, GetVendorName)
@@ -358,10 +376,11 @@ Gura_DeclareMethod(wx_ConfigBase, GetVendorName)
 
 Gura_ImplementMethod(wx_ConfigBase, GetVendorName)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetVendorName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, HasEntry)
@@ -373,11 +392,12 @@ Gura_DeclareMethod(wx_ConfigBase, HasEntry)
 
 Gura_ImplementMethod(wx_ConfigBase, HasEntry)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strName = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strName = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->HasEntry(strName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, HasGroup)
@@ -389,11 +409,12 @@ Gura_DeclareMethod(wx_ConfigBase, HasGroup)
 
 Gura_ImplementMethod(wx_ConfigBase, HasGroup)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strName = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strName = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->HasGroup(strName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, IsExpandingEnvVars)
@@ -404,10 +425,11 @@ Gura_DeclareMethod(wx_ConfigBase, IsExpandingEnvVars)
 
 Gura_ImplementMethod(wx_ConfigBase, IsExpandingEnvVars)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsExpandingEnvVars();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, IsRecordingDefaults)
@@ -418,10 +440,11 @@ Gura_DeclareMethod(wx_ConfigBase, IsRecordingDefaults)
 
 Gura_ImplementMethod(wx_ConfigBase, IsRecordingDefaults)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsRecordingDefaults();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read)
@@ -434,16 +457,17 @@ Gura_DeclareMethod(wx_ConfigBase, Read)
 
 Gura_ImplementMethod(wx_ConfigBase, Read)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	wxString str = wxString::FromUTF8(args.GetString(1));
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	wxString str = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->Read(key, str);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_1)
@@ -459,17 +483,18 @@ Gura_DeclareMethod(wx_ConfigBase, Read_1)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	wxString str = wxString::FromUTF8(args.GetString(1));
-	wxString defaultVal = wxString::FromUTF8(args.GetString(2));
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	wxString str = wxString::FromUTF8(arg.GetString(1));
+	wxString defaultVal = wxString::FromUTF8(arg.GetString(2));
 	bool rtn = pThis->GetEntity()->Read(key, str, defaultVal);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_2)
@@ -482,12 +507,13 @@ Gura_DeclareMethod(wx_ConfigBase, Read_2)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_2)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	wxString defaultVal = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	wxString defaultVal = wxString::FromUTF8(arg.GetString(1));
 	wxString rtn = pThis->GetEntity()->Read(key, defaultVal);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_3)
@@ -500,12 +526,13 @@ Gura_DeclareMethod(wx_ConfigBase, Read_3)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_3)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	long l = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	long l = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->Read(key, l);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_4)
@@ -521,17 +548,18 @@ Gura_DeclareMethod(wx_ConfigBase, Read_4)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_4)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	long l = args.GetLong(1);
-	long defaultVal = args.GetLong(2);
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	long l = arg.GetLong(1);
+	long defaultVal = arg.GetLong(2);
 	bool rtn = pThis->GetEntity()->Read(key, l, defaultVal);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_5)
@@ -544,12 +572,13 @@ Gura_DeclareMethod(wx_ConfigBase, Read_5)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_5)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	long defaultVal = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	long defaultVal = arg.GetLong(1);
 	long rtn = pThis->GetEntity()->Read(key, defaultVal);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_6)
@@ -562,12 +591,13 @@ Gura_DeclareMethod(wx_ConfigBase, Read_6)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_6)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	double d = args.GetDouble(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	double d = arg.GetDouble(1);
 	bool rtn = pThis->GetEntity()->Read(key, d);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_7)
@@ -583,17 +613,18 @@ Gura_DeclareMethod(wx_ConfigBase, Read_7)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_7)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	double d = args.GetDouble(1);
-	double defaultVal = args.GetDouble(2);
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	double d = arg.GetDouble(1);
+	double defaultVal = arg.GetDouble(2);
 	bool rtn = pThis->GetEntity()->Read(key, d, defaultVal);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_8)
@@ -606,12 +637,13 @@ Gura_DeclareMethod(wx_ConfigBase, Read_8)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_8)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	bool b = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	bool b = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->Read(key, b);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Read_9)
@@ -627,17 +659,18 @@ Gura_DeclareMethod(wx_ConfigBase, Read_9)
 
 Gura_ImplementMethod(wx_ConfigBase, Read_9)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	bool d = args.GetBoolean(1);
-	bool defaultVal = args.GetBoolean(2);
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	bool d = arg.GetBoolean(1);
+	bool defaultVal = arg.GetBoolean(2);
 	bool rtn = pThis->GetEntity()->Read(key, d, defaultVal);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, RenameEntry)
@@ -650,12 +683,13 @@ Gura_DeclareMethod(wx_ConfigBase, RenameEntry)
 
 Gura_ImplementMethod(wx_ConfigBase, RenameEntry)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString oldName = wxString::FromUTF8(args.GetString(0));
-	wxString newName = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString oldName = wxString::FromUTF8(arg.GetString(0));
+	wxString newName = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->RenameEntry(oldName, newName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, RenameGroup)
@@ -668,12 +702,13 @@ Gura_DeclareMethod(wx_ConfigBase, RenameGroup)
 
 Gura_ImplementMethod(wx_ConfigBase, RenameGroup)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString oldName = wxString::FromUTF8(args.GetString(0));
-	wxString newName = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString oldName = wxString::FromUTF8(arg.GetString(0));
+	wxString newName = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->RenameGroup(oldName, newName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_ConfigBase, Set)
@@ -685,10 +720,11 @@ Gura_DeclareClassMethod(wx_ConfigBase, Set)
 
 Gura_ImplementClassMethod(wx_ConfigBase, Set)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxConfigBase *pConfig = Object_wx_ConfigBase::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxConfigBase *pConfig = Object_wx_ConfigBase::GetObject(arg, 0)->GetEntity();
 	wxConfigBase *rtn = (wxConfigBase *)wxConfigBase::Set(pConfig);
-	return ReturnValue(env, sig, args, Value(new Object_wx_ConfigBase(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ConfigBase(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, SetExpandEnvVars)
@@ -699,12 +735,13 @@ Gura_DeclareMethod(wx_ConfigBase, SetExpandEnvVars)
 
 Gura_ImplementMethod(wx_ConfigBase, SetExpandEnvVars)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bDoIt = true;
-	if (args.IsValid(0)) bDoIt = args.GetBoolean(0);
+	if (arg.IsValid(0)) bDoIt = arg.GetBoolean(0);
 	pThis->GetEntity()->SetExpandEnvVars(bDoIt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, SetPath)
@@ -715,11 +752,12 @@ Gura_DeclareMethod(wx_ConfigBase, SetPath)
 
 Gura_ImplementMethod(wx_ConfigBase, SetPath)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strPath = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strPath = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetPath(strPath);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, SetRecordDefaults)
@@ -730,12 +768,13 @@ Gura_DeclareMethod(wx_ConfigBase, SetRecordDefaults)
 
 Gura_ImplementMethod(wx_ConfigBase, SetRecordDefaults)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bDoIt = true;
-	if (args.IsValid(0)) bDoIt = args.GetBoolean(0);
+	if (arg.IsValid(0)) bDoIt = arg.GetBoolean(0);
 	pThis->GetEntity()->SetRecordDefaults(bDoIt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Write)
@@ -748,12 +787,13 @@ Gura_DeclareMethod(wx_ConfigBase, Write)
 
 Gura_ImplementMethod(wx_ConfigBase, Write)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	wxString value = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	wxString value = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->Write(key, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Write_1)
@@ -766,12 +806,13 @@ Gura_DeclareMethod(wx_ConfigBase, Write_1)
 
 Gura_ImplementMethod(wx_ConfigBase, Write_1)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	long value = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	long value = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->Write(key, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Write_2)
@@ -784,12 +825,13 @@ Gura_DeclareMethod(wx_ConfigBase, Write_2)
 
 Gura_ImplementMethod(wx_ConfigBase, Write_2)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	double value = args.GetDouble(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	double value = arg.GetDouble(1);
 	bool rtn = pThis->GetEntity()->Write(key, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ConfigBase, Write_3)
@@ -802,12 +844,13 @@ Gura_DeclareMethod(wx_ConfigBase, Write_3)
 
 Gura_ImplementMethod(wx_ConfigBase, Write_3)
 {
-	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString key = wxString::FromUTF8(args.GetString(0));
-	bool value = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_ConfigBase *pThis = Object_wx_ConfigBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString key = wxString::FromUTF8(arg.GetString(0));
+	bool value = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->Write(key, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -815,20 +858,20 @@ Gura_ImplementMethod(wx_ConfigBase, Write_3)
 //----------------------------------------------------------------------------
 Object_wx_ConfigBase::~Object_wx_ConfigBase()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_ConfigBase::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_ConfigBase::ToString(bool exprFlag)
 {
 	String rtn("<wx.ConfigBase:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -890,7 +933,7 @@ Gura_ImplementUserInheritableClass(wx_ConfigBase)
 
 Gura_ImplementDescendantCreator(wx_ConfigBase)
 {
-	return new Object_wx_ConfigBase((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_ConfigBase((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
