@@ -26,11 +26,11 @@ Gura_DeclarePrivUserSymbol(Unselect);
 //----------------------------------------------------------------------------
 class wx_DataViewCtrl: public wxDataViewCtrl, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_DataViewCtrl *_pObj;
 public:
-	inline wx_DataViewCtrl() : wxDataViewCtrl(), _sig(NULL), _pObj(NULL) {}
-	inline wx_DataViewCtrl(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxValidator& validator) : wxDataViewCtrl(parent, id, pos, size, style, validator), _sig(NULL), _pObj(NULL) {}
+	inline wx_DataViewCtrl() : wxDataViewCtrl(), _pObj(nullptr) {}
+	inline wx_DataViewCtrl(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxValidator& validator) : wxDataViewCtrl(parent, id, pos, size, style, validator), _pObj(nullptr) {}
 	//virtual bool AppendColumn(wxDataViewColumn* col);
 	//virtual bool AssociateModel(wxDataViewListModel* model);
 	//virtual bool ClearColumns();
@@ -46,8 +46,8 @@ public:
 	//virtual void SetSelections(const wxArrayInt& aSelections);
 	//virtual void Unselect(unsigned int row);
 	~wx_DataViewCtrl();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_DataViewCtrl *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_DataViewCtrl *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -55,12 +55,12 @@ public:
 
 wx_DataViewCtrl::~wx_DataViewCtrl()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_DataViewCtrl::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -75,17 +75,18 @@ Gura_DeclareFunction(DataViewCtrlEmpty)
 
 Gura_ImplementFunction(DataViewCtrlEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_DataViewCtrl *pEntity = new wx_DataViewCtrl();
-	Object_wx_DataViewCtrl *pObj = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DataViewCtrl *pObj = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DataViewCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(DataViewCtrl)
@@ -103,27 +104,28 @@ Gura_DeclareFunction(DataViewCtrl)
 
 Gura_ImplementFunction(DataViewCtrl)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(5)) validator = Object_wx_Validator::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(5)) validator = Object_wx_Validator::GetObject(arg, 5)->GetEntity();
 	wx_DataViewCtrl *pEntity = new wx_DataViewCtrl(parent, id, *pos, *size, style, *validator);
-	Object_wx_DataViewCtrl *pObj = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DataViewCtrl *pObj = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DataViewCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendColumn)
@@ -135,11 +137,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDataViewColumn *col = Object_wx_DataViewColumn::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDataViewColumn *col = Object_wx_DataViewColumn::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AppendColumn(col);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendBitmapColumn)
@@ -154,16 +157,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendBitmapColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendBitmapColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = -1;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendBitmapColumn(label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendBitmapColumn_1)
@@ -178,16 +182,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendBitmapColumn_1)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendBitmapColumn_1)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *label = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *label = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = -1;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendBitmapColumn(*label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendDateColumn)
@@ -202,16 +207,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendDateColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendDateColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_ACTIVATABLE;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = -1;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendDateColumn(label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendDateColumn_1)
@@ -226,16 +232,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendDateColumn_1)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendDateColumn_1)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *label = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *label = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_ACTIVATABLE;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = -1;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendDateColumn(*label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendProgressColumn)
@@ -250,16 +257,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendProgressColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendProgressColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = 80;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendProgressColumn(label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendProgressColumn_1)
@@ -274,16 +282,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendProgressColumn_1)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendProgressColumn_1)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *label = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *label = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = 80;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendProgressColumn(*label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendTextColumn)
@@ -298,16 +307,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendTextColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendTextColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = -1;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendTextColumn(label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendTextColumn_1)
@@ -322,16 +332,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendTextColumn_1)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendTextColumn_1)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *label = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *label = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = -1;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendTextColumn(*label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendToggleColumn)
@@ -346,16 +357,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendToggleColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendToggleColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = 30;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendToggleColumn(label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AppendToggleColumn_1)
@@ -370,16 +382,17 @@ Gura_DeclareMethod(wx_DataViewCtrl, AppendToggleColumn_1)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AppendToggleColumn_1)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *label = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *label = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	unsigned model_column = arg.GetInt(1);
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(2)) mode = static_cast<wxDataViewCellMode>(args.GetInt(2));
+	if (arg.IsValid(2)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(2));
 	int width = 30;
-	if (args.IsValid(3)) width = args.GetInt(3);
+	if (arg.IsValid(3)) width = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AppendToggleColumn(*label, model_column, mode, width);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, AssociateModel)
@@ -391,11 +404,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, AssociateModel)
 
 Gura_ImplementMethod(wx_DataViewCtrl, AssociateModel)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AssociateModel(model);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, Create)
@@ -412,20 +426,21 @@ Gura_DeclareMethod(wx_DataViewCtrl, Create)
 
 Gura_ImplementMethod(wx_DataViewCtrl, Create)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(5)) validator = Object_wx_Validator::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(5)) validator = Object_wx_Validator::GetObject(arg, 5)->GetEntity();
 	bool rtn = pThis->GetEntity()->Create(parent, id, *pos, *size, style, *validator);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, ClearColumns)
@@ -436,10 +451,11 @@ Gura_DeclareMethod(wx_DataViewCtrl, ClearColumns)
 
 Gura_ImplementMethod(wx_DataViewCtrl, ClearColumns)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ClearColumns();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, ClearSelection)
@@ -449,10 +465,11 @@ Gura_DeclareMethod(wx_DataViewCtrl, ClearSelection)
 
 Gura_ImplementMethod(wx_DataViewCtrl, ClearSelection)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ClearSelection();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, DeleteColumn)
@@ -464,11 +481,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, DeleteColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, DeleteColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned pos = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned pos = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->DeleteColumn(pos);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, GetColumn)
@@ -480,11 +498,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, GetColumn)
 
 Gura_ImplementMethod(wx_DataViewCtrl, GetColumn)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned pos = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned pos = arg.GetInt(0);
 	wxDataViewColumn *rtn = (wxDataViewColumn *)pThis->GetEntity()->GetColumn(pos);
-	return ReturnValue(env, sig, args, Value(new Object_wx_DataViewColumn(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DataViewColumn(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, GetModel)
@@ -495,10 +514,11 @@ Gura_DeclareMethod(wx_DataViewCtrl, GetModel)
 
 Gura_ImplementMethod(wx_DataViewCtrl, GetModel)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDataViewListModel *rtn = (wxDataViewListModel *)pThis->GetEntity()->GetModel();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DataViewListModel(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DataViewListModel(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, GetNumberOfColumns)
@@ -509,10 +529,11 @@ Gura_DeclareMethod(wx_DataViewCtrl, GetNumberOfColumns)
 
 Gura_ImplementMethod(wx_DataViewCtrl, GetNumberOfColumns)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	unsigned rtn = pThis->GetEntity()->GetNumberOfColumns();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, GetSelection)
@@ -523,26 +544,28 @@ Gura_DeclareMethod(wx_DataViewCtrl, GetSelection)
 
 Gura_ImplementMethod(wx_DataViewCtrl, GetSelection)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, GetSelections)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
-	DeclareArg(env, "aSelections", VTYPE_number, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "aSelections", VTYPE_number, OCCUR_Once, FLAG_ListVar);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 Gura_ImplementMethod(wx_DataViewCtrl, GetSelections)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	std::auto_ptr<wxArrayInt> aSelections(CreateArrayInt(args.GetList(0)));
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	std::unique_ptr<wxArrayInt> aSelections(CreateArrayInt(arg.GetList(0)));
 	int rtn = pThis->GetEntity()->GetSelections(*aSelections);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, IsSelected)
@@ -554,11 +577,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, IsSelected)
 
 Gura_ImplementMethod(wx_DataViewCtrl, IsSelected)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned row = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned row = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsSelected(row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, SetSelection)
@@ -569,11 +593,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, SetSelection)
 
 Gura_ImplementMethod(wx_DataViewCtrl, SetSelection)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int row = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int row = arg.GetInt(0);
 	pThis->GetEntity()->SetSelection(row);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, SetSelectionRange)
@@ -585,27 +610,29 @@ Gura_DeclareMethod(wx_DataViewCtrl, SetSelectionRange)
 
 Gura_ImplementMethod(wx_DataViewCtrl, SetSelectionRange)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned from = args.GetInt(0);
-	unsigned to = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned from = arg.GetInt(0);
+	unsigned to = arg.GetInt(1);
 	pThis->GetEntity()->SetSelectionRange(from, to);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, SetSelections)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
-	DeclareArg(env, "aSelections", VTYPE_number, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "aSelections", VTYPE_number, OCCUR_Once, FLAG_ListVar);
 }
 
 Gura_ImplementMethod(wx_DataViewCtrl, SetSelections)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	std::auto_ptr<wxArrayInt> aSelections(CreateArrayInt(args.GetList(0)));
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	std::unique_ptr<wxArrayInt> aSelections(CreateArrayInt(arg.GetList(0)));
 	pThis->GetEntity()->SetSelections(*aSelections);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewCtrl, Unselect)
@@ -616,11 +643,12 @@ Gura_DeclareMethod(wx_DataViewCtrl, Unselect)
 
 Gura_ImplementMethod(wx_DataViewCtrl, Unselect)
 {
-	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned row = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCtrl *pThis = Object_wx_DataViewCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned row = arg.GetInt(0);
 	pThis->GetEntity()->Unselect(row);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -632,13 +660,13 @@ Object_wx_DataViewCtrl::~Object_wx_DataViewCtrl()
 
 Object *Object_wx_DataViewCtrl::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_DataViewCtrl::ToString(bool exprFlag)
 {
 	String rtn("<wx.DataViewCtrl:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -699,7 +727,7 @@ Gura_ImplementUserInheritableClass(wx_DataViewCtrl)
 
 Gura_ImplementDescendantCreator(wx_DataViewCtrl)
 {
-	return new Object_wx_DataViewCtrl((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_DataViewCtrl((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
