@@ -26,10 +26,10 @@ Gura_DeclarePrivUserSymbol(StartDrag);
 //----------------------------------------------------------------------------
 class wx_DataViewCustomRenderer: public wxDataViewCustomRenderer, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_DataViewCustomRenderer *_pObj;
 public:
-	inline wx_DataViewCustomRenderer(const wxString& varianttype, wxDataViewCellMode mode) : wxDataViewCustomRenderer(varianttype, mode), _sig(NULL), _pObj(NULL) {}
+	inline wx_DataViewCustomRenderer(const wxString& varianttype, wxDataViewCellMode mode) : wxDataViewCustomRenderer(varianttype, mode), _pObj(nullptr) {}
 	// wxDataViewRenderer
 	virtual wxDataViewCellMode GetMode();
 	virtual wxDataViewColumn* GetOwner();
@@ -47,8 +47,8 @@ public:
 	virtual bool RightClick(wxPoint cursor, wxRect cell, wxDataViewListModel* model, unsigned int col, unsigned int row);
 	virtual bool StartDrag(wxPoint cursor, wxRect cell, wxDataViewListModel* model, unsigned int col, unsigned int row);
 	~wx_DataViewCustomRenderer();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_DataViewCustomRenderer *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_DataViewCustomRenderer *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -56,38 +56,38 @@ public:
 
 wx_DataViewCustomRenderer::~wx_DataViewCustomRenderer()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_DataViewCustomRenderer::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 wxDataViewCellMode wx_DataViewCustomRenderer::GetMode()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetMode);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::GetMode();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return wxDATAVIEW_CELL_INERT;
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::GetMode();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return wxDATAVIEW_CELL_INERT;
 	return static_cast<wxDataViewCellMode>(rtn.GetInt());
 }
 
 wxDataViewColumn* wx_DataViewCustomRenderer::GetOwner()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetOwner);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::GetOwner();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_wx_DataViewColumn)) return NULL;
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::GetOwner();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_wx_DataViewColumn)) return nullptr;
 	return Object_wx_DataViewColumn::GetObject(rtn)->GetEntity();
 }
 
 bool wx_DataViewCustomRenderer::GetValue(wxVariant& value)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetValue);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::GetValue(value);
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_wx_Variant, true)) return false;
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::GetValue(value);
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_wx_Variant, true)) return false;
 	if (rtn.IsInvalid()) return false;
 	value = *Object_wx_Variant::GetObject(rtn)->GetEntity();
 	return true;
@@ -96,68 +96,68 @@ bool wx_DataViewCustomRenderer::GetValue(wxVariant& value)
 wxString wx_DataViewCustomRenderer::GetVariantType()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetVariantType);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::GetVariantType();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_string)) return wxEmptyString;
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::GetVariantType();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_string)) return wxEmptyString;
 	return wxString::FromUTF8(rtn.GetString());
 }
 
 void wx_DataViewCustomRenderer::SetOwner(wxDataViewColumn* owner)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, SetOwner);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::SetOwner(owner);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::SetOwner(owner);
 	ValueList valListArg;
 	valListArg.reserve(1);
-	valListArg.push_back(Value(new Object_wx_DataViewColumn(owner, NULL, OwnerFalse)));
-	_pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	CheckMethodResult(_sig);
+	valListArg.push_back(Value(new Object_wx_DataViewColumn(owner, nullptr, OwnerFalse)));
+	_pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	CheckMethodResult(_pObj->GetSignal());
 }
 
 bool wx_DataViewCustomRenderer::SetValue(const wxVariant& value)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, SetValue);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::SetValue(value);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::SetValue(value);
 	ValueList valListArg;
 	valListArg.reserve(1);
-	valListArg.push_back(Value(new Object_wx_Variant(new wxVariant(value), NULL, OwnerTrue)));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	valListArg.push_back(Value(new Object_wx_Variant(new wxVariant(value), nullptr, OwnerTrue)));
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewCustomRenderer::Validate(wxVariant& value)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, Validate);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::Validate(value);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::Validate(value);
 	ValueList valListArg;
 	valListArg.reserve(1);
-	valListArg.push_back(Value(new Object_wx_Variant(new wxVariant(value), NULL, OwnerTrue)));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	valListArg.push_back(Value(new Object_wx_Variant(new wxVariant(value), nullptr, OwnerTrue)));
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewCustomRenderer::Activate(wxRect cell, wxDataViewListModel* model, unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, Activate);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::Activate(cell, model, col, row);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::Activate(cell, model, col, row);
 	ValueList valListArg;
 	valListArg.reserve(4);
-	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, NULL, OwnerFalse)));
+	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, nullptr, OwnerFalse)));
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 wxDC* wx_DataViewCustomRenderer::GetDC()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetDC);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::GetDC();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_wx_DC)) return NULL;
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::GetDC();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_wx_DC)) return nullptr;
 	return Object_wx_DC::GetObject(rtn)->GetEntity();
 }
 
@@ -165,29 +165,29 @@ wxDC* wx_DataViewCustomRenderer::GetDC()
 wxSize wx_DataViewCustomRenderer::GetSize()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetSize);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewCustomRenderer#GetSize method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewCustomRenderer#GetSize method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return wxSize();
 	}
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_wx_Size)) return wxSize();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_wx_Size)) return wxSize();
 	return *Object_wx_Size::GetObject(rtn)->GetEntity();
 }
 
 bool wx_DataViewCustomRenderer::LeftClick(wxPoint cursor, wxRect cell, wxDataViewListModel* model, unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, LeftClick);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::LeftClick(cursor, cell, model, col, row);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::LeftClick(cursor, cell, model, col, row);
 	ValueList valListArg;
 	valListArg.reserve(5);
-	valListArg.push_back(Value(new Object_wx_Point(new wxPoint(cursor), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, NULL, OwnerFalse)));
+	valListArg.push_back(Value(new Object_wx_Point(new wxPoint(cursor), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, nullptr, OwnerFalse)));
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
@@ -195,50 +195,50 @@ bool wx_DataViewCustomRenderer::LeftClick(wxPoint cursor, wxRect cell, wxDataVie
 bool wx_DataViewCustomRenderer::Render(wxRect cell, wxDC* dc, int state)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, Render);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewCustomRenderer#Render method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewCustomRenderer#Render method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return false;
 	}
 	ValueList valListArg;
 	valListArg.reserve(3);
-	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_DC(dc, NULL, OwnerFalse)));
+	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_DC(dc, nullptr, OwnerFalse)));
 	valListArg.push_back(Value(state));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewCustomRenderer::RightClick(wxPoint cursor, wxRect cell, wxDataViewListModel* model, unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RightClick);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::RightClick(cursor, cell, model, col, row);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::RightClick(cursor, cell, model, col, row);
 	ValueList valListArg;
 	valListArg.reserve(5);
-	valListArg.push_back(Value(new Object_wx_Point(new wxPoint(cursor), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, NULL, OwnerFalse)));
+	valListArg.push_back(Value(new Object_wx_Point(new wxPoint(cursor), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, nullptr, OwnerFalse)));
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewCustomRenderer::StartDrag(wxPoint cursor, wxRect cell, wxDataViewListModel* model, unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, StartDrag);
-	if (pFunc == NULL) return wxDataViewCustomRenderer::StartDrag(cursor, cell, model, col, row);
+	if (pFunc == nullptr) return wxDataViewCustomRenderer::StartDrag(cursor, cell, model, col, row);
 	ValueList valListArg;
 	valListArg.reserve(5);
-	valListArg.push_back(Value(new Object_wx_Point(new wxPoint(cursor), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), NULL, OwnerTrue)));
-	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, NULL, OwnerFalse)));
+	valListArg.push_back(Value(new Object_wx_Point(new wxPoint(cursor), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_Rect(new wxRect(cell), nullptr, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_DataViewListModel(model, nullptr, OwnerFalse)));
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
@@ -256,21 +256,22 @@ Gura_DeclareFunction(DataViewCustomRenderer)
 
 Gura_ImplementFunction(DataViewCustomRenderer)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxString varianttype = wxT("string");
-	if (args.IsValid(0)) varianttype = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) varianttype = wxString::FromUTF8(arg.GetString(0));
 	wxDataViewCellMode mode = wxDATAVIEW_CELL_INERT;
-	if (args.IsValid(1)) mode = static_cast<wxDataViewCellMode>(args.GetInt(1));
+	if (arg.IsValid(1)) mode = static_cast<wxDataViewCellMode>(arg.GetInt(1));
 	wx_DataViewCustomRenderer *pEntity = new wx_DataViewCustomRenderer(varianttype, mode);
-	Object_wx_DataViewCustomRenderer *pObj = Object_wx_DataViewCustomRenderer::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DataViewCustomRenderer *pObj = Object_wx_DataViewCustomRenderer::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DataViewCustomRenderer(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_DataViewCustomRenderer, Activate)
@@ -285,14 +286,15 @@ Gura_DeclareMethod(wx_DataViewCustomRenderer, Activate)
 
 Gura_ImplementMethod(wx_DataViewCustomRenderer, Activate)
 {
-	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *cell = Object_wx_Rect::GetObject(args, 0)->GetEntity();
-	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(args, 1)->GetEntity();
-	unsigned col = args.GetInt(2);
-	unsigned row = args.GetInt(3);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *cell = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
+	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(arg, 1)->GetEntity();
+	unsigned col = arg.GetInt(2);
+	unsigned row = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->wxDataViewCustomRenderer::Activate(*cell, model, col, row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCustomRenderer, GetDC)
@@ -303,10 +305,11 @@ Gura_DeclareMethod(wx_DataViewCustomRenderer, GetDC)
 
 Gura_ImplementMethod(wx_DataViewCustomRenderer, GetDC)
 {
-	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDC *rtn = (wxDC *)pThis->GetEntity()->wxDataViewCustomRenderer::GetDC();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DC(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DC(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DataViewCustomRenderer, LeftClick)
@@ -322,15 +325,16 @@ Gura_DeclareMethod(wx_DataViewCustomRenderer, LeftClick)
 
 Gura_ImplementMethod(wx_DataViewCustomRenderer, LeftClick)
 {
-	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *cursor = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxRect *cell = Object_wx_Rect::GetObject(args, 1)->GetEntity();
-	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(args, 2)->GetEntity();
-	unsigned col = args.GetInt(3);
-	unsigned row = args.GetInt(4);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *cursor = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxRect *cell = Object_wx_Rect::GetObject(arg, 1)->GetEntity();
+	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(arg, 2)->GetEntity();
+	unsigned col = arg.GetInt(3);
+	unsigned row = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->wxDataViewCustomRenderer::LeftClick(*cursor, *cell, model, col, row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCustomRenderer, RightClick)
@@ -346,15 +350,16 @@ Gura_DeclareMethod(wx_DataViewCustomRenderer, RightClick)
 
 Gura_ImplementMethod(wx_DataViewCustomRenderer, RightClick)
 {
-	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *cursor = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxRect *cell = Object_wx_Rect::GetObject(args, 1)->GetEntity();
-	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(args, 2)->GetEntity();
-	unsigned col = args.GetInt(3);
-	unsigned row = args.GetInt(4);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *cursor = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxRect *cell = Object_wx_Rect::GetObject(arg, 1)->GetEntity();
+	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(arg, 2)->GetEntity();
+	unsigned col = arg.GetInt(3);
+	unsigned row = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->wxDataViewCustomRenderer::RightClick(*cursor, *cell, model, col, row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewCustomRenderer, StartDrag)
@@ -370,15 +375,16 @@ Gura_DeclareMethod(wx_DataViewCustomRenderer, StartDrag)
 
 Gura_ImplementMethod(wx_DataViewCustomRenderer, StartDrag)
 {
-	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *cursor = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxRect *cell = Object_wx_Rect::GetObject(args, 1)->GetEntity();
-	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(args, 2)->GetEntity();
-	unsigned col = args.GetInt(3);
-	unsigned row = args.GetInt(4);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewCustomRenderer *pThis = Object_wx_DataViewCustomRenderer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *cursor = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxRect *cell = Object_wx_Rect::GetObject(arg, 1)->GetEntity();
+	wxDataViewListModel *model = Object_wx_DataViewListModel::GetObject(arg, 2)->GetEntity();
+	unsigned col = arg.GetInt(3);
+	unsigned row = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->wxDataViewCustomRenderer::StartDrag(*cursor, *cell, model, col, row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -390,13 +396,13 @@ Object_wx_DataViewCustomRenderer::~Object_wx_DataViewCustomRenderer()
 
 Object *Object_wx_DataViewCustomRenderer::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_DataViewCustomRenderer::ToString(bool exprFlag)
 {
 	String rtn("<wx.DataViewCustomRenderer:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -435,7 +441,7 @@ Gura_ImplementUserInheritableClass(wx_DataViewCustomRenderer)
 
 Gura_ImplementDescendantCreator(wx_DataViewCustomRenderer)
 {
-	return new Object_wx_DataViewCustomRenderer((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_DataViewCustomRenderer((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
