@@ -24,10 +24,10 @@ Gura_DeclarePrivUserSymbol(ValueChanged);
 //----------------------------------------------------------------------------
 class wx_DataViewListModel: public wxDataViewListModel, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_DataViewListModel *_pObj;
 public:
-	inline wx_DataViewListModel() : wxDataViewListModel(), _sig(NULL), _pObj(NULL) {}
+	inline wx_DataViewListModel() : wxDataViewListModel(), _pObj(nullptr) {}
 	virtual wxString GetColType(unsigned int col);
 	virtual unsigned int GetNumberOfCols();
 	virtual unsigned int GetNumberOfRows();
@@ -41,8 +41,8 @@ public:
 	virtual bool SetValue(wxVariant& variant, unsigned int col, unsigned int row);
 	virtual bool ValueChanged(unsigned int col, unsigned int row);
 	~wx_DataViewListModel();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_DataViewListModel *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_DataViewListModel *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -50,28 +50,28 @@ public:
 
 wx_DataViewListModel::~wx_DataViewListModel()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_DataViewListModel::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 // pure virtual function
 wxString wx_DataViewListModel::GetColType(unsigned int col)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetColType);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetColType method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetColType method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return wxEmptyString;
 	}
 	ValueList valListArg;
 	valListArg.reserve(1);
 	valListArg.push_back(Value(col));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_string)) return wxEmptyString;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_string)) return wxEmptyString;
 	return wxString::FromUTF8(rtn.GetString());
 }
 
@@ -79,13 +79,13 @@ wxString wx_DataViewListModel::GetColType(unsigned int col)
 unsigned int wx_DataViewListModel::GetNumberOfCols()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetNumberOfCols);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetNumberOfCols method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetNumberOfCols method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return 0;
 	}
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_number)) return 0;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_number)) return 0;
 	return rtn.GetUInt();
 }
 
@@ -93,13 +93,13 @@ unsigned int wx_DataViewListModel::GetNumberOfCols()
 unsigned int wx_DataViewListModel::GetNumberOfRows()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetNumberOfRows);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetNumberOfRows method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetNumberOfRows method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return 0;
 	}
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_number)) return 0;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_number)) return 0;
 	return rtn.GetUInt();
 }
 
@@ -107,8 +107,8 @@ unsigned int wx_DataViewListModel::GetNumberOfRows()
 void wx_DataViewListModel::GetValue(wxVariant& variant, unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, GetValue);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetValue method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewListModel#GetValue method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return;
 	}
@@ -116,62 +116,62 @@ void wx_DataViewListModel::GetValue(wxVariant& variant, unsigned int col, unsign
 	valListArg.reserve(2);
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_wx_Variant)) return;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_wx_Variant)) return;
 	variant = *Object_wx_Variant::GetObject(rtn)->GetEntity();
 }
 
 bool wx_DataViewListModel::RowAppended()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RowAppended);
-	if (pFunc == NULL) return wxDataViewListModel::RowAppended();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	if (pFunc == nullptr) return wxDataViewListModel::RowAppended();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewListModel::RowChanged(unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RowChanged);
-	if (pFunc == NULL) return wxDataViewListModel::RowChanged(row);
+	if (pFunc == nullptr) return wxDataViewListModel::RowChanged(row);
 	ValueList valListArg;
 	valListArg.reserve(1);
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewListModel::RowDeleted(unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RowDeleted);
-	if (pFunc == NULL) return wxDataViewListModel::RowDeleted(row);
+	if (pFunc == nullptr) return wxDataViewListModel::RowDeleted(row);
 	ValueList valListArg;
 	valListArg.reserve(1);
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewListModel::RowInserted(unsigned int before)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RowInserted);
-	if (pFunc == NULL) return wxDataViewListModel::RowInserted(before);
+	if (pFunc == nullptr) return wxDataViewListModel::RowInserted(before);
 	ValueList valListArg;
 	valListArg.reserve(1);
 	valListArg.push_back(Value(before));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewListModel::RowPrepended()
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RowPrepended);
-	if (pFunc == NULL) return wxDataViewListModel::RowPrepended();
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, ValueList::Null);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	if (pFunc == nullptr) return wxDataViewListModel::RowPrepended();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, ValueList::Empty);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
@@ -179,20 +179,20 @@ bool wx_DataViewListModel::RowsReordered(unsigned int* new_order)
 {
 	Environment &env = *_pObj;
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, RowsReordered);
-	if (pFunc == NULL) return wxDataViewListModel::RowsReordered(new_order);
+	if (pFunc == nullptr) return wxDataViewListModel::RowsReordered(new_order);
 	size_t nRows = GetNumberOfRows();
-	if (_sig.IsSignalled()) return false;
+	if (_pObj->GeSignal().IsSignalled()) return false;
 	Value v;
 	do {
-		ValueList &valList = v.InitAsList(env);
-		valList.reserve(nRows);
-		for (size_t iRow = 0; iRow < nRows; iRow++) valList.push_back(Value(new_order[iRow]));
+		Object_list *pObjList = v.InitAsList(env);
+		pObjList->Reserve(nRows);
+		for (size_t iRow = 0; iRow < nRows; iRow++) pObjList->Add(Value(new_order[iRow]));
 	} while (0);
 	ValueList valListArg;
 	valListArg.reserve(1);
 	valListArg.push_back(v);
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
@@ -200,31 +200,31 @@ bool wx_DataViewListModel::RowsReordered(unsigned int* new_order)
 bool wx_DataViewListModel::SetValue(wxVariant& variant, unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, SetValue);
-	if (pFunc == NULL) {
-		_sig.SetError(ERR_NotImplementedError, "wx.DataViewListModel#SetValue method is missing");
+	if (pFunc == nullptr) {
+		_pObj->GetSignal().SetError(ERR_NotImplementedError, "wx.DataViewListModel#SetValue method is missing");
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 		return false;
 	}
 	ValueList valListArg;
 	valListArg.reserve(3);
-	valListArg.push_back(Value(new Object_wx_Variant(new wxVariant(variant), NULL, OwnerTrue)));
+	valListArg.push_back(Value(new Object_wx_Variant(new wxVariant(variant), nullptr, OwnerTrue)));
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 bool wx_DataViewListModel::ValueChanged(unsigned int col, unsigned int row)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, ValueChanged);
-	if (pFunc == NULL) return wxDataViewListModel::ValueChanged(col, row);
+	if (pFunc == nullptr) return wxDataViewListModel::ValueChanged(col, row);
 	ValueList valListArg;
 	valListArg.reserve(2);
 	valListArg.push_back(Value(col));
 	valListArg.push_back(Value(row));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valListArg);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valListArg);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
@@ -240,17 +240,18 @@ Gura_DeclareFunction(DataViewListModel)
 
 Gura_ImplementFunction(DataViewListModel)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_DataViewListModel *pEntity = new wx_DataViewListModel();
-	Object_wx_DataViewListModel *pObj = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DataViewListModel *pObj = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DataViewListModel(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, AddNotifier)
@@ -261,11 +262,12 @@ Gura_DeclareMethod(wx_DataViewListModel, AddNotifier)
 
 Gura_ImplementMethod(wx_DataViewListModel, AddNotifier)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDataViewListModelNotifier *notifier = Object_wx_DataViewListModelNotifier::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDataViewListModelNotifier *notifier = Object_wx_DataViewListModelNotifier::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddNotifier(notifier);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, AddViewingColumn)
@@ -277,12 +279,13 @@ Gura_DeclareMethod(wx_DataViewListModel, AddViewingColumn)
 
 Gura_ImplementMethod(wx_DataViewListModel, AddViewingColumn)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDataViewColumn *view_column = Object_wx_DataViewColumn::GetObject(args, 0)->GetEntity();
-	unsigned model_column = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDataViewColumn *view_column = Object_wx_DataViewColumn::GetObject(arg, 0)->GetEntity();
+	unsigned model_column = arg.GetInt(1);
 	pThis->GetEntity()->AddViewingColumn(view_column, model_column);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, Cleared)
@@ -293,10 +296,11 @@ Gura_DeclareMethod(wx_DataViewListModel, Cleared)
 
 Gura_ImplementMethod(wx_DataViewListModel, Cleared)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Cleared();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RemoveNotifier)
@@ -307,11 +311,12 @@ Gura_DeclareMethod(wx_DataViewListModel, RemoveNotifier)
 
 Gura_ImplementMethod(wx_DataViewListModel, RemoveNotifier)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDataViewListModelNotifier *notifier = Object_wx_DataViewListModelNotifier::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDataViewListModelNotifier *notifier = Object_wx_DataViewListModelNotifier::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->RemoveNotifier(notifier);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RemoveViewingColumn)
@@ -322,11 +327,12 @@ Gura_DeclareMethod(wx_DataViewListModel, RemoveViewingColumn)
 
 Gura_ImplementMethod(wx_DataViewListModel, RemoveViewingColumn)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDataViewColumn *column = Object_wx_DataViewColumn::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDataViewColumn *column = Object_wx_DataViewColumn::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->RemoveViewingColumn(column);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RowAppended)
@@ -337,10 +343,11 @@ Gura_DeclareMethod(wx_DataViewListModel, RowAppended)
 
 Gura_ImplementMethod(wx_DataViewListModel, RowAppended)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::RowAppended();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RowChanged)
@@ -352,11 +359,12 @@ Gura_DeclareMethod(wx_DataViewListModel, RowChanged)
 
 Gura_ImplementMethod(wx_DataViewListModel, RowChanged)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned row = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned row = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::RowChanged(row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RowDeleted)
@@ -368,11 +376,12 @@ Gura_DeclareMethod(wx_DataViewListModel, RowDeleted)
 
 Gura_ImplementMethod(wx_DataViewListModel, RowDeleted)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned row = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned row = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::RowDeleted(row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RowInserted)
@@ -384,11 +393,12 @@ Gura_DeclareMethod(wx_DataViewListModel, RowInserted)
 
 Gura_ImplementMethod(wx_DataViewListModel, RowInserted)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned before = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned before = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::RowInserted(before);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RowPrepended)
@@ -399,27 +409,29 @@ Gura_DeclareMethod(wx_DataViewListModel, RowPrepended)
 
 Gura_ImplementMethod(wx_DataViewListModel, RowPrepended)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::RowPrepended();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, RowsReordered)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
-	DeclareArg(env, "new_order", VTYPE_number, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "new_order", VTYPE_number, OCCUR_Once, FLAG_ListVar);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 Gura_ImplementMethod(wx_DataViewListModel, RowsReordered)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	CArrayOfInt new_order(args.GetList(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	CArrayOfInt new_order(arg.GetList(0));
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::RowsReordered(
 					reinterpret_cast<unsigned int *>(new_order.Data()));
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DataViewListModel, ValueChanged)
@@ -432,12 +444,13 @@ Gura_DeclareMethod(wx_DataViewListModel, ValueChanged)
 
 Gura_ImplementMethod(wx_DataViewListModel, ValueChanged)
 {
-	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned col = args.GetInt(0);
-	unsigned row = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DataViewListModel *pThis = Object_wx_DataViewListModel::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned col = arg.GetInt(0);
+	unsigned row = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->wxDataViewListModel::ValueChanged(col, row);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -449,13 +462,13 @@ Object_wx_DataViewListModel::~Object_wx_DataViewListModel()
 
 Object *Object_wx_DataViewListModel::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_DataViewListModel::ToString(bool exprFlag)
 {
 	String rtn("<wx.DataViewListModel:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -499,7 +512,7 @@ Gura_ImplementUserInheritableClass(wx_DataViewListModel)
 
 Gura_ImplementDescendantCreator(wx_DataViewListModel)
 {
-	return new Object_wx_DataViewListModel((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_DataViewListModel((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
