@@ -13,15 +13,15 @@ Gura_DeclarePrivUserSymbol(DoOK);
 //----------------------------------------------------------------------------
 class wx_Dialog: public wxDialog, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Dialog *_pObj;
 public:
-	inline wx_Dialog() : wxDialog(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Dialog(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxDialog(parent, id, title, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_Dialog() : wxDialog(), _pObj(nullptr) {}
+	inline wx_Dialog(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxDialog(parent, id, title, pos, size, style, name), _pObj(nullptr) {}
 	//virtual bool DoOK();
 	~wx_Dialog();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Dialog *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Dialog *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -29,12 +29,12 @@ public:
 
 wx_Dialog::~wx_Dialog()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Dialog::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,17 +49,18 @@ Gura_DeclareFunction(DialogEmpty)
 
 Gura_ImplementFunction(DialogEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Dialog *pEntity = new wx_Dialog();
-	Object_wx_Dialog *pObj = Object_wx_Dialog::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Dialog *pObj = Object_wx_Dialog::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Dialog(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Dialog)
@@ -78,29 +79,30 @@ Gura_DeclareFunction(Dialog)
 
 Gura_ImplementFunction(Dialog)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = args.IsValid(0)?
-			Object_wx_Window::GetObject(args, 0)->GetEntity() : NULL;
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString title = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = arg.IsValid(0)?
+			Object_wx_Window::GetObject(arg, 0)->GetEntity() : nullptr;
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString title = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = wxDEFAULT_DIALOG_STYLE;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString name = wxT("dialogBox");
-	if (args.IsValid(6)) name = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) name = wxString::FromUTF8(arg.GetString(6));
 	wx_Dialog *pEntity = new wx_Dialog(parent, id, title, *pos, *size, style, name);
-	Object_wx_Dialog *pObj = Object_wx_Dialog::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Dialog *pObj = Object_wx_Dialog::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Dialog(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Dialog, AddMainButtonId)
@@ -111,11 +113,12 @@ Gura_DeclareMethod(wx_Dialog, AddMainButtonId)
 
 Gura_ImplementMethod(wx_Dialog, AddMainButtonId)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(0));
 	pThis->GetEntity()->AddMainButtonId(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, CanDoLayoutAdaptation)
@@ -126,10 +129,11 @@ Gura_DeclareMethod(wx_Dialog, CanDoLayoutAdaptation)
 
 Gura_ImplementMethod(wx_Dialog, CanDoLayoutAdaptation)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanDoLayoutAdaptation();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, Centre)
@@ -140,12 +144,13 @@ Gura_DeclareMethod(wx_Dialog, Centre)
 
 Gura_ImplementMethod(wx_Dialog, Centre)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int direction = wxBOTH;
-	if (args.IsValid(0)) direction = args.GetInt(0);
+	if (arg.IsValid(0)) direction = arg.GetInt(0);
 	pThis->GetEntity()->Centre(direction);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, Create)
@@ -163,22 +168,23 @@ Gura_DeclareMethod(wx_Dialog, Create)
 
 Gura_ImplementMethod(wx_Dialog, Create)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = args.IsValid(0)?
-			Object_wx_Window::GetObject(args, 0)->GetEntity() : NULL;
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString title = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = arg.IsValid(0)?
+			Object_wx_Window::GetObject(arg, 0)->GetEntity() : nullptr;
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString title = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = wxDEFAULT_DIALOG_STYLE;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString name = wxT("dialogBox");
-	if (args.IsValid(6)) name = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) name = wxString::FromUTF8(arg.GetString(6));
 	bool rtn = pThis->GetEntity()->Create(parent, id, title, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, CreateButtonSizer)
@@ -190,11 +196,12 @@ Gura_DeclareMethod(wx_Dialog, CreateButtonSizer)
 
 Gura_ImplementMethod(wx_Dialog, CreateButtonSizer)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long flags = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long flags = arg.GetLong(0);
 	wxSizer *rtn = (wxSizer *)pThis->GetEntity()->CreateButtonSizer(flags);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Sizer(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Sizer(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Dialog, CreateSeparatedButtonSizer)
@@ -206,11 +213,12 @@ Gura_DeclareMethod(wx_Dialog, CreateSeparatedButtonSizer)
 
 Gura_ImplementMethod(wx_Dialog, CreateSeparatedButtonSizer)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long flags = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long flags = arg.GetLong(0);
 	wxSizer *rtn = (wxSizer *)pThis->GetEntity()->CreateSeparatedButtonSizer(flags);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Sizer(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Sizer(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Dialog, CreateStdDialogButtonSizer)
@@ -222,11 +230,12 @@ Gura_DeclareMethod(wx_Dialog, CreateStdDialogButtonSizer)
 
 Gura_ImplementMethod(wx_Dialog, CreateStdDialogButtonSizer)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long flags = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long flags = arg.GetLong(0);
 	wxStdDialogButtonSizer *rtn = (wxStdDialogButtonSizer *)pThis->GetEntity()->CreateStdDialogButtonSizer(flags);
-	return ReturnValue(env, sig, args, Value(new Object_wx_StdDialogButtonSizer(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_StdDialogButtonSizer(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Dialog, DoLayoutAdaptation)
@@ -237,10 +246,11 @@ Gura_DeclareMethod(wx_Dialog, DoLayoutAdaptation)
 
 Gura_ImplementMethod(wx_Dialog, DoLayoutAdaptation)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DoLayoutAdaptation();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, DoOK)
@@ -251,14 +261,15 @@ Gura_DeclareMethod(wx_Dialog, DoOK)
 
 Gura_ImplementMethod(wx_Dialog, DoOK)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DoOK();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, EndModal)
@@ -269,11 +280,12 @@ Gura_DeclareMethod(wx_Dialog, EndModal)
 
 Gura_ImplementMethod(wx_Dialog, EndModal)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int retCode = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int retCode = arg.GetInt(0);
 	pThis->GetEntity()->EndModal(retCode);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, GetAffirmativeId)
@@ -284,10 +296,11 @@ Gura_DeclareMethod(wx_Dialog, GetAffirmativeId)
 
 Gura_ImplementMethod(wx_Dialog, GetAffirmativeId)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetAffirmativeId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetEscapeId)
@@ -298,10 +311,11 @@ Gura_DeclareMethod(wx_Dialog, GetEscapeId)
 
 Gura_ImplementMethod(wx_Dialog, GetEscapeId)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetEscapeId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetLayoutAdaptationDone)
@@ -312,10 +326,11 @@ Gura_DeclareMethod(wx_Dialog, GetLayoutAdaptationDone)
 
 Gura_ImplementMethod(wx_Dialog, GetLayoutAdaptationDone)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetLayoutAdaptationDone();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetLayoutAdaptationLevel)
@@ -326,10 +341,11 @@ Gura_DeclareMethod(wx_Dialog, GetLayoutAdaptationLevel)
 
 Gura_ImplementMethod(wx_Dialog, GetLayoutAdaptationLevel)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLayoutAdaptationLevel();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetLayoutAdaptationMode)
@@ -340,10 +356,11 @@ Gura_DeclareMethod(wx_Dialog, GetLayoutAdaptationMode)
 
 Gura_ImplementMethod(wx_Dialog, GetLayoutAdaptationMode)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDialogLayoutAdaptationMode rtn = pThis->GetEntity()->GetLayoutAdaptationMode();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetReturnCode)
@@ -354,10 +371,11 @@ Gura_DeclareMethod(wx_Dialog, GetReturnCode)
 
 Gura_ImplementMethod(wx_Dialog, GetReturnCode)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetReturnCode();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetMainButtonIds)
@@ -368,10 +386,11 @@ Gura_DeclareMethod(wx_Dialog, GetMainButtonIds)
 
 Gura_ImplementMethod(wx_Dialog, GetMainButtonIds)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxArrayInt &rtn = pThis->GetEntity()->GetMainButtonIds();
-	return ReturnValue(env, sig, args, ArrayIntToValue(env, rtn));
+	return ReturnValue(env, arg, ArrayIntToValue(env, rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, GetToolBar)
@@ -382,14 +401,15 @@ Gura_DeclareMethod(wx_Dialog, GetToolBar)
 
 Gura_ImplementMethod(wx_Dialog, GetToolBar)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxToolBar *rtn = (wxToolBar *)pThis->GetEntity()->GetToolBar();
-	return ReturnValue(env, sig, args, Value(new Object_wx_ToolBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ToolBar(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, Iconize)
@@ -400,11 +420,12 @@ Gura_DeclareMethod(wx_Dialog, Iconize)
 
 Gura_ImplementMethod(wx_Dialog, Iconize)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool iconize = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool iconize = arg.GetBoolean(0);
 	pThis->GetEntity()->Iconize(iconize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, IsIconized)
@@ -415,10 +436,11 @@ Gura_DeclareMethod(wx_Dialog, IsIconized)
 
 Gura_ImplementMethod(wx_Dialog, IsIconized)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsIconized();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, IsMainButtonId)
@@ -430,11 +452,12 @@ Gura_DeclareMethod(wx_Dialog, IsMainButtonId)
 
 Gura_ImplementMethod(wx_Dialog, IsMainButtonId)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(0));
 	bool rtn = pThis->GetEntity()->IsMainButtonId(id);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, IsModal)
@@ -445,10 +468,11 @@ Gura_DeclareMethod(wx_Dialog, IsModal)
 
 Gura_ImplementMethod(wx_Dialog, IsModal)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsModal();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, OnSysColourChanged)
@@ -461,15 +485,16 @@ Gura_DeclareMethod(wx_Dialog, OnSysColourChanged)
 
 Gura_ImplementMethod(wx_Dialog, OnSysColourChanged)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSysColourChangedEvent *event = Object_wx_SysColourChangedEvent::GetObject(args, 0)->GetEntity();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSysColourChangedEvent *event = Object_wx_SysColourChangedEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnSysColourChanged(*event);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetAffirmativeId)
@@ -480,11 +505,12 @@ Gura_DeclareMethod(wx_Dialog, SetAffirmativeId)
 
 Gura_ImplementMethod(wx_Dialog, SetAffirmativeId)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->SetAffirmativeId(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetEscapeId)
@@ -495,11 +521,12 @@ Gura_DeclareMethod(wx_Dialog, SetEscapeId)
 
 Gura_ImplementMethod(wx_Dialog, SetEscapeId)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->SetEscapeId(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetIcon)
@@ -510,11 +537,12 @@ Gura_DeclareMethod(wx_Dialog, SetIcon)
 
 Gura_ImplementMethod(wx_Dialog, SetIcon)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIcon *icon = Object_wx_Icon::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIcon *icon = Object_wx_Icon::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetIcon(*icon);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetIcons)
@@ -525,11 +553,12 @@ Gura_DeclareMethod(wx_Dialog, SetIcons)
 
 Gura_ImplementMethod(wx_Dialog, SetIcons)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIconBundle *icons = Object_wx_IconBundle::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIconBundle *icons = Object_wx_IconBundle::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetIcons(*icons);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetLayoutAdaptationDone)
@@ -540,11 +569,12 @@ Gura_DeclareMethod(wx_Dialog, SetLayoutAdaptationDone)
 
 Gura_ImplementMethod(wx_Dialog, SetLayoutAdaptationDone)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool done = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool done = arg.GetBoolean(0);
 	pThis->GetEntity()->SetLayoutAdaptationDone(done);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetLayoutAdaptationLevel)
@@ -555,11 +585,12 @@ Gura_DeclareMethod(wx_Dialog, SetLayoutAdaptationLevel)
 
 Gura_ImplementMethod(wx_Dialog, SetLayoutAdaptationLevel)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int level = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int level = arg.GetInt(0);
 	pThis->GetEntity()->SetLayoutAdaptationLevel(level);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetLayoutAdaptationMode)
@@ -570,11 +601,12 @@ Gura_DeclareMethod(wx_Dialog, SetLayoutAdaptationMode)
 
 Gura_ImplementMethod(wx_Dialog, SetLayoutAdaptationMode)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDialogLayoutAdaptationMode mode = static_cast<wxDialogLayoutAdaptationMode>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDialogLayoutAdaptationMode mode = static_cast<wxDialogLayoutAdaptationMode>(arg.GetInt(0));
 	pThis->GetEntity()->SetLayoutAdaptationMode(mode);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, SetReturnCode)
@@ -585,11 +617,12 @@ Gura_DeclareMethod(wx_Dialog, SetReturnCode)
 
 Gura_ImplementMethod(wx_Dialog, SetReturnCode)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int retCode = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int retCode = arg.GetInt(0);
 	pThis->GetEntity()->SetReturnCode(retCode);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Dialog, Show)
@@ -601,11 +634,12 @@ Gura_DeclareMethod(wx_Dialog, Show)
 
 Gura_ImplementMethod(wx_Dialog, Show)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool show = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool show = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Show(show);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, ShowModal)
@@ -616,10 +650,11 @@ Gura_DeclareMethod(wx_Dialog, ShowModal)
 
 Gura_ImplementMethod(wx_Dialog, ShowModal)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->ShowModal();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Dialog, ShowWindowModal)
@@ -629,10 +664,11 @@ Gura_DeclareMethod(wx_Dialog, ShowWindowModal)
 
 Gura_ImplementMethod(wx_Dialog, ShowWindowModal)
 {
-	Object_wx_Dialog *pThis = Object_wx_Dialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Dialog *pThis = Object_wx_Dialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ShowWindowModal();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -644,13 +680,13 @@ Object_wx_Dialog::~Object_wx_Dialog()
 
 Object *Object_wx_Dialog::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Dialog::ToString(bool exprFlag)
 {
 	String rtn("<wx.Dialog:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -706,7 +742,7 @@ Gura_ImplementUserInheritableClass(wx_Dialog)
 
 Gura_ImplementDescendantCreator(wx_Dialog)
 {
-	return new Object_wx_Dialog((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Dialog((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
