@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_DocManager: public wxDocManager, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_DocManager *_pObj;
 public:
-	inline wx_DocManager(long flags, bool initialize) : wxDocManager(flags, initialize), _sig(NULL), _pObj(NULL) {}
+	inline wx_DocManager(long flags, bool initialize) : wxDocManager(flags, initialize), _pObj(nullptr) {}
 	~wx_DocManager();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_DocManager *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_DocManager *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_DocManager::~wx_DocManager()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_DocManager::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,21 +47,22 @@ Gura_DeclareFunction(DocManager)
 
 Gura_ImplementFunction(DocManager)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	long flags = wxDEFAULT_DOCMAN_FLAGS;
-	if (args.IsValid(0)) flags = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	long flags = 0;
+	if (arg.IsValid(0)) flags = arg.GetLong(0);
 	bool initialize = true;
-	if (args.IsValid(1)) initialize = args.GetBoolean(1);
+	if (arg.IsValid(1)) initialize = arg.GetBoolean(1);
 	wx_DocManager *pEntity = new wx_DocManager(flags, initialize);
-	Object_wx_DocManager *pObj = Object_wx_DocManager::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DocManager *pObj = Object_wx_DocManager::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DocManager(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_DocManager, ActivateView)
@@ -73,13 +74,14 @@ Gura_DeclareMethod(wx_DocManager, ActivateView)
 
 Gura_ImplementMethod(wx_DocManager, ActivateView)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxView *doc = Object_wx_View::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxView *doc = Object_wx_View::GetObject(arg, 0)->GetEntity();
 	bool activate = true;
-	if (args.IsValid(1)) activate = args.GetBoolean(1);
+	if (arg.IsValid(1)) activate = arg.GetBoolean(1);
 	pThis->GetEntity()->ActivateView(doc, activate);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, AddDocument)
@@ -90,11 +92,12 @@ Gura_DeclareMethod(wx_DocManager, AddDocument)
 
 Gura_ImplementMethod(wx_DocManager, AddDocument)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocument *doc = Object_wx_Document::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocument *doc = Object_wx_Document::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddDocument(doc);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, AddFileToHistory)
@@ -105,11 +108,12 @@ Gura_DeclareMethod(wx_DocManager, AddFileToHistory)
 
 Gura_ImplementMethod(wx_DocManager, AddFileToHistory)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString filename = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString filename = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->AddFileToHistory(filename);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, AssociateTemplate)
@@ -120,11 +124,12 @@ Gura_DeclareMethod(wx_DocManager, AssociateTemplate)
 
 Gura_ImplementMethod(wx_DocManager, AssociateTemplate)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocTemplate *temp = Object_wx_DocTemplate::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocTemplate *temp = Object_wx_DocTemplate::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AssociateTemplate(temp);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, CloseDocuments)
@@ -136,12 +141,13 @@ Gura_DeclareMethod(wx_DocManager, CloseDocuments)
 
 Gura_ImplementMethod(wx_DocManager, CloseDocuments)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool force = true;
-	if (args.IsValid(0)) force = args.GetBoolean(0);
+	if (arg.IsValid(0)) force = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->CloseDocuments(force);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DocManager, CreateDocument)
@@ -154,12 +160,13 @@ Gura_DeclareMethod(wx_DocManager, CreateDocument)
 
 Gura_ImplementMethod(wx_DocManager, CreateDocument)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString path = wxString::FromUTF8(args.GetString(0));
-	long flags = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString path = wxString::FromUTF8(arg.GetString(0));
+	long flags = arg.GetLong(1);
 	wxDocument *rtn = (wxDocument *)pThis->GetEntity()->CreateDocument(path, flags);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Document(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Document(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, CreateView)
@@ -172,12 +179,13 @@ Gura_DeclareMethod(wx_DocManager, CreateView)
 
 Gura_ImplementMethod(wx_DocManager, CreateView)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocument *doc = Object_wx_Document::GetObject(args, 0)->GetEntity();
-	long flags = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocument *doc = Object_wx_Document::GetObject(arg, 0)->GetEntity();
+	long flags = arg.GetLong(1);
 	wxView *rtn = (wxView *)pThis->GetEntity()->CreateView(doc, flags);
-	return ReturnValue(env, sig, args, Value(new Object_wx_View(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_View(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, DisassociateTemplate)
@@ -188,11 +196,12 @@ Gura_DeclareMethod(wx_DocManager, DisassociateTemplate)
 
 Gura_ImplementMethod(wx_DocManager, DisassociateTemplate)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocTemplate *temp = Object_wx_DocTemplate::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocTemplate *temp = Object_wx_DocTemplate::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->DisassociateTemplate(temp);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FileHistoryAddFilesToMenu)
@@ -202,10 +211,11 @@ Gura_DeclareMethod(wx_DocManager, FileHistoryAddFilesToMenu)
 
 Gura_ImplementMethod(wx_DocManager, FileHistoryAddFilesToMenu)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->FileHistoryAddFilesToMenu();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FileHistoryAddFilesToMenu_1)
@@ -216,11 +226,12 @@ Gura_DeclareMethod(wx_DocManager, FileHistoryAddFilesToMenu_1)
 
 Gura_ImplementMethod(wx_DocManager, FileHistoryAddFilesToMenu_1)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FileHistoryAddFilesToMenu(menu);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FileHistoryLoad)
@@ -231,11 +242,12 @@ Gura_DeclareMethod(wx_DocManager, FileHistoryLoad)
 
 Gura_ImplementMethod(wx_DocManager, FileHistoryLoad)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxConfigBase *config = Object_wx_ConfigBase::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxConfigBase *config = Object_wx_ConfigBase::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FileHistoryLoad(*config);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FileHistoryRemoveMenu)
@@ -246,11 +258,12 @@ Gura_DeclareMethod(wx_DocManager, FileHistoryRemoveMenu)
 
 Gura_ImplementMethod(wx_DocManager, FileHistoryRemoveMenu)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FileHistoryRemoveMenu(menu);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FileHistorySave)
@@ -261,11 +274,12 @@ Gura_DeclareMethod(wx_DocManager, FileHistorySave)
 
 Gura_ImplementMethod(wx_DocManager, FileHistorySave)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxConfigBase *resourceFile = Object_wx_ConfigBase::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxConfigBase *resourceFile = Object_wx_ConfigBase::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FileHistorySave(*resourceFile);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FileHistoryUseMenu)
@@ -276,11 +290,12 @@ Gura_DeclareMethod(wx_DocManager, FileHistoryUseMenu)
 
 Gura_ImplementMethod(wx_DocManager, FileHistoryUseMenu)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FileHistoryUseMenu(menu);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, FindTemplateForPath)
@@ -292,11 +307,12 @@ Gura_DeclareMethod(wx_DocManager, FindTemplateForPath)
 
 Gura_ImplementMethod(wx_DocManager, FindTemplateForPath)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString path = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString path = wxString::FromUTF8(arg.GetString(0));
 	wxDocTemplate *rtn = (wxDocTemplate *)pThis->GetEntity()->FindTemplateForPath(path);
-	return ReturnValue(env, sig, args, Value(new Object_wx_DocTemplate(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DocTemplate(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetCurrentDocument)
@@ -307,10 +323,11 @@ Gura_DeclareMethod(wx_DocManager, GetCurrentDocument)
 
 Gura_ImplementMethod(wx_DocManager, GetCurrentDocument)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDocument *rtn = (wxDocument *)pThis->GetEntity()->GetCurrentDocument();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Document(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Document(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetCurrentView)
@@ -321,10 +338,11 @@ Gura_DeclareMethod(wx_DocManager, GetCurrentView)
 
 Gura_ImplementMethod(wx_DocManager, GetCurrentView)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxView *rtn = (wxView *)pThis->GetEntity()->GetCurrentView();
-	return ReturnValue(env, sig, args, Value(new Object_wx_View(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_View(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetDocuments)
@@ -335,10 +353,11 @@ Gura_DeclareMethod(wx_DocManager, GetDocuments)
 
 Gura_ImplementMethod(wx_DocManager, GetDocuments)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxList &rtn = pThis->GetEntity()->GetDocuments();
-	return ReturnValue(env, sig, args, Value(new Object_wx_List(new wxList(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_List(new wxList(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetFileHistory)
@@ -349,10 +368,11 @@ Gura_DeclareMethod(wx_DocManager, GetFileHistory)
 
 Gura_ImplementMethod(wx_DocManager, GetFileHistory)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFileHistory *rtn = (wxFileHistory *)pThis->GetEntity()->GetFileHistory();
-	return ReturnValue(env, sig, args, Value(new Object_wx_FileHistory(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_FileHistory(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetLastDirectory)
@@ -363,10 +383,11 @@ Gura_DeclareMethod(wx_DocManager, GetLastDirectory)
 
 Gura_ImplementMethod(wx_DocManager, GetLastDirectory)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetLastDirectory();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetMaxDocsOpen)
@@ -377,10 +398,11 @@ Gura_DeclareMethod(wx_DocManager, GetMaxDocsOpen)
 
 Gura_ImplementMethod(wx_DocManager, GetMaxDocsOpen)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMaxDocsOpen();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetHistoryFilesCount)
@@ -391,10 +413,11 @@ Gura_DeclareMethod(wx_DocManager, GetHistoryFilesCount)
 
 Gura_ImplementMethod(wx_DocManager, GetHistoryFilesCount)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetHistoryFilesCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DocManager, GetTemplates)
@@ -405,10 +428,11 @@ Gura_DeclareMethod(wx_DocManager, GetTemplates)
 
 Gura_ImplementMethod(wx_DocManager, GetTemplates)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxList &rtn = pThis->GetEntity()->GetTemplates();
-	return ReturnValue(env, sig, args, Value(new Object_wx_List(new wxList(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_List(new wxList(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_DocManager, Initialize)
@@ -419,10 +443,11 @@ Gura_DeclareMethod(wx_DocManager, Initialize)
 
 Gura_ImplementMethod(wx_DocManager, Initialize)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Initialize();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DocManager, MakeDefaultName)
@@ -434,11 +459,16 @@ Gura_DeclareMethod(wx_DocManager, MakeDefaultName)
 
 Gura_ImplementMethod(wx_DocManager, MakeDefaultName)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString buf = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString buf = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->MakeDefaultName(buf);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, MakeNewDocumentName)
@@ -449,10 +479,11 @@ Gura_DeclareMethod(wx_DocManager, MakeNewDocumentName)
 
 Gura_ImplementMethod(wx_DocManager, MakeNewDocumentName)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->MakeNewDocumentName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_DocManager, OnCreateFileHistory)
@@ -463,10 +494,11 @@ Gura_DeclareMethod(wx_DocManager, OnCreateFileHistory)
 
 Gura_ImplementMethod(wx_DocManager, OnCreateFileHistory)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFileHistory *rtn = (wxFileHistory *)pThis->GetEntity()->OnCreateFileHistory();
-	return ReturnValue(env, sig, args, Value(new Object_wx_FileHistory(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_FileHistory(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileClose)
@@ -477,11 +509,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileClose)
 
 Gura_ImplementMethod(wx_DocManager, OnFileClose)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileClose(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileCloseAll)
@@ -492,11 +525,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileCloseAll)
 
 Gura_ImplementMethod(wx_DocManager, OnFileCloseAll)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileCloseAll(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileNew)
@@ -507,11 +541,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileNew)
 
 Gura_ImplementMethod(wx_DocManager, OnFileNew)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileNew(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileOpen)
@@ -522,11 +557,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileOpen)
 
 Gura_ImplementMethod(wx_DocManager, OnFileOpen)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileOpen(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileRevert)
@@ -537,11 +573,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileRevert)
 
 Gura_ImplementMethod(wx_DocManager, OnFileRevert)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileRevert(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileSave)
@@ -552,11 +589,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileSave)
 
 Gura_ImplementMethod(wx_DocManager, OnFileSave)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileSave(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, OnFileSaveAs)
@@ -567,11 +605,12 @@ Gura_DeclareMethod(wx_DocManager, OnFileSaveAs)
 
 Gura_ImplementMethod(wx_DocManager, OnFileSaveAs)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandEvent *event = Object_wx_CommandEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnFileSaveAs(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, RemoveDocument)
@@ -582,11 +621,12 @@ Gura_DeclareMethod(wx_DocManager, RemoveDocument)
 
 Gura_ImplementMethod(wx_DocManager, RemoveDocument)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocument *doc = Object_wx_Document::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocument *doc = Object_wx_Document::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->RemoveDocument(doc);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, SelectDocumentPath)
@@ -604,19 +644,20 @@ Gura_DeclareMethod(wx_DocManager, SelectDocumentPath)
 
 Gura_ImplementMethod(wx_DocManager, SelectDocumentPath)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocTemplate *templates = Object_wx_DocTemplate::GetObject(args, 0)->GetEntity();
-	int noTemplates = args.GetInt(1);
-	wxString path = wxString::FromUTF8(args.GetString(2));
-	long flags = args.GetLong(3);
-	bool save = args.GetBoolean(4);
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocTemplate *templates = Object_wx_DocTemplate::GetObject(arg, 0)->GetEntity();
+	int noTemplates = arg.GetInt(1);
+	wxString path = wxString::FromUTF8(arg.GetString(2));
+	long flags = arg.GetLong(3);
+	bool save = arg.GetBoolean(4);
 	wxDocTemplate *rtn = (wxDocTemplate *)pThis->GetEntity()->SelectDocumentPath(*templates, noTemplates, path, flags, save);
-	return ReturnValue(env, sig, args, Value(new Object_wx_DocTemplate(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DocTemplate(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, SelectDocumentType)
@@ -632,18 +673,19 @@ Gura_DeclareMethod(wx_DocManager, SelectDocumentType)
 
 Gura_ImplementMethod(wx_DocManager, SelectDocumentType)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocTemplate *templates = Object_wx_DocTemplate::GetObject(args, 0)->GetEntity();
-	int noTemplates = args.GetInt(1);
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocTemplate *templates = Object_wx_DocTemplate::GetObject(arg, 0)->GetEntity();
+	int noTemplates = arg.GetInt(1);
 	bool sort = false;
-	if (args.IsValid(2)) sort = args.GetBoolean(2);
+	if (arg.IsValid(2)) sort = arg.GetBoolean(2);
 	wxDocTemplate *rtn = (wxDocTemplate *)pThis->GetEntity()->SelectDocumentType(*templates, noTemplates, sort);
-	return ReturnValue(env, sig, args, Value(new Object_wx_DocTemplate(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DocTemplate(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, SelectViewType)
@@ -659,18 +701,19 @@ Gura_DeclareMethod(wx_DocManager, SelectViewType)
 
 Gura_ImplementMethod(wx_DocManager, SelectViewType)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocTemplate *templates = Object_wx_DocTemplate::GetObject(args, 0)->GetEntity();
-	int noTemplates = args.GetInt(1);
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocTemplate *templates = Object_wx_DocTemplate::GetObject(arg, 0)->GetEntity();
+	int noTemplates = arg.GetInt(1);
 	bool sort = false;
-	if (args.IsValid(2)) sort = args.GetBoolean(2);
+	if (arg.IsValid(2)) sort = arg.GetBoolean(2);
 	wxDocTemplate *rtn = (wxDocTemplate *)pThis->GetEntity()->SelectViewType(*templates, noTemplates, sort);
-	return ReturnValue(env, sig, args, Value(new Object_wx_DocTemplate(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DocTemplate(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, SetLastDirectory)
@@ -681,11 +724,12 @@ Gura_DeclareMethod(wx_DocManager, SetLastDirectory)
 
 Gura_ImplementMethod(wx_DocManager, SetLastDirectory)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString dir = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString dir = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetLastDirectory(dir);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DocManager, SetMaxDocsOpen)
@@ -696,11 +740,12 @@ Gura_DeclareMethod(wx_DocManager, SetMaxDocsOpen)
 
 Gura_ImplementMethod(wx_DocManager, SetMaxDocsOpen)
 {
-	Object_wx_DocManager *pThis = Object_wx_DocManager::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_DocManager *pThis = Object_wx_DocManager::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->SetMaxDocsOpen(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -712,13 +757,13 @@ Object_wx_DocManager::~Object_wx_DocManager()
 
 Object *Object_wx_DocManager::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_DocManager::ToString(bool exprFlag)
 {
 	String rtn("<wx.DocManager:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -778,7 +823,7 @@ Gura_ImplementUserInheritableClass(wx_DocManager)
 
 Gura_ImplementDescendantCreator(wx_DocManager)
 {
-	return new Object_wx_DocManager((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_DocManager((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
