@@ -34,10 +34,10 @@ Gura_DeclarePrivUserSymbol(SetCommandProcessor);
 //----------------------------------------------------------------------------
 class wx_Document: public wxDocument, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Document *_pObj;
 public:
-	inline wx_Document() : wxDocument(), _sig(NULL), _pObj(NULL) {}
+	inline wx_Document() : wxDocument(), _pObj(nullptr) {}
 	//virtual bool AddView(wxView * view);
 	//virtual bool Close();
 	//virtual bool DeleteAllViews();
@@ -61,8 +61,8 @@ public:
 	//virtual wxOutputStream& SaveObject(wxOutputStream& stream);
 	//virtual void SetCommandProcessor(wxCommandProcessor * processor);
 	~wx_Document();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Document *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Document *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -70,12 +70,12 @@ public:
 
 wx_Document::~wx_Document()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Document::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -90,17 +90,18 @@ Gura_DeclareFunction(DocumentEmpty)
 
 Gura_ImplementFunction(DocumentEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Document *pEntity = new wx_Document();
-	Object_wx_Document *pObj = Object_wx_Document::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Document *pObj = Object_wx_Document::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Document(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Document, AddView)
@@ -112,11 +113,12 @@ Gura_DeclareMethod(wx_Document, AddView)
 
 Gura_ImplementMethod(wx_Document, AddView)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxView *view = Object_wx_View::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxView *view = Object_wx_View::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddView(view);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, Close)
@@ -127,10 +129,11 @@ Gura_DeclareMethod(wx_Document, Close)
 
 Gura_ImplementMethod(wx_Document, Close)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Close();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, DeleteAllViews)
@@ -141,10 +144,11 @@ Gura_DeclareMethod(wx_Document, DeleteAllViews)
 
 Gura_ImplementMethod(wx_Document, DeleteAllViews)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DeleteAllViews();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, GetCommandProcessor)
@@ -155,10 +159,11 @@ Gura_DeclareMethod(wx_Document, GetCommandProcessor)
 
 Gura_ImplementMethod(wx_Document, GetCommandProcessor)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxCommandProcessor *rtn = (wxCommandProcessor *)pThis->GetEntity()->GetCommandProcessor();
-	return ReturnValue(env, sig, args, Value(new Object_wx_CommandProcessor(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_CommandProcessor(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Document, GetDocumentTemplate)
@@ -169,10 +174,11 @@ Gura_DeclareMethod(wx_Document, GetDocumentTemplate)
 
 Gura_ImplementMethod(wx_Document, GetDocumentTemplate)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDocTemplate *rtn = (wxDocTemplate *)pThis->GetEntity()->GetDocumentTemplate();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DocTemplate(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DocTemplate(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Document, GetDocumentManager)
@@ -183,10 +189,11 @@ Gura_DeclareMethod(wx_Document, GetDocumentManager)
 
 Gura_ImplementMethod(wx_Document, GetDocumentManager)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDocManager *rtn = (wxDocManager *)pThis->GetEntity()->GetDocumentManager();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DocManager(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DocManager(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Document, GetDocumentName)
@@ -197,10 +204,11 @@ Gura_DeclareMethod(wx_Document, GetDocumentName)
 
 Gura_ImplementMethod(wx_Document, GetDocumentName)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetDocumentName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Document, GetDocumentWindow)
@@ -211,10 +219,11 @@ Gura_DeclareMethod(wx_Document, GetDocumentWindow)
 
 Gura_ImplementMethod(wx_Document, GetDocumentWindow)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetDocumentWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Document, GetFilename)
@@ -225,10 +234,11 @@ Gura_DeclareMethod(wx_Document, GetFilename)
 
 Gura_ImplementMethod(wx_Document, GetFilename)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetFilename();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Document, GetFirstView)
@@ -239,10 +249,11 @@ Gura_DeclareMethod(wx_Document, GetFirstView)
 
 Gura_ImplementMethod(wx_Document, GetFirstView)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxView *rtn = (wxView *)pThis->GetEntity()->GetFirstView();
-	return ReturnValue(env, sig, args, Value(new Object_wx_View(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_View(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Document, GetPrintableName)
@@ -253,11 +264,16 @@ Gura_DeclareMethod(wx_Document, GetPrintableName)
 
 Gura_ImplementMethod(wx_Document, GetPrintableName)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->GetPrintableName(name);
-	return Value::Null;
+	return Value::Nil;
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, GetTitle)
@@ -268,10 +284,11 @@ Gura_DeclareMethod(wx_Document, GetTitle)
 
 Gura_ImplementMethod(wx_Document, GetTitle)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetTitle();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Document, GetViews)
@@ -282,10 +299,11 @@ Gura_DeclareMethod(wx_Document, GetViews)
 
 Gura_ImplementMethod(wx_Document, GetViews)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxList &rtn = pThis->GetEntity()->GetViews();
-	return ReturnValue(env, sig, args, Value(new Object_wx_List(new wxList(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_List(new wxList(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Document, IsModified)
@@ -296,10 +314,11 @@ Gura_DeclareMethod(wx_Document, IsModified)
 
 Gura_ImplementMethod(wx_Document, IsModified)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsModified();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, LoadObject)
@@ -310,8 +329,9 @@ Gura_DeclareMethod(wx_Document, LoadObject)
 
 Gura_ImplementMethod(wx_Document, LoadObject)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, LoadObject_1)
@@ -325,15 +345,16 @@ Gura_DeclareMethod(wx_Document, LoadObject_1)
 
 Gura_ImplementMethod(wx_Document, LoadObject_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxInputStream *stream = Object_wx_InputStream::GetObject(args, 0)->GetEntity();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxInputStream *stream = Object_wx_InputStream::GetObject(arg, 0)->GetEntity();
 	wxInputStream &rtn = pThis->GetEntity()->LoadObject(*stream);
-	return ReturnValue(env, sig, args, Value(new Object_wx_InputStream(new wxInputStream(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_InputStream(new wxInputStream(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, Modify)
@@ -344,11 +365,12 @@ Gura_DeclareMethod(wx_Document, Modify)
 
 Gura_ImplementMethod(wx_Document, Modify)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool modify = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool modify = arg.GetBoolean(0);
 	pThis->GetEntity()->Modify(modify);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, OnChangedViewList)
@@ -358,10 +380,11 @@ Gura_DeclareMethod(wx_Document, OnChangedViewList)
 
 Gura_ImplementMethod(wx_Document, OnChangedViewList)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnChangedViewList();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, OnCloseDocument)
@@ -372,10 +395,11 @@ Gura_DeclareMethod(wx_Document, OnCloseDocument)
 
 Gura_ImplementMethod(wx_Document, OnCloseDocument)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->OnCloseDocument();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, OnCreate)
@@ -388,12 +412,13 @@ Gura_DeclareMethod(wx_Document, OnCreate)
 
 Gura_ImplementMethod(wx_Document, OnCreate)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString path = wxString::FromUTF8(args.GetString(0));
-	long flags = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString path = wxString::FromUTF8(arg.GetString(0));
+	long flags = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->OnCreate(path, flags);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, OnCreateCommandProcessor)
@@ -404,10 +429,11 @@ Gura_DeclareMethod(wx_Document, OnCreateCommandProcessor)
 
 Gura_ImplementMethod(wx_Document, OnCreateCommandProcessor)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxCommandProcessor *rtn = (wxCommandProcessor *)pThis->GetEntity()->OnCreateCommandProcessor();
-	return ReturnValue(env, sig, args, Value(new Object_wx_CommandProcessor(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_CommandProcessor(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Document, OnNewDocument)
@@ -418,10 +444,11 @@ Gura_DeclareMethod(wx_Document, OnNewDocument)
 
 Gura_ImplementMethod(wx_Document, OnNewDocument)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->OnNewDocument();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, OnOpenDocument)
@@ -433,11 +460,12 @@ Gura_DeclareMethod(wx_Document, OnOpenDocument)
 
 Gura_ImplementMethod(wx_Document, OnOpenDocument)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString filename = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString filename = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->OnOpenDocument(filename);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, OnSaveDocument)
@@ -449,11 +477,12 @@ Gura_DeclareMethod(wx_Document, OnSaveDocument)
 
 Gura_ImplementMethod(wx_Document, OnSaveDocument)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString filename = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString filename = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->OnSaveDocument(filename);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, OnSaveModified)
@@ -464,10 +493,11 @@ Gura_DeclareMethod(wx_Document, OnSaveModified)
 
 Gura_ImplementMethod(wx_Document, OnSaveModified)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->OnSaveModified();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, RemoveView)
@@ -479,11 +509,12 @@ Gura_DeclareMethod(wx_Document, RemoveView)
 
 Gura_ImplementMethod(wx_Document, RemoveView)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxView *view = Object_wx_View::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxView *view = Object_wx_View::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->RemoveView(view);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, Save)
@@ -494,10 +525,11 @@ Gura_DeclareMethod(wx_Document, Save)
 
 Gura_ImplementMethod(wx_Document, Save)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Save();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, SaveAs)
@@ -508,10 +540,11 @@ Gura_DeclareMethod(wx_Document, SaveAs)
 
 Gura_ImplementMethod(wx_Document, SaveAs)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->SaveAs();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Document, SaveObject)
@@ -525,15 +558,16 @@ Gura_DeclareMethod(wx_Document, SaveObject)
 
 Gura_ImplementMethod(wx_Document, SaveObject)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	Stream & stream = args.GetStream(0);
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	Stream & stream = arg.GetStream(0);
 	Stream & rtn = pThis->GetEntity()->SaveObject(stream);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, SaveObject_1)
@@ -547,15 +581,16 @@ Gura_DeclareMethod(wx_Document, SaveObject_1)
 
 Gura_ImplementMethod(wx_Document, SaveObject_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxOutputStream *stream = Object_wx_OutputStream::GetObject(args, 0)->GetEntity();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxOutputStream *stream = Object_wx_OutputStream::GetObject(arg, 0)->GetEntity();
 	wxOutputStream &rtn = pThis->GetEntity()->SaveObject(*stream);
-	return ReturnValue(env, sig, args, Value(new Object_wx_OutputStream(new wxOutputStream(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_OutputStream(new wxOutputStream(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, SetCommandProcessor)
@@ -566,11 +601,12 @@ Gura_DeclareMethod(wx_Document, SetCommandProcessor)
 
 Gura_ImplementMethod(wx_Document, SetCommandProcessor)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCommandProcessor *processor = Object_wx_CommandProcessor::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCommandProcessor *processor = Object_wx_CommandProcessor::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetCommandProcessor(processor);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, SetDocumentName)
@@ -581,11 +617,12 @@ Gura_DeclareMethod(wx_Document, SetDocumentName)
 
 Gura_ImplementMethod(wx_Document, SetDocumentName)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetDocumentName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, SetDocumentTemplate)
@@ -596,11 +633,12 @@ Gura_DeclareMethod(wx_Document, SetDocumentTemplate)
 
 Gura_ImplementMethod(wx_Document, SetDocumentTemplate)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDocTemplate *templ = Object_wx_DocTemplate::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDocTemplate *templ = Object_wx_DocTemplate::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetDocumentTemplate(templ);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, SetFilename)
@@ -612,13 +650,14 @@ Gura_DeclareMethod(wx_Document, SetFilename)
 
 Gura_ImplementMethod(wx_Document, SetFilename)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString filename = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString filename = wxString::FromUTF8(arg.GetString(0));
 	bool notifyViews = false;
-	if (args.IsValid(1)) notifyViews = args.GetBoolean(1);
+	if (arg.IsValid(1)) notifyViews = arg.GetBoolean(1);
 	pThis->GetEntity()->SetFilename(filename, notifyViews);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, SetTitle)
@@ -629,11 +668,12 @@ Gura_DeclareMethod(wx_Document, SetTitle)
 
 Gura_ImplementMethod(wx_Document, SetTitle)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetTitle(title);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Document, UpdateAllViews)
@@ -645,14 +685,15 @@ Gura_DeclareMethod(wx_Document, UpdateAllViews)
 
 Gura_ImplementMethod(wx_Document, UpdateAllViews)
 {
-	Object_wx_Document *pThis = Object_wx_Document::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxView *sender = (wxView *)(NULL);
-	if (args.IsValid(0)) sender = Object_wx_View::GetObject(args, 0)->GetEntity();
-	wxObject *hint = (wxObject *)(NULL);
-	if (args.IsValid(1)) hint = Object_wx_Object::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Document *pThis = Object_wx_Document::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxView *sender = (wxView *)(nullptr);
+	if (arg.IsValid(0)) sender = Object_wx_View::GetObject(arg, 0)->GetEntity();
+	wxObject *hint = (wxObject *)(nullptr);
+	if (arg.IsValid(1)) hint = Object_wx_Object::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->UpdateAllViews(sender, hint);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -664,13 +705,13 @@ Object_wx_Document::~Object_wx_Document()
 
 Object *Object_wx_Document::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Document::ToString(bool exprFlag)
 {
 	String rtn("<wx.Document:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -748,7 +789,7 @@ Gura_ImplementUserInheritableClass(wx_Document)
 
 Gura_ImplementDescendantCreator(wx_Document)
 {
-	return new Object_wx_Document((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Document((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
