@@ -14,21 +14,21 @@ Gura_DeclarePrivUserSymbol(GetImageRect);
 //----------------------------------------------------------------------------
 class wx_DragImage: public wxDragImage, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_DragImage *_pObj;
 public:
-	inline wx_DragImage() : wxDragImage(), _sig(NULL), _pObj(NULL) {}
-	//inline wx_DragImage(const wxBitmap& image, const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(image, cursor, cursorHotspot), _sig(NULL), _pObj(NULL) {}
-	//inline wx_DragImage(const wxIcon& image, const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(image, cursor, cursorHotspot), _sig(NULL), _pObj(NULL) {}
-	//inline wx_DragImage(const wxString& text, const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(text, cursor, cursorHotspot), _sig(NULL), _pObj(NULL) {}
-	//inline wx_DragImage(const wxTreeCtrl& treeCtrl, wxTreeItemId& id) : wxDragImage(treeCtrl, id), _sig(NULL), _pObj(NULL) {}
-	//inline wx_DragImage(const wxListCtrl& treeCtrl, long id) : wxDragImage(treeCtrl, id), _sig(NULL), _pObj(NULL) {}
-	//inline wx_DragImage(const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(cursor, cursorHotspot), _sig(NULL), _pObj(NULL) {}
+	inline wx_DragImage() : wxDragImage(), _pObj(nullptr) {}
+	//inline wx_DragImage(const wxBitmap& image, const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(image, cursor, cursorHotspot), _pObj(nullptr) {}
+	//inline wx_DragImage(const wxIcon& image, const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(image, cursor, cursorHotspot), _pObj(nullptr) {}
+	//inline wx_DragImage(const wxString& text, const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(text, cursor, cursorHotspot), _pObj(nullptr) {}
+	//inline wx_DragImage(const wxTreeCtrl& treeCtrl, wxTreeItemId& id) : wxDragImage(treeCtrl, id), _pObj(nullptr) {}
+	//inline wx_DragImage(const wxListCtrl& treeCtrl, long id) : wxDragImage(treeCtrl, id), _pObj(nullptr) {}
+	//inline wx_DragImage(const wxCursor& cursor, const wxPoint& cursorHotspot) : wxDragImage(cursor, cursorHotspot), _pObj(nullptr) {}
 	//virtual bool DoDrawImage(wxDC& dc, const wxPoint& pos);
 	//virtual wxRect GetImageRect(const wxPoint& pos);
 	~wx_DragImage();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_DragImage *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_DragImage *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -36,12 +36,12 @@ public:
 
 wx_DragImage::~wx_DragImage()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_DragImage::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -56,17 +56,18 @@ Gura_DeclareFunction(DragImageEmpty)
 
 Gura_ImplementFunction(DragImageEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_DragImage *pEntity = new wx_DragImage();
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 #if 0
@@ -82,22 +83,23 @@ Gura_DeclareFunction(DragImage)
 
 Gura_ImplementFunction(DragImage)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxBitmap *image = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxBitmap *image = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
 	wxCursor *cursor = (wxCursor *)(&wxNullCursor);
-	if (args.IsValid(1)) cursor = Object_wx_Cursor::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) cursor = Object_wx_Cursor::GetObject(arg, 1)->GetEntity();
 	wxPoint cursorHotspot = wxPoint(0, 0);
-	if (args.IsValid(2)) cursorHotspot = *Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) cursorHotspot = *Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wx_DragImage *pEntity = new wx_DragImage(*image, *cursor, cursorHotspot);
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(DragImage_1)
@@ -112,22 +114,23 @@ Gura_DeclareFunction(DragImage_1)
 
 Gura_ImplementFunction(DragImage_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxIcon *image = Object_wx_Icon::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxIcon *image = Object_wx_Icon::GetObject(arg, 0)->GetEntity();
 	wxCursor *cursor = (wxCursor *)(&wxNullCursor);
-	if (args.IsValid(1)) cursor = Object_wx_Cursor::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) cursor = Object_wx_Cursor::GetObject(arg, 1)->GetEntity();
 	wxPoint cursorHotspot = wxPoint(0, 0);
-	if (args.IsValid(2)) cursorHotspot = *Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) cursorHotspot = *Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wx_DragImage *pEntity = new wx_DragImage(*image, *cursor, cursorHotspot);
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(DragImage_2)
@@ -142,22 +145,23 @@ Gura_DeclareFunction(DragImage_2)
 
 Gura_ImplementFunction(DragImage_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxCursor *cursor = (wxCursor *)(&wxNullCursor);
-	if (args.IsValid(1)) cursor = Object_wx_Cursor::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) cursor = Object_wx_Cursor::GetObject(arg, 1)->GetEntity();
 	wxPoint cursorHotspot = wxPoint(0, 0);
-	if (args.IsValid(2)) cursorHotspot = *Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) cursorHotspot = *Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wx_DragImage *pEntity = new wx_DragImage(text, *cursor, cursorHotspot);
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(DragImage_3)
@@ -171,19 +175,20 @@ Gura_DeclareFunction(DragImage_3)
 
 Gura_ImplementFunction(DragImage_3)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxTreeCtrl *treeCtrl = Object_wx_TreeCtrl::GetObject(args, 0)->GetEntity();
-	wxTreeItemId *id = Object_wx_TreeItemId::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxTreeCtrl *treeCtrl = Object_wx_TreeCtrl::GetObject(arg, 0)->GetEntity();
+	wxTreeItemId *id = Object_wx_TreeItemId::GetObject(arg, 1)->GetEntity();
 	wx_DragImage *pEntity = new wx_DragImage(*treeCtrl, *id);
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(DragImage_4)
@@ -197,19 +202,20 @@ Gura_DeclareFunction(DragImage_4)
 
 Gura_ImplementFunction(DragImage_4)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxListCtrl *treeCtrl = Object_wx_ListCtrl::GetObject(args, 0)->GetEntity();
-	long id = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxListCtrl *treeCtrl = Object_wx_ListCtrl::GetObject(arg, 0)->GetEntity();
+	long id = arg.GetLong(1);
 	wx_DragImage *pEntity = new wx_DragImage(*treeCtrl, id);
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(DragImage_5)
@@ -225,25 +231,26 @@ Gura_DeclareFunction(DragImage_5)
 
 Gura_ImplementFunction(DragImage_5)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxCursor *cursor = (wxCursor *)(&wxNullCursor);
-	if (args.IsValid(0)) cursor = Object_wx_Cursor::GetObject(args, 0)->GetEntity();
+	if (arg.IsValid(0)) cursor = Object_wx_Cursor::GetObject(arg, 0)->GetEntity();
 	wxPoint *cursorHotspot = (wxPoint *)(&wxPoint(0, 0));
-	if (args.IsValid(1)) cursorHotspot = Object_wx_Point::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) cursorHotspot = Object_wx_Point::GetObject(arg, 1)->GetEntity();
 	wx_DragImage *pEntity = new wx_DragImage(*cursor, *cursorHotspot);
-	Object_wx_DragImage *pObj = Object_wx_DragImage::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_DragImage *pObj = Object_wx_DragImage::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_DragImage(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 #endif
 
@@ -259,16 +266,17 @@ Gura_DeclareMethod(wx_DragImage, BeginDrag)
 
 Gura_ImplementMethod(wx_DragImage, BeginDrag)
 {
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *hotspot = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxWindow *window = Object_wx_Window::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *hotspot = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxWindow *window = Object_wx_Window::GetObject(arg, 1)->GetEntity();
 	bool fullScreen = false;
-	if (args.IsValid(2)) fullScreen = args.GetBoolean(2);
-	wxRect *rect = (wxRect *)(NULL);
-	if (args.IsValid(3)) rect = Object_wx_Rect::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(2)) fullScreen = arg.GetBoolean(2);
+	wxRect *rect = (wxRect *)(nullptr);
+	if (arg.IsValid(3)) rect = Object_wx_Rect::GetObject(arg, 3)->GetEntity();
 	bool rtn = pThis->GetEntity()->BeginDrag(*hotspot, window, fullScreen, rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DragImage, BeginDrag_1)
@@ -282,13 +290,14 @@ Gura_DeclareMethod(wx_DragImage, BeginDrag_1)
 
 Gura_ImplementMethod(wx_DragImage, BeginDrag_1)
 {
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *hotspot = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxWindow *window = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxWindow *boundingWindow = Object_wx_Window::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *hotspot = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxWindow *window = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxWindow *boundingWindow = Object_wx_Window::GetObject(arg, 2)->GetEntity();
 	bool rtn = pThis->GetEntity()->BeginDrag(*hotspot, window, boundingWindow);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DragImage, DoDrawImage)
@@ -303,16 +312,17 @@ Gura_DeclareMethod(wx_DragImage, DoDrawImage)
 
 Gura_ImplementMethod(wx_DragImage, DoDrawImage)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC *dc = Object_wx_DC::GetObject(args, 0)->GetEntity();
-	wxPoint *pos = Object_wx_Point::GetObject(args, 1)->GetEntity();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC *dc = Object_wx_DC::GetObject(arg, 0)->GetEntity();
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->DoDrawImage(*dc, *pos);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DragImage, EndDrag)
@@ -323,10 +333,11 @@ Gura_DeclareMethod(wx_DragImage, EndDrag)
 
 Gura_ImplementMethod(wx_DragImage, EndDrag)
 {
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->EndDrag();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DragImage, GetImageRect)
@@ -340,15 +351,16 @@ Gura_DeclareMethod(wx_DragImage, GetImageRect)
 
 Gura_ImplementMethod(wx_DragImage, GetImageRect)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pos = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	wxRect rtn = pThis->GetEntity()->GetImageRect(*pos);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_DragImage, Hide)
@@ -359,10 +371,11 @@ Gura_DeclareMethod(wx_DragImage, Hide)
 
 Gura_ImplementMethod(wx_DragImage, Hide)
 {
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Hide();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DragImage, Move)
@@ -374,11 +387,12 @@ Gura_DeclareMethod(wx_DragImage, Move)
 
 Gura_ImplementMethod(wx_DragImage, Move)
 {
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Move(*pt);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DragImage, Show)
@@ -389,10 +403,11 @@ Gura_DeclareMethod(wx_DragImage, Show)
 
 Gura_ImplementMethod(wx_DragImage, Show)
 {
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Show();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_DragImage, UpdateBackingFromWindow)
@@ -409,18 +424,19 @@ Gura_DeclareMethod(wx_DragImage, UpdateBackingFromWindow)
 
 Gura_ImplementMethod(wx_DragImage, UpdateBackingFromWindow)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_DragImage *pThis = Object_wx_DragImage::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC *windowDC = Object_wx_DC::GetObject(args, 0)->GetEntity();
-	wxMemoryDC *destDC = Object_wx_MemoryDC::GetObject(args, 1)->GetEntity();
-	wxRect *sourceRect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
-	wxRect *destRect = Object_wx_Rect::GetObject(args, 3)->GetEntity();
+	Object_wx_DragImage *pThis = Object_wx_DragImage::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC *windowDC = Object_wx_DC::GetObject(arg, 0)->GetEntity();
+	wxMemoryDC *destDC = Object_wx_MemoryDC::GetObject(arg, 1)->GetEntity();
+	wxRect *sourceRect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
+	wxRect *destRect = Object_wx_Rect::GetObject(arg, 3)->GetEntity();
 	bool rtn = pThis->GetEntity()->UpdateBackingFromWindow(*windowDC, *destDC, *sourceRect, *destRect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -432,13 +448,13 @@ Object_wx_DragImage::~Object_wx_DragImage()
 
 Object *Object_wx_DragImage::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_DragImage::ToString(bool exprFlag)
 {
 	String rtn("<wx.DragImage:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -475,7 +491,7 @@ Gura_ImplementUserInheritableClass(wx_DragImage)
 
 Gura_ImplementDescendantCreator(wx_DragImage)
 {
-	return new Object_wx_DragImage((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_DragImage((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
