@@ -14,15 +14,15 @@ Gura_DeclarePrivUserSymbol(SearchEventTable);
 //----------------------------------------------------------------------------
 class wx_EvtHandler: public wxEvtHandler, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_EvtHandler *_pObj;
 public:
-	inline wx_EvtHandler() : wxEvtHandler(), _sig(NULL), _pObj(NULL) {}
+	inline wx_EvtHandler() : wxEvtHandler(), _pObj(nullptr) {}
 	//virtual bool ProcessEvent(wxEvent& event);
 	//virtual bool SearchEventTable(wxEventTable& table, wxEvent& event);
 	~wx_EvtHandler();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_EvtHandler *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_EvtHandler *pObj) {
+		_pObj = pObj;
 	}
 	void ObjectEventFunction(wxEvent &event);
 	// virtual function of GuraObjectObserver
@@ -31,12 +31,12 @@ public:
 
 wx_EvtHandler::~wx_EvtHandler()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_EvtHandler::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 void wx_EvtHandler::ObjectEventFunction(wxEvent &event)
@@ -49,7 +49,7 @@ void wx_EvtHandler::ObjectEventFunction(wxEvent &event)
 	if (sig.IsSignalled()) {
 		SetLogError(sig);
 		wxWindow *window = wxDynamicCast(wxApp::GetInstance(), wxApp)->GetTopWindow();
-		if (window != NULL) window->Close(true);
+		if (window != nullptr) window->Close(true);
 		wxDynamicCast(wxApp::GetInstance(), wxApp)->ExitMainLoop();
 	}
 }
@@ -66,17 +66,18 @@ Gura_DeclareFunction(EvtHandler)
 
 Gura_ImplementFunction(EvtHandler)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_EvtHandler *pEntity = new wx_EvtHandler();
-	Object_wx_EvtHandler *pObj = Object_wx_EvtHandler::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_EvtHandler *pObj = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_EvtHandler(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_EvtHandler, AddPendingEvent)
@@ -87,11 +88,12 @@ Gura_DeclareMethod(wx_EvtHandler, AddPendingEvent)
 
 Gura_ImplementMethod(wx_EvtHandler, AddPendingEvent)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvent *event = Object_wx_Event::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvent *event = Object_wx_Event::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddPendingEvent(*event);
-	return Value::Null;
+	return Value::Nil;
 }
 
 // wx.EvtHandler#Bind(eventType:wx.EventType, id?:number, lastId?:number):void {block:func_scope}
@@ -101,23 +103,24 @@ Gura_DeclareMethod(wx_EvtHandler, Bind)
 	DeclareArg(env, "eventType", VTYPE_wx_EventFactory);
 	DeclareArg(env, "id", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "lastId", VTYPE_number, OCCUR_ZeroOrOnce);
-	DeclareBlock(OCCUR_Once, NULL, Function::BLKSCOPE_SameAsFunc);
+	DeclareBlock(OCCUR_Once, nullptr, Function::BLKSCOPE_SameAsFunc);
 }
 
 Gura_ImplementMethod(wx_EvtHandler, Bind)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	Object_wx_EventFactory *pObjEventFactory =
-							Object_wx_EventFactory::GetObject(args, 0);
-	int id = args.IsValid(1)? args.GetInt(1) : wxID_ANY;
-	int lastId = args.IsValid(2)? args.GetInt(2) : wxID_ANY;
+							Object_wx_EventFactory::GetObject(arg, 0);
+	int id = arg.IsValid(1)? arg.GetInt(1) : wxID_ANY;
+	int lastId = arg.IsValid(2)? arg.GetInt(2) : wxID_ANY;
 	wxEvtHandler *pEvtHandler = wxDynamicCast(pThis->GetEntity(), wxEvtHandler);
-	const Function *pFunc = args.GetBlockFunc(env, sig, GetSymbolForBlock());
+	const Function *pFunc = arg.GetBlockFunc(env, GetSymbolForBlock());
 	Object_function *pObjFunc = new Object_function(env, Function::Reference(pFunc));
 	pObjEventFactory->Connect(env, sig, pEvtHandler, id, lastId,
-			wxEventHandler(wx_EvtHandler::ObjectEventFunction), pObjFunc, NULL);
-	return Value::Null;
+			wxEventHandler(wx_EvtHandler::ObjectEventFunction), pObjFunc, nullptr);
+	return Value::Nil;
 }
 
 // wx.EvtHandler#Connect(eventType:wx.EventType, func:function, id?:number, lastId?:number):void:map
@@ -132,17 +135,18 @@ Gura_DeclareMethod(wx_EvtHandler, Connect)
 
 Gura_ImplementMethod(wx_EvtHandler, Connect)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	Object_wx_EventFactory *pObjEventFactory =
-							Object_wx_EventFactory::GetObject(args, 0);
-	Object_function *pObjFunc = Object_function::GetObject(args, 1);
-	int id = args.IsValid(2)? args.GetInt(1) : wxID_ANY;
-	int lastId = args.IsValid(3)? args.GetInt(2) : wxID_ANY;
+							Object_wx_EventFactory::GetObject(arg, 0);
+	Object_function *pObjFunc = Object_function::GetObject(arg, 1);
+	int id = arg.IsValid(2)? arg.GetInt(1) : wxID_ANY;
+	int lastId = arg.IsValid(3)? arg.GetInt(2) : wxID_ANY;
 	wxEvtHandler *pEvtHandler = wxDynamicCast(pThis->GetEntity(), wxEvtHandler);
 	pObjEventFactory->Connect(env, sig, pEvtHandler, id, lastId,
-			wxEventHandler(wx_EvtHandler::ObjectEventFunction), pObjFunc, NULL);
-	return Value::Null;
+			wxEventHandler(wx_EvtHandler::ObjectEventFunction), pObjFunc, nullptr);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, Disconnect)
@@ -159,22 +163,23 @@ Gura_DeclareMethod(wx_EvtHandler, Disconnect)
 
 Gura_ImplementMethod(wx_EvtHandler, Disconnect)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxEventType eventType = wxEVT_NULL;
-	if (args.IsValid(0)) eventType = static_cast<wxEventType>(args.GetInt(0));
-	wxObjectEventFunction *function = (wxObjectEventFunction *)(&NULL);
-	if (args.IsValid(1)) function = Object_wx_ObjectEventFunction::GetObject(args, 1)->GetEntity();
-	wxObject *userData = (wxObject *)(NULL);
-	if (args.IsValid(2)) userData = Object_wx_Object::GetObject(args, 2)->GetEntity();
-	wxEvtHandler *eventSink = (wxEvtHandler *)(NULL);
-	if (args.IsValid(3)) eventSink = Object_wx_EvtHandler::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(0)) eventType = static_cast<wxEventType>(arg.GetInt(0));
+	wxObjectEventFunction *function = (wxObjectEventFunction *)(&nullptr);
+	if (arg.IsValid(1)) function = Object_wx_ObjectEventFunction::GetObject(arg, 1)->GetEntity();
+	wxObject *userData = (wxObject *)(nullptr);
+	if (arg.IsValid(2)) userData = Object_wx_Object::GetObject(arg, 2)->GetEntity();
+	wxEvtHandler *eventSink = (wxEvtHandler *)(nullptr);
+	if (arg.IsValid(3)) eventSink = Object_wx_EvtHandler::GetObject(arg, 3)->GetEntity();
 	bool rtn = pThis->GetEntity()->Disconnect(eventType, *function, userData, eventSink);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, Disconnect_1)
@@ -192,24 +197,25 @@ Gura_DeclareMethod(wx_EvtHandler, Disconnect_1)
 
 Gura_ImplementMethod(wx_EvtHandler, Disconnect_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int id = wxID_ANY;
-	if (args.IsValid(0)) id = args.GetInt(0);
+	if (arg.IsValid(0)) id = arg.GetInt(0);
 	wxEventType eventType = wxEVT_NULL;
-	if (args.IsValid(1)) eventType = static_cast<wxEventType>(args.GetInt(1));
-	wxObjectEventFunction *function = (wxObjectEventFunction *)(&NULL);
-	if (args.IsValid(2)) function = Object_wx_ObjectEventFunction::GetObject(args, 2)->GetEntity();
-	wxObject *userData = (wxObject *)(NULL);
-	if (args.IsValid(3)) userData = Object_wx_Object::GetObject(args, 3)->GetEntity();
-	wxEvtHandler *eventSink = (wxEvtHandler *)(NULL);
-	if (args.IsValid(4)) eventSink = Object_wx_EvtHandler::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(1)) eventType = static_cast<wxEventType>(arg.GetInt(1));
+	wxObjectEventFunction *function = (wxObjectEventFunction *)(&nullptr);
+	if (arg.IsValid(2)) function = Object_wx_ObjectEventFunction::GetObject(arg, 2)->GetEntity();
+	wxObject *userData = (wxObject *)(nullptr);
+	if (arg.IsValid(3)) userData = Object_wx_Object::GetObject(arg, 3)->GetEntity();
+	wxEvtHandler *eventSink = (wxEvtHandler *)(nullptr);
+	if (arg.IsValid(4)) eventSink = Object_wx_EvtHandler::GetObject(arg, 4)->GetEntity();
 	bool rtn = pThis->GetEntity()->Disconnect(id, eventType, *function, userData, eventSink);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, Disconnect_2)
@@ -228,25 +234,26 @@ Gura_DeclareMethod(wx_EvtHandler, Disconnect_2)
 
 Gura_ImplementMethod(wx_EvtHandler, Disconnect_2)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	int lastId = wxID_ANY;
-	if (args.IsValid(1)) lastId = args.GetInt(1);
+	if (arg.IsValid(1)) lastId = arg.GetInt(1);
 	wxEventType eventType = wxEVT_NULL;
-	if (args.IsValid(2)) eventType = static_cast<wxEventType>(args.GetInt(2));
-	wxObjectEventFunction *function = (wxObjectEventFunction *)(&NULL);
-	if (args.IsValid(3)) function = Object_wx_ObjectEventFunction::GetObject(args, 3)->GetEntity();
-	wxObject *userData = (wxObject *)(NULL);
-	if (args.IsValid(4)) userData = Object_wx_Object::GetObject(args, 4)->GetEntity();
-	wxEvtHandler *eventSink = (wxEvtHandler *)(NULL);
-	if (args.IsValid(5)) eventSink = Object_wx_EvtHandler::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(2)) eventType = static_cast<wxEventType>(arg.GetInt(2));
+	wxObjectEventFunction *function = (wxObjectEventFunction *)(&nullptr);
+	if (arg.IsValid(3)) function = Object_wx_ObjectEventFunction::GetObject(arg, 3)->GetEntity();
+	wxObject *userData = (wxObject *)(nullptr);
+	if (arg.IsValid(4)) userData = Object_wx_Object::GetObject(arg, 4)->GetEntity();
+	wxEvtHandler *eventSink = (wxEvtHandler *)(nullptr);
+	if (arg.IsValid(5)) eventSink = Object_wx_EvtHandler::GetObject(arg, 5)->GetEntity();
 	bool rtn = pThis->GetEntity()->Disconnect(id, lastId, eventType, *function, userData, eventSink);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, GetClientData)
@@ -256,10 +263,11 @@ Gura_DeclareMethod(wx_EvtHandler, GetClientData)
 
 Gura_ImplementMethod(wx_EvtHandler, GetClientData)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetClientData();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, GetClientObject)
@@ -270,11 +278,12 @@ Gura_DeclareMethod(wx_EvtHandler, GetClientObject)
 
 Gura_ImplementMethod(wx_EvtHandler, GetClientObject)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wx_ClientData *rtn = dynamic_cast<wx_ClientData *>(pThis->GetEntity()->GetClientObject());
-	if (rtn == NULL) return Value::Null;
-	return ReturnValue(env, sig, args, Value(new Object_wx_ClientData(rtn, NULL, OwnerFalse)));
+	if (rtn == nullptr) return Value::Nil;
+	return ReturnValue(env, arg, Value(new Object_wx_ClientData(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_EvtHandler, GetEvtHandlerEnabled)
@@ -285,10 +294,11 @@ Gura_DeclareMethod(wx_EvtHandler, GetEvtHandlerEnabled)
 
 Gura_ImplementMethod(wx_EvtHandler, GetEvtHandlerEnabled)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetEvtHandlerEnabled();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_EvtHandler, GetNextHandler)
@@ -299,10 +309,11 @@ Gura_DeclareMethod(wx_EvtHandler, GetNextHandler)
 
 Gura_ImplementMethod(wx_EvtHandler, GetNextHandler)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxEvtHandler *rtn = (wxEvtHandler *)pThis->GetEntity()->GetNextHandler();
-	return ReturnValue(env, sig, args, Value(new Object_wx_EvtHandler(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_EvtHandler(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_EvtHandler, GetPreviousHandler)
@@ -313,10 +324,11 @@ Gura_DeclareMethod(wx_EvtHandler, GetPreviousHandler)
 
 Gura_ImplementMethod(wx_EvtHandler, GetPreviousHandler)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxEvtHandler *rtn = (wxEvtHandler *)pThis->GetEntity()->GetPreviousHandler();
-	return ReturnValue(env, sig, args, Value(new Object_wx_EvtHandler(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_EvtHandler(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_EvtHandler, ProcessEvent)
@@ -328,11 +340,12 @@ Gura_DeclareMethod(wx_EvtHandler, ProcessEvent)
 
 Gura_ImplementMethod(wx_EvtHandler, ProcessEvent)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvent *event = Object_wx_Event::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvent *event = Object_wx_Event::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->ProcessEvent(*event);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_EvtHandler, SearchEventTable)
@@ -347,16 +360,17 @@ Gura_DeclareMethod(wx_EvtHandler, SearchEventTable)
 
 Gura_ImplementMethod(wx_EvtHandler, SearchEventTable)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEventTable *table = Object_wx_EventTable::GetObject(args, 0)->GetEntity();
-	wxEvent *event = Object_wx_Event::GetObject(args, 1)->GetEntity();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEventTable *table = Object_wx_EventTable::GetObject(arg, 0)->GetEntity();
+	wxEvent *event = Object_wx_Event::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->SearchEventTable(*table, *event);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, SetClientData)
@@ -369,15 +383,16 @@ Gura_DeclareMethod(wx_EvtHandler, SetClientData)
 
 Gura_ImplementMethod(wx_EvtHandler, SetClientData)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int data = args.GetInt(0);
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int data = arg.GetInt(0);
 	pThis->GetEntity()->SetClientData(data);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, SetClientObject)
@@ -388,11 +403,12 @@ Gura_DeclareMethod(wx_EvtHandler, SetClientObject)
 
 Gura_ImplementMethod(wx_EvtHandler, SetClientObject)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxClientData *data = Object_wx_ClientData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxClientData *data = Object_wx_ClientData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetClientObject(data);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, SetEvtHandlerEnabled)
@@ -403,11 +419,12 @@ Gura_DeclareMethod(wx_EvtHandler, SetEvtHandlerEnabled)
 
 Gura_ImplementMethod(wx_EvtHandler, SetEvtHandlerEnabled)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool enabled = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool enabled = arg.GetBoolean(0);
 	pThis->GetEntity()->SetEvtHandlerEnabled(enabled);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, SetNextHandler)
@@ -418,11 +435,12 @@ Gura_DeclareMethod(wx_EvtHandler, SetNextHandler)
 
 Gura_ImplementMethod(wx_EvtHandler, SetNextHandler)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvtHandler *handler = Object_wx_EvtHandler::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvtHandler *handler = Object_wx_EvtHandler::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetNextHandler(handler);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_EvtHandler, SetPreviousHandler)
@@ -433,11 +451,12 @@ Gura_DeclareMethod(wx_EvtHandler, SetPreviousHandler)
 
 Gura_ImplementMethod(wx_EvtHandler, SetPreviousHandler)
 {
-	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvtHandler *handler = Object_wx_EvtHandler::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_EvtHandler *pThis = Object_wx_EvtHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvtHandler *handler = Object_wx_EvtHandler::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPreviousHandler(handler);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -449,13 +468,13 @@ Object_wx_EvtHandler::~Object_wx_EvtHandler()
 
 Object *Object_wx_EvtHandler::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_EvtHandler::ToString(bool exprFlag)
 {
 	String rtn("<wx.EvtHandler:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -495,7 +514,7 @@ Gura_ImplementUserInheritableClass(wx_EvtHandler)
 
 Gura_ImplementDescendantCreator(wx_EvtHandler)
 {
-	return new Object_wx_EvtHandler((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_EvtHandler((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
