@@ -13,11 +13,11 @@ class wx_Font: public wxFont, public GuraObjectObserver {
 private:
 	Object_wx_Font *_pObj;
 public:
-	inline wx_Font() : wxFont(), _pObj(NULL) {}
-	inline wx_Font(const wxFont& font) : wxFont(font), _pObj(NULL) {}
-	inline wx_Font(int pointSize, wxFontFamily family, int style, wxFontWeight weight, const bool underline, const wxString& faceName, wxFontEncoding encoding) : wxFont(pointSize, family, style, weight, underline, faceName, encoding), _pObj(NULL) {}
+	inline wx_Font() : wxFont(), _pObj(nullptr) {}
+	inline wx_Font(const wxFont& font) : wxFont(font), _pObj(nullptr) {}
+	inline wx_Font(int pointSize, wxFontFamily family, int style, wxFontWeight weight, const bool underline, const wxString& faceName, wxFontEncoding encoding) : wxFont(pointSize, family, style, weight, underline, faceName, encoding), _pObj(nullptr) {}
 #if defined(__WXMSW__)
-	inline wx_Font(const wxSize& pixelSize, wxFontFamily family, int style, wxFontWeight weight, const bool underline, const wxString& faceName, wxFontEncoding encoding) : wxFont(pixelSize, family, style, weight, underline, faceName, encoding), _pObj(NULL) {}
+	inline wx_Font(const wxSize& pixelSize, wxFontFamily family, int style, wxFontWeight weight, const bool underline, const wxString& faceName, wxFontEncoding encoding) : wxFont(pixelSize, family, style, weight, underline, faceName, encoding), _pObj(nullptr) {}
 #endif
 	~wx_Font();
 	inline void AssocWithGura(Object_wx_Font *pObj) {
@@ -29,12 +29,12 @@ public:
 
 wx_Font::~wx_Font()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Font::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,17 +49,18 @@ Gura_DeclareFunction(FontEmpty)
 
 Gura_ImplementFunction(FontEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Font *pEntity = new wx_Font();
-	Object_wx_Font *pObj = Object_wx_Font::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Font *pObj = Object_wx_Font::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Font(pEntity, pEntity, OwnerFalse);
 		pEntity->AssocWithGura(pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
 	pEntity->AssocWithGura(pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Font)
@@ -78,27 +79,28 @@ Gura_DeclareFunction(Font)
 
 Gura_ImplementFunction(Font)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int pointSize = args.GetInt(0);
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(1));
-	int style = args.GetInt(2);
-	wxFontWeight weight = static_cast<wxFontWeight>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int pointSize = arg.GetInt(0);
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(1));
+	int style = arg.GetInt(2);
+	wxFontWeight weight = static_cast<wxFontWeight>(arg.GetInt(3));
 	bool underline = false;
-	if (args.IsValid(4)) underline = args.GetBoolean(4);
+	if (arg.IsValid(4)) underline = arg.GetBoolean(4);
 	wxString faceName = wxT("");
-	if (args.IsValid(5)) faceName = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) faceName = wxString::FromUTF8(arg.GetString(5));
 	wxFontEncoding encoding = wxFONTENCODING_DEFAULT;
-	if (args.IsValid(6)) encoding = static_cast<wxFontEncoding>(args.GetInt(6));
+	if (arg.IsValid(6)) encoding = static_cast<wxFontEncoding>(arg.GetInt(6));
 	wx_Font *pEntity = new wx_Font(pointSize, family, style, weight, underline, faceName, encoding);
-	Object_wx_Font *pObj = Object_wx_Font::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Font *pObj = Object_wx_Font::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Font(pEntity, pEntity, OwnerFalse);
 		pEntity->AssocWithGura(pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
 	pEntity->AssocWithGura(pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(FontEx)
@@ -117,31 +119,32 @@ Gura_DeclareFunction(FontEx)
 
 Gura_ImplementFunction(FontEx)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if defined(__WXMSW__)
-	wxSize *pixelSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(1));
-	int style = args.GetInt(2);
-	wxFontWeight weight = static_cast<wxFontWeight>(args.GetInt(3));
+	wxSize *pixelSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(1));
+	int style = arg.GetInt(2);
+	wxFontWeight weight = static_cast<wxFontWeight>(arg.GetInt(3));
 	bool underline = false;
-	if (args.IsValid(4)) underline = args.GetBoolean(4);
+	if (arg.IsValid(4)) underline = arg.GetBoolean(4);
 	wxString faceName = wxT("");
-	if (args.IsValid(5)) faceName = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) faceName = wxString::FromUTF8(arg.GetString(5));
 	wxFontEncoding encoding = wxFONTENCODING_DEFAULT;
-	if (args.IsValid(6)) encoding = static_cast<wxFontEncoding>(args.GetInt(6));
+	if (arg.IsValid(6)) encoding = static_cast<wxFontEncoding>(arg.GetInt(6));
 	wx_Font *pEntity = new wx_Font(*pixelSize, family, style, weight, underline, faceName, encoding);
-	Object_wx_Font *pObj = Object_wx_Font::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Font *pObj = Object_wx_Font::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Font(pEntity, pEntity, OwnerFalse);
 		pEntity->AssocWithGura(pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
 	pEntity->AssocWithGura(pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	return ReturnValue(env, arg, arg.GetValueThis());
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -153,10 +156,11 @@ Gura_DeclareMethod(wx_Font, IsFixedWidth)
 
 Gura_ImplementMethod(wx_Font, IsFixedWidth)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsFixedWidth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Font, GetDefaultEncoding)
@@ -167,9 +171,10 @@ Gura_DeclareClassMethod(wx_Font, GetDefaultEncoding)
 
 Gura_ImplementClassMethod(wx_Font, GetDefaultEncoding)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxFontEncoding rtn = wxFont::GetDefaultEncoding();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetEncoding)
@@ -180,10 +185,11 @@ Gura_DeclareMethod(wx_Font, GetEncoding)
 
 Gura_ImplementMethod(wx_Font, GetEncoding)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFontEncoding rtn = pThis->GetEntity()->GetEncoding();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetFaceName)
@@ -194,10 +200,11 @@ Gura_DeclareMethod(wx_Font, GetFaceName)
 
 Gura_ImplementMethod(wx_Font, GetFaceName)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetFaceName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Font, GetFamily)
@@ -208,10 +215,11 @@ Gura_DeclareMethod(wx_Font, GetFamily)
 
 Gura_ImplementMethod(wx_Font, GetFamily)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFamily();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetFamilyString)
@@ -222,10 +230,11 @@ Gura_DeclareMethod(wx_Font, GetFamilyString)
 
 Gura_ImplementMethod(wx_Font, GetFamilyString)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetFamilyString();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Font, GetNativeFontInfo)
@@ -236,14 +245,15 @@ Gura_DeclareMethod(wx_Font, GetNativeFontInfo)
 
 Gura_ImplementMethod(wx_Font, GetNativeFontInfo)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxNativeFontInfo *rtn = pThis->GetEntity()->GetNativeFontInfo();
 	Value value;
-	if (rtn != NULL) {
-		value = Value(new Object_wx_NativeFontInfo(new wxNativeFontInfo(*rtn), NULL, OwnerTrue));
+	if (rtn != nullptr) {
+		value = Value(new Object_wx_NativeFontInfo(new wxNativeFontInfo(*rtn), nullptr, OwnerTrue));
 	}
-	return ReturnValue(env, sig, args, value);
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Font, GetNativeFontInfoDesc)
@@ -254,10 +264,11 @@ Gura_DeclareMethod(wx_Font, GetNativeFontInfoDesc)
 
 Gura_ImplementMethod(wx_Font, GetNativeFontInfoDesc)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetNativeFontInfoDesc();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Font, GetNativeFontInfoUserDesc)
@@ -268,10 +279,11 @@ Gura_DeclareMethod(wx_Font, GetNativeFontInfoUserDesc)
 
 Gura_ImplementMethod(wx_Font, GetNativeFontInfoUserDesc)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetNativeFontInfoUserDesc();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Font, GetPointSize)
@@ -282,10 +294,11 @@ Gura_DeclareMethod(wx_Font, GetPointSize)
 
 Gura_ImplementMethod(wx_Font, GetPointSize)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetPointSize();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetStyle)
@@ -296,10 +309,11 @@ Gura_DeclareMethod(wx_Font, GetStyle)
 
 Gura_ImplementMethod(wx_Font, GetStyle)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetStyle();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetStyleString)
@@ -310,10 +324,11 @@ Gura_DeclareMethod(wx_Font, GetStyleString)
 
 Gura_ImplementMethod(wx_Font, GetStyleString)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetStyleString();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Font, GetUnderlined)
@@ -324,10 +339,11 @@ Gura_DeclareMethod(wx_Font, GetUnderlined)
 
 Gura_ImplementMethod(wx_Font, GetUnderlined)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetUnderlined();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetWeight)
@@ -338,10 +354,11 @@ Gura_DeclareMethod(wx_Font, GetWeight)
 
 Gura_ImplementMethod(wx_Font, GetWeight)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWeight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, GetWeightString)
@@ -352,10 +369,11 @@ Gura_DeclareMethod(wx_Font, GetWeightString)
 
 Gura_ImplementMethod(wx_Font, GetWeightString)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetWeightString();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_Font, New)
@@ -373,19 +391,20 @@ Gura_DeclareClassMethod(wx_Font, New)
 
 Gura_ImplementClassMethod(wx_Font, New)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int pointSize = args.GetInt(0);
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(1));
-	int style = args.GetInt(2);
-	wxFontWeight weight = static_cast<wxFontWeight>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int pointSize = arg.GetInt(0);
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(1));
+	int style = arg.GetInt(2);
+	wxFontWeight weight = static_cast<wxFontWeight>(arg.GetInt(3));
 	bool underline = false;
-	if (args.IsValid(4)) underline = args.GetBoolean(4);
+	if (arg.IsValid(4)) underline = arg.GetBoolean(4);
 	wxString faceName = wxT("");
-	if (args.IsValid(5)) faceName = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) faceName = wxString::FromUTF8(arg.GetString(5));
 	wxFontEncoding encoding = wxFONTENCODING_DEFAULT;
-	if (args.IsValid(6)) encoding = static_cast<wxFontEncoding>(args.GetInt(6));
+	if (arg.IsValid(6)) encoding = static_cast<wxFontEncoding>(arg.GetInt(6));
 	wxFont *rtn = (wxFont *)wxFont::New(pointSize, family, style, weight, underline, faceName, encoding);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareClassMethod(wx_Font, New_1)
@@ -401,17 +420,18 @@ Gura_DeclareClassMethod(wx_Font, New_1)
 
 Gura_ImplementClassMethod(wx_Font, New_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int pointSize = args.GetInt(0);
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int pointSize = arg.GetInt(0);
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(1));
 	int flags = wxFONTFLAG_DEFAULT;
-	if (args.IsValid(2)) flags = args.GetInt(2);
+	if (arg.IsValid(2)) flags = arg.GetInt(2);
 	wxString faceName = wxT("");
-	if (args.IsValid(3)) faceName = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) faceName = wxString::FromUTF8(arg.GetString(3));
 	wxFontEncoding encoding = wxFONTENCODING_DEFAULT;
-	if (args.IsValid(4)) encoding = static_cast<wxFontEncoding>(args.GetInt(4));
+	if (arg.IsValid(4)) encoding = static_cast<wxFontEncoding>(arg.GetInt(4));
 	wxFont *rtn = (wxFont *)wxFont::New(pointSize, family, flags, faceName, encoding);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareClassMethod(wx_Font, New_2)
@@ -429,19 +449,20 @@ Gura_DeclareClassMethod(wx_Font, New_2)
 
 Gura_ImplementClassMethod(wx_Font, New_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxSize *pixelSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(1));
-	int style = args.GetInt(2);
-	wxFontWeight weight = static_cast<wxFontWeight>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxSize *pixelSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(1));
+	int style = arg.GetInt(2);
+	wxFontWeight weight = static_cast<wxFontWeight>(arg.GetInt(3));
 	bool underline = false;
-	if (args.IsValid(4)) underline = args.GetBoolean(4);
+	if (arg.IsValid(4)) underline = arg.GetBoolean(4);
 	wxString faceName = wxT("");
-	if (args.IsValid(5)) faceName = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) faceName = wxString::FromUTF8(arg.GetString(5));
 	wxFontEncoding encoding = wxFONTENCODING_DEFAULT;
-	if (args.IsValid(6)) encoding = static_cast<wxFontEncoding>(args.GetInt(6));
+	if (arg.IsValid(6)) encoding = static_cast<wxFontEncoding>(arg.GetInt(6));
 	wxFont *rtn = (wxFont *)wxFont::New(*pixelSize, family, style, weight, underline, faceName, encoding);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareClassMethod(wx_Font, New_3)
@@ -457,17 +478,18 @@ Gura_DeclareClassMethod(wx_Font, New_3)
 
 Gura_ImplementClassMethod(wx_Font, New_3)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxSize *pixelSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxSize *pixelSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(1));
 	int flags = wxFONTFLAG_DEFAULT;
-	if (args.IsValid(2)) flags = args.GetInt(2);
+	if (arg.IsValid(2)) flags = arg.GetInt(2);
 	wxString faceName = wxT("");
-	if (args.IsValid(3)) faceName = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) faceName = wxString::FromUTF8(arg.GetString(3));
 	wxFontEncoding encoding = wxFONTENCODING_DEFAULT;
-	if (args.IsValid(4)) encoding = static_cast<wxFontEncoding>(args.GetInt(4));
+	if (arg.IsValid(4)) encoding = static_cast<wxFontEncoding>(arg.GetInt(4));
 	wxFont *rtn = (wxFont *)wxFont::New(*pixelSize, family, flags, faceName, encoding);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Font, IsOk)
@@ -478,10 +500,11 @@ Gura_DeclareMethod(wx_Font, IsOk)
 
 Gura_ImplementMethod(wx_Font, IsOk)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Font, SetDefaultEncoding)
@@ -492,10 +515,11 @@ Gura_DeclareClassMethod(wx_Font, SetDefaultEncoding)
 
 Gura_ImplementClassMethod(wx_Font, SetDefaultEncoding)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxFontEncoding encoding = static_cast<wxFontEncoding>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxFontEncoding encoding = static_cast<wxFontEncoding>(arg.GetInt(0));
 	wxFont::SetDefaultEncoding(encoding);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Font, SetEncoding)
@@ -506,11 +530,12 @@ Gura_DeclareMethod(wx_Font, SetEncoding)
 
 Gura_ImplementMethod(wx_Font, SetEncoding)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFontEncoding encoding = static_cast<wxFontEncoding>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFontEncoding encoding = static_cast<wxFontEncoding>(arg.GetInt(0));
 	pThis->GetEntity()->SetEncoding(encoding);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Font, SetFaceName)
@@ -522,11 +547,12 @@ Gura_DeclareMethod(wx_Font, SetFaceName)
 
 Gura_ImplementMethod(wx_Font, SetFaceName)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString faceName = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString faceName = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->SetFaceName(faceName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, SetFamily)
@@ -537,11 +563,12 @@ Gura_DeclareMethod(wx_Font, SetFamily)
 
 Gura_ImplementMethod(wx_Font, SetFamily)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFontFamily family = static_cast<wxFontFamily>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFontFamily family = static_cast<wxFontFamily>(arg.GetInt(0));
 	pThis->GetEntity()->SetFamily(family);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Font, SetNativeFontInfo)
@@ -553,11 +580,12 @@ Gura_DeclareMethod(wx_Font, SetNativeFontInfo)
 
 Gura_ImplementMethod(wx_Font, SetNativeFontInfo)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString info = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString info = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->SetNativeFontInfo(info);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, SetNativeFontInfoUserDesc)
@@ -569,11 +597,12 @@ Gura_DeclareMethod(wx_Font, SetNativeFontInfoUserDesc)
 
 Gura_ImplementMethod(wx_Font, SetNativeFontInfoUserDesc)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString info = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString info = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->SetNativeFontInfoUserDesc(info);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Font, SetPointSize)
@@ -584,11 +613,12 @@ Gura_DeclareMethod(wx_Font, SetPointSize)
 
 Gura_ImplementMethod(wx_Font, SetPointSize)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pointSize = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pointSize = arg.GetInt(0);
 	pThis->GetEntity()->SetPointSize(pointSize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Font, SetStyle)
@@ -599,11 +629,12 @@ Gura_DeclareMethod(wx_Font, SetStyle)
 
 Gura_ImplementMethod(wx_Font, SetStyle)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int style = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int style = arg.GetInt(0);
 	pThis->GetEntity()->SetStyle(style);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Font, SetUnderlined)
@@ -614,11 +645,12 @@ Gura_DeclareMethod(wx_Font, SetUnderlined)
 
 Gura_ImplementMethod(wx_Font, SetUnderlined)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool underlined = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool underlined = arg.GetBoolean(0);
 	pThis->GetEntity()->SetUnderlined(underlined);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Font, SetWeight)
@@ -629,11 +661,12 @@ Gura_DeclareMethod(wx_Font, SetWeight)
 
 Gura_ImplementMethod(wx_Font, SetWeight)
 {
-	Object_wx_Font *pThis = Object_wx_Font::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFontWeight weight = static_cast<wxFontWeight>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Font *pThis = Object_wx_Font::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFontWeight weight = static_cast<wxFontWeight>(arg.GetInt(0));
 	pThis->GetEntity()->SetWeight(weight);
-	return Value::Null;
+	return Value::Nil;
 }
 
 // operator ==
@@ -670,7 +703,7 @@ Object *Object_wx_Font::Clone() const
 String Object_wx_Font::ToString(bool exprFlag)
 {
 	String rtn("<wx.Font:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -725,7 +758,7 @@ Gura_ImplementUserInheritableClass(wx_Font)
 
 Gura_ImplementDescendantCreator(wx_Font)
 {
-	return new Object_wx_Font((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Font((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
