@@ -18,11 +18,11 @@ Gura_DeclarePrivUserSymbol(SetStatusWidths);
 //----------------------------------------------------------------------------
 class wx_Frame: public wxFrame, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Frame *_pObj;
 public:
-	inline wx_Frame() : wxFrame(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Frame(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxFrame(parent, id, title, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_Frame() : wxFrame(), _pObj(nullptr) {}
+	inline wx_Frame(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxFrame(parent, id, title, pos, size, style, name), _pObj(nullptr) {}
 	//virtual wxStatusBar* CreateStatusBar(int number, long style, wxWindowID id, const wxString& name);
 	//virtual wxToolBar* CreateToolBar(long style, wxWindowID id, const wxString& name);
 	//virtual wxStatusBar* OnCreateStatusBar(int number, long style, wxWindowID id, const wxString& name);
@@ -30,8 +30,8 @@ public:
 	//virtual void SetStatusText(const wxString& text, int number);
 	//virtual void SetStatusWidths(int n, int * widths);
 	~wx_Frame();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Frame *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Frame *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -46,12 +46,12 @@ public:
 
 wx_Frame::~wx_Frame()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Frame::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -66,17 +66,18 @@ Gura_DeclareFunction(FrameEmpty)
 
 Gura_ImplementFunction(FrameEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Frame *pEntity = new wx_Frame();
-	Object_wx_Frame *pObj = Object_wx_Frame::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Frame *pObj = Object_wx_Frame::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Frame(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Frame)
@@ -95,29 +96,30 @@ Gura_DeclareFunction(Frame)
 
 Gura_ImplementFunction(Frame)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = args.IsValid(0)?
-			Object_wx_Window::GetObject(args, 0)->GetEntity() : NULL;
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString title = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = arg.IsValid(0)?
+			Object_wx_Window::GetObject(arg, 0)->GetEntity() : nullptr;
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString title = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = wxDEFAULT_FRAME_STYLE;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString name = wxT("frame");
-	if (args.IsValid(6)) name = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) name = wxString::FromUTF8(arg.GetString(6));
 	wx_Frame *pEntity = new wx_Frame(parent, id, title, *pos, *size, style, name);
-	Object_wx_Frame *pObj = Object_wx_Frame::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Frame *pObj = Object_wx_Frame::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Frame(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Frame, Centre)
@@ -128,12 +130,13 @@ Gura_DeclareMethod(wx_Frame, Centre)
 
 Gura_ImplementMethod(wx_Frame, Centre)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int direction = wxBOTH;
-	if (args.IsValid(0)) direction = args.GetInt(0);
+	if (arg.IsValid(0)) direction = arg.GetInt(0);
 	pThis->GetEntity()->Centre(direction);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, Create)
@@ -151,22 +154,23 @@ Gura_DeclareMethod(wx_Frame, Create)
 
 Gura_ImplementMethod(wx_Frame, Create)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = args.IsValid(0)?
-			Object_wx_Window::GetObject(args, 0)->GetEntity() : NULL;
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString title = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = arg.IsValid(0)?
+			Object_wx_Window::GetObject(arg, 0)->GetEntity() : nullptr;
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString title = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = wxDEFAULT_FRAME_STYLE;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString name = wxT("frame");
-	if (args.IsValid(6)) name = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) name = wxString::FromUTF8(arg.GetString(6));
 	bool rtn = pThis->GetEntity()->Create(parent, id, title, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Frame, CreateStatusBar)
@@ -181,18 +185,19 @@ Gura_DeclareMethod(wx_Frame, CreateStatusBar)
 
 Gura_ImplementMethod(wx_Frame, CreateStatusBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int number = 1;
-	if (args.IsValid(0)) number = args.GetInt(0);
+	if (arg.IsValid(0)) number = arg.GetInt(0);
 	long style = wxST_SIZEGRIP | wxFULL_REPAINT_ON_RESIZE;
-	if (args.IsValid(1)) style = args.GetLong(1);
+	if (arg.IsValid(1)) style = arg.GetLong(1);
 	wxWindowID id = 0;
-	if (args.IsValid(2)) id = static_cast<wxWindowID>(args.GetInt(2));
+	if (arg.IsValid(2)) id = static_cast<wxWindowID>(arg.GetInt(2));
 	wxString name = wxT("statusBar");
-	if (args.IsValid(3)) name = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) name = wxString::FromUTF8(arg.GetString(3));
 	wxStatusBar *rtn = (wxStatusBar *)pThis->GetEntity()->CreateStatusBar(number, style, id, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_StatusBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_StatusBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Frame, CreateToolBar)
@@ -206,16 +211,17 @@ Gura_DeclareMethod(wx_Frame, CreateToolBar)
 
 Gura_ImplementMethod(wx_Frame, CreateToolBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long style = wxNO_BORDER | wxTB_HORIZONTAL;
-	if (args.IsValid(0)) style = args.GetLong(0);
+	if (arg.IsValid(0)) style = arg.GetLong(0);
 	wxWindowID id = -1;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString name = wxT("toolBar");
-	if (args.IsValid(2)) name = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) name = wxString::FromUTF8(arg.GetString(2));
 	wxToolBar *rtn = (wxToolBar *)pThis->GetEntity()->CreateToolBar(style, id, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_ToolBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ToolBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Frame, GetClientAreaOrigin)
@@ -226,10 +232,11 @@ Gura_DeclareMethod(wx_Frame, GetClientAreaOrigin)
 
 Gura_ImplementMethod(wx_Frame, GetClientAreaOrigin)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetClientAreaOrigin();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Frame, GetMenuBar)
@@ -240,14 +247,15 @@ Gura_DeclareMethod(wx_Frame, GetMenuBar)
 
 Gura_ImplementMethod(wx_Frame, GetMenuBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMenuBar *rtn = (wxMenuBar *)pThis->GetEntity()->GetMenuBar();
 	Value value;
-	if (rtn != NULL) {
-		value = Value(new Object_wx_MenuBar(rtn, NULL, OwnerFalse));
+	if (rtn != nullptr) {
+		value = Value(new Object_wx_MenuBar(rtn, nullptr, OwnerFalse));
 	}
-	return ReturnValue(env, sig, args, value);
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Frame, GetStatusBar)
@@ -258,14 +266,15 @@ Gura_DeclareMethod(wx_Frame, GetStatusBar)
 
 Gura_ImplementMethod(wx_Frame, GetStatusBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxStatusBar *rtn = (wxStatusBar *)pThis->GetEntity()->GetStatusBar();
 	Value value;
-	if (rtn != NULL) {
-		value = Value(new Object_wx_StatusBar(rtn, NULL, OwnerFalse));
+	if (rtn != nullptr) {
+		value = Value(new Object_wx_StatusBar(rtn, nullptr, OwnerFalse));
 	}
-	return ReturnValue(env, sig, args, value);
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Frame, GetStatusBarPane)
@@ -276,10 +285,11 @@ Gura_DeclareMethod(wx_Frame, GetStatusBarPane)
 
 Gura_ImplementMethod(wx_Frame, GetStatusBarPane)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetStatusBarPane();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Frame, GetToolBar)
@@ -290,14 +300,15 @@ Gura_DeclareMethod(wx_Frame, GetToolBar)
 
 Gura_ImplementMethod(wx_Frame, GetToolBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxToolBar *rtn = (wxToolBar *)pThis->GetEntity()->GetToolBar();
 	Value value;
-	if (rtn != NULL) {
-		value = Value(new Object_wx_ToolBar(rtn, NULL, OwnerFalse));
+	if (rtn != nullptr) {
+		value = Value(new Object_wx_ToolBar(rtn, nullptr, OwnerFalse));
 	}
-	return ReturnValue(env, sig, args, value);
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Frame, OnCreateStatusBar)
@@ -312,14 +323,15 @@ Gura_DeclareMethod(wx_Frame, OnCreateStatusBar)
 
 Gura_ImplementMethod(wx_Frame, OnCreateStatusBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int number = args.GetInt(0);
-	long style = args.GetLong(1);
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(2));
-	wxString name = wxString::FromUTF8(args.GetString(3));
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int number = arg.GetInt(0);
+	long style = arg.GetLong(1);
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(2));
+	wxString name = wxString::FromUTF8(arg.GetString(3));
 	wxStatusBar *rtn = (wxStatusBar *)pThis->GetEntity()->OnCreateStatusBar(number, style, id, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_StatusBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_StatusBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Frame, OnCreateToolBar)
@@ -333,13 +345,14 @@ Gura_DeclareMethod(wx_Frame, OnCreateToolBar)
 
 Gura_ImplementMethod(wx_Frame, OnCreateToolBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long style = args.GetLong(0);
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString name = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long style = arg.GetLong(0);
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString name = wxString::FromUTF8(arg.GetString(2));
 	wxToolBar *rtn = (wxToolBar *)pThis->GetEntity()->OnCreateToolBar(style, id, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_ToolBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ToolBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Frame, ProcessCommand)
@@ -350,11 +363,12 @@ Gura_DeclareMethod(wx_Frame, ProcessCommand)
 
 Gura_ImplementMethod(wx_Frame, ProcessCommand)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->ProcessCommand(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SendSizeEvent)
@@ -364,10 +378,11 @@ Gura_DeclareMethod(wx_Frame, SendSizeEvent)
 
 Gura_ImplementMethod(wx_Frame, SendSizeEvent)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->SendSizeEvent();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SetMenuBar)
@@ -378,11 +393,12 @@ Gura_DeclareMethod(wx_Frame, SetMenuBar)
 
 Gura_ImplementMethod(wx_Frame, SetMenuBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuBar *menuBar = Object_wx_MenuBar::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuBar *menuBar = Object_wx_MenuBar::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMenuBar(menuBar);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SetStatusBar)
@@ -393,12 +409,13 @@ Gura_DeclareMethod(wx_Frame, SetStatusBar)
 
 Gura_ImplementMethod(wx_Frame, SetStatusBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxStatusBar *statusBar = args.IsValid(0)?
-			Object_wx_StatusBar::GetObject(args, 0)->GetEntity() : NULL;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxStatusBar *statusBar = arg.IsValid(0)?
+			Object_wx_StatusBar::GetObject(arg, 0)->GetEntity() : nullptr;
 	pThis->GetEntity()->SetStatusBar(statusBar);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SetStatusBarPane)
@@ -409,11 +426,12 @@ Gura_DeclareMethod(wx_Frame, SetStatusBarPane)
 
 Gura_ImplementMethod(wx_Frame, SetStatusBarPane)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->SetStatusBarPane(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SetStatusText)
@@ -425,28 +443,30 @@ Gura_DeclareMethod(wx_Frame, SetStatusText)
 
 Gura_ImplementMethod(wx_Frame, SetStatusText)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	int number = 0;
-	if (args.IsValid(1)) number = args.GetInt(1);
+	if (arg.IsValid(1)) number = arg.GetInt(1);
 	pThis->GetEntity()->SetStatusText(text, number);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SetStatusWidths)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
-	DeclareArg(env, "widths", VTYPE_number, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "widths", VTYPE_number, OCCUR_Once, FLAG_ListVar);
 }
 
 Gura_ImplementMethod(wx_Frame, SetStatusWidths)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	CArrayOfInt widths(args.GetList(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	CArrayOfInt widths(arg.GetList(0));
 	pThis->GetEntity()->SetStatusWidths(widths.Count(), widths.Data());
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, SetToolBar)
@@ -457,11 +477,12 @@ Gura_DeclareMethod(wx_Frame, SetToolBar)
 
 Gura_ImplementMethod(wx_Frame, SetToolBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxToolBar *toolBar = Object_wx_ToolBar::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxToolBar *toolBar = Object_wx_ToolBar::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetToolBar(toolBar);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, PositionMenuBar)
@@ -471,10 +492,11 @@ Gura_DeclareMethod(wx_Frame, PositionMenuBar)
 
 Gura_ImplementMethod(wx_Frame, PositionMenuBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	dynamic_cast<wx_Frame *>(pThis->GetEntity())->_PositionMenuBar();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, DetachMenuBar)
@@ -484,10 +506,11 @@ Gura_DeclareMethod(wx_Frame, DetachMenuBar)
 
 Gura_ImplementMethod(wx_Frame, DetachMenuBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	dynamic_cast<wx_Frame *>(pThis->GetEntity())->_DetachMenuBar();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, AttachMenuBar)
@@ -498,11 +521,12 @@ Gura_DeclareMethod(wx_Frame, AttachMenuBar)
 
 Gura_ImplementMethod(wx_Frame, AttachMenuBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuBar *menuBar = Object_wx_MenuBar::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuBar *menuBar = Object_wx_MenuBar::GetObject(arg, 0)->GetEntity();
 	dynamic_cast<wx_Frame *>(pThis->GetEntity())->_AttachMenuBar(menuBar);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, PositionStatusBar)
@@ -512,10 +536,11 @@ Gura_DeclareMethod(wx_Frame, PositionStatusBar)
 
 Gura_ImplementMethod(wx_Frame, PositionStatusBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	dynamic_cast<wx_Frame *>(pThis->GetEntity())->_PositionStatusBar();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Frame, PositionToolBar)
@@ -525,10 +550,11 @@ Gura_DeclareMethod(wx_Frame, PositionToolBar)
 
 Gura_ImplementMethod(wx_Frame, PositionToolBar)
 {
-	Object_wx_Frame *pThis = Object_wx_Frame::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Frame *pThis = Object_wx_Frame::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	dynamic_cast<wx_Frame *>(pThis->GetEntity())->_PositionToolBar();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -540,13 +566,13 @@ Object_wx_Frame::~Object_wx_Frame()
 
 Object *Object_wx_Frame::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Frame::ToString(bool exprFlag)
 {
 	String rtn("<wx.Frame:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -597,7 +623,7 @@ Gura_ImplementUserInheritableClass(wx_Frame)
 
 Gura_ImplementDescendantCreator(wx_Frame)
 {
-	return new Object_wx_Frame((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Frame((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
