@@ -11,12 +11,12 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_GraphicsPath: public wxGraphicsPath, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_GraphicsPath *_pObj;
 public:
 	~wx_GraphicsPath();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_GraphicsPath *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_GraphicsPath *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -24,12 +24,12 @@ public:
 
 wx_GraphicsPath::~wx_GraphicsPath()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_GraphicsPath::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -44,12 +44,13 @@ Gura_DeclareMethod(wx_GraphicsPath, MoveToPoint)
 
 Gura_ImplementMethod(wx_GraphicsPath, MoveToPoint)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->MoveToPoint(*x, *y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, MoveToPoint_1)
@@ -60,11 +61,12 @@ Gura_DeclareMethod(wx_GraphicsPath, MoveToPoint_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, MoveToPoint_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint2DDouble *p = Object_wx_Point2DDouble::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint2DDouble *p = Object_wx_Point2DDouble::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->MoveToPoint(*p);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddArc)
@@ -80,16 +82,17 @@ Gura_DeclareMethod(wx_GraphicsPath, AddArc)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddArc)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *r = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *startAngle = Object_wx_Double::GetObject(args, 3)->GetEntity();
-	wxDouble *endAngle = Object_wx_Double::GetObject(args, 4)->GetEntity();
-	bool clockwise = args.GetBoolean(5);
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *r = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *startAngle = Object_wx_Double::GetObject(arg, 3)->GetEntity();
+	wxDouble *endAngle = Object_wx_Double::GetObject(arg, 4)->GetEntity();
+	bool clockwise = arg.GetBoolean(5);
 	pThis->GetEntity()->AddArc(*x, *y, *r, *startAngle, *endAngle, clockwise);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddArc_1)
@@ -104,15 +107,16 @@ Gura_DeclareMethod(wx_GraphicsPath, AddArc_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddArc_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint2DDouble *c = Object_wx_Point2DDouble::GetObject(args, 0)->GetEntity();
-	wxDouble *r = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *startAngle = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *endAngle = Object_wx_Double::GetObject(args, 3)->GetEntity();
-	bool clockwise = args.GetBoolean(4);
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint2DDouble *c = Object_wx_Point2DDouble::GetObject(arg, 0)->GetEntity();
+	wxDouble *r = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *startAngle = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *endAngle = Object_wx_Double::GetObject(arg, 3)->GetEntity();
+	bool clockwise = arg.GetBoolean(4);
 	pThis->GetEntity()->AddArc(*c, *r, *startAngle, *endAngle, clockwise);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddArcToPoint)
@@ -127,15 +131,16 @@ Gura_DeclareMethod(wx_GraphicsPath, AddArcToPoint)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddArcToPoint)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x1 = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y1 = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *x2 = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *y2 = Object_wx_Double::GetObject(args, 3)->GetEntity();
-	wxDouble *r = Object_wx_Double::GetObject(args, 4)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x1 = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y1 = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *x2 = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *y2 = Object_wx_Double::GetObject(arg, 3)->GetEntity();
+	wxDouble *r = Object_wx_Double::GetObject(arg, 4)->GetEntity();
 	pThis->GetEntity()->AddArcToPoint(*x1, *y1, *x2, *y2, *r);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddCircle)
@@ -148,13 +153,14 @@ Gura_DeclareMethod(wx_GraphicsPath, AddCircle)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddCircle)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *r = Object_wx_Double::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *r = Object_wx_Double::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->AddCircle(*x, *y, *r);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddCurveToPoint)
@@ -170,16 +176,17 @@ Gura_DeclareMethod(wx_GraphicsPath, AddCurveToPoint)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddCurveToPoint)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *cx1 = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *cy1 = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *cx2 = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *cy2 = Object_wx_Double::GetObject(args, 3)->GetEntity();
-	wxDouble *x = Object_wx_Double::GetObject(args, 4)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 5)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *cx1 = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *cy1 = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *cx2 = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *cy2 = Object_wx_Double::GetObject(arg, 3)->GetEntity();
+	wxDouble *x = Object_wx_Double::GetObject(arg, 4)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 5)->GetEntity();
 	pThis->GetEntity()->AddCurveToPoint(*cx1, *cy1, *cx2, *cy2, *x, *y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddCurveToPoint_1)
@@ -192,13 +199,14 @@ Gura_DeclareMethod(wx_GraphicsPath, AddCurveToPoint_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddCurveToPoint_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint2DDouble *c1 = Object_wx_Point2DDouble::GetObject(args, 0)->GetEntity();
-	wxPoint2DDouble *c2 = Object_wx_Point2DDouble::GetObject(args, 1)->GetEntity();
-	wxPoint2DDouble *e = Object_wx_Point2DDouble::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint2DDouble *c1 = Object_wx_Point2DDouble::GetObject(arg, 0)->GetEntity();
+	wxPoint2DDouble *c2 = Object_wx_Point2DDouble::GetObject(arg, 1)->GetEntity();
+	wxPoint2DDouble *e = Object_wx_Point2DDouble::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->AddCurveToPoint(*c1, *c2, *e);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddEllipse)
@@ -212,14 +220,15 @@ Gura_DeclareMethod(wx_GraphicsPath, AddEllipse)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddEllipse)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *w = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *h = Object_wx_Double::GetObject(args, 3)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *w = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *h = Object_wx_Double::GetObject(arg, 3)->GetEntity();
 	pThis->GetEntity()->AddEllipse(*x, *y, *w, *h);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddLineToPoint)
@@ -231,12 +240,13 @@ Gura_DeclareMethod(wx_GraphicsPath, AddLineToPoint)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddLineToPoint)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->AddLineToPoint(*x, *y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddLineToPoint_1)
@@ -247,11 +257,12 @@ Gura_DeclareMethod(wx_GraphicsPath, AddLineToPoint_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddLineToPoint_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint2DDouble *p = Object_wx_Point2DDouble::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint2DDouble *p = Object_wx_Point2DDouble::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddLineToPoint(*p);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddPath)
@@ -262,11 +273,12 @@ Gura_DeclareMethod(wx_GraphicsPath, AddPath)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddPath)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGraphicsPath *path = Object_wx_GraphicsPath::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGraphicsPath *path = Object_wx_GraphicsPath::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddPath(*path);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddQuadCurveToPoint)
@@ -280,14 +292,15 @@ Gura_DeclareMethod(wx_GraphicsPath, AddQuadCurveToPoint)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddQuadCurveToPoint)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *cx = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *cy = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *x = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 3)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *cx = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *cy = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *x = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 3)->GetEntity();
 	pThis->GetEntity()->AddQuadCurveToPoint(*cx, *cy, *x, *y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddRectangle)
@@ -301,14 +314,15 @@ Gura_DeclareMethod(wx_GraphicsPath, AddRectangle)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddRectangle)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *w = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *h = Object_wx_Double::GetObject(args, 3)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *w = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *h = Object_wx_Double::GetObject(arg, 3)->GetEntity();
 	pThis->GetEntity()->AddRectangle(*x, *y, *w, *h);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, AddRoundedRectangle)
@@ -323,15 +337,16 @@ Gura_DeclareMethod(wx_GraphicsPath, AddRoundedRectangle)
 
 Gura_ImplementMethod(wx_GraphicsPath, AddRoundedRectangle)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *w = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *h = Object_wx_Double::GetObject(args, 3)->GetEntity();
-	wxDouble *radius = Object_wx_Double::GetObject(args, 4)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *w = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *h = Object_wx_Double::GetObject(arg, 3)->GetEntity();
+	wxDouble *radius = Object_wx_Double::GetObject(arg, 4)->GetEntity();
 	pThis->GetEntity()->AddRoundedRectangle(*x, *y, *w, *h, *radius);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, CloseSubpath)
@@ -341,10 +356,11 @@ Gura_DeclareMethod(wx_GraphicsPath, CloseSubpath)
 
 Gura_ImplementMethod(wx_GraphicsPath, CloseSubpath)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->CloseSubpath();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, Contains)
@@ -357,13 +373,14 @@ Gura_DeclareMethod(wx_GraphicsPath, Contains)
 
 Gura_ImplementMethod(wx_GraphicsPath, Contains)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint2DDouble *c = Object_wx_Point2DDouble::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint2DDouble *c = Object_wx_Point2DDouble::GetObject(arg, 0)->GetEntity();
 	int fillStyle = wxODDEVEN_RULE;
-	if (args.IsValid(1)) fillStyle = args.GetInt(1);
+	if (arg.IsValid(1)) fillStyle = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->Contains(*c, fillStyle);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, Contains_1)
@@ -377,14 +394,15 @@ Gura_DeclareMethod(wx_GraphicsPath, Contains_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, Contains_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
 	int fillStyle = wxODDEVEN_RULE;
-	if (args.IsValid(2)) fillStyle = args.GetInt(2);
+	if (arg.IsValid(2)) fillStyle = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->Contains(*x, *y, fillStyle);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, GetBox)
@@ -395,10 +413,11 @@ Gura_DeclareMethod(wx_GraphicsPath, GetBox)
 
 Gura_ImplementMethod(wx_GraphicsPath, GetBox)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRect2DDouble rtn = pThis->GetEntity()->GetBox();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect2DDouble(new wxRect2DDouble(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect2DDouble(new wxRect2DDouble(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, GetBox_1)
@@ -412,14 +431,15 @@ Gura_DeclareMethod(wx_GraphicsPath, GetBox_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, GetBox_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
-	wxDouble *w = Object_wx_Double::GetObject(args, 2)->GetEntity();
-	wxDouble *h = Object_wx_Double::GetObject(args, 3)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
+	wxDouble *w = Object_wx_Double::GetObject(arg, 2)->GetEntity();
+	wxDouble *h = Object_wx_Double::GetObject(arg, 3)->GetEntity();
 	pThis->GetEntity()->GetBox(x, y, w, h);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, GetCurrentPoint)
@@ -431,12 +451,13 @@ Gura_DeclareMethod(wx_GraphicsPath, GetCurrentPoint)
 
 Gura_ImplementMethod(wx_GraphicsPath, GetCurrentPoint)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDouble *x = Object_wx_Double::GetObject(args, 0)->GetEntity();
-	wxDouble *y = Object_wx_Double::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDouble *x = Object_wx_Double::GetObject(arg, 0)->GetEntity();
+	wxDouble *y = Object_wx_Double::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->GetCurrentPoint(x, y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, GetCurrentPoint_1)
@@ -447,10 +468,11 @@ Gura_DeclareMethod(wx_GraphicsPath, GetCurrentPoint_1)
 
 Gura_ImplementMethod(wx_GraphicsPath, GetCurrentPoint_1)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint2DDouble rtn = pThis->GetEntity()->GetCurrentPoint();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point2DDouble(new wxPoint2DDouble(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point2DDouble(new wxPoint2DDouble(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, Transform)
@@ -461,11 +483,12 @@ Gura_DeclareMethod(wx_GraphicsPath, Transform)
 
 Gura_ImplementMethod(wx_GraphicsPath, Transform)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGraphicsMatrix *matrix = Object_wx_GraphicsMatrix::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGraphicsMatrix *matrix = Object_wx_GraphicsMatrix::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Transform(*matrix);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, GetNativePath)
@@ -475,10 +498,11 @@ Gura_DeclareMethod(wx_GraphicsPath, GetNativePath)
 
 Gura_ImplementMethod(wx_GraphicsPath, GetNativePath)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetNativePath();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GraphicsPath, UnGetNativePath)
@@ -489,11 +513,12 @@ Gura_DeclareMethod(wx_GraphicsPath, UnGetNativePath)
 
 Gura_ImplementMethod(wx_GraphicsPath, UnGetNativePath)
 {
-	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int p = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_GraphicsPath *pThis = Object_wx_GraphicsPath::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int p = arg.GetInt(0);
 	pThis->GetEntity()->UnGetNativePath(p);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -505,13 +530,13 @@ Object_wx_GraphicsPath::~Object_wx_GraphicsPath()
 
 Object *Object_wx_GraphicsPath::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_GraphicsPath::ToString(bool exprFlag)
 {
 	String rtn("<wx.GraphicsPath:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -555,7 +580,7 @@ Gura_ImplementUserInheritableClass(wx_GraphicsPath)
 
 Gura_ImplementDescendantCreator(wx_GraphicsPath)
 {
-	return new Object_wx_GraphicsPath((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_GraphicsPath((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
