@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_GridBagSizer: public wxGridBagSizer, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_GridBagSizer *_pObj;
 public:
-	inline wx_GridBagSizer(int vgap, int hgap) : wxGridBagSizer(vgap, hgap), _sig(NULL), _pObj(NULL) {}
+	inline wx_GridBagSizer(int vgap, int hgap) : wxGridBagSizer(vgap, hgap), _pObj(nullptr) {}
 	~wx_GridBagSizer();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_GridBagSizer *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_GridBagSizer *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_GridBagSizer::~wx_GridBagSizer()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_GridBagSizer::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,21 +47,22 @@ Gura_DeclareFunction(GridBagSizer)
 
 Gura_ImplementFunction(GridBagSizer)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	int vgap = 0;
-	if (args.IsValid(0)) vgap = args.GetInt(0);
+	if (arg.IsValid(0)) vgap = arg.GetInt(0);
 	int hgap = 0;
-	if (args.IsValid(1)) hgap = args.GetInt(1);
+	if (arg.IsValid(1)) hgap = arg.GetInt(1);
 	wx_GridBagSizer *pEntity = new wx_GridBagSizer(vgap, hgap);
-	Object_wx_GridBagSizer *pObj = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_GridBagSizer *pObj = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_GridBagSizer(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, Add)
@@ -78,29 +79,30 @@ Gura_DeclareMethod(wx_GridBagSizer, Add)
 
 Gura_ImplementMethod(wx_GridBagSizer, Add)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBPosition *pos = Object_wx_GBPosition::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBPosition *pos = Object_wx_GBPosition::GetObject(arg, 1)->GetEntity();
 	wxGBSpan *span = (wxGBSpan *)(&wxDefaultSpan);
-	if (args.IsValid(2)) span = Object_wx_GBSpan::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) span = Object_wx_GBSpan::GetObject(arg, 2)->GetEntity();
 	int flag = 0;
-	if (args.IsValid(3)) flag = args.GetInt(3);
+	if (arg.IsValid(3)) flag = arg.GetInt(3);
 	int border = 0;
-	if (args.IsValid(4)) border = args.GetInt(4);
-	wxObject *userData = (wxObject *)(NULL);
-	if (args.IsValid(5)) userData = Object_wx_Object::GetObject(args, 5)->GetEntity();
-	wxSizerItem *rtn = NULL;
-	if (args.IsInstanceOf(0, VTYPE_wx_Window)) {
-		wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	if (arg.IsValid(4)) border = arg.GetInt(4);
+	wxObject *userData = (wxObject *)(nullptr);
+	if (arg.IsValid(5)) userData = Object_wx_Object::GetObject(arg, 5)->GetEntity();
+	wxSizerItem *rtn = nullptr;
+	if (arg.IsInstanceOf(0, VTYPE_wx_Window)) {
+		wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 		rtn = (wxSizerItem *)pThis->GetEntity()->Add(window, *pos, *span, flag, border, userData);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Sizer)) {
-		wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Sizer)) {
+		wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
 		rtn = (wxSizerItem *)pThis->GetEntity()->Add(sizer, *pos, *span, flag, border, userData);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_wx_SizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_SizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, AddSpacer)
@@ -118,21 +120,22 @@ Gura_DeclareMethod(wx_GridBagSizer, AddSpacer)
 
 Gura_ImplementMethod(wx_GridBagSizer, AddSpacer)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
-	int height = args.GetInt(1);
-	wxGBPosition *pos = Object_wx_GBPosition::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
+	int height = arg.GetInt(1);
+	wxGBPosition *pos = Object_wx_GBPosition::GetObject(arg, 2)->GetEntity();
 	wxGBSpan *span = (wxGBSpan *)(&wxDefaultSpan);
-	if (args.IsValid(3)) span = Object_wx_GBSpan::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) span = Object_wx_GBSpan::GetObject(arg, 3)->GetEntity();
 	int flag = 0;
-	if (args.IsValid(4)) flag = args.GetInt(4);
+	if (arg.IsValid(4)) flag = arg.GetInt(4);
 	int border = 0;
-	if (args.IsValid(5)) border = args.GetInt(5);
-	wxObject *userData = (wxObject *)(NULL);
-	if (args.IsValid(6)) userData = Object_wx_Object::GetObject(args, 6)->GetEntity();
+	if (arg.IsValid(5)) border = arg.GetInt(5);
+	wxObject *userData = (wxObject *)(nullptr);
+	if (arg.IsValid(6)) userData = Object_wx_Object::GetObject(arg, 6)->GetEntity();
 	wxSizerItem *rtn = (wxSizerItem *)pThis->GetEntity()->Add(width, height, *pos, *span, flag, border, userData);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_SizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, AddItem)
@@ -144,11 +147,12 @@ Gura_DeclareMethod(wx_GridBagSizer, AddItem)
 
 Gura_ImplementMethod(wx_GridBagSizer, AddItem)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBSizerItem *item = Object_wx_GBSizerItem::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBSizerItem *item = Object_wx_GBSizerItem::GetObject(arg, 0)->GetEntity();
 	wxSizerItem *rtn = (wxSizerItem *)pThis->GetEntity()->Add(item);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_SizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, CalcMin)
@@ -159,10 +163,11 @@ Gura_DeclareMethod(wx_GridBagSizer, CalcMin)
 
 Gura_ImplementMethod(wx_GridBagSizer, CalcMin)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->CalcMin();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, CheckForIntersection)
@@ -175,13 +180,14 @@ Gura_DeclareMethod(wx_GridBagSizer, CheckForIntersection)
 
 Gura_ImplementMethod(wx_GridBagSizer, CheckForIntersection)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBSizerItem *item = Object_wx_GBSizerItem::GetObject(args, 0)->GetEntity();
-	wxGBSizerItem *excludeItem = (wxGBSizerItem *)(NULL);
-	if (args.IsValid(1)) excludeItem = Object_wx_GBSizerItem::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBSizerItem *item = Object_wx_GBSizerItem::GetObject(arg, 0)->GetEntity();
+	wxGBSizerItem *excludeItem = (wxGBSizerItem *)(nullptr);
+	if (arg.IsValid(1)) excludeItem = Object_wx_GBSizerItem::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->CheckForIntersection(item, excludeItem);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, CheckForIntersectionPos)
@@ -195,14 +201,15 @@ Gura_DeclareMethod(wx_GridBagSizer, CheckForIntersectionPos)
 
 Gura_ImplementMethod(wx_GridBagSizer, CheckForIntersectionPos)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBPosition *pos = Object_wx_GBPosition::GetObject(args, 0)->GetEntity();
-	wxGBSpan *span = Object_wx_GBSpan::GetObject(args, 1)->GetEntity();
-	wxGBSizerItem *excludeItem = (wxGBSizerItem *)(NULL);
-	if (args.IsValid(2)) excludeItem = Object_wx_GBSizerItem::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBPosition *pos = Object_wx_GBPosition::GetObject(arg, 0)->GetEntity();
+	wxGBSpan *span = Object_wx_GBSpan::GetObject(arg, 1)->GetEntity();
+	wxGBSizerItem *excludeItem = (wxGBSizerItem *)(nullptr);
+	if (arg.IsValid(2)) excludeItem = Object_wx_GBSizerItem::GetObject(arg, 2)->GetEntity();
 	bool rtn = pThis->GetEntity()->CheckForIntersection(*pos, *span, excludeItem);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, FindItem)
@@ -214,20 +221,21 @@ Gura_DeclareMethod(wx_GridBagSizer, FindItem)
 
 Gura_ImplementMethod(wx_GridBagSizer, FindItem)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBSizerItem *rtn = NULL;
-	if (args.IsInstanceOf(0, VTYPE_wx_Window)) {
-		wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBSizerItem *rtn = nullptr;
+	if (arg.IsInstanceOf(0, VTYPE_wx_Window)) {
+		wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 		rtn = (wxGBSizerItem *)pThis->GetEntity()->FindItem(window);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Sizer)) {
-		wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Sizer)) {
+		wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
 		rtn = (wxGBSizerItem *)pThis->GetEntity()->FindItem(sizer);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_wx_GBSizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GBSizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, FindItemAtPoint)
@@ -239,11 +247,12 @@ Gura_DeclareMethod(wx_GridBagSizer, FindItemAtPoint)
 
 Gura_ImplementMethod(wx_GridBagSizer, FindItemAtPoint)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	wxGBSizerItem *rtn = (wxGBSizerItem *)pThis->GetEntity()->FindItemAtPoint(*pt);
-	return ReturnValue(env, sig, args, Value(new Object_wx_GBSizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GBSizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, FindItemAtPosition)
@@ -255,11 +264,12 @@ Gura_DeclareMethod(wx_GridBagSizer, FindItemAtPosition)
 
 Gura_ImplementMethod(wx_GridBagSizer, FindItemAtPosition)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBPosition *pos = Object_wx_GBPosition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBPosition *pos = Object_wx_GBPosition::GetObject(arg, 0)->GetEntity();
 	wxGBSizerItem *rtn = (wxGBSizerItem *)pThis->GetEntity()->FindItemAtPosition(*pos);
-	return ReturnValue(env, sig, args, Value(new Object_wx_GBSizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GBSizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, FindItemWithData)
@@ -271,11 +281,12 @@ Gura_DeclareMethod(wx_GridBagSizer, FindItemWithData)
 
 Gura_ImplementMethod(wx_GridBagSizer, FindItemWithData)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxObject *userData = Object_wx_Object::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxObject *userData = Object_wx_Object::GetObject(arg, 0)->GetEntity();
 	wxGBSizerItem *rtn = (wxGBSizerItem *)pThis->GetEntity()->FindItemWithData(userData);
-	return ReturnValue(env, sig, args, Value(new Object_wx_GBSizerItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GBSizerItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, GetCellSize)
@@ -288,12 +299,13 @@ Gura_DeclareMethod(wx_GridBagSizer, GetCellSize)
 
 Gura_ImplementMethod(wx_GridBagSizer, GetCellSize)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int row = args.GetInt(0);
-	int col = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int row = arg.GetInt(0);
+	int col = arg.GetInt(1);
 	wxSize rtn = pThis->GetEntity()->GetCellSize(row, col);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, GetEmptyCellSize)
@@ -304,10 +316,11 @@ Gura_DeclareMethod(wx_GridBagSizer, GetEmptyCellSize)
 
 Gura_ImplementMethod(wx_GridBagSizer, GetEmptyCellSize)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetEmptyCellSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, GetItemPosition)
@@ -319,23 +332,24 @@ Gura_DeclareMethod(wx_GridBagSizer, GetItemPosition)
 
 Gura_ImplementMethod(wx_GridBagSizer, GetItemPosition)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxGBPosition rtn;
-	if (args.IsInstanceOf(0, VTYPE_wx_Window)) {
-		wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	if (arg.IsInstanceOf(0, VTYPE_wx_Window)) {
+		wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->GetItemPosition(window);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Sizer)) {
-		wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Sizer)) {
+		wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->GetItemPosition(sizer);
-	} else if (args.IsInstanceOf(0, VTYPE_number)) {
-		size_t index = args.GetSizeT(0);
+	} else if (arg.IsInstanceOf(0, VTYPE_number)) {
+		size_t index = arg.GetSizeT(0);
 		rtn = pThis->GetEntity()->GetItemPosition(index);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_wx_GBPosition(new wxGBPosition(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_GBPosition(new wxGBPosition(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, GetItemSpan)
@@ -347,23 +361,24 @@ Gura_DeclareMethod(wx_GridBagSizer, GetItemSpan)
 
 Gura_ImplementMethod(wx_GridBagSizer, GetItemSpan)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxGBSpan rtn;
-	if (args.IsInstanceOf(0, VTYPE_wx_Window)) {
-		wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	if (arg.IsInstanceOf(0, VTYPE_wx_Window)) {
+		wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->GetItemSpan(window);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Sizer)) {
-		wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Sizer)) {
+		wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->GetItemSpan(sizer);
-	} else if (args.IsInstanceOf(0, VTYPE_number)) {
-		size_t index = args.GetSizeT(0);
+	} else if (arg.IsInstanceOf(0, VTYPE_number)) {
+		size_t index = arg.GetSizeT(0);
 		rtn = pThis->GetEntity()->GetItemSpan(index);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_wx_GBSpan(new wxGBSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_GBSpan(new wxGBSpan(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, RecalcSizes)
@@ -373,10 +388,11 @@ Gura_DeclareMethod(wx_GridBagSizer, RecalcSizes)
 
 Gura_ImplementMethod(wx_GridBagSizer, RecalcSizes)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->RecalcSizes();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, SetEmptyCellSize)
@@ -387,11 +403,12 @@ Gura_DeclareMethod(wx_GridBagSizer, SetEmptyCellSize)
 
 Gura_ImplementMethod(wx_GridBagSizer, SetEmptyCellSize)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *sz = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *sz = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetEmptyCellSize(*sz);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, SetItemPosition)
@@ -404,24 +421,25 @@ Gura_DeclareMethod(wx_GridBagSizer, SetItemPosition)
 
 Gura_ImplementMethod(wx_GridBagSizer, SetItemPosition)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBPosition *pos = Object_wx_GBPosition::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBPosition *pos = Object_wx_GBPosition::GetObject(arg, 1)->GetEntity();
 	bool rtn = false;
-	if (args.IsInstanceOf(0, VTYPE_wx_Window)) {
-		wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	if (arg.IsInstanceOf(0, VTYPE_wx_Window)) {
+		wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->SetItemPosition(window, *pos);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Sizer)) {
-		wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Sizer)) {
+		wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->SetItemPosition(sizer, *pos);
-	} else if (args.IsInstanceOf(0, VTYPE_number)) {
-		size_t index = args.GetSizeT(0);
+	} else if (arg.IsInstanceOf(0, VTYPE_number)) {
+		size_t index = arg.GetSizeT(0);
 		rtn = pThis->GetEntity()->SetItemPosition(index, *pos);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridBagSizer, SetItemSpan)
@@ -434,24 +452,25 @@ Gura_DeclareMethod(wx_GridBagSizer, SetItemSpan)
 
 Gura_ImplementMethod(wx_GridBagSizer, SetItemSpan)
 {
-	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGBSpan *span = Object_wx_GBSpan::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridBagSizer *pThis = Object_wx_GridBagSizer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGBSpan *span = Object_wx_GBSpan::GetObject(arg, 1)->GetEntity();
 	bool rtn = false;
-	if (args.IsInstanceOf(0, VTYPE_wx_Window)) {
-		wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	if (arg.IsInstanceOf(0, VTYPE_wx_Window)) {
+		wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->SetItemSpan(window, *span);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Sizer)) {
-		wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Sizer)) {
+		wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
 		rtn = pThis->GetEntity()->SetItemSpan(sizer, *span);
-	} else if (args.IsInstanceOf(0, VTYPE_number)) {
-		size_t index = args.GetSizeT(0);
+	} else if (arg.IsInstanceOf(0, VTYPE_number)) {
+		size_t index = arg.GetSizeT(0);
 		bool rtn = pThis->GetEntity()->SetItemSpan(index, *span);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -463,13 +482,13 @@ Object_wx_GridBagSizer::~Object_wx_GridBagSizer()
 
 Object *Object_wx_GridBagSizer::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_GridBagSizer::ToString(bool exprFlag)
 {
 	String rtn("<wx.GridBagSizer:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -507,7 +526,7 @@ Gura_ImplementUserInheritableClass(wx_GridBagSizer)
 
 Gura_ImplementDescendantCreator(wx_GridBagSizer)
 {
-	return new Object_wx_GridBagSizer((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_GridBagSizer((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
