@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_GridCellAttr: public wxGridCellAttr, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_GridCellAttr *_pObj;
 public:
-	inline wx_GridCellAttr() : wxGridCellAttr(), _sig(NULL), _pObj(NULL) {}
-	inline wx_GridCellAttr(const wxColour& colText, const wxColour& colBack, const wxFont& font, int hAlign, int vAlign) : wxGridCellAttr(colText, colBack, font, hAlign, vAlign), _sig(NULL), _pObj(NULL) {}
+	inline wx_GridCellAttr() : wxGridCellAttr(), _pObj(nullptr) {}
+	inline wx_GridCellAttr(const wxColour& colText, const wxColour& colBack, const wxFont& font, int hAlign, int vAlign) : wxGridCellAttr(colText, colBack, font, hAlign, vAlign), _pObj(nullptr) {}
 	~wx_GridCellAttr();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_GridCellAttr *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_GridCellAttr *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_GridCellAttr::~wx_GridCellAttr()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_GridCellAttr::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(GridCellAttrEmpty)
 
 Gura_ImplementFunction(GridCellAttrEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_GridCellAttr *pEntity = new wx_GridCellAttr();
-	Object_wx_GridCellAttr *pObj = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_GridCellAttr *pObj = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_GridCellAttr(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(GridCellAttr)
@@ -73,22 +74,23 @@ Gura_DeclareFunction(GridCellAttr)
 
 Gura_ImplementFunction(GridCellAttr)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxColour *colText = Object_wx_Colour::GetObject(args, 0)->GetEntity();
-	wxColour *colBack = Object_wx_Colour::GetObject(args, 1)->GetEntity();
-	wxFont *font = Object_wx_Font::GetObject(args, 2)->GetEntity();
-	int hAlign = args.GetInt(3);
-	int vAlign = args.GetInt(4);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxColour *colText = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
+	wxColour *colBack = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
+	wxFont *font = Object_wx_Font::GetObject(arg, 2)->GetEntity();
+	int hAlign = arg.GetInt(3);
+	int vAlign = arg.GetInt(4);
 	wx_GridCellAttr *pEntity = new wx_GridCellAttr(*colText, *colBack, *font, hAlign, vAlign);
-	Object_wx_GridCellAttr *pObj = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_GridCellAttr *pObj = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_GridCellAttr(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, Clone)
@@ -99,10 +101,11 @@ Gura_DeclareMethod(wx_GridCellAttr, Clone)
 
 Gura_ImplementMethod(wx_GridCellAttr, Clone)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxGridCellAttr *rtn = (wxGridCellAttr *)pThis->GetEntity()->Clone();
-	return ReturnValue(env, sig, args, Value(new Object_wx_GridCellAttr(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GridCellAttr(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, IncRef)
@@ -112,10 +115,11 @@ Gura_DeclareMethod(wx_GridCellAttr, IncRef)
 
 Gura_ImplementMethod(wx_GridCellAttr, IncRef)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->IncRef();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, DecRef)
@@ -125,10 +129,11 @@ Gura_DeclareMethod(wx_GridCellAttr, DecRef)
 
 Gura_ImplementMethod(wx_GridCellAttr, DecRef)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DecRef();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetTextColour)
@@ -139,11 +144,12 @@ Gura_DeclareMethod(wx_GridCellAttr, SetTextColour)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetTextColour)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colText = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colText = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetTextColour(*colText);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetBackgroundColour)
@@ -154,11 +160,12 @@ Gura_DeclareMethod(wx_GridCellAttr, SetBackgroundColour)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetBackgroundColour)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colBack = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colBack = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetBackgroundColour(*colBack);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetFont)
@@ -169,11 +176,12 @@ Gura_DeclareMethod(wx_GridCellAttr, SetFont)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetFont)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetAlignment)
@@ -185,12 +193,13 @@ Gura_DeclareMethod(wx_GridCellAttr, SetAlignment)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetAlignment)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int hAlign = args.GetInt(0);
-	int vAlign = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int hAlign = arg.GetInt(0);
+	int vAlign = arg.GetInt(1);
 	pThis->GetEntity()->SetAlignment(hAlign, vAlign);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetReadOnly)
@@ -201,12 +210,13 @@ Gura_DeclareMethod(wx_GridCellAttr, SetReadOnly)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetReadOnly)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool isReadOnly = true;
-	if (args.IsValid(0)) isReadOnly = args.GetBoolean(0);
+	if (arg.IsValid(0)) isReadOnly = arg.GetBoolean(0);
 	pThis->GetEntity()->SetReadOnly(isReadOnly);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetRenderer)
@@ -217,11 +227,12 @@ Gura_DeclareMethod(wx_GridCellAttr, SetRenderer)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetRenderer)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGridCellRenderer *renderer = Object_wx_GridCellRenderer::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGridCellRenderer *renderer = Object_wx_GridCellRenderer::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetRenderer(renderer);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetEditor)
@@ -232,11 +243,12 @@ Gura_DeclareMethod(wx_GridCellAttr, SetEditor)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetEditor)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGridCellEditor *editor = Object_wx_GridCellEditor::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGridCellEditor *editor = Object_wx_GridCellEditor::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetEditor(editor);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, HasTextColour)
@@ -247,10 +259,11 @@ Gura_DeclareMethod(wx_GridCellAttr, HasTextColour)
 
 Gura_ImplementMethod(wx_GridCellAttr, HasTextColour)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasTextColour();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, HasBackgroundColour)
@@ -261,10 +274,11 @@ Gura_DeclareMethod(wx_GridCellAttr, HasBackgroundColour)
 
 Gura_ImplementMethod(wx_GridCellAttr, HasBackgroundColour)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasBackgroundColour();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, HasFont)
@@ -275,10 +289,11 @@ Gura_DeclareMethod(wx_GridCellAttr, HasFont)
 
 Gura_ImplementMethod(wx_GridCellAttr, HasFont)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasFont();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, HasAlignment)
@@ -289,10 +304,11 @@ Gura_DeclareMethod(wx_GridCellAttr, HasAlignment)
 
 Gura_ImplementMethod(wx_GridCellAttr, HasAlignment)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasAlignment();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, HasRenderer)
@@ -303,10 +319,11 @@ Gura_DeclareMethod(wx_GridCellAttr, HasRenderer)
 
 Gura_ImplementMethod(wx_GridCellAttr, HasRenderer)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasRenderer();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, HasEditor)
@@ -317,10 +334,11 @@ Gura_DeclareMethod(wx_GridCellAttr, HasEditor)
 
 Gura_ImplementMethod(wx_GridCellAttr, HasEditor)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasEditor();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, GetTextColour)
@@ -331,10 +349,11 @@ Gura_DeclareMethod(wx_GridCellAttr, GetTextColour)
 
 Gura_ImplementMethod(wx_GridCellAttr, GetTextColour)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetTextColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, GetBackgroundColour)
@@ -345,10 +364,11 @@ Gura_DeclareMethod(wx_GridCellAttr, GetBackgroundColour)
 
 Gura_ImplementMethod(wx_GridCellAttr, GetBackgroundColour)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetBackgroundColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, GetFont)
@@ -359,10 +379,11 @@ Gura_DeclareMethod(wx_GridCellAttr, GetFont)
 
 Gura_ImplementMethod(wx_GridCellAttr, GetFont)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxFont &rtn = pThis->GetEntity()->GetFont();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(new wxFont(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(new wxFont(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, GetAlignment)
@@ -373,12 +394,13 @@ Gura_DeclareMethod(wx_GridCellAttr, GetAlignment)
 
 Gura_ImplementMethod(wx_GridCellAttr, GetAlignment)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int hAlign = 0;
 	int vAlign = 0;
 	pThis->GetEntity()->GetAlignment(&hAlign, &vAlign);
-	return ReturnValue(env, sig, args, Value::CreateList(env, hAlign, vAlign));
+	return ReturnValue(env, arg, Value::CreateList(env, hAlign, vAlign));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, GetRenderer)
@@ -392,13 +414,14 @@ Gura_DeclareMethod(wx_GridCellAttr, GetRenderer)
 
 Gura_ImplementMethod(wx_GridCellAttr, GetRenderer)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGrid *grid = Object_wx_Grid::GetObject(args, 0)->GetEntity();
-	int row = args.GetInt(1);
-	int col = args.GetInt(2);
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGrid *grid = Object_wx_Grid::GetObject(arg, 0)->GetEntity();
+	int row = arg.GetInt(1);
+	int col = arg.GetInt(2);
 	wxGridCellRenderer *rtn = (wxGridCellRenderer *)pThis->GetEntity()->GetRenderer(grid, row, col);
-	return ReturnValue(env, sig, args, Value(new Object_wx_GridCellRenderer(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GridCellRenderer(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, GetEditor)
@@ -412,13 +435,14 @@ Gura_DeclareMethod(wx_GridCellAttr, GetEditor)
 
 Gura_ImplementMethod(wx_GridCellAttr, GetEditor)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGrid *grid = Object_wx_Grid::GetObject(args, 0)->GetEntity();
-	int row = args.GetInt(1);
-	int col = args.GetInt(2);
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGrid *grid = Object_wx_Grid::GetObject(arg, 0)->GetEntity();
+	int row = arg.GetInt(1);
+	int col = arg.GetInt(2);
 	wxGridCellEditor *rtn = (wxGridCellEditor *)pThis->GetEntity()->GetEditor(grid, row, col);
-	return ReturnValue(env, sig, args, Value(new Object_wx_GridCellEditor(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_GridCellEditor(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, IsReadOnly)
@@ -429,10 +453,11 @@ Gura_DeclareMethod(wx_GridCellAttr, IsReadOnly)
 
 Gura_ImplementMethod(wx_GridCellAttr, IsReadOnly)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsReadOnly();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_GridCellAttr, SetDefAttr)
@@ -443,11 +468,12 @@ Gura_DeclareMethod(wx_GridCellAttr, SetDefAttr)
 
 Gura_ImplementMethod(wx_GridCellAttr, SetDefAttr)
 {
-	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxGridCellAttr *defAttr = Object_wx_GridCellAttr::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_GridCellAttr *pThis = Object_wx_GridCellAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxGridCellAttr *defAttr = Object_wx_GridCellAttr::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetDefAttr(defAttr);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -455,20 +481,20 @@ Gura_ImplementMethod(wx_GridCellAttr, SetDefAttr)
 //----------------------------------------------------------------------------
 Object_wx_GridCellAttr::~Object_wx_GridCellAttr()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	//if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_GridCellAttr::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_GridCellAttr::ToString(bool exprFlag)
 {
 	String rtn("<wx.GridCellAttr:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -513,7 +539,7 @@ Gura_ImplementUserInheritableClass(wx_GridCellAttr)
 
 Gura_ImplementDescendantCreator(wx_GridCellAttr)
 {
-	return new Object_wx_GridCellAttr((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_GridCellAttr((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
