@@ -29,13 +29,13 @@ Gura_DeclarePrivUserSymbol(Quit);
 //----------------------------------------------------------------------------
 class wx_HelpController: public wxHelpController, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_HelpController *_pObj;
 public:
 #if defined(__WXMSW__)
-	inline wx_HelpController(wxWindow* parentWindow) : wxHelpController(parentWindow), _sig(NULL), _pObj(NULL) {}
+	inline wx_HelpController(wxWindow* parentWindow) : wxHelpController(parentWindow), _pObj(nullptr) {}
 #else
-	inline wx_HelpController(wxWindow* parentWindow) : wxHelpController(wxHF_DEFAULT_STYLE, parentWindow), _sig(NULL), _pObj(NULL) {}
+	inline wx_HelpController(wxWindow* parentWindow) : wxHelpController(wxHF_DEFAULT_STYLE, parentWindow), _pObj(nullptr) {}
 #endif
 	//virtual bool Initialize(const wxString& file);
 	//virtual bool Initialize(const wxString& file, int server);
@@ -55,8 +55,8 @@ public:
 	//virtual void SetViewer(const wxString& viewer, long flags);
 	//virtual bool Quit();
 	~wx_HelpController();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_HelpController *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_HelpController *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -64,12 +64,12 @@ public:
 
 wx_HelpController::~wx_HelpController()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_HelpController::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -85,19 +85,20 @@ Gura_DeclareFunction(HelpController)
 
 Gura_ImplementFunction(HelpController)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parentWindow = (wxWindow *)(NULL);
-	if (args.IsValid(0)) parentWindow = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parentWindow = (wxWindow *)(nullptr);
+	if (arg.IsValid(0)) parentWindow = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wx_HelpController *pEntity = new wx_HelpController(parentWindow);
-	Object_wx_HelpController *pObj = Object_wx_HelpController::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_HelpController *pObj = Object_wx_HelpController::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_HelpController(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_HelpController, Initialize)
@@ -109,11 +110,12 @@ Gura_DeclareMethod(wx_HelpController, Initialize)
 
 Gura_ImplementMethod(wx_HelpController, Initialize)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString file = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString file = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Initialize(file);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, Initialize_1)
@@ -126,12 +128,13 @@ Gura_DeclareMethod(wx_HelpController, Initialize_1)
 
 Gura_ImplementMethod(wx_HelpController, Initialize_1)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString file = wxString::FromUTF8(args.GetString(0));
-	int server = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString file = wxString::FromUTF8(arg.GetString(0));
+	int server = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->Initialize(file, server);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, DisplayBlock)
@@ -143,11 +146,12 @@ Gura_DeclareMethod(wx_HelpController, DisplayBlock)
 
 Gura_ImplementMethod(wx_HelpController, DisplayBlock)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long blockNo = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long blockNo = arg.GetLong(0);
 	bool rtn = pThis->GetEntity()->DisplayBlock(blockNo);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, DisplayContents)
@@ -158,10 +162,11 @@ Gura_DeclareMethod(wx_HelpController, DisplayContents)
 
 Gura_ImplementMethod(wx_HelpController, DisplayContents)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DisplayContents();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, DisplayContextPopup)
@@ -173,11 +178,12 @@ Gura_DeclareMethod(wx_HelpController, DisplayContextPopup)
 
 Gura_ImplementMethod(wx_HelpController, DisplayContextPopup)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int contextId = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int contextId = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->DisplayContextPopup(contextId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, DisplaySection)
@@ -189,11 +195,12 @@ Gura_DeclareMethod(wx_HelpController, DisplaySection)
 
 Gura_ImplementMethod(wx_HelpController, DisplaySection)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString section = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString section = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->DisplaySection(section);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, DisplaySection_1)
@@ -205,11 +212,12 @@ Gura_DeclareMethod(wx_HelpController, DisplaySection_1)
 
 Gura_ImplementMethod(wx_HelpController, DisplaySection_1)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int sectionNo = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int sectionNo = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->DisplaySection(sectionNo);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, DisplayTextPopup)
@@ -222,12 +230,13 @@ Gura_DeclareMethod(wx_HelpController, DisplayTextPopup)
 
 Gura_ImplementMethod(wx_HelpController, DisplayTextPopup)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
-	wxPoint *pos = Object_wx_Point::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->DisplayTextPopup(text, *pos);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, GetFrameParameters)
@@ -243,20 +252,21 @@ Gura_DeclareMethod(wx_HelpController, GetFrameParameters)
 
 Gura_ImplementMethod(wx_HelpController, GetFrameParameters)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = (wxSize *)(NULL);
-	if (args.IsValid(0)) size = Object_wx_Size::GetObject(args, 0)->GetEntity();
-	wxPoint *pos = (wxPoint *)(NULL);
-	if (args.IsValid(1)) pos = Object_wx_Point::GetObject(args, 1)->GetEntity();
-	bool newFrameEachTime = NULL;
-	if (args.IsValid(2)) newFrameEachTime = args.GetBoolean(2);
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = (wxSize *)(nullptr);
+	if (arg.IsValid(0)) size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
+	wxPoint *pos = (wxPoint *)(nullptr);
+	if (arg.IsValid(1)) pos = Object_wx_Point::GetObject(arg, 1)->GetEntity();
+	bool newFrameEachTime = nullptr;
+	if (arg.IsValid(2)) newFrameEachTime = arg.GetBoolean(2);
 	wxFrame *rtn = (wxFrame *)pThis->GetEntity()->GetFrameParameters(size, pos, newFrameEachTime);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Frame(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Frame(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HelpController, GetParentWindow)
@@ -267,10 +277,11 @@ Gura_DeclareMethod(wx_HelpController, GetParentWindow)
 
 Gura_ImplementMethod(wx_HelpController, GetParentWindow)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetParentWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HelpController, KeywordSearch)
@@ -283,13 +294,14 @@ Gura_DeclareMethod(wx_HelpController, KeywordSearch)
 
 Gura_ImplementMethod(wx_HelpController, KeywordSearch)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString keyWord = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString keyWord = wxString::FromUTF8(arg.GetString(0));
 	wxHelpSearchMode mode = wxHELP_SEARCH_ALL;
-	if (args.IsValid(1)) mode = static_cast<wxHelpSearchMode>(args.GetInt(1));
+	if (arg.IsValid(1)) mode = static_cast<wxHelpSearchMode>(arg.GetInt(1));
 	bool rtn = pThis->GetEntity()->KeywordSearch(keyWord, mode);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, LoadFile)
@@ -301,12 +313,13 @@ Gura_DeclareMethod(wx_HelpController, LoadFile)
 
 Gura_ImplementMethod(wx_HelpController, LoadFile)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString file = wxT("");
-	if (args.IsValid(0)) file = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) file = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->LoadFile(file);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HelpController, OnQuit)
@@ -317,10 +330,11 @@ Gura_DeclareMethod(wx_HelpController, OnQuit)
 
 Gura_ImplementMethod(wx_HelpController, OnQuit)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnQuit();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HelpController, SetFrameParameters)
@@ -334,16 +348,17 @@ Gura_DeclareMethod(wx_HelpController, SetFrameParameters)
 
 Gura_ImplementMethod(wx_HelpController, SetFrameParameters)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
-	wxSize *size = Object_wx_Size::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
+	wxSize *size = Object_wx_Size::GetObject(arg, 1)->GetEntity();
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	bool newFrameEachTime = false;
-	if (args.IsValid(3)) newFrameEachTime = args.GetBoolean(3);
+	if (arg.IsValid(3)) newFrameEachTime = arg.GetBoolean(3);
 	pThis->GetEntity()->SetFrameParameters(title, *size, *pos, newFrameEachTime);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HelpController, SetParentWindow)
@@ -354,11 +369,12 @@ Gura_DeclareMethod(wx_HelpController, SetParentWindow)
 
 Gura_ImplementMethod(wx_HelpController, SetParentWindow)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parentWindow = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parentWindow = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetParentWindow(parentWindow);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HelpController, SetViewer)
@@ -370,12 +386,13 @@ Gura_DeclareMethod(wx_HelpController, SetViewer)
 
 Gura_ImplementMethod(wx_HelpController, SetViewer)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString viewer = wxString::FromUTF8(args.GetString(0));
-	long flags = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString viewer = wxString::FromUTF8(arg.GetString(0));
+	long flags = arg.GetLong(1);
 	pThis->GetEntity()->SetViewer(viewer, flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HelpController, Quit)
@@ -386,10 +403,11 @@ Gura_DeclareMethod(wx_HelpController, Quit)
 
 Gura_ImplementMethod(wx_HelpController, Quit)
 {
-	Object_wx_HelpController *pThis = Object_wx_HelpController::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HelpController *pThis = Object_wx_HelpController::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Quit();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -401,13 +419,13 @@ Object_wx_HelpController::~Object_wx_HelpController()
 
 Object *Object_wx_HelpController::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_HelpController::ToString(bool exprFlag)
 {
 	String rtn("<wx.HelpController:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -461,7 +479,7 @@ Gura_ImplementUserInheritableClass(wx_HelpController)
 
 Gura_ImplementDescendantCreator(wx_HelpController)
 {
-	return new Object_wx_HelpController((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_HelpController((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
