@@ -14,16 +14,16 @@ Gura_DeclarePrivUserSymbol(SetDC);
 //----------------------------------------------------------------------------
 class wx_HtmlWinParser: public wxHtmlWinParser, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_HtmlWinParser *_pObj;
 public:
-	inline wx_HtmlWinParser() : wxHtmlWinParser(), _sig(NULL), _pObj(NULL) {}
-	//inline wx_HtmlWinParser(wxHtmlWindowInterface *wndIface) : wxHtmlWinParser(*wndIface), _sig(NULL), _pObj(NULL) {}
+	inline wx_HtmlWinParser() : wxHtmlWinParser(), _pObj(nullptr) {}
+	//inline wx_HtmlWinParser(wxHtmlWindowInterface *wndIface) : wxHtmlWinParser(*wndIface), _pObj(nullptr) {}
 	//virtual wxFont* CreateCurrentFont();
 	//virtual void SetDC(wxDC *dc, double pixel_scale);
 	~wx_HtmlWinParser();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_HtmlWinParser *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_HtmlWinParser *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -31,12 +31,12 @@ public:
 
 wx_HtmlWinParser::~wx_HtmlWinParser()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_HtmlWinParser::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -51,17 +51,18 @@ Gura_DeclareFunction(HtmlWinParserEmpty)
 
 Gura_ImplementFunction(HtmlWinParserEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_HtmlWinParser *pEntity = new wx_HtmlWinParser();
-	Object_wx_HtmlWinParser *pObj = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_HtmlWinParser *pObj = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_HtmlWinParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(HtmlWinParser)
@@ -76,22 +77,23 @@ Gura_DeclareFunction(HtmlWinParser)
 
 Gura_ImplementFunction(HtmlWinParser)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxHtmlWindowInterface **wndIface = Object_wx_HtmlWindowInterface::GetObject(args, 0)->GetEntity();
+	wxHtmlWindowInterface **wndIface = Object_wx_HtmlWindowInterface::GetObject(arg, 0)->GetEntity();
 	wx_HtmlWinParser *pEntity = new wx_HtmlWinParser(**wndIface);
-	Object_wx_HtmlWinParser *pObj = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_HtmlWinParser *pObj = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_HtmlWinParser(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_HtmlWinParser, AddModule)
@@ -104,14 +106,15 @@ Gura_DeclareClassMethod(wx_HtmlWinParser, AddModule)
 
 Gura_ImplementClassMethod(wx_HtmlWinParser, AddModule)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxHtmlTagsModule **module = Object_wx_HtmlTagsModule::GetObject(args, 0)->GetEntity();
+	wxHtmlTagsModule **module = Object_wx_HtmlTagsModule::GetObject(arg, 0)->GetEntity();
 	wxHtmlWinParser::AddModule(**module);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, CloseContainer)
@@ -122,10 +125,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, CloseContainer)
 
 Gura_ImplementMethod(wx_HtmlWinParser, CloseContainer)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxHtmlContainerCell *rtn = (wxHtmlContainerCell *)pThis->GetEntity()->CloseContainer();
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlContainerCell(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlContainerCell(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, CreateCurrentFont)
@@ -136,10 +140,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, CreateCurrentFont)
 
 Gura_ImplementMethod(wx_HtmlWinParser, CreateCurrentFont)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFont *rtn = (wxFont *)pThis->GetEntity()->CreateCurrentFont();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetActualColor)
@@ -150,10 +155,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetActualColor)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetActualColor)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetActualColor();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetAlign)
@@ -164,10 +170,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetAlign)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetAlign)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetAlign();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetCharHeight)
@@ -178,10 +185,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetCharHeight)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetCharHeight)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetCharHeight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetCharWidth)
@@ -192,10 +200,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetCharWidth)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetCharWidth)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetCharWidth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetContainer)
@@ -206,10 +215,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetContainer)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetContainer)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxHtmlContainerCell *rtn = (wxHtmlContainerCell *)pThis->GetEntity()->GetContainer();
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlContainerCell(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlContainerCell(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetDC)
@@ -220,10 +230,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetDC)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetDC)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDC *rtn = (wxDC *)pThis->GetEntity()->GetDC();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DC(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DC(rtn, nullptr, OwnerFalse)));
 }
 
 #if 0
@@ -235,14 +246,15 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetEncodingConverter)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetEncodingConverter)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxEncodingConverter *rtn = (wxEncodingConverter *)pThis->GetEntity()->GetEncodingConverter();
-	return ReturnValue(env, sig, args, Value(new Object_wx_EncodingConverter(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_EncodingConverter(rtn, nullptr, OwnerFalse)));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 #endif
@@ -255,10 +267,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetFontBold)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetFontBold)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFontBold();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetFontFace)
@@ -269,10 +282,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetFontFace)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetFontFace)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetFontFace();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetFontFixed)
@@ -283,10 +297,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetFontFixed)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetFontFixed)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFontFixed();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetFontItalic)
@@ -297,10 +312,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetFontItalic)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetFontItalic)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFontItalic();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetFontSize)
@@ -311,10 +327,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetFontSize)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetFontSize)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFontSize();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetFontUnderlined)
@@ -325,10 +342,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetFontUnderlined)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetFontUnderlined)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFontUnderlined();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 #if 0
@@ -340,14 +358,15 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetInputEncoding)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetInputEncoding)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFontEncoding rtn = pThis->GetEntity()->GetInputEncoding();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 #endif
@@ -360,10 +379,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetLink)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetLink)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxHtmlLinkInfo &rtn = pThis->GetEntity()->GetLink();
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlLinkInfo(new wxHtmlLinkInfo(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlLinkInfo(new wxHtmlLinkInfo(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, GetLinkColor)
@@ -374,10 +394,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetLinkColor)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetLinkColor)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetLinkColor();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 #if 0
@@ -389,14 +410,15 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetOutputEncoding)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetOutputEncoding)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFontEncoding rtn = pThis->GetEntity()->GetOutputEncoding();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 #endif
@@ -410,10 +432,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, GetWindow)
 
 Gura_ImplementMethod(wx_HtmlWinParser, GetWindow)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxHtmlWindow *rtn = (wxHtmlWindow *)pThis->GetEntity()->GetWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlWindow(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlWindow(rtn, nullptr, OwnerFalse)));
 }
 #endif
 
@@ -425,10 +448,11 @@ Gura_DeclareMethod(wx_HtmlWinParser, OpenContainer)
 
 Gura_ImplementMethod(wx_HtmlWinParser, OpenContainer)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxHtmlContainerCell *rtn = (wxHtmlContainerCell *)pThis->GetEntity()->OpenContainer();
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlContainerCell(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlContainerCell(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetActualColor)
@@ -439,11 +463,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetActualColor)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetActualColor)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *clr = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *clr = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetActualColor(*clr);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetAlign)
@@ -454,11 +479,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetAlign)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetAlign)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int a = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int a = arg.GetInt(0);
 	pThis->GetEntity()->SetAlign(a);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetContainer)
@@ -470,11 +496,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetContainer)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetContainer)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxHtmlContainerCell *c = Object_wx_HtmlContainerCell::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxHtmlContainerCell *c = Object_wx_HtmlContainerCell::GetObject(arg, 0)->GetEntity();
 	wxHtmlContainerCell *rtn = (wxHtmlContainerCell *)pThis->GetEntity()->SetContainer(c);
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlContainerCell(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlContainerCell(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetDC)
@@ -488,17 +515,18 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetDC)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetDC)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC **dc = Object_wx_DC::GetObject(args, 0)->GetEntity();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC **dc = Object_wx_DC::GetObject(arg, 0)->GetEntity();
 	double pixel_scale = 1.0;
-	if (args.IsValid(1)) pixel_scale = args.GetDouble(1);
+	if (arg.IsValid(1)) pixel_scale = arg.GetDouble(1);
 	pThis->GetEntity()->SetDC(**dc, pixel_scale);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFontBold)
@@ -509,11 +537,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFontBold)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFontBold)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
 	pThis->GetEntity()->SetFontBold(x);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFontFace)
@@ -524,11 +553,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFontFace)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFontFace)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString face = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString face = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetFontFace(face);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFontFixed)
@@ -539,11 +569,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFontFixed)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFontFixed)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
 	pThis->GetEntity()->SetFontFixed(x);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFontItalic)
@@ -554,11 +585,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFontItalic)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFontItalic)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
 	pThis->GetEntity()->SetFontItalic(x);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFontSize)
@@ -569,11 +601,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFontSize)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFontSize)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int s = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int s = arg.GetInt(0);
 	pThis->GetEntity()->SetFontSize(s);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFontUnderlined)
@@ -584,11 +617,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFontUnderlined)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFontUnderlined)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
 	pThis->GetEntity()->SetFontUnderlined(x);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetFonts)
@@ -603,18 +637,19 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetFonts)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetFonts)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString normal_face = wxString::FromUTF8(args.GetString(0));
-	wxString fixed_face = wxString::FromUTF8(args.GetString(1));
-	int *sizes = NULL;
-	if (args.IsValid(2)) *sizes = args.GetInt(2);
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString normal_face = wxString::FromUTF8(arg.GetString(0));
+	wxString fixed_face = wxString::FromUTF8(arg.GetString(1));
+	int *sizes = nullptr;
+	if (arg.IsValid(2)) *sizes = arg.GetInt(2);
 	pThis->GetEntity()->SetFonts(normal_face, fixed_face, *sizes);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 #if 0
@@ -626,15 +661,16 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetInputEncoding)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetInputEncoding)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFontEncoding enc = static_cast<wxFontEncoding>(args.GetInt(0));
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFontEncoding enc = static_cast<wxFontEncoding>(arg.GetInt(0));
 	pThis->GetEntity()->SetInputEncoding(enc);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 #endif
@@ -647,11 +683,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetLink)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetLink)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxHtmlLinkInfo *link = Object_wx_HtmlLinkInfo::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxHtmlLinkInfo *link = Object_wx_HtmlLinkInfo::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetLink(*link);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWinParser, SetLinkColor)
@@ -662,11 +699,12 @@ Gura_DeclareMethod(wx_HtmlWinParser, SetLinkColor)
 
 Gura_ImplementMethod(wx_HtmlWinParser, SetLinkColor)
 {
-	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *clr = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWinParser *pThis = Object_wx_HtmlWinParser::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *clr = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetLinkColor(*clr);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -678,13 +716,13 @@ Object_wx_HtmlWinParser::~Object_wx_HtmlWinParser()
 
 Object *Object_wx_HtmlWinParser::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_HtmlWinParser::ToString(bool exprFlag)
 {
 	String rtn("<wx.HtmlWinParser:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -743,7 +781,7 @@ Gura_ImplementUserInheritableClass(wx_HtmlWinParser)
 
 Gura_ImplementDescendantCreator(wx_HtmlWinParser)
 {
-	return new Object_wx_HtmlWinParser((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_HtmlWinParser((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
