@@ -21,11 +21,11 @@ Gura_DeclarePrivUserSymbol(WriteCustomization);
 //----------------------------------------------------------------------------
 class wx_HtmlWindow: public wxHtmlWindow, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	AutoPtr<Object_wx_HtmlWindow> _pObj;
 public:
-	inline wx_HtmlWindow() : wxHtmlWindow(), _sig(NULL), _pObj(NULL) {}
-	inline wx_HtmlWindow(wxWindow *parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxHtmlWindow(parent, id, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_HtmlWindow() : wxHtmlWindow(), _pObj(nullptr) {}
+	inline wx_HtmlWindow(wxWindow *parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxHtmlWindow(parent, id, pos, size, style, name), _pObj(nullptr) {}
 	//virtual bool LoadFile(const wxFileName& filename);
 	//virtual bool LoadPage(const wxString& location);
 	virtual bool OnCellClicked(wxHtmlCell *cell, wxCoord x, wxCoord y, const wxMouseEvent& event);
@@ -36,8 +36,8 @@ public:
 	//virtual void ReadCustomization(wxConfigBase *cfg, wxString path);
 	//virtual void WriteCustomization(wxConfigBase *cfg, wxString path);
 	~wx_HtmlWindow();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_HtmlWindow *pObj) {
-		_sig = sig, _pObj.reset(Object_wx_HtmlWindow::Reference(pObj));
+	inline void AssocWithGura(Object_wx_HtmlWindow *pObj) {
+		_pObj.reset(Object_wx_HtmlWindow::Reference(pObj));
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -71,69 +71,69 @@ void wx_HtmlWindow::GuraObjectDeleted()
 bool wx_HtmlWindow::OnCellClicked(wxHtmlCell *cell, wxCoord x, wxCoord y, const wxMouseEvent& event)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnCellClicked);
-	if (pFunc == NULL) return wxHtmlWindow::OnCellClicked(cell, x, y, event);
+	if (pFunc == nullptr) return wxHtmlWindow::OnCellClicked(cell, x, y, event);
 	Environment &env = *_pObj;
 	ValueList valList;
 	valList.reserve(4);
-	valList.push_back(Value(new Object_wx_HtmlCell(cell, NULL, OwnerFalse)));
+	valList.push_back(Value(new Object_wx_HtmlCell(cell, nullptr, OwnerFalse)));
 	valList.push_back(Value(x));
 	valList.push_back(Value(y));
-	valList.push_back(Value(new Object_wx_MouseEvent(const_cast<wxMouseEvent *>(&event), NULL, OwnerTrue)));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valList);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_boolean)) return false;
+	valList.push_back(Value(new Object_wx_MouseEvent(const_cast<wxMouseEvent *>(&event), nullptr, OwnerTrue)));
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valList);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_boolean)) return false;
 	return rtn.GetBoolean();
 }
 
 void wx_HtmlWindow::OnCellMouseHover(wxHtmlCell *cell, wxCoord x, wxCoord y)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnCellMouseHover);
-	if (pFunc == NULL) {
+	if (pFunc == nullptr) {
 		wxHtmlWindow::OnCellMouseHover(cell, x, y);
 		return;
 	}
 	Environment &env = *_pObj;
 	ValueList valList;
 	valList.reserve(3);
-	valList.push_back(Value(new Object_wx_HtmlCell(cell, NULL, OwnerFalse)));
+	valList.push_back(Value(new Object_wx_HtmlCell(cell, nullptr, OwnerFalse)));
 	valList.push_back(Value(x));
 	valList.push_back(Value(y));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valList);
-	CheckMethodResult(_sig);
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valList);
+	CheckMethodResult(_pObj->GetSignal());
 }
 
 void wx_HtmlWindow::OnLinkClicked(const wxHtmlLinkInfo& link)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnLinkClicked);
-	if (pFunc == NULL) {
+	if (pFunc == nullptr) {
 		wxHtmlWindow::OnLinkClicked(link);
 		return;
 	}
 	Environment &env = *_pObj;
 	ValueList valList;
 	valList.reserve(1);
-	valList.push_back(Value(new Object_wx_HtmlLinkInfo(const_cast<wxHtmlLinkInfo *>(&link), NULL, OwnerTrue)));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valList);
-	CheckMethodResult(_sig);
+	valList.push_back(Value(new Object_wx_HtmlLinkInfo(const_cast<wxHtmlLinkInfo *>(&link), nullptr, OwnerTrue)));
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valList);
+	CheckMethodResult(_pObj->GetSignal());
 }
 
 wxHtmlOpeningStatus wx_HtmlWindow::OnOpeningURL(wxHtmlURLType type, const wxString& url, wxString * redirect)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnOpeningURL);
-	if (pFunc == NULL) return wxHtmlWindow::OnOpeningURL(type, url, redirect);
+	if (pFunc == nullptr) return wxHtmlWindow::OnOpeningURL(type, url, redirect);
 	Environment &env = *_pObj;
 	ValueList valList;
 	valList.reserve(2);
 	valList.push_back(Value(type));
 	valList.push_back(Value(url.ToUTF8()));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valList);
-	if (!CheckMethodResult(_sig, rtn, VTYPE_list)) return wxHTML_OPEN;
-	ValueList &valListRtn = rtn.GetList();
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valList);
+	if (!CheckMethodResult(_pObj->GetSignal(), rtn, VTYPE_list)) return wxHTML_OPEN;
+	const ValueList &valListRtn = rtn.GetList();
 	if (valListRtn.size() != 2) {
-		_sig.SetError(ERR_ValueError, "a list of two elements is expected");
+		_pObj->GetSignal().SetError(ERR_ValueError, "a list of two elements is expected");
 		return wxHTML_OPEN;
 	}
 	if (!valListRtn[0].Is_number() || valListRtn[1].Is_string()) {
-		_sig.SetError(ERR_ValueError, "unexpected result type");
+		_pObj->GetSignal().SetError(ERR_ValueError, "unexpected result type");
 		return wxHTML_OPEN;
 	}
 	*redirect = wxString::FromUTF8(valListRtn[1].GetString());
@@ -143,7 +143,7 @@ wxHtmlOpeningStatus wx_HtmlWindow::OnOpeningURL(wxHtmlURLType type, const wxStri
 void wx_HtmlWindow::OnSetTitle(const wxString& title)
 {
 	const Function *pFunc = Gura_LookupWxMethod(_pObj, OnSetTitle);
-	if (pFunc == NULL) {
+	if (pFunc == nullptr) {
 		wxHtmlWindow::OnSetTitle(title);
 		return;
 	}
@@ -151,8 +151,8 @@ void wx_HtmlWindow::OnSetTitle(const wxString& title)
 	ValueList valList;
 	valList.reserve(1);
 	valList.push_back(Value(title.ToUTF8()));
-	Value rtn = _pObj->EvalMethod(*_pObj, _sig, pFunc, valList);
-	CheckMethodResult(_sig);
+	Value rtn = _pObj->EvalMethod(*_pObj, pFunc, valList);
+	CheckMethodResult(_pObj->GetSignal());
 }
 
 //----------------------------------------------------------------------------
@@ -167,17 +167,18 @@ Gura_DeclareFunction(HtmlWindowEmpty)
 
 Gura_ImplementFunction(HtmlWindowEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_HtmlWindow *pEntity = new wx_HtmlWindow();
-	Object_wx_HtmlWindow *pObj = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_HtmlWindow *pObj = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_HtmlWindow(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(HtmlWindow)
@@ -195,28 +196,29 @@ Gura_DeclareFunction(HtmlWindow)
 
 Gura_ImplementFunction(HtmlWindow)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = -1;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = wxHW_DEFAULT_STYLE;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxT("htmlWindow");
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	wx_HtmlWindow *pEntity = new wx_HtmlWindow(parent, id, *pos, *size, style, name);
-	Object_wx_HtmlWindow *pObj = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_HtmlWindow *pObj = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_HtmlWindow(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareClassMethod(wx_HtmlWindow, AddFilter)
@@ -227,10 +229,11 @@ Gura_DeclareClassMethod(wx_HtmlWindow, AddFilter)
 
 Gura_ImplementClassMethod(wx_HtmlWindow, AddFilter)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxHtmlFilter *filter = Object_wx_HtmlFilter::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxHtmlFilter *filter = Object_wx_HtmlFilter::GetObject(arg, 0)->GetEntity();
 	wxHtmlWindow::AddFilter(filter);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, AppendToPage)
@@ -242,11 +245,12 @@ Gura_DeclareMethod(wx_HtmlWindow, AppendToPage)
 
 Gura_ImplementMethod(wx_HtmlWindow, AppendToPage)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString source = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString source = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->AppendToPage(source);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, GetInternalRepresentation)
@@ -257,10 +261,11 @@ Gura_DeclareMethod(wx_HtmlWindow, GetInternalRepresentation)
 
 Gura_ImplementMethod(wx_HtmlWindow, GetInternalRepresentation)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxHtmlContainerCell *rtn = (wxHtmlContainerCell *)pThis->GetEntity()->GetInternalRepresentation();
-	return ReturnValue(env, sig, args, Value(new Object_wx_HtmlContainerCell(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_HtmlContainerCell(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, GetOpenedAnchor)
@@ -271,10 +276,11 @@ Gura_DeclareMethod(wx_HtmlWindow, GetOpenedAnchor)
 
 Gura_ImplementMethod(wx_HtmlWindow, GetOpenedAnchor)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetOpenedAnchor();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, GetOpenedPage)
@@ -285,10 +291,11 @@ Gura_DeclareMethod(wx_HtmlWindow, GetOpenedPage)
 
 Gura_ImplementMethod(wx_HtmlWindow, GetOpenedPage)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetOpenedPage();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, GetOpenedPageTitle)
@@ -299,10 +306,11 @@ Gura_DeclareMethod(wx_HtmlWindow, GetOpenedPageTitle)
 
 Gura_ImplementMethod(wx_HtmlWindow, GetOpenedPageTitle)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetOpenedPageTitle();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, GetRelatedFrame)
@@ -313,10 +321,11 @@ Gura_DeclareMethod(wx_HtmlWindow, GetRelatedFrame)
 
 Gura_ImplementMethod(wx_HtmlWindow, GetRelatedFrame)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFrame *rtn = (wxFrame *)pThis->GetEntity()->GetRelatedFrame();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Frame(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Frame(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, HistoryBack)
@@ -327,10 +336,11 @@ Gura_DeclareMethod(wx_HtmlWindow, HistoryBack)
 
 Gura_ImplementMethod(wx_HtmlWindow, HistoryBack)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HistoryBack();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, HistoryCanBack)
@@ -341,10 +351,11 @@ Gura_DeclareMethod(wx_HtmlWindow, HistoryCanBack)
 
 Gura_ImplementMethod(wx_HtmlWindow, HistoryCanBack)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HistoryCanBack();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, HistoryCanForward)
@@ -355,10 +366,11 @@ Gura_DeclareMethod(wx_HtmlWindow, HistoryCanForward)
 
 Gura_ImplementMethod(wx_HtmlWindow, HistoryCanForward)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HistoryCanForward();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, HistoryClear)
@@ -368,10 +380,11 @@ Gura_DeclareMethod(wx_HtmlWindow, HistoryClear)
 
 Gura_ImplementMethod(wx_HtmlWindow, HistoryClear)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->HistoryClear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, HistoryForward)
@@ -382,10 +395,11 @@ Gura_DeclareMethod(wx_HtmlWindow, HistoryForward)
 
 Gura_ImplementMethod(wx_HtmlWindow, HistoryForward)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HistoryForward();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, LoadFile)
@@ -397,11 +411,12 @@ Gura_DeclareMethod(wx_HtmlWindow, LoadFile)
 
 Gura_ImplementMethod(wx_HtmlWindow, LoadFile)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFileName *filename = Object_wx_FileName::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFileName *filename = Object_wx_FileName::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->LoadFile(*filename);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, LoadPage)
@@ -413,11 +428,12 @@ Gura_DeclareMethod(wx_HtmlWindow, LoadPage)
 
 Gura_ImplementMethod(wx_HtmlWindow, LoadPage)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString location = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString location = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->LoadPage(location);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, OnCellClicked)
@@ -432,14 +448,15 @@ Gura_DeclareMethod(wx_HtmlWindow, OnCellClicked)
 
 Gura_ImplementMethod(wx_HtmlWindow, OnCellClicked)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxHtmlCell *cell = Object_wx_HtmlCell::GetObject(args, 0)->GetEntity();
-	wxCoord x = static_cast<wxCoord>(args.GetInt(1));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(2));
-	wxMouseEvent *event = Object_wx_MouseEvent::GetObject(args, 3)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxHtmlCell *cell = Object_wx_HtmlCell::GetObject(arg, 0)->GetEntity();
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(1));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(2));
+	wxMouseEvent *event = Object_wx_MouseEvent::GetObject(arg, 3)->GetEntity();
 	bool rtn = ((wx_HtmlWindow *)pThis->GetEntity())->_OnCellClicked(cell, x, y, *event);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, OnCellMouseHover)
@@ -452,13 +469,14 @@ Gura_DeclareMethod(wx_HtmlWindow, OnCellMouseHover)
 
 Gura_ImplementMethod(wx_HtmlWindow, OnCellMouseHover)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxHtmlCell *cell = Object_wx_HtmlCell::GetObject(args, 0)->GetEntity();
-	wxCoord x = static_cast<wxCoord>(args.GetInt(1));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxHtmlCell *cell = Object_wx_HtmlCell::GetObject(arg, 0)->GetEntity();
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(1));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(2));
 	((wx_HtmlWindow *)pThis->GetEntity())->_OnCellMouseHover(cell, x, y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, OnLinkClicked)
@@ -469,11 +487,12 @@ Gura_DeclareMethod(wx_HtmlWindow, OnLinkClicked)
 
 Gura_ImplementMethod(wx_HtmlWindow, OnLinkClicked)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxHtmlLinkInfo *link = Object_wx_HtmlLinkInfo::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxHtmlLinkInfo *link = Object_wx_HtmlLinkInfo::GetObject(arg, 0)->GetEntity();
 	((wx_HtmlWindow *)pThis->GetEntity())->_OnLinkClicked(*link);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, OnOpeningURL)
@@ -486,13 +505,14 @@ Gura_DeclareMethod(wx_HtmlWindow, OnOpeningURL)
 
 Gura_ImplementMethod(wx_HtmlWindow, OnOpeningURL)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxHtmlURLType type = static_cast<wxHtmlURLType>(args.GetInt(0));
-	wxString url = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxHtmlURLType type = static_cast<wxHtmlURLType>(arg.GetInt(0));
+	wxString url = wxString::FromUTF8(arg.GetString(1));
 	wxString redirect;
 	wxHtmlOpeningStatus rtn = ((wx_HtmlWindow *)pThis->GetEntity())->_OnOpeningURL(type, url, &redirect);
-	return ReturnValue(env, sig, args, Value::CreateList(env,
+	return ReturnValue(env, arg, Value::CreateList(env,
 							Value(rtn), Value(redirect.ToUTF8())));
 }
 
@@ -504,11 +524,12 @@ Gura_DeclareMethod(wx_HtmlWindow, OnSetTitle)
 
 Gura_ImplementMethod(wx_HtmlWindow, OnSetTitle)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
 	((wx_HtmlWindow *)pThis->GetEntity())->_OnSetTitle(title);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, ReadCustomization)
@@ -520,13 +541,14 @@ Gura_DeclareMethod(wx_HtmlWindow, ReadCustomization)
 
 Gura_ImplementMethod(wx_HtmlWindow, ReadCustomization)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxConfigBase *cfg = Object_wx_ConfigBase::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxConfigBase *cfg = Object_wx_ConfigBase::GetObject(arg, 0)->GetEntity();
 	wxString path = wxEmptyString;
-	if (args.IsValid(1)) path = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) path = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->ReadCustomization(cfg, path);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SelectAll)
@@ -536,10 +558,11 @@ Gura_DeclareMethod(wx_HtmlWindow, SelectAll)
 
 Gura_ImplementMethod(wx_HtmlWindow, SelectAll)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->SelectAll();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SelectionToText)
@@ -550,10 +573,11 @@ Gura_DeclareMethod(wx_HtmlWindow, SelectionToText)
 
 Gura_ImplementMethod(wx_HtmlWindow, SelectionToText)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->SelectionToText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SelectLine)
@@ -564,11 +588,12 @@ Gura_DeclareMethod(wx_HtmlWindow, SelectLine)
 
 Gura_ImplementMethod(wx_HtmlWindow, SelectLine)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pos = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SelectLine(*pos);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SelectWord)
@@ -579,11 +604,12 @@ Gura_DeclareMethod(wx_HtmlWindow, SelectWord)
 
 Gura_ImplementMethod(wx_HtmlWindow, SelectWord)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pos = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SelectWord(*pos);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SetBorders)
@@ -594,11 +620,12 @@ Gura_DeclareMethod(wx_HtmlWindow, SetBorders)
 
 Gura_ImplementMethod(wx_HtmlWindow, SetBorders)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int b = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int b = arg.GetInt(0);
 	pThis->GetEntity()->SetBorders(b);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SetFonts)
@@ -606,31 +633,32 @@ Gura_DeclareMethod(wx_HtmlWindow, SetFonts)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "normal_face", VTYPE_string, OCCUR_Once);
 	DeclareArg(env, "fixed_face", VTYPE_string, OCCUR_Once);
-	DeclareArg(env, "sizes", VTYPE_number, OCCUR_ZeroOrOnce, FLAG_List);
+	DeclareArg(env, "sizes", VTYPE_number, OCCUR_ZeroOrOnce, FLAG_ListVar);
 }
 
 Gura_ImplementMethod(wx_HtmlWindow, SetFonts)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString normal_face = wxString::FromUTF8(args.GetString(0));
-	wxString fixed_face = wxString::FromUTF8(args.GetString(1));
-	int *sizes = NULL;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString normal_face = wxString::FromUTF8(arg.GetString(0));
+	wxString fixed_face = wxString::FromUTF8(arg.GetString(1));
+	int *sizes = nullptr;
 	int sizesBuff[7] = { 0, 0, 0, 0, 0, 0, 0 };
-	if (args.IsValid(2)) {
-		if (args.GetList(2).size() != 7) {
+	if (arg.IsValid(2)) {
+		if (arg.GetList(2).size() != 7) {
 			sig.SetError(ERR_ValueError, "sizes must contain seven numbers");
-			return Value::Null;
+			return Value::Nil;
 		}
 		size_t i = 0;
-		foreach_const (ValueList, pValue, args.GetList(2)) {
+		foreach_const (ValueList, pValue, arg.GetList(2)) {
 			const Value &value = *pValue;
 			sizes[i++] = value.GetInt();
 		}
 		sizes = sizesBuff;
 	}
 	pThis->GetEntity()->SetFonts(normal_face, fixed_face, sizes);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SetPage)
@@ -642,11 +670,12 @@ Gura_DeclareMethod(wx_HtmlWindow, SetPage)
 
 Gura_ImplementMethod(wx_HtmlWindow, SetPage)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString source = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString source = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->SetPage(source);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SetRelatedFrame)
@@ -658,12 +687,13 @@ Gura_DeclareMethod(wx_HtmlWindow, SetRelatedFrame)
 
 Gura_ImplementMethod(wx_HtmlWindow, SetRelatedFrame)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFrame *frame = Object_wx_Frame::GetObject(args, 0)->GetEntity();
-	wxString format = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFrame *frame = Object_wx_Frame::GetObject(arg, 0)->GetEntity();
+	wxString format = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetRelatedFrame(frame, format);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, SetRelatedStatusBar)
@@ -674,11 +704,12 @@ Gura_DeclareMethod(wx_HtmlWindow, SetRelatedStatusBar)
 
 Gura_ImplementMethod(wx_HtmlWindow, SetRelatedStatusBar)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int bar = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int bar = arg.GetInt(0);
 	pThis->GetEntity()->SetRelatedStatusBar(bar);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, ToText)
@@ -689,10 +720,11 @@ Gura_DeclareMethod(wx_HtmlWindow, ToText)
 
 Gura_ImplementMethod(wx_HtmlWindow, ToText)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->ToText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_HtmlWindow, WriteCustomization)
@@ -704,13 +736,14 @@ Gura_DeclareMethod(wx_HtmlWindow, WriteCustomization)
 
 Gura_ImplementMethod(wx_HtmlWindow, WriteCustomization)
 {
-	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxConfigBase *cfg = Object_wx_ConfigBase::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_HtmlWindow *pThis = Object_wx_HtmlWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxConfigBase *cfg = Object_wx_ConfigBase::GetObject(arg, 0)->GetEntity();
 	wxString path = wxEmptyString;
-	if (args.IsValid(1)) path = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) path = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->WriteCustomization(cfg, path);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -722,13 +755,13 @@ Object_wx_HtmlWindow::~Object_wx_HtmlWindow()
 
 Object *Object_wx_HtmlWindow::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_HtmlWindow::ToString(bool exprFlag)
 {
 	String rtn("<wx.HtmlWindow:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -789,7 +822,7 @@ Gura_ImplementUserInheritableClass(wx_HtmlWindow)
 
 Gura_ImplementDescendantCreator(wx_HtmlWindow)
 {
-	return new Object_wx_HtmlWindow((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_HtmlWindow((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
