@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Joystick: public wxJoystick, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Joystick *_pObj;
 public:
-	inline wx_Joystick(int joystick) : wxJoystick(joystick), _sig(NULL), _pObj(NULL) {}
+	inline wx_Joystick(int joystick) : wxJoystick(joystick), _pObj(nullptr) {}
 	~wx_Joystick();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Joystick *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Joystick *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_Joystick::~wx_Joystick()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Joystick::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,19 +46,20 @@ Gura_DeclareFunction(Joystick)
 
 Gura_ImplementFunction(Joystick)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	int joystick = wxJOYSTICK1;
-	if (args.IsValid(0)) joystick = args.GetInt(0);
+	if (arg.IsValid(0)) joystick = arg.GetInt(0);
 	wx_Joystick *pEntity = new wx_Joystick(joystick);
-	Object_wx_Joystick *pObj = Object_wx_Joystick::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Joystick *pObj = Object_wx_Joystick::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Joystick(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Joystick, GetButtonState)
@@ -69,10 +70,11 @@ Gura_DeclareMethod(wx_Joystick, GetButtonState)
 
 Gura_ImplementMethod(wx_Joystick, GetButtonState)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetButtonState();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetManufacturerId)
@@ -83,10 +85,11 @@ Gura_DeclareMethod(wx_Joystick, GetManufacturerId)
 
 Gura_ImplementMethod(wx_Joystick, GetManufacturerId)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetManufacturerId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetMovementThreshold)
@@ -97,10 +100,11 @@ Gura_DeclareMethod(wx_Joystick, GetMovementThreshold)
 
 Gura_ImplementMethod(wx_Joystick, GetMovementThreshold)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMovementThreshold();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetNumberAxes)
@@ -111,10 +115,11 @@ Gura_DeclareMethod(wx_Joystick, GetNumberAxes)
 
 Gura_ImplementMethod(wx_Joystick, GetNumberAxes)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetNumberAxes();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetNumberButtons)
@@ -125,10 +130,11 @@ Gura_DeclareMethod(wx_Joystick, GetNumberButtons)
 
 Gura_ImplementMethod(wx_Joystick, GetNumberButtons)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetNumberButtons();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Joystick, GetNumberJoysticks)
@@ -139,9 +145,10 @@ Gura_DeclareClassMethod(wx_Joystick, GetNumberJoysticks)
 
 Gura_ImplementClassMethod(wx_Joystick, GetNumberJoysticks)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	int rtn = wxJoystick::GetNumberJoysticks();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetPollingMax)
@@ -152,10 +159,11 @@ Gura_DeclareMethod(wx_Joystick, GetPollingMax)
 
 Gura_ImplementMethod(wx_Joystick, GetPollingMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetPollingMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetPollingMin)
@@ -166,10 +174,11 @@ Gura_DeclareMethod(wx_Joystick, GetPollingMin)
 
 Gura_ImplementMethod(wx_Joystick, GetPollingMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetPollingMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetProductId)
@@ -180,10 +189,11 @@ Gura_DeclareMethod(wx_Joystick, GetProductId)
 
 Gura_ImplementMethod(wx_Joystick, GetProductId)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetProductId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetProductName)
@@ -194,10 +204,11 @@ Gura_DeclareMethod(wx_Joystick, GetProductName)
 
 Gura_ImplementMethod(wx_Joystick, GetProductName)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetProductName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetPosition)
@@ -208,10 +219,11 @@ Gura_DeclareMethod(wx_Joystick, GetPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetPosition();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetPOVPosition)
@@ -222,10 +234,11 @@ Gura_DeclareMethod(wx_Joystick, GetPOVPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetPOVPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetPOVPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetPOVCTSPosition)
@@ -236,10 +249,11 @@ Gura_DeclareMethod(wx_Joystick, GetPOVCTSPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetPOVCTSPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetPOVCTSPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetRudderMax)
@@ -250,10 +264,11 @@ Gura_DeclareMethod(wx_Joystick, GetRudderMax)
 
 Gura_ImplementMethod(wx_Joystick, GetRudderMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetRudderMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetRudderMin)
@@ -264,10 +279,11 @@ Gura_DeclareMethod(wx_Joystick, GetRudderMin)
 
 Gura_ImplementMethod(wx_Joystick, GetRudderMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetRudderMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetRudderPosition)
@@ -278,10 +294,11 @@ Gura_DeclareMethod(wx_Joystick, GetRudderPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetRudderPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetRudderPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetUMax)
@@ -292,10 +309,11 @@ Gura_DeclareMethod(wx_Joystick, GetUMax)
 
 Gura_ImplementMethod(wx_Joystick, GetUMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetUMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetUMin)
@@ -306,10 +324,11 @@ Gura_DeclareMethod(wx_Joystick, GetUMin)
 
 Gura_ImplementMethod(wx_Joystick, GetUMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetUMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetUPosition)
@@ -320,10 +339,11 @@ Gura_DeclareMethod(wx_Joystick, GetUPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetUPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetUPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetVMax)
@@ -334,10 +354,11 @@ Gura_DeclareMethod(wx_Joystick, GetVMax)
 
 Gura_ImplementMethod(wx_Joystick, GetVMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetVMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetVMin)
@@ -348,10 +369,11 @@ Gura_DeclareMethod(wx_Joystick, GetVMin)
 
 Gura_ImplementMethod(wx_Joystick, GetVMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetVMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetVPosition)
@@ -362,10 +384,11 @@ Gura_DeclareMethod(wx_Joystick, GetVPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetVPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetVPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetXMax)
@@ -376,10 +399,11 @@ Gura_DeclareMethod(wx_Joystick, GetXMax)
 
 Gura_ImplementMethod(wx_Joystick, GetXMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetXMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetXMin)
@@ -390,10 +414,11 @@ Gura_DeclareMethod(wx_Joystick, GetXMin)
 
 Gura_ImplementMethod(wx_Joystick, GetXMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetXMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetYMax)
@@ -404,10 +429,11 @@ Gura_DeclareMethod(wx_Joystick, GetYMax)
 
 Gura_ImplementMethod(wx_Joystick, GetYMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetYMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetYMin)
@@ -418,10 +444,11 @@ Gura_DeclareMethod(wx_Joystick, GetYMin)
 
 Gura_ImplementMethod(wx_Joystick, GetYMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetYMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetZMax)
@@ -432,10 +459,11 @@ Gura_DeclareMethod(wx_Joystick, GetZMax)
 
 Gura_ImplementMethod(wx_Joystick, GetZMax)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetZMax();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetZMin)
@@ -446,10 +474,11 @@ Gura_DeclareMethod(wx_Joystick, GetZMin)
 
 Gura_ImplementMethod(wx_Joystick, GetZMin)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetZMin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, GetZPosition)
@@ -460,10 +489,11 @@ Gura_DeclareMethod(wx_Joystick, GetZPosition)
 
 Gura_ImplementMethod(wx_Joystick, GetZPosition)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetZPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasPOV)
@@ -474,10 +504,11 @@ Gura_DeclareMethod(wx_Joystick, HasPOV)
 
 Gura_ImplementMethod(wx_Joystick, HasPOV)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasPOV();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasPOV4Dir)
@@ -488,10 +519,11 @@ Gura_DeclareMethod(wx_Joystick, HasPOV4Dir)
 
 Gura_ImplementMethod(wx_Joystick, HasPOV4Dir)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasPOV4Dir();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasPOVCTS)
@@ -502,10 +534,11 @@ Gura_DeclareMethod(wx_Joystick, HasPOVCTS)
 
 Gura_ImplementMethod(wx_Joystick, HasPOVCTS)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasPOVCTS();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasRudder)
@@ -516,10 +549,11 @@ Gura_DeclareMethod(wx_Joystick, HasRudder)
 
 Gura_ImplementMethod(wx_Joystick, HasRudder)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasRudder();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasU)
@@ -530,10 +564,11 @@ Gura_DeclareMethod(wx_Joystick, HasU)
 
 Gura_ImplementMethod(wx_Joystick, HasU)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasU();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasV)
@@ -544,10 +579,11 @@ Gura_DeclareMethod(wx_Joystick, HasV)
 
 Gura_ImplementMethod(wx_Joystick, HasV)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasV();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, HasZ)
@@ -558,10 +594,11 @@ Gura_DeclareMethod(wx_Joystick, HasZ)
 
 Gura_ImplementMethod(wx_Joystick, HasZ)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasZ();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, IsOk)
@@ -572,10 +609,11 @@ Gura_DeclareMethod(wx_Joystick, IsOk)
 
 Gura_ImplementMethod(wx_Joystick, IsOk)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, ReleaseCapture)
@@ -586,10 +624,11 @@ Gura_DeclareMethod(wx_Joystick, ReleaseCapture)
 
 Gura_ImplementMethod(wx_Joystick, ReleaseCapture)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ReleaseCapture();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, SetCapture)
@@ -602,13 +641,14 @@ Gura_DeclareMethod(wx_Joystick, SetCapture)
 
 Gura_ImplementMethod(wx_Joystick, SetCapture)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	int pollingFreq = 0;
-	if (args.IsValid(1)) pollingFreq = args.GetInt(1);
+	if (arg.IsValid(1)) pollingFreq = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->SetCapture(win, pollingFreq);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Joystick, SetMovementThreshold)
@@ -619,11 +659,12 @@ Gura_DeclareMethod(wx_Joystick, SetMovementThreshold)
 
 Gura_ImplementMethod(wx_Joystick, SetMovementThreshold)
 {
-	Object_wx_Joystick *pThis = Object_wx_Joystick::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int threshold = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Joystick *pThis = Object_wx_Joystick::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int threshold = arg.GetInt(0);
 	pThis->GetEntity()->SetMovementThreshold(threshold);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -635,13 +676,13 @@ Object_wx_Joystick::~Object_wx_Joystick()
 
 Object *Object_wx_Joystick::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Joystick::ToString(bool exprFlag)
 {
 	String rtn("<wx.Joystick:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -701,7 +742,7 @@ Gura_ImplementUserInheritableClass(wx_Joystick)
 
 Gura_ImplementDescendantCreator(wx_Joystick)
 {
-	return new Object_wx_Joystick((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Joystick((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
