@@ -11,15 +11,15 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Locale: public wxLocale, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Locale *_pObj;
 public:
-	inline wx_Locale() : wxLocale(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Locale(int language, int flags) : wxLocale(language, flags), _sig(NULL), _pObj(NULL) {}
-	//inline wx_Locale(const char *szName, const char *szShort, const char *szLocale, bool bLoadDefault, bool bConvertEncoding) : wxLocale(*szName, *szShort, *szLocale, bLoadDefault, bConvertEncoding), _sig(NULL), _pObj(NULL) {}
+	inline wx_Locale() : wxLocale(), _pObj(nullptr) {}
+	inline wx_Locale(int language, int flags) : wxLocale(language, flags), _pObj(nullptr) {}
+	//inline wx_Locale(const char *szName, const char *szShort, const char *szLocale, bool bLoadDefault, bool bConvertEncoding) : wxLocale(*szName, *szShort, *szLocale, bLoadDefault, bConvertEncoding), _pObj(nullptr) {}
 	~wx_Locale();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Locale *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Locale *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -27,12 +27,12 @@ public:
 
 wx_Locale::~wx_Locale()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Locale::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,25 +49,26 @@ Gura_DeclareFunction(Locale)
 
 Gura_ImplementFunction(Locale)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wx_Locale *pEntity = NULL;
-	if (args.IsValid(0)) {
-		int language = args.GetInt(0);
-		int flags = wxLOCALE_LOAD_DEFAULT | wxLOCALE_CONV_ENCODING;
-		if (args.IsValid(1)) flags = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wx_Locale *pEntity = nullptr;
+	if (arg.IsValid(0)) {
+		int language = arg.GetInt(0);
+		int flags = wxLOCALE_LOAD_DEFAULT;
+		if (arg.IsValid(1)) flags = arg.GetInt(1);
 		pEntity = new wx_Locale(language, flags);
 	} else {
 		pEntity = new wx_Locale();
 	}
-	Object_wx_Locale *pObj = Object_wx_Locale::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Locale *pObj = Object_wx_Locale::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Locale(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 #if 0
@@ -87,30 +88,31 @@ Gura_DeclareFunction(Locale_1)
 
 Gura_ImplementFunction(Locale_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	char *szName = args.GetChar(0);
-	char *szShort = NULL;
-	if (args.IsValid(1)) *szShort = args.GetChar(1);
-	char *szLocale = NULL;
-	if (args.IsValid(2)) *szLocale = args.GetChar(2);
+	char *szName = arg.GetChar(0);
+	char *szShort = nullptr;
+	if (arg.IsValid(1)) *szShort = arg.GetChar(1);
+	char *szLocale = nullptr;
+	if (arg.IsValid(2)) *szLocale = arg.GetChar(2);
 	bool bLoadDefault = true;
-	if (args.IsValid(3)) bLoadDefault = args.GetBoolean(3);
+	if (arg.IsValid(3)) bLoadDefault = arg.GetBoolean(3);
 	bool bConvertEncoding = false;
-	if (args.IsValid(4)) bConvertEncoding = args.GetBoolean(4);
+	if (arg.IsValid(4)) bConvertEncoding = arg.GetBoolean(4);
 	wx_Locale *pEntity = new wx_Locale(*szName, *szShort, *szLocale, bLoadDefault, bConvertEncoding);
-	Object_wx_Locale *pObj = Object_wx_Locale::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Locale *pObj = Object_wx_Locale::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Locale(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 #endif
 
@@ -125,23 +127,24 @@ Gura_DeclareMethod(wx_Locale, AddCatalog)
 
 Gura_ImplementMethod(wx_Locale, AddCatalog)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = false;
-	if (args.IsValid(1) && args.IsValid(2)) {
-		const char *szDomain = args.GetString(0);
-		wxLanguage msgIdLanguage = static_cast<wxLanguage>(args.GetInt(1));
-		const char *msgIdCharset = args.GetString(2);
+	if (arg.IsValid(1) && arg.IsValid(2)) {
+		const char *szDomain = arg.GetString(0);
+		wxLanguage msgIdLanguage = static_cast<wxLanguage>(arg.GetInt(1));
+		const char *msgIdCharset = arg.GetString(2);
 		rtn = pThis->GetEntity()->AddCatalog(szDomain, msgIdLanguage, msgIdCharset);
 	} else {
-		const char *szDomain = args.GetString(0);
+		const char *szDomain = arg.GetString(0);
 		rtn = pThis->GetEntity()->AddCatalog(szDomain);
 	}
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -153,10 +156,11 @@ Gura_DeclareClassMethod(wx_Locale, AddCatalogLookupPathPrefix)
 
 Gura_ImplementClassMethod(wx_Locale, AddCatalogLookupPathPrefix)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString prefix = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString prefix = wxString::FromUTF8(arg.GetString(0));
 	wxLocale::AddCatalogLookupPathPrefix(prefix);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_Locale, AddLanguage)
@@ -167,10 +171,11 @@ Gura_DeclareClassMethod(wx_Locale, AddLanguage)
 
 Gura_ImplementClassMethod(wx_Locale, AddLanguage)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxLanguageInfo *info = Object_wx_LanguageInfo::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxLanguageInfo *info = Object_wx_LanguageInfo::GetObject(arg, 0)->GetEntity();
 	wxLocale::AddLanguage(*info);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_Locale, FindLanguageInfo)
@@ -182,14 +187,15 @@ Gura_DeclareClassMethod(wx_Locale, FindLanguageInfo)
 
 Gura_ImplementClassMethod(wx_Locale, FindLanguageInfo)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString locale = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString locale = wxString::FromUTF8(arg.GetString(0));
 	wxLanguageInfo *rtn = (wxLanguageInfo *)wxLocale::FindLanguageInfo(locale);
 	Value value;
-	if (rtn != NULL) {
-		value = Value(new Object_wx_LanguageInfo(rtn, NULL, OwnerFalse));
+	if (rtn != nullptr) {
+		value = Value(new Object_wx_LanguageInfo(rtn, nullptr, OwnerFalse));
 	}
-	return ReturnValue(env, sig, args, value);
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Locale, GetCanonicalName)
@@ -200,10 +206,11 @@ Gura_DeclareMethod(wx_Locale, GetCanonicalName)
 
 Gura_ImplementMethod(wx_Locale, GetCanonicalName)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetCanonicalName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Locale, GetLanguage)
@@ -214,10 +221,11 @@ Gura_DeclareMethod(wx_Locale, GetLanguage)
 
 Gura_ImplementMethod(wx_Locale, GetLanguage)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLanguage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Locale, GetLanguageInfo)
@@ -229,14 +237,15 @@ Gura_DeclareClassMethod(wx_Locale, GetLanguageInfo)
 
 Gura_ImplementClassMethod(wx_Locale, GetLanguageInfo)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int lang = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int lang = arg.GetInt(0);
 	wxLanguageInfo *rtn = (wxLanguageInfo *)wxLocale::GetLanguageInfo(lang);
 	Value value;
-	if (rtn != NULL) {
-		value = Value(new Object_wx_LanguageInfo(rtn, NULL, OwnerFalse));
+	if (rtn != nullptr) {
+		value = Value(new Object_wx_LanguageInfo(rtn, nullptr, OwnerFalse));
 	}
-	return ReturnValue(env, sig, args, value);
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareClassMethod(wx_Locale, GetLanguageName)
@@ -248,10 +257,11 @@ Gura_DeclareClassMethod(wx_Locale, GetLanguageName)
 
 Gura_ImplementClassMethod(wx_Locale, GetLanguageName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int lang = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int lang = arg.GetInt(0);
 	wxString rtn = wxLocale::GetLanguageName(lang);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Locale, GetLocale)
@@ -262,10 +272,11 @@ Gura_DeclareMethod(wx_Locale, GetLocale)
 
 Gura_ImplementMethod(wx_Locale, GetLocale)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = wxString(pThis->GetEntity()->GetLocale());
-	return ReturnValue(env, sig, args, Value(rtn.ToUTF8()));
+	return ReturnValue(env, arg, Value(rtn.ToUTF8()));
 }
 
 Gura_DeclareMethod(wx_Locale, GetName)
@@ -276,10 +287,11 @@ Gura_DeclareMethod(wx_Locale, GetName)
 
 Gura_ImplementMethod(wx_Locale, GetName)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Locale, GetString)
@@ -294,17 +306,18 @@ Gura_DeclareMethod(wx_Locale, GetString)
 
 Gura_ImplementMethod(wx_Locale, GetString)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char *szOrigString = args.GetChar(0);
-	char *szDomain = NULL;
-	if (args.IsValid(1)) *szDomain = args.GetChar(1);
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char *szOrigString = arg.GetChar(0);
+	char *szDomain = nullptr;
+	if (arg.IsValid(1)) *szDomain = arg.GetChar(1);
 	char rtn = pThis->GetEntity()->GetString(*szOrigString, *szDomain);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Locale, GetString_1)
@@ -321,19 +334,20 @@ Gura_DeclareMethod(wx_Locale, GetString_1)
 
 Gura_ImplementMethod(wx_Locale, GetString_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char *szOrigString = args.GetChar(0);
-	char *szOrigString2 = args.GetChar(1);
-	size_t n = args.GetSizeT(2);
-	char *szDomain = NULL;
-	if (args.IsValid(3)) *szDomain = args.GetChar(3);
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char *szOrigString = arg.GetChar(0);
+	char *szOrigString2 = arg.GetChar(1);
+	size_t n = arg.GetSizeT(2);
+	char *szDomain = nullptr;
+	if (arg.IsValid(3)) *szDomain = arg.GetChar(3);
 	char rtn = pThis->GetEntity()->GetString(*szOrigString, *szOrigString2, n, *szDomain);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Locale, GetHeaderValue)
@@ -346,17 +360,18 @@ Gura_DeclareMethod(wx_Locale, GetHeaderValue)
 
 Gura_ImplementMethod(wx_Locale, GetHeaderValue)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	const char *szHeader = args.GetString(0);
-	const char *szDomain = NULL;
-	if (args.IsValid(1)) szDomain = args.GetString(1);
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	const char *szHeader = arg.GetString(0);
+	const char *szDomain = nullptr;
+	if (arg.IsValid(1)) szDomain = arg.GetString(1);
 	wxString rtn = pThis->GetEntity()->GetHeaderValue(szHeader, szDomain);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -368,10 +383,11 @@ Gura_DeclareMethod(wx_Locale, GetSysName)
 
 Gura_ImplementMethod(wx_Locale, GetSysName)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetSysName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_Locale, GetSystemEncoding)
@@ -382,9 +398,10 @@ Gura_DeclareClassMethod(wx_Locale, GetSystemEncoding)
 
 Gura_ImplementClassMethod(wx_Locale, GetSystemEncoding)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxFontEncoding rtn = wxLocale::GetSystemEncoding();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_Locale, GetSystemEncodingName)
@@ -395,9 +412,10 @@ Gura_DeclareClassMethod(wx_Locale, GetSystemEncodingName)
 
 Gura_ImplementClassMethod(wx_Locale, GetSystemEncodingName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxString rtn = wxLocale::GetSystemEncodingName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_Locale, GetSystemLanguage)
@@ -408,9 +426,10 @@ Gura_DeclareClassMethod(wx_Locale, GetSystemLanguage)
 
 Gura_ImplementClassMethod(wx_Locale, GetSystemLanguage)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	int rtn = wxLocale::GetSystemLanguage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Locale, Init)
@@ -423,14 +442,15 @@ Gura_DeclareMethod(wx_Locale, Init)
 
 Gura_ImplementMethod(wx_Locale, Init)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int language = wxLANGUAGE_DEFAULT;
-	if (args.IsValid(0)) language = args.GetInt(0);
-	int flags = wxLOCALE_LOAD_DEFAULT | wxLOCALE_CONV_ENCODING;
-	if (args.IsValid(1)) flags = args.GetInt(1);
+	if (arg.IsValid(0)) language = arg.GetInt(0);
+	int flags = wxLOCALE_LOAD_DEFAULT;
+	if (arg.IsValid(1)) flags = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->Init(language, flags);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Locale, Init_1)
@@ -448,23 +468,24 @@ Gura_DeclareMethod(wx_Locale, Init_1)
 
 Gura_ImplementMethod(wx_Locale, Init_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char *szName = args.GetChar(0);
-	char *szShort = NULL;
-	if (args.IsValid(1)) *szShort = args.GetChar(1);
-	char *szLocale = NULL;
-	if (args.IsValid(2)) *szLocale = args.GetChar(2);
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char *szName = arg.GetChar(0);
+	char *szShort = nullptr;
+	if (arg.IsValid(1)) *szShort = arg.GetChar(1);
+	char *szLocale = nullptr;
+	if (arg.IsValid(2)) *szLocale = arg.GetChar(2);
 	bool bLoadDefault = true;
-	if (args.IsValid(3)) bLoadDefault = args.GetBoolean(3);
+	if (arg.IsValid(3)) bLoadDefault = arg.GetBoolean(3);
 	bool bConvertEncoding = false;
-	if (args.IsValid(4)) bConvertEncoding = args.GetBoolean(4);
+	if (arg.IsValid(4)) bConvertEncoding = arg.GetBoolean(4);
 	bool rtn = pThis->GetEntity()->Init(*szName, *szShort, *szLocale, bLoadDefault, bConvertEncoding);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_Locale, IsAvailable)
@@ -476,10 +497,11 @@ Gura_DeclareClassMethod(wx_Locale, IsAvailable)
 
 Gura_ImplementClassMethod(wx_Locale, IsAvailable)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int lang = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int lang = arg.GetInt(0);
 	bool rtn = wxLocale::IsAvailable(lang);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Locale, IsLoaded)
@@ -491,15 +513,16 @@ Gura_DeclareMethod(wx_Locale, IsLoaded)
 
 Gura_ImplementMethod(wx_Locale, IsLoaded)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	const char *domain = args.GetString(0);
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	const char *domain = arg.GetString(0);
 	bool rtn = pThis->GetEntity()->IsLoaded(domain);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -511,10 +534,11 @@ Gura_DeclareMethod(wx_Locale, IsOk)
 
 Gura_ImplementMethod(wx_Locale, IsOk)
 {
-	Object_wx_Locale *pThis = Object_wx_Locale::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Locale *pThis = Object_wx_Locale::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -522,20 +546,20 @@ Gura_ImplementMethod(wx_Locale, IsOk)
 //----------------------------------------------------------------------------
 Object_wx_Locale::~Object_wx_Locale()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_Locale::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Locale::ToString(bool exprFlag)
 {
 	String rtn("<wx.Locale:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -578,7 +602,7 @@ Gura_ImplementUserInheritableClass(wx_Locale)
 
 Gura_ImplementDescendantCreator(wx_Locale)
 {
-	return new Object_wx_Locale((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Locale((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
