@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_MediaCtrl: public wxMediaCtrl, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_MediaCtrl *_pObj;
 public:
-	inline wx_MediaCtrl() : wxMediaCtrl(), _sig(NULL), _pObj(NULL) {}
-	inline wx_MediaCtrl(wxWindow* parent, wxWindowID id, const wxString& fileName, const wxPoint& pos, const wxSize& size, long style, const wxString& szBackend, const wxValidator& validator, const wxString& name) : wxMediaCtrl(parent, id, fileName, pos, size, style, szBackend, validator, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_MediaCtrl() : wxMediaCtrl(), _pObj(nullptr) {}
+	inline wx_MediaCtrl(wxWindow* parent, wxWindowID id, const wxString& fileName, const wxPoint& pos, const wxSize& size, long style, const wxString& szBackend, const wxValidator& validator, const wxString& name) : wxMediaCtrl(parent, id, fileName, pos, size, style, szBackend, validator, name), _pObj(nullptr) {}
 	~wx_MediaCtrl();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_MediaCtrl *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_MediaCtrl *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_MediaCtrl::~wx_MediaCtrl()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_MediaCtrl::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(MediaCtrlEmpty)
 
 Gura_ImplementFunction(MediaCtrlEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_MediaCtrl *pEntity = new wx_MediaCtrl();
-	Object_wx_MediaCtrl *pObj = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_MediaCtrl *pObj = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_MediaCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(MediaCtrl)
@@ -77,33 +78,34 @@ Gura_DeclareFunction(MediaCtrl)
 
 Gura_ImplementFunction(MediaCtrl)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString fileName = wxT("");
-	if (args.IsValid(2)) fileName = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) fileName = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = 0;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString szBackend = wxT("");
-	if (args.IsValid(6)) szBackend = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) szBackend = wxString::FromUTF8(arg.GetString(6));
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(7)) validator = Object_wx_Validator::GetObject(args, 7)->GetEntity();
+	if (arg.IsValid(7)) validator = Object_wx_Validator::GetObject(arg, 7)->GetEntity();
 	wxString name = wxPanelNameStr;
-	if (args.IsValid(8)) name = wxString::FromUTF8(args.GetString(8));
+	if (arg.IsValid(8)) name = wxString::FromUTF8(arg.GetString(8));
 	wx_MediaCtrl *pEntity = new wx_MediaCtrl(parent, id, fileName, *pos, *size, style, szBackend, *validator, name);
-	Object_wx_MediaCtrl *pObj = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_MediaCtrl *pObj = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_MediaCtrl(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Create)
@@ -123,26 +125,27 @@ Gura_DeclareMethod(wx_MediaCtrl, Create)
 
 Gura_ImplementMethod(wx_MediaCtrl, Create)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxString fileName = wxT("");
-	if (args.IsValid(2)) fileName = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) fileName = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) pos = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) pos = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
 	long style = 0;
-	if (args.IsValid(5)) style = args.GetLong(5);
+	if (arg.IsValid(5)) style = arg.GetLong(5);
 	wxString szBackend = wxT("");
-	if (args.IsValid(6)) szBackend = wxString::FromUTF8(args.GetString(6));
+	if (arg.IsValid(6)) szBackend = wxString::FromUTF8(arg.GetString(6));
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(7)) validator = Object_wx_Validator::GetObject(args, 7)->GetEntity();
+	if (arg.IsValid(7)) validator = Object_wx_Validator::GetObject(arg, 7)->GetEntity();
 	wxString name = wxPanelNameStr;
-	if (args.IsValid(8)) name = wxString::FromUTF8(args.GetString(8));
+	if (arg.IsValid(8)) name = wxString::FromUTF8(arg.GetString(8));
 	bool rtn = pThis->GetEntity()->Create(parent, id, fileName, *pos, *size, style, szBackend, *validator, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, GetBestSize)
@@ -153,10 +156,11 @@ Gura_DeclareMethod(wx_MediaCtrl, GetBestSize)
 
 Gura_ImplementMethod(wx_MediaCtrl, GetBestSize)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetBestSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, GetPlaybackRate)
@@ -167,10 +171,11 @@ Gura_DeclareMethod(wx_MediaCtrl, GetPlaybackRate)
 
 Gura_ImplementMethod(wx_MediaCtrl, GetPlaybackRate)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	double rtn = pThis->GetEntity()->GetPlaybackRate();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, GetVolume)
@@ -181,10 +186,11 @@ Gura_DeclareMethod(wx_MediaCtrl, GetVolume)
 
 Gura_ImplementMethod(wx_MediaCtrl, GetVolume)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	double rtn = pThis->GetEntity()->GetVolume();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, GetState)
@@ -195,10 +201,11 @@ Gura_DeclareMethod(wx_MediaCtrl, GetState)
 
 Gura_ImplementMethod(wx_MediaCtrl, GetState)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetState();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Length)
@@ -209,10 +216,11 @@ Gura_DeclareMethod(wx_MediaCtrl, Length)
 
 Gura_ImplementMethod(wx_MediaCtrl, Length)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFileOffset rtn = pThis->GetEntity()->Length();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Load)
@@ -224,11 +232,12 @@ Gura_DeclareMethod(wx_MediaCtrl, Load)
 
 Gura_ImplementMethod(wx_MediaCtrl, Load)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString fileName = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString fileName = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Load(fileName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Load_1)
@@ -240,11 +249,12 @@ Gura_DeclareMethod(wx_MediaCtrl, Load_1)
 
 Gura_ImplementMethod(wx_MediaCtrl, Load_1)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxURI *uri = Object_wx_URI::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxURI *uri = Object_wx_URI::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Load(*uri);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Load_2)
@@ -257,12 +267,13 @@ Gura_DeclareMethod(wx_MediaCtrl, Load_2)
 
 Gura_ImplementMethod(wx_MediaCtrl, Load_2)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxURI *uri = Object_wx_URI::GetObject(args, 0)->GetEntity();
-	wxURI *proxy = Object_wx_URI::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxURI *uri = Object_wx_URI::GetObject(arg, 0)->GetEntity();
+	wxURI *proxy = Object_wx_URI::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->Load(*uri, *proxy);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, LoadURI)
@@ -274,11 +285,12 @@ Gura_DeclareMethod(wx_MediaCtrl, LoadURI)
 
 Gura_ImplementMethod(wx_MediaCtrl, LoadURI)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString uri = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString uri = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->LoadURI(uri);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, LoadURIWithProxy)
@@ -291,12 +303,13 @@ Gura_DeclareMethod(wx_MediaCtrl, LoadURIWithProxy)
 
 Gura_ImplementMethod(wx_MediaCtrl, LoadURIWithProxy)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString uri = wxString::FromUTF8(args.GetString(0));
-	wxString proxy = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString uri = wxString::FromUTF8(arg.GetString(0));
+	wxString proxy = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->LoadURIWithProxy(uri, proxy);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Pause)
@@ -307,10 +320,11 @@ Gura_DeclareMethod(wx_MediaCtrl, Pause)
 
 Gura_ImplementMethod(wx_MediaCtrl, Pause)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Pause();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Play)
@@ -321,10 +335,11 @@ Gura_DeclareMethod(wx_MediaCtrl, Play)
 
 Gura_ImplementMethod(wx_MediaCtrl, Play)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Play();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Seek)
@@ -337,12 +352,13 @@ Gura_DeclareMethod(wx_MediaCtrl, Seek)
 
 Gura_ImplementMethod(wx_MediaCtrl, Seek)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFileOffset where = static_cast<wxFileOffset>(args.GetInt64(0));
-	wxSeekMode mode = static_cast<wxSeekMode>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFileOffset where = static_cast<wxFileOffset>(arg.GetInt64(0));
+	wxSeekMode mode = static_cast<wxSeekMode>(arg.GetInt(1));
 	wxFileOffset rtn = pThis->GetEntity()->Seek(where, mode);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, SetPlaybackRate)
@@ -354,11 +370,12 @@ Gura_DeclareMethod(wx_MediaCtrl, SetPlaybackRate)
 
 Gura_ImplementMethod(wx_MediaCtrl, SetPlaybackRate)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	double dRate = args.GetDouble(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	double dRate = arg.GetDouble(0);
 	bool rtn = pThis->GetEntity()->SetPlaybackRate(dRate);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, SetVolume)
@@ -370,11 +387,12 @@ Gura_DeclareMethod(wx_MediaCtrl, SetVolume)
 
 Gura_ImplementMethod(wx_MediaCtrl, SetVolume)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	double dVolume = args.GetDouble(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	double dVolume = arg.GetDouble(0);
 	bool rtn = pThis->GetEntity()->SetVolume(dVolume);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, ShowPlayerControls)
@@ -386,12 +404,13 @@ Gura_DeclareMethod(wx_MediaCtrl, ShowPlayerControls)
 
 Gura_ImplementMethod(wx_MediaCtrl, ShowPlayerControls)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMediaCtrlPlayerControls flags = wxMEDIACTRLPLAYERCONTROLS_DEFAULT;
-	if (args.IsValid(0)) flags = static_cast<wxMediaCtrlPlayerControls>(args.GetInt(0));
+	if (arg.IsValid(0)) flags = static_cast<wxMediaCtrlPlayerControls>(arg.GetInt(0));
 	bool rtn = pThis->GetEntity()->ShowPlayerControls(flags);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Stop)
@@ -402,10 +421,11 @@ Gura_DeclareMethod(wx_MediaCtrl, Stop)
 
 Gura_ImplementMethod(wx_MediaCtrl, Stop)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Stop();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MediaCtrl, Tell)
@@ -416,10 +436,11 @@ Gura_DeclareMethod(wx_MediaCtrl, Tell)
 
 Gura_ImplementMethod(wx_MediaCtrl, Tell)
 {
-	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MediaCtrl *pThis = Object_wx_MediaCtrl::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFileOffset rtn = pThis->GetEntity()->Tell();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -431,13 +452,13 @@ Object_wx_MediaCtrl::~Object_wx_MediaCtrl()
 
 Object *Object_wx_MediaCtrl::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_MediaCtrl::ToString(bool exprFlag)
 {
 	String rtn("<wx.MediaCtrl:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -477,7 +498,7 @@ Gura_ImplementUserInheritableClass(wx_MediaCtrl)
 
 Gura_ImplementDescendantCreator(wx_MediaCtrl)
 {
-	return new Object_wx_MediaCtrl((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_MediaCtrl((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
