@@ -13,14 +13,14 @@ Value MenuItemListToValue(Environment &env, const wxMenuItemList &list);
 //----------------------------------------------------------------------------
 class wx_Menu: public wxMenu, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Menu *_pObj;
 public:
-	inline wx_Menu(const wxString& title, long style) : wxMenu(title, style), _sig(NULL), _pObj(NULL) {}
-	inline wx_Menu(long style) : wxMenu(style), _sig(NULL), _pObj(NULL) {}
+	inline wx_Menu(const wxString& title, long style) : wxMenu(title, style), _pObj(nullptr) {}
+	inline wx_Menu(long style) : wxMenu(style), _pObj(nullptr) {}
 	~wx_Menu();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Menu *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Menu *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -28,12 +28,12 @@ public:
 
 wx_Menu::~wx_Menu()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Menu::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -50,21 +50,22 @@ Gura_DeclareFunction(Menu)
 
 Gura_ImplementFunction(Menu)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxString title = wxT("");
-	if (args.IsValid(0)) title = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) title = wxString::FromUTF8(arg.GetString(0));
 	long style = 0;
-	if (args.IsValid(1)) style = args.GetLong(1);
+	if (arg.IsValid(1)) style = arg.GetLong(1);
 	wx_Menu *pEntity = new wx_Menu(title, style);
-	Object_wx_Menu *pObj = Object_wx_Menu::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Menu *pObj = Object_wx_Menu::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Menu(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Menu_1)
@@ -77,18 +78,19 @@ Gura_DeclareFunction(Menu_1)
 
 Gura_ImplementFunction(Menu_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	long style = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	long style = arg.GetLong(0);
 	wx_Menu *pEntity = new wx_Menu(style);
-	Object_wx_Menu *pObj = Object_wx_Menu::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Menu *pObj = Object_wx_Menu::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Menu(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Menu, Append)
@@ -103,17 +105,18 @@ Gura_DeclareMethod(wx_Menu, Append)
 
 Gura_ImplementMethod(wx_Menu, Append)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString item = wxT("");
-	if (args.IsValid(1)) item = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) item = wxString::FromUTF8(arg.GetString(1));
 	wxString helpString = wxT("");
-	if (args.IsValid(2)) helpString = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) helpString = wxString::FromUTF8(arg.GetString(2));
 	wxItemKind kind = wxITEM_NORMAL;
-	if (args.IsValid(3)) kind = static_cast<wxItemKind>(args.GetInt(3));
+	if (arg.IsValid(3)) kind = static_cast<wxItemKind>(arg.GetInt(3));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Append(id, item, helpString, kind);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethodAlias(wx_Menu, AppendMenu_, "AppendMenu")
@@ -128,15 +131,16 @@ Gura_DeclareMethodAlias(wx_Menu, AppendMenu_, "AppendMenu")
 
 Gura_ImplementMethod(wx_Menu, AppendMenu_)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString item = wxString::FromUTF8(args.GetString(1));
-	wxMenu *subMenu = Object_wx_Menu::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString item = wxString::FromUTF8(arg.GetString(1));
+	wxMenu *subMenu = Object_wx_Menu::GetObject(arg, 2)->GetEntity();
 	wxString helpString = wxT("");
-	if (args.IsValid(3)) helpString = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) helpString = wxString::FromUTF8(arg.GetString(3));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Append(id, item, subMenu, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, AppendItem)
@@ -148,11 +152,12 @@ Gura_DeclareMethod(wx_Menu, AppendItem)
 
 Gura_ImplementMethod(wx_Menu, AppendItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuItem *menuItem = Object_wx_MenuItem::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuItem *menuItem = Object_wx_MenuItem::GetObject(arg, 0)->GetEntity();
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Append(menuItem);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, AppendCheckItem)
@@ -166,14 +171,15 @@ Gura_DeclareMethod(wx_Menu, AppendCheckItem)
 
 Gura_ImplementMethod(wx_Menu, AppendCheckItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString item = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString item = wxString::FromUTF8(arg.GetString(1));
 	wxString helpString = wxT("");
-	if (args.IsValid(2)) helpString = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) helpString = wxString::FromUTF8(arg.GetString(2));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->AppendCheckItem(id, item, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, AppendRadioItem)
@@ -187,14 +193,15 @@ Gura_DeclareMethod(wx_Menu, AppendRadioItem)
 
 Gura_ImplementMethod(wx_Menu, AppendRadioItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString item = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString item = wxString::FromUTF8(arg.GetString(1));
 	wxString helpString = wxT("");
-	if (args.IsValid(2)) helpString = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) helpString = wxString::FromUTF8(arg.GetString(2));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->AppendRadioItem(id, item, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, AppendSeparator)
@@ -205,10 +212,11 @@ Gura_DeclareMethod(wx_Menu, AppendSeparator)
 
 Gura_ImplementMethod(wx_Menu, AppendSeparator)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->AppendSeparator();
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, AppendSubMenu)
@@ -222,14 +230,15 @@ Gura_DeclareMethod(wx_Menu, AppendSubMenu)
 
 Gura_ImplementMethod(wx_Menu, AppendSubMenu)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *submenu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *submenu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	wxString help = wxEmptyString;
-	if (args.IsValid(2)) help = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) help = wxString::FromUTF8(arg.GetString(2));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->AppendSubMenu(submenu, text, help);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, Break)
@@ -239,10 +248,11 @@ Gura_DeclareMethod(wx_Menu, Break)
 
 Gura_ImplementMethod(wx_Menu, Break)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Break();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, Check)
@@ -254,12 +264,13 @@ Gura_DeclareMethod(wx_Menu, Check)
 
 Gura_ImplementMethod(wx_Menu, Check)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	bool check = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	bool check = arg.GetBoolean(1);
 	pThis->GetEntity()->Check(id, check);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, Delete)
@@ -270,11 +281,12 @@ Gura_DeclareMethod(wx_Menu, Delete)
 
 Gura_ImplementMethod(wx_Menu, Delete)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->Delete(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, DeleteItem)
@@ -285,11 +297,12 @@ Gura_DeclareMethod(wx_Menu, DeleteItem)
 
 Gura_ImplementMethod(wx_Menu, DeleteItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuItem *item = Object_wx_MenuItem::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuItem *item = Object_wx_MenuItem::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Delete(item);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, Destroy)
@@ -300,11 +313,12 @@ Gura_DeclareMethod(wx_Menu, Destroy)
 
 Gura_ImplementMethod(wx_Menu, Destroy)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->Destroy(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, DestroyItem)
@@ -315,11 +329,12 @@ Gura_DeclareMethod(wx_Menu, DestroyItem)
 
 Gura_ImplementMethod(wx_Menu, DestroyItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuItem *item = Object_wx_MenuItem::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuItem *item = Object_wx_MenuItem::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Destroy(item);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, Enable)
@@ -331,12 +346,13 @@ Gura_DeclareMethod(wx_Menu, Enable)
 
 Gura_ImplementMethod(wx_Menu, Enable)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	bool enable = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	bool enable = arg.GetBoolean(1);
 	pThis->GetEntity()->Enable(id, enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, FindItem)
@@ -348,11 +364,12 @@ Gura_DeclareMethod(wx_Menu, FindItem)
 
 Gura_ImplementMethod(wx_Menu, FindItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString itemString = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString itemString = wxString::FromUTF8(arg.GetString(0));
 	int rtn = pThis->GetEntity()->FindItem(itemString);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Menu, FindItemById)
@@ -364,14 +381,15 @@ Gura_DeclareMethod(wx_Menu, FindItemById)
 
 Gura_ImplementMethod(wx_Menu, FindItemById)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxMenu **menu = NULL;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxMenu **menu = nullptr;
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->FindItem(id, menu);
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Menu, FindItemByPosition)
@@ -383,13 +401,14 @@ Gura_DeclareMethod(wx_Menu, FindItemByPosition)
 
 Gura_ImplementMethod(wx_Menu, FindItemByPosition)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t position = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t position = arg.GetSizeT(0);
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->FindItemByPosition(position);
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Menu, GetHelpString)
@@ -401,11 +420,12 @@ Gura_DeclareMethod(wx_Menu, GetHelpString)
 
 Gura_ImplementMethod(wx_Menu, GetHelpString)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetHelpString(id);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Menu, GetLabel)
@@ -417,11 +437,12 @@ Gura_DeclareMethod(wx_Menu, GetLabel)
 
 Gura_ImplementMethod(wx_Menu, GetLabel)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetLabel(id);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Menu, GetLabelText)
@@ -433,11 +454,12 @@ Gura_DeclareMethod(wx_Menu, GetLabelText)
 
 Gura_ImplementMethod(wx_Menu, GetLabelText)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetLabelText(id);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Menu, GetMenuItemCount)
@@ -448,10 +470,11 @@ Gura_DeclareMethod(wx_Menu, GetMenuItemCount)
 
 Gura_ImplementMethod(wx_Menu, GetMenuItemCount)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetMenuItemCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Menu, GetMenuItems)
@@ -462,10 +485,11 @@ Gura_DeclareMethod(wx_Menu, GetMenuItems)
 
 Gura_ImplementMethod(wx_Menu, GetMenuItems)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMenuItemList &rtn = pThis->GetEntity()->GetMenuItems();
-	return ReturnValue(env, sig, args, MenuItemListToValue(env, rtn));
+	return ReturnValue(env, arg, MenuItemListToValue(env, rtn));
 }
 
 Gura_DeclareMethod(wx_Menu, GetTitle)
@@ -476,10 +500,11 @@ Gura_DeclareMethod(wx_Menu, GetTitle)
 
 Gura_ImplementMethod(wx_Menu, GetTitle)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetTitle();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Menu, InsertItem)
@@ -492,12 +517,13 @@ Gura_DeclareMethod(wx_Menu, InsertItem)
 
 Gura_ImplementMethod(wx_Menu, InsertItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
-	wxMenuItem *item = Object_wx_MenuItem::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
+	wxMenuItem *item = Object_wx_MenuItem::GetObject(arg, 1)->GetEntity();
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Insert(pos, item);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, Insert)
@@ -513,18 +539,19 @@ Gura_DeclareMethod(wx_Menu, Insert)
 
 Gura_ImplementMethod(wx_Menu, Insert)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
-	int id = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
+	int id = arg.GetInt(1);
 	wxString item = wxT("");
-	if (args.IsValid(2)) item = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) item = wxString::FromUTF8(arg.GetString(2));
 	wxString helpString = wxT("");
-	if (args.IsValid(3)) helpString = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) helpString = wxString::FromUTF8(arg.GetString(3));
 	wxItemKind kind = wxITEM_NORMAL;
-	if (args.IsValid(4)) kind = static_cast<wxItemKind>(args.GetInt(4));
+	if (arg.IsValid(4)) kind = static_cast<wxItemKind>(arg.GetInt(4));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Insert(pos, id, item, helpString, kind);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, InsertCheckItem)
@@ -539,15 +566,16 @@ Gura_DeclareMethod(wx_Menu, InsertCheckItem)
 
 Gura_ImplementMethod(wx_Menu, InsertCheckItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
-	int id = args.GetInt(1);
-	wxString item = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
+	int id = arg.GetInt(1);
+	wxString item = wxString::FromUTF8(arg.GetString(2));
 	wxString helpString = wxT("");
-	if (args.IsValid(3)) helpString = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) helpString = wxString::FromUTF8(arg.GetString(3));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->InsertCheckItem(pos, id, item, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, InsertRadioItem)
@@ -562,15 +590,16 @@ Gura_DeclareMethod(wx_Menu, InsertRadioItem)
 
 Gura_ImplementMethod(wx_Menu, InsertRadioItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
-	int id = args.GetInt(1);
-	wxString item = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
+	int id = arg.GetInt(1);
+	wxString item = wxString::FromUTF8(arg.GetString(2));
 	wxString helpString = wxT("");
-	if (args.IsValid(3)) helpString = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) helpString = wxString::FromUTF8(arg.GetString(3));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->InsertRadioItem(pos, id, item, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, InsertSeparator)
@@ -582,11 +611,12 @@ Gura_DeclareMethod(wx_Menu, InsertSeparator)
 
 Gura_ImplementMethod(wx_Menu, InsertSeparator)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->InsertSeparator(pos);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, IsChecked)
@@ -598,11 +628,12 @@ Gura_DeclareMethod(wx_Menu, IsChecked)
 
 Gura_ImplementMethod(wx_Menu, IsChecked)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsChecked(id);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Menu, IsEnabled)
@@ -614,11 +645,12 @@ Gura_DeclareMethod(wx_Menu, IsEnabled)
 
 Gura_ImplementMethod(wx_Menu, IsEnabled)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsEnabled(id);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Menu, PrependItem)
@@ -630,11 +662,12 @@ Gura_DeclareMethod(wx_Menu, PrependItem)
 
 Gura_ImplementMethod(wx_Menu, PrependItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuItem *item = Object_wx_MenuItem::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuItem *item = Object_wx_MenuItem::GetObject(arg, 0)->GetEntity();
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Prepend(item);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, Prepend)
@@ -649,17 +682,18 @@ Gura_DeclareMethod(wx_Menu, Prepend)
 
 Gura_ImplementMethod(wx_Menu, Prepend)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString item = wxT("");
-	if (args.IsValid(1)) item = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) item = wxString::FromUTF8(arg.GetString(1));
 	wxString helpString = wxT("");
-	if (args.IsValid(2)) helpString = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) helpString = wxString::FromUTF8(arg.GetString(2));
 	wxItemKind kind = wxITEM_NORMAL;
-	if (args.IsValid(3)) kind = static_cast<wxItemKind>(args.GetInt(3));
+	if (arg.IsValid(3)) kind = static_cast<wxItemKind>(arg.GetInt(3));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Prepend(id, item, helpString, kind);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, PrependCheckItem)
@@ -673,14 +707,15 @@ Gura_DeclareMethod(wx_Menu, PrependCheckItem)
 
 Gura_ImplementMethod(wx_Menu, PrependCheckItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString item = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString item = wxString::FromUTF8(arg.GetString(1));
 	wxString helpString = wxT("");
-	if (args.IsValid(2)) helpString = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) helpString = wxString::FromUTF8(arg.GetString(2));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->PrependCheckItem(id, item, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, PrependRadioItem)
@@ -694,14 +729,15 @@ Gura_DeclareMethod(wx_Menu, PrependRadioItem)
 
 Gura_ImplementMethod(wx_Menu, PrependRadioItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString item = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString item = wxString::FromUTF8(arg.GetString(1));
 	wxString helpString = wxT("");
-	if (args.IsValid(2)) helpString = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) helpString = wxString::FromUTF8(arg.GetString(2));
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->PrependRadioItem(id, item, helpString);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, PrependSeparator)
@@ -712,10 +748,11 @@ Gura_DeclareMethod(wx_Menu, PrependSeparator)
 
 Gura_ImplementMethod(wx_Menu, PrependSeparator)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->PrependSeparator();
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, Remove)
@@ -727,11 +764,12 @@ Gura_DeclareMethod(wx_Menu, Remove)
 
 Gura_ImplementMethod(wx_Menu, Remove)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Remove(id);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, RemoveItem)
@@ -743,11 +781,12 @@ Gura_DeclareMethod(wx_Menu, RemoveItem)
 
 Gura_ImplementMethod(wx_Menu, RemoveItem)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenuItem *item = Object_wx_MenuItem::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenuItem *item = Object_wx_MenuItem::GetObject(arg, 0)->GetEntity();
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->Remove(item);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Menu, SetHelpString)
@@ -759,12 +798,13 @@ Gura_DeclareMethod(wx_Menu, SetHelpString)
 
 Gura_ImplementMethod(wx_Menu, SetHelpString)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString helpString = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString helpString = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetHelpString(id, helpString);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, SetLabel)
@@ -776,12 +816,13 @@ Gura_DeclareMethod(wx_Menu, SetLabel)
 
 Gura_ImplementMethod(wx_Menu, SetLabel)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString label = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString label = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetLabel(id, label);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, SetTitle)
@@ -792,11 +833,12 @@ Gura_DeclareMethod(wx_Menu, SetTitle)
 
 Gura_ImplementMethod(wx_Menu, SetTitle)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetTitle(title);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Menu, UpdateUI)
@@ -807,12 +849,13 @@ Gura_DeclareMethod(wx_Menu, UpdateUI)
 
 Gura_ImplementMethod(wx_Menu, UpdateUI)
 {
-	Object_wx_Menu *pThis = Object_wx_Menu::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvtHandler *source = (wxEvtHandler *)(NULL);
-	if (args.IsValid(0)) source = Object_wx_EvtHandler::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Menu *pThis = Object_wx_Menu::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvtHandler *source = (wxEvtHandler *)(nullptr);
+	if (arg.IsValid(0)) source = Object_wx_EvtHandler::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->UpdateUI(source);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -824,13 +867,13 @@ Object_wx_Menu::~Object_wx_Menu()
 
 Object *Object_wx_Menu::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Menu::ToString(bool exprFlag)
 {
 	String rtn("<wx.Menu:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -892,16 +935,16 @@ Gura_ImplementUserInheritableClass(wx_Menu)
 
 Gura_ImplementDescendantCreator(wx_Menu)
 {
-	return new Object_wx_Menu((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Menu((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Value MenuItemListToValue(Environment &env, const wxMenuItemList &list)
 {
 	Value rtn;
-	ValueList &valList = rtn.InitAsList(env);
-	valList.reserve(list.GetCount());
+	Object_list *pObjList = rtn.InitAsList(env);
+	pObjList->Reserve(list.GetCount());
 	foreach_const (wxMenuItemList, pItem, list) {
-		valList.push_back(Value(new Object_wx_MenuItem(*pItem, NULL, OwnerFalse)));
+		pObjList->Add(Value(new Object_wx_MenuItem(*pItem, nullptr, OwnerFalse)));
 	}
 	return rtn;
 }
