@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_MenuBar: public wxMenuBar, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_MenuBar *_pObj;
 public:
-	inline wx_MenuBar(long style) : wxMenuBar(style), _sig(NULL), _pObj(NULL) {}
-	//inline wx_MenuBar(size_t n, wxMenu* menus[], const wxString titles[], long style) : wxMenuBar(n, menus[], titles[], style), _sig(NULL), _pObj(NULL) {}
+	inline wx_MenuBar(long style) : wxMenuBar(style), _pObj(nullptr) {}
+	//inline wx_MenuBar(size_t n, wxMenu* menus[], const wxString titles[], long style) : wxMenuBar(n, menus[], titles[], style), _pObj(nullptr) {}
 	~wx_MenuBar();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_MenuBar *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_MenuBar *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_MenuBar::~wx_MenuBar()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_MenuBar::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,19 +47,20 @@ Gura_DeclareFunction(MenuBar)
 
 Gura_ImplementFunction(MenuBar)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	long style = 0;
-	if (args.IsValid(0)) style = args.GetLong(0);
+	if (arg.IsValid(0)) style = arg.GetLong(0);
 	wx_MenuBar *pEntity = new wx_MenuBar(style);
-	Object_wx_MenuBar *pObj = Object_wx_MenuBar::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_MenuBar *pObj = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_MenuBar(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(MenuBar_1)
@@ -77,26 +78,27 @@ Gura_DeclareFunction(MenuBar_1)
 
 Gura_ImplementFunction(MenuBar_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	size_t n = args.GetSizeT(0);
-	wxMenu *menus[] = Object_wx_Menu::GetObject(args, 1)->GetEntity();
-	wxString titles[] = wxString::FromUTF8(args.GetString(2));
+	size_t n = arg.GetSizeT(0);
+	wxMenu *menus[] = Object_wx_Menu::GetObject(arg, 1)->GetEntity();
+	wxString titles[] = wxString::FromUTF8(arg.GetString(2));
 	long style = 0;
-	if (args.IsValid(3)) style = args.GetLong(3);
+	if (arg.IsValid(3)) style = arg.GetLong(3);
 	wx_MenuBar *pEntity = new wx_MenuBar(n, menus[], titles[], style);
-	Object_wx_MenuBar *pObj = Object_wx_MenuBar::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_MenuBar *pObj = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_MenuBar(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, Append)
@@ -109,12 +111,13 @@ Gura_DeclareMethod(wx_MenuBar, Append)
 
 Gura_ImplementMethod(wx_MenuBar, Append)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
-	wxString title = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
+	wxString title = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->Append(menu, title);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, Check)
@@ -126,12 +129,13 @@ Gura_DeclareMethod(wx_MenuBar, Check)
 
 Gura_ImplementMethod(wx_MenuBar, Check)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	bool check = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	bool check = arg.GetBoolean(1);
 	pThis->GetEntity()->Check(id, check);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, Enable)
@@ -143,12 +147,13 @@ Gura_DeclareMethod(wx_MenuBar, Enable)
 
 Gura_ImplementMethod(wx_MenuBar, Enable)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	bool enable = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	bool enable = arg.GetBoolean(1);
 	pThis->GetEntity()->Enable(id, enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, EnableTop)
@@ -160,12 +165,13 @@ Gura_DeclareMethod(wx_MenuBar, EnableTop)
 
 Gura_ImplementMethod(wx_MenuBar, EnableTop)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
-	bool enable = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
+	bool enable = arg.GetBoolean(1);
 	pThis->GetEntity()->EnableTop(pos, enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, FindMenu)
@@ -177,11 +183,12 @@ Gura_DeclareMethod(wx_MenuBar, FindMenu)
 
 Gura_ImplementMethod(wx_MenuBar, FindMenu)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
 	int rtn = pThis->GetEntity()->FindMenu(title);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, FindMenuItem)
@@ -194,12 +201,13 @@ Gura_DeclareMethod(wx_MenuBar, FindMenuItem)
 
 Gura_ImplementMethod(wx_MenuBar, FindMenuItem)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString menuString = wxString::FromUTF8(args.GetString(0));
-	wxString itemString = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString menuString = wxString::FromUTF8(arg.GetString(0));
+	wxString itemString = wxString::FromUTF8(arg.GetString(1));
 	int rtn = pThis->GetEntity()->FindMenuItem(menuString, itemString);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, FindItem)
@@ -214,17 +222,18 @@ Gura_DeclareMethod(wx_MenuBar, FindItem)
 
 Gura_ImplementMethod(wx_MenuBar, FindItem)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxMenu ***menu = (wxMenu *)(&NULL);
-	if (args.IsValid(1)) **menu = Object_wx_Menu::GetObject(args, 1)->GetEntity();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxMenu ***menu = (wxMenu *)(&nullptr);
+	if (arg.IsValid(1)) **menu = Object_wx_Menu::GetObject(arg, 1)->GetEntity();
 	wxMenuItem *rtn = (wxMenuItem *)pThis->GetEntity()->FindItem(id, ***menu);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuItem(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuItem(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetHelpString)
@@ -236,11 +245,12 @@ Gura_DeclareMethod(wx_MenuBar, GetHelpString)
 
 Gura_ImplementMethod(wx_MenuBar, GetHelpString)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetHelpString(id);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetLabel)
@@ -252,11 +262,12 @@ Gura_DeclareMethod(wx_MenuBar, GetLabel)
 
 Gura_ImplementMethod(wx_MenuBar, GetLabel)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetLabel(id);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetLabelTop)
@@ -268,11 +279,16 @@ Gura_DeclareMethod(wx_MenuBar, GetLabelTop)
 
 Gura_ImplementMethod(wx_MenuBar, GetLabelTop)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetLabelTop(pos);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetMenu)
@@ -284,11 +300,12 @@ Gura_DeclareMethod(wx_MenuBar, GetMenu)
 
 Gura_ImplementMethod(wx_MenuBar, GetMenu)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int menuIndex = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int menuIndex = arg.GetInt(0);
 	wxMenu *rtn = (wxMenu *)pThis->GetEntity()->GetMenu(menuIndex);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Menu(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Menu(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetMenuCount)
@@ -299,10 +316,11 @@ Gura_DeclareMethod(wx_MenuBar, GetMenuCount)
 
 Gura_ImplementMethod(wx_MenuBar, GetMenuCount)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMenuCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetMenuLabel)
@@ -314,11 +332,12 @@ Gura_DeclareMethod(wx_MenuBar, GetMenuLabel)
 
 Gura_ImplementMethod(wx_MenuBar, GetMenuLabel)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetMenuLabel(pos);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuBar, GetMenuLabelText)
@@ -330,11 +349,12 @@ Gura_DeclareMethod(wx_MenuBar, GetMenuLabelText)
 
 Gura_ImplementMethod(wx_MenuBar, GetMenuLabelText)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetMenuLabelText(pos);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuBar, Insert)
@@ -348,13 +368,14 @@ Gura_DeclareMethod(wx_MenuBar, Insert)
 
 Gura_ImplementMethod(wx_MenuBar, Insert)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 1)->GetEntity();
-	wxString title = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 1)->GetEntity();
+	wxString title = wxString::FromUTF8(arg.GetString(2));
 	bool rtn = pThis->GetEntity()->Insert(pos, menu, title);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, IsChecked)
@@ -366,11 +387,12 @@ Gura_DeclareMethod(wx_MenuBar, IsChecked)
 
 Gura_ImplementMethod(wx_MenuBar, IsChecked)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsChecked(id);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, IsEnabled)
@@ -382,11 +404,12 @@ Gura_DeclareMethod(wx_MenuBar, IsEnabled)
 
 Gura_ImplementMethod(wx_MenuBar, IsEnabled)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsEnabled(id);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuBar, Refresh)
@@ -396,10 +419,11 @@ Gura_DeclareMethod(wx_MenuBar, Refresh)
 
 Gura_ImplementMethod(wx_MenuBar, Refresh)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Refresh();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, Remove)
@@ -411,11 +435,12 @@ Gura_DeclareMethod(wx_MenuBar, Remove)
 
 Gura_ImplementMethod(wx_MenuBar, Remove)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
 	wxMenu *rtn = (wxMenu *)pThis->GetEntity()->Remove(pos);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Menu(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Menu(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_MenuBar, Replace)
@@ -429,13 +454,14 @@ Gura_DeclareMethod(wx_MenuBar, Replace)
 
 Gura_ImplementMethod(wx_MenuBar, Replace)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 1)->GetEntity();
-	wxString title = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 1)->GetEntity();
+	wxString title = wxString::FromUTF8(arg.GetString(2));
 	wxMenu *rtn = (wxMenu *)pThis->GetEntity()->Replace(pos, menu, title);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Menu(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Menu(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_MenuBar, SetHelpString)
@@ -447,12 +473,13 @@ Gura_DeclareMethod(wx_MenuBar, SetHelpString)
 
 Gura_ImplementMethod(wx_MenuBar, SetHelpString)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString helpString = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString helpString = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetHelpString(id, helpString);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, SetLabel)
@@ -464,12 +491,13 @@ Gura_DeclareMethod(wx_MenuBar, SetLabel)
 
 Gura_ImplementMethod(wx_MenuBar, SetLabel)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
-	wxString label = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
+	wxString label = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetLabel(id, label);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, SetLabelTop)
@@ -481,12 +509,17 @@ Gura_DeclareMethod(wx_MenuBar, SetLabelTop)
 
 Gura_ImplementMethod(wx_MenuBar, SetLabelTop)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
-	wxString label = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
+	wxString label = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetLabelTop(pos, label);
-	return Value::Null;
+	return Value::Nil;
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuBar, SetMenuLabel)
@@ -498,12 +531,13 @@ Gura_DeclareMethod(wx_MenuBar, SetMenuLabel)
 
 Gura_ImplementMethod(wx_MenuBar, SetMenuLabel)
 {
-	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
-	wxString label = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuBar *pThis = Object_wx_MenuBar::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
+	wxString label = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetMenuLabel(pos, label);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -515,13 +549,13 @@ Object_wx_MenuBar::~Object_wx_MenuBar()
 
 Object *Object_wx_MenuBar::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_MenuBar::ToString(bool exprFlag)
 {
 	String rtn("<wx.MenuBar:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -566,7 +600,7 @@ Gura_ImplementUserInheritableClass(wx_MenuBar)
 
 Gura_ImplementDescendantCreator(wx_MenuBar)
 {
-	return new Object_wx_MenuBar((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_MenuBar((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
