@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_MenuItem: public wxMenuItem, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_MenuItem *_pObj;
 public:
-	inline wx_MenuItem(wxMenu* parentMenu, int id, const wxString& text, const wxString& helpString, wxItemKind kind, wxMenu* subMenu) : wxMenuItem(parentMenu, id, text, helpString, kind, subMenu), _sig(NULL), _pObj(NULL) {}
+	inline wx_MenuItem(wxMenu* parentMenu, int id, const wxString& text, const wxString& helpString, wxItemKind kind, wxMenu* subMenu) : wxMenuItem(parentMenu, id, text, helpString, kind, subMenu), _pObj(nullptr) {}
 	~wx_MenuItem();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_MenuItem *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_MenuItem *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_MenuItem::~wx_MenuItem()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_MenuItem::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -51,29 +51,30 @@ Gura_DeclareFunction(MenuItem)
 
 Gura_ImplementFunction(MenuItem)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxMenu *parentMenu = (wxMenu *)(NULL);
-	if (args.IsValid(0)) parentMenu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxMenu *parentMenu = (wxMenu *)(nullptr);
+	if (arg.IsValid(0)) parentMenu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	int id = wxID_SEPARATOR;
-	if (args.IsValid(1)) id = args.GetInt(1);
+	if (arg.IsValid(1)) id = arg.GetInt(1);
 	wxString text = wxT("");
-	if (args.IsValid(2)) text = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) text = wxString::FromUTF8(arg.GetString(2));
 	wxString helpString = wxT("");
-	if (args.IsValid(3)) helpString = wxString::FromUTF8(args.GetString(3));
+	if (arg.IsValid(3)) helpString = wxString::FromUTF8(arg.GetString(3));
 	wxItemKind kind = wxITEM_NORMAL;
-	if (args.IsValid(4)) kind = static_cast<wxItemKind>(args.GetInt(4));
-	wxMenu *subMenu = (wxMenu *)(NULL);
-	if (args.IsValid(5)) subMenu = Object_wx_Menu::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(4)) kind = static_cast<wxItemKind>(arg.GetInt(4));
+	wxMenu *subMenu = (wxMenu *)(nullptr);
+	if (arg.IsValid(5)) subMenu = Object_wx_Menu::GetObject(arg, 5)->GetEntity();
 	wx_MenuItem *pEntity = new wx_MenuItem(parentMenu, id, text, helpString, kind, subMenu);
-	Object_wx_MenuItem *pObj = Object_wx_MenuItem::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_MenuItem *pObj = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_MenuItem(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_MenuItem, Check)
@@ -84,12 +85,13 @@ Gura_DeclareMethod(wx_MenuItem, Check)
 
 Gura_ImplementMethod(wx_MenuItem, Check)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool check = true;
-	if (args.IsValid(0)) check = args.GetBoolean(0);
+	if (arg.IsValid(0)) check = arg.GetBoolean(0);
 	pThis->GetEntity()->Check(check);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, Enable)
@@ -100,12 +102,13 @@ Gura_DeclareMethod(wx_MenuItem, Enable)
 
 Gura_ImplementMethod(wx_MenuItem, Enable)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	pThis->GetEntity()->Enable(enable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetAccel)
@@ -116,12 +119,13 @@ Gura_DeclareMethod(wx_MenuItem, GetAccel)
 
 Gura_ImplementMethod(wx_MenuItem, GetAccel)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxAcceleratorEntry *rtn = pThis->GetEntity()->GetAccel();
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_AcceleratorEntry(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_AcceleratorEntry(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetBackgroundColour)
@@ -132,14 +136,15 @@ Gura_DeclareMethod(wx_MenuItem, GetBackgroundColour)
 
 Gura_ImplementMethod(wx_MenuItem, GetBackgroundColour)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxColour &rtn = pThis->GetEntity()->GetBackgroundColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -152,16 +157,17 @@ Gura_DeclareMethod(wx_MenuItem, GetBitmap)
 
 Gura_ImplementMethod(wx_MenuItem, GetBitmap)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool checked = true;
-	if (args.IsValid(0)) checked = args.GetBoolean(0);
+	if (arg.IsValid(0)) checked = arg.GetBoolean(0);
 	const wxBitmap &rtn = pThis->GetEntity()->GetBitmap(checked);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -173,14 +179,15 @@ Gura_DeclareMethod(wx_MenuItem, GetFont)
 
 Gura_ImplementMethod(wx_MenuItem, GetFont)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFont &rtn = pThis->GetEntity()->GetFont();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(new wxFont(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(new wxFont(rtn), nullptr, OwnerTrue)));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -192,10 +199,11 @@ Gura_DeclareMethod(wx_MenuItem, GetHelp)
 
 Gura_ImplementMethod(wx_MenuItem, GetHelp)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetHelp();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetId)
@@ -206,10 +214,11 @@ Gura_DeclareMethod(wx_MenuItem, GetId)
 
 Gura_ImplementMethod(wx_MenuItem, GetId)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetItemLabel)
@@ -220,10 +229,11 @@ Gura_DeclareMethod(wx_MenuItem, GetItemLabel)
 
 Gura_ImplementMethod(wx_MenuItem, GetItemLabel)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetItemLabel();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetItemLabelText)
@@ -234,10 +244,11 @@ Gura_DeclareMethod(wx_MenuItem, GetItemLabelText)
 
 Gura_ImplementMethod(wx_MenuItem, GetItemLabelText)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetItemLabelText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetKind)
@@ -248,10 +259,11 @@ Gura_DeclareMethod(wx_MenuItem, GetKind)
 
 Gura_ImplementMethod(wx_MenuItem, GetKind)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxItemKind rtn = pThis->GetEntity()->GetKind();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetLabel)
@@ -262,10 +274,15 @@ Gura_DeclareMethod(wx_MenuItem, GetLabel)
 
 Gura_ImplementMethod(wx_MenuItem, GetLabel)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetLabel();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_MenuItem, GetLabelText)
@@ -277,10 +294,11 @@ Gura_DeclareClassMethod(wx_MenuItem, GetLabelText)
 
 Gura_ImplementClassMethod(wx_MenuItem, GetLabelText)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxString rtn = wxMenuItem::GetLabelText(text);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_MenuItem, GetLabelFromText)
@@ -292,10 +310,15 @@ Gura_DeclareClassMethod(wx_MenuItem, GetLabelFromText)
 
 Gura_ImplementClassMethod(wx_MenuItem, GetLabelFromText)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+#if 0
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxString rtn = wxMenuItem::GetLabelFromText(text);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetMarginWidth)
@@ -306,14 +329,15 @@ Gura_DeclareMethod(wx_MenuItem, GetMarginWidth)
 
 Gura_ImplementMethod(wx_MenuItem, GetMarginWidth)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMarginWidth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -325,10 +349,11 @@ Gura_DeclareMethod(wx_MenuItem, GetMenu)
 
 Gura_ImplementMethod(wx_MenuItem, GetMenu)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMenu *rtn = (wxMenu *)pThis->GetEntity()->GetMenu();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Menu(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Menu(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetName)
@@ -339,14 +364,15 @@ Gura_DeclareMethod(wx_MenuItem, GetName)
 
 Gura_ImplementMethod(wx_MenuItem, GetName)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetText)
@@ -357,10 +383,15 @@ Gura_DeclareMethod(wx_MenuItem, GetText)
 
 Gura_ImplementMethod(wx_MenuItem, GetText)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetSubMenu)
@@ -371,10 +402,11 @@ Gura_DeclareMethod(wx_MenuItem, GetSubMenu)
 
 Gura_ImplementMethod(wx_MenuItem, GetSubMenu)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMenu *rtn = (wxMenu *)pThis->GetEntity()->GetSubMenu();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Menu(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Menu(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_MenuItem, GetTextColour)
@@ -385,14 +417,15 @@ Gura_DeclareMethod(wx_MenuItem, GetTextColour)
 
 Gura_ImplementMethod(wx_MenuItem, GetTextColour)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxColour &rtn = pThis->GetEntity()->GetTextColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -404,10 +437,11 @@ Gura_DeclareMethod(wx_MenuItem, IsCheckable)
 
 Gura_ImplementMethod(wx_MenuItem, IsCheckable)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsCheckable();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, IsChecked)
@@ -418,10 +452,11 @@ Gura_DeclareMethod(wx_MenuItem, IsChecked)
 
 Gura_ImplementMethod(wx_MenuItem, IsChecked)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsChecked();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, IsEnabled)
@@ -432,10 +467,11 @@ Gura_DeclareMethod(wx_MenuItem, IsEnabled)
 
 Gura_ImplementMethod(wx_MenuItem, IsEnabled)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsEnabled();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, IsSeparator)
@@ -446,10 +482,11 @@ Gura_DeclareMethod(wx_MenuItem, IsSeparator)
 
 Gura_ImplementMethod(wx_MenuItem, IsSeparator)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsSeparator();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, IsSubMenu)
@@ -460,10 +497,11 @@ Gura_DeclareMethod(wx_MenuItem, IsSubMenu)
 
 Gura_ImplementMethod(wx_MenuItem, IsSubMenu)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsSubMenu();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetBackgroundColour)
@@ -474,15 +512,16 @@ Gura_DeclareMethod(wx_MenuItem, SetBackgroundColour)
 
 Gura_ImplementMethod(wx_MenuItem, SetBackgroundColour)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colour = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colour = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetBackgroundColour(*colour);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -494,11 +533,12 @@ Gura_DeclareMethod(wx_MenuItem, SetBitmap)
 
 Gura_ImplementMethod(wx_MenuItem, SetBitmap)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *bmp = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *bmp = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetBitmap(*bmp);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetBitmaps)
@@ -510,17 +550,18 @@ Gura_DeclareMethod(wx_MenuItem, SetBitmaps)
 
 Gura_ImplementMethod(wx_MenuItem, SetBitmaps)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *checked = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *checked = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
 	wxBitmap *unchecked = (wxBitmap *)(&wxNullBitmap);
-	if (args.IsValid(1)) unchecked = Object_wx_Bitmap::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) unchecked = Object_wx_Bitmap::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetBitmaps(*checked, *unchecked);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -532,15 +573,16 @@ Gura_DeclareMethod(wx_MenuItem, SetFont)
 
 Gura_ImplementMethod(wx_MenuItem, SetFont)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetFont(*font);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -552,11 +594,12 @@ Gura_DeclareMethod(wx_MenuItem, SetHelp)
 
 Gura_ImplementMethod(wx_MenuItem, SetHelp)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString helpString = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString helpString = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetHelp(helpString);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetItemLabel)
@@ -567,11 +610,12 @@ Gura_DeclareMethod(wx_MenuItem, SetItemLabel)
 
 Gura_ImplementMethod(wx_MenuItem, SetItemLabel)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetItemLabel(label);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetMarginWidth)
@@ -582,15 +626,16 @@ Gura_DeclareMethod(wx_MenuItem, SetMarginWidth)
 
 Gura_ImplementMethod(wx_MenuItem, SetMarginWidth)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
 	pThis->GetEntity()->SetMarginWidth(width);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -602,11 +647,12 @@ Gura_DeclareMethod(wx_MenuItem, SetMenu)
 
 Gura_ImplementMethod(wx_MenuItem, SetMenu)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMenu(menu);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetSubMenu)
@@ -617,11 +663,12 @@ Gura_DeclareMethod(wx_MenuItem, SetSubMenu)
 
 Gura_ImplementMethod(wx_MenuItem, SetSubMenu)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetSubMenu(menu);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetText)
@@ -632,11 +679,16 @@ Gura_DeclareMethod(wx_MenuItem, SetText)
 
 Gura_ImplementMethod(wx_MenuItem, SetText)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetText(text);
-	return Value::Null;
+	return Value::Nil;
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MenuItem, SetTextColour)
@@ -647,15 +699,16 @@ Gura_DeclareMethod(wx_MenuItem, SetTextColour)
 
 Gura_ImplementMethod(wx_MenuItem, SetTextColour)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colour = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colour = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetTextColour(*colour);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -666,11 +719,12 @@ Gura_DeclareMethod(wx_MenuItem, Toggle)
 
 Gura_ImplementMethod(wx_MenuItem, Toggle)
 {
-	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxMenu *menu = Object_wx_Menu::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MenuItem *pThis = Object_wx_MenuItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxMenu *menu = Object_wx_Menu::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Toggle();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -682,13 +736,13 @@ Object_wx_MenuItem::~Object_wx_MenuItem()
 
 Object *Object_wx_MenuItem::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_MenuItem::ToString(bool exprFlag)
 {
 	String rtn("<wx.MenuItem:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -745,7 +799,7 @@ Gura_ImplementUserInheritableClass(wx_MenuItem)
 
 Gura_ImplementDescendantCreator(wx_MenuItem)
 {
-	return new Object_wx_MenuItem((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_MenuItem((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
