@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_MouseEvent: public wxMouseEvent, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_MouseEvent *_pObj;
 public:
-	inline wx_MouseEvent(WXTYPE mouseEventType) : wxMouseEvent(mouseEventType), _sig(NULL), _pObj(NULL) {}
+	inline wx_MouseEvent(WXTYPE mouseEventType) : wxMouseEvent(mouseEventType), _pObj(nullptr) {}
 	~wx_MouseEvent();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_MouseEvent *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_MouseEvent *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_MouseEvent::~wx_MouseEvent()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_MouseEvent::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,19 +46,20 @@ Gura_DeclareFunction(MouseEvent)
 
 Gura_ImplementFunction(MouseEvent)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	WXTYPE mouseEventType = 0;
-	if (args.IsValid(0)) mouseEventType = static_cast<WXTYPE>(args.GetInt(0));
+	if (arg.IsValid(0)) mouseEventType = static_cast<WXTYPE>(arg.GetInt(0));
 	wx_MouseEvent *pEntity = new wx_MouseEvent(mouseEventType);
-	Object_wx_MouseEvent *pObj = Object_wx_MouseEvent::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_MouseEvent *pObj = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_MouseEvent(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_MouseEvent, AltDown)
@@ -69,10 +70,11 @@ Gura_DeclareMethod(wx_MouseEvent, AltDown)
 
 Gura_ImplementMethod(wx_MouseEvent, AltDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->AltDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, Button)
@@ -84,11 +86,12 @@ Gura_DeclareMethod(wx_MouseEvent, Button)
 
 Gura_ImplementMethod(wx_MouseEvent, Button)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int button = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int button = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->Button(button);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, ButtonDClick)
@@ -100,12 +103,13 @@ Gura_DeclareMethod(wx_MouseEvent, ButtonDClick)
 
 Gura_ImplementMethod(wx_MouseEvent, ButtonDClick)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int but = wxMOUSE_BTN_ANY;
-	if (args.IsValid(0)) but = args.GetInt(0);
+	if (arg.IsValid(0)) but = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->ButtonDClick(but);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, ButtonDown)
@@ -117,12 +121,13 @@ Gura_DeclareMethod(wx_MouseEvent, ButtonDown)
 
 Gura_ImplementMethod(wx_MouseEvent, ButtonDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int but = -1;
-	if (args.IsValid(0)) but = args.GetInt(0);
+	if (arg.IsValid(0)) but = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->ButtonDown(but);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, ButtonUp)
@@ -134,12 +139,13 @@ Gura_DeclareMethod(wx_MouseEvent, ButtonUp)
 
 Gura_ImplementMethod(wx_MouseEvent, ButtonUp)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int but = -1;
-	if (args.IsValid(0)) but = args.GetInt(0);
+	if (arg.IsValid(0)) but = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->ButtonUp(but);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, CmdDown)
@@ -150,10 +156,11 @@ Gura_DeclareMethod(wx_MouseEvent, CmdDown)
 
 Gura_ImplementMethod(wx_MouseEvent, CmdDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CmdDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, ControlDown)
@@ -164,10 +171,11 @@ Gura_DeclareMethod(wx_MouseEvent, ControlDown)
 
 Gura_ImplementMethod(wx_MouseEvent, ControlDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ControlDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, Dragging)
@@ -178,10 +186,11 @@ Gura_DeclareMethod(wx_MouseEvent, Dragging)
 
 Gura_ImplementMethod(wx_MouseEvent, Dragging)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Dragging();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, Entering)
@@ -192,10 +201,11 @@ Gura_DeclareMethod(wx_MouseEvent, Entering)
 
 Gura_ImplementMethod(wx_MouseEvent, Entering)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Entering();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetButton)
@@ -206,10 +216,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetButton)
 
 Gura_ImplementMethod(wx_MouseEvent, GetButton)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetButton();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetPosition)
@@ -220,10 +231,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetPosition)
 
 Gura_ImplementMethod(wx_MouseEvent, GetPosition)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetPosition();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetPosition_1)
@@ -237,16 +249,17 @@ Gura_DeclareMethod(wx_MouseEvent, GetPosition_1)
 
 Gura_ImplementMethod(wx_MouseEvent, GetPosition_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->GetPosition(x, y);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetPosition_2)
@@ -260,16 +273,17 @@ Gura_DeclareMethod(wx_MouseEvent, GetPosition_2)
 
 Gura_ImplementMethod(wx_MouseEvent, GetPosition_2)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long x = args.GetLong(0);
-	long y = args.GetLong(1);
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long x = arg.GetLong(0);
+	long y = arg.GetLong(1);
 	pThis->GetEntity()->GetPosition(x, y);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetLogicalPosition)
@@ -281,11 +295,12 @@ Gura_DeclareMethod(wx_MouseEvent, GetLogicalPosition)
 
 Gura_ImplementMethod(wx_MouseEvent, GetLogicalPosition)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC *dc = Object_wx_DC::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC *dc = Object_wx_DC::GetObject(arg, 0)->GetEntity();
 	wxPoint rtn = pThis->GetEntity()->GetLogicalPosition(*dc);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetLinesPerAction)
@@ -296,10 +311,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetLinesPerAction)
 
 Gura_ImplementMethod(wx_MouseEvent, GetLinesPerAction)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLinesPerAction();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetWheelRotation)
@@ -310,10 +326,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetWheelRotation)
 
 Gura_ImplementMethod(wx_MouseEvent, GetWheelRotation)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWheelRotation();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetWheelDelta)
@@ -324,10 +341,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetWheelDelta)
 
 Gura_ImplementMethod(wx_MouseEvent, GetWheelDelta)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWheelDelta();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetX)
@@ -338,10 +356,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetX)
 
 Gura_ImplementMethod(wx_MouseEvent, GetX)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetX();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, GetY)
@@ -352,10 +371,11 @@ Gura_DeclareMethod(wx_MouseEvent, GetY)
 
 Gura_ImplementMethod(wx_MouseEvent, GetY)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetY();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, IsButton)
@@ -366,10 +386,11 @@ Gura_DeclareMethod(wx_MouseEvent, IsButton)
 
 Gura_ImplementMethod(wx_MouseEvent, IsButton)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsButton();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, IsPageScroll)
@@ -380,10 +401,11 @@ Gura_DeclareMethod(wx_MouseEvent, IsPageScroll)
 
 Gura_ImplementMethod(wx_MouseEvent, IsPageScroll)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsPageScroll();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, Leaving)
@@ -394,10 +416,11 @@ Gura_DeclareMethod(wx_MouseEvent, Leaving)
 
 Gura_ImplementMethod(wx_MouseEvent, Leaving)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Leaving();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, LeftDClick)
@@ -408,10 +431,11 @@ Gura_DeclareMethod(wx_MouseEvent, LeftDClick)
 
 Gura_ImplementMethod(wx_MouseEvent, LeftDClick)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->LeftDClick();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, LeftDown)
@@ -422,10 +446,11 @@ Gura_DeclareMethod(wx_MouseEvent, LeftDown)
 
 Gura_ImplementMethod(wx_MouseEvent, LeftDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->LeftDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, LeftIsDown)
@@ -436,10 +461,11 @@ Gura_DeclareMethod(wx_MouseEvent, LeftIsDown)
 
 Gura_ImplementMethod(wx_MouseEvent, LeftIsDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->LeftIsDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, LeftUp)
@@ -450,10 +476,11 @@ Gura_DeclareMethod(wx_MouseEvent, LeftUp)
 
 Gura_ImplementMethod(wx_MouseEvent, LeftUp)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->LeftUp();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, MetaDown)
@@ -464,10 +491,11 @@ Gura_DeclareMethod(wx_MouseEvent, MetaDown)
 
 Gura_ImplementMethod(wx_MouseEvent, MetaDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->MetaDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, MiddleDClick)
@@ -478,10 +506,11 @@ Gura_DeclareMethod(wx_MouseEvent, MiddleDClick)
 
 Gura_ImplementMethod(wx_MouseEvent, MiddleDClick)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->MiddleDClick();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, MiddleDown)
@@ -492,10 +521,11 @@ Gura_DeclareMethod(wx_MouseEvent, MiddleDown)
 
 Gura_ImplementMethod(wx_MouseEvent, MiddleDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->MiddleDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, MiddleIsDown)
@@ -506,10 +536,11 @@ Gura_DeclareMethod(wx_MouseEvent, MiddleIsDown)
 
 Gura_ImplementMethod(wx_MouseEvent, MiddleIsDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->MiddleIsDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, MiddleUp)
@@ -520,10 +551,11 @@ Gura_DeclareMethod(wx_MouseEvent, MiddleUp)
 
 Gura_ImplementMethod(wx_MouseEvent, MiddleUp)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->MiddleUp();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, Moving)
@@ -534,10 +566,11 @@ Gura_DeclareMethod(wx_MouseEvent, Moving)
 
 Gura_ImplementMethod(wx_MouseEvent, Moving)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Moving();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, RightDClick)
@@ -548,10 +581,11 @@ Gura_DeclareMethod(wx_MouseEvent, RightDClick)
 
 Gura_ImplementMethod(wx_MouseEvent, RightDClick)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->RightDClick();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, RightDown)
@@ -562,10 +596,11 @@ Gura_DeclareMethod(wx_MouseEvent, RightDown)
 
 Gura_ImplementMethod(wx_MouseEvent, RightDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->RightDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, RightIsDown)
@@ -576,10 +611,11 @@ Gura_DeclareMethod(wx_MouseEvent, RightIsDown)
 
 Gura_ImplementMethod(wx_MouseEvent, RightIsDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->RightIsDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, RightUp)
@@ -590,10 +626,11 @@ Gura_DeclareMethod(wx_MouseEvent, RightUp)
 
 Gura_ImplementMethod(wx_MouseEvent, RightUp)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->RightUp();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_MouseEvent, ShiftDown)
@@ -604,10 +641,11 @@ Gura_DeclareMethod(wx_MouseEvent, ShiftDown)
 
 Gura_ImplementMethod(wx_MouseEvent, ShiftDown)
 {
-	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_MouseEvent *pThis = Object_wx_MouseEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ShiftDown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -619,13 +657,13 @@ Object_wx_MouseEvent::~Object_wx_MouseEvent()
 
 Object *Object_wx_MouseEvent::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_MouseEvent::ToString(bool exprFlag)
 {
 	String rtn("<wx.MouseEvent:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -682,7 +720,7 @@ Gura_ImplementUserInheritableClass(wx_MouseEvent)
 
 Gura_ImplementDescendantCreator(wx_MouseEvent)
 {
-	return new Object_wx_MouseEvent((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_MouseEvent((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
