@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Notebook: public wxNotebook, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Notebook *_pObj;
 public:
-	inline wx_Notebook() : wxNotebook(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Notebook(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxNotebook(parent, id, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_Notebook() : wxNotebook(), _pObj(nullptr) {}
+	inline wx_Notebook(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxNotebook(parent, id, pos, size, style, name), _pObj(nullptr) {}
 	~wx_Notebook();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Notebook *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Notebook *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_Notebook::~wx_Notebook()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Notebook::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(NotebookEmpty)
 
 Gura_ImplementFunction(NotebookEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Notebook *pEntity = new wx_Notebook();
-	Object_wx_Notebook *pObj = Object_wx_Notebook::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Notebook *pObj = Object_wx_Notebook::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Notebook(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Notebook)
@@ -74,27 +75,28 @@ Gura_DeclareFunction(Notebook)
 
 Gura_ImplementFunction(Notebook)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxNotebookNameStr;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	wx_Notebook *pEntity = new wx_Notebook(parent, id, *pos, *size, style, name);
-	Object_wx_Notebook *pObj = Object_wx_Notebook::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Notebook *pObj = Object_wx_Notebook::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Notebook(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Notebook, AddPage)
@@ -109,16 +111,17 @@ Gura_DeclareMethod(wx_Notebook, AddPage)
 
 Gura_ImplementMethod(wx_Notebook, AddPage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *page = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *page = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	bool select = false;
-	if (args.IsValid(2)) select = args.GetBoolean(2);
+	if (arg.IsValid(2)) select = arg.GetBoolean(2);
 	int imageId = -1;
-	if (args.IsValid(3)) imageId = args.GetInt(3);
+	if (arg.IsValid(3)) imageId = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AddPage(page, text, select, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, AdvanceSelection)
@@ -129,12 +132,13 @@ Gura_DeclareMethod(wx_Notebook, AdvanceSelection)
 
 Gura_ImplementMethod(wx_Notebook, AdvanceSelection)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool forward = true;
-	if (args.IsValid(0)) forward = args.GetBoolean(0);
+	if (arg.IsValid(0)) forward = arg.GetBoolean(0);
 	pThis->GetEntity()->AdvanceSelection(forward);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Notebook, AssignImageList)
@@ -145,11 +149,12 @@ Gura_DeclareMethod(wx_Notebook, AssignImageList)
 
 Gura_ImplementMethod(wx_Notebook, AssignImageList)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxImageList *imageList = Object_wx_ImageList::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxImageList *imageList = Object_wx_ImageList::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AssignImageList(imageList);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Notebook, ChangeSelection)
@@ -161,11 +166,12 @@ Gura_DeclareMethod(wx_Notebook, ChangeSelection)
 
 Gura_ImplementMethod(wx_Notebook, ChangeSelection)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->ChangeSelection(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, Create)
@@ -182,20 +188,21 @@ Gura_DeclareMethod(wx_Notebook, Create)
 
 Gura_ImplementMethod(wx_Notebook, Create)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxNotebookNameStr;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	bool rtn = pThis->GetEntity()->Create(parent, id, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, DeleteAllPages)
@@ -206,10 +213,11 @@ Gura_DeclareMethod(wx_Notebook, DeleteAllPages)
 
 Gura_ImplementMethod(wx_Notebook, DeleteAllPages)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DeleteAllPages();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, DeletePage)
@@ -221,11 +229,12 @@ Gura_DeclareMethod(wx_Notebook, DeletePage)
 
 Gura_ImplementMethod(wx_Notebook, DeletePage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->DeletePage(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, GetCurrentPage)
@@ -236,12 +245,13 @@ Gura_DeclareMethod(wx_Notebook, GetCurrentPage)
 
 Gura_ImplementMethod(wx_Notebook, GetCurrentPage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetCurrentPage();
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_Window(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_Window(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Notebook, GetImageList)
@@ -252,12 +262,13 @@ Gura_DeclareMethod(wx_Notebook, GetImageList)
 
 Gura_ImplementMethod(wx_Notebook, GetImageList)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxImageList *rtn = (wxImageList *)pThis->GetEntity()->GetImageList();
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_ImageList(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_ImageList(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Notebook, GetPage)
@@ -269,13 +280,14 @@ Gura_DeclareMethod(wx_Notebook, GetPage)
 
 Gura_ImplementMethod(wx_Notebook, GetPage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetPage(page);
 	Value value;
-	if (rtn != NULL) value = Value(new Object_wx_Window(rtn, NULL, OwnerFalse));
-	return ReturnValue(env, sig, args, value);
+	if (rtn != nullptr) value = Value(new Object_wx_Window(rtn, nullptr, OwnerFalse));
+	return ReturnValue(env, arg, value);
 }
 
 Gura_DeclareMethod(wx_Notebook, GetPageCount)
@@ -286,10 +298,11 @@ Gura_DeclareMethod(wx_Notebook, GetPageCount)
 
 Gura_ImplementMethod(wx_Notebook, GetPageCount)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetPageCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, GetPageImage)
@@ -301,11 +314,12 @@ Gura_DeclareMethod(wx_Notebook, GetPageImage)
 
 Gura_ImplementMethod(wx_Notebook, GetPageImage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t nPage = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t nPage = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->GetPageImage(nPage);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, GetPageText)
@@ -317,11 +331,12 @@ Gura_DeclareMethod(wx_Notebook, GetPageText)
 
 Gura_ImplementMethod(wx_Notebook, GetPageText)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t nPage = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t nPage = arg.GetSizeT(0);
 	wxString rtn = pThis->GetEntity()->GetPageText(nPage);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Notebook, GetRowCount)
@@ -332,10 +347,11 @@ Gura_DeclareMethod(wx_Notebook, GetRowCount)
 
 Gura_ImplementMethod(wx_Notebook, GetRowCount)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetRowCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, GetSelection)
@@ -346,10 +362,11 @@ Gura_DeclareMethod(wx_Notebook, GetSelection)
 
 Gura_ImplementMethod(wx_Notebook, GetSelection)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, GetThemeBackgroundColour)
@@ -360,10 +377,11 @@ Gura_DeclareMethod(wx_Notebook, GetThemeBackgroundColour)
 
 Gura_ImplementMethod(wx_Notebook, GetThemeBackgroundColour)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxColour rtn = pThis->GetEntity()->GetThemeBackgroundColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Notebook, HitTest)
@@ -375,12 +393,13 @@ Gura_DeclareMethod(wx_Notebook, HitTest)
 
 Gura_ImplementMethod(wx_Notebook, HitTest)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	long flags = 0;
 	int rtn = pThis->GetEntity()->HitTest(*pt, &flags);
-	return ReturnValue(env, sig, args, Value::CreateList(env, rtn, flags));
+	return ReturnValue(env, arg, Value::CreateList(env, rtn, flags));
 }
 
 Gura_DeclareMethod(wx_Notebook, InsertPage)
@@ -396,17 +415,18 @@ Gura_DeclareMethod(wx_Notebook, InsertPage)
 
 Gura_ImplementMethod(wx_Notebook, InsertPage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t index = args.GetSizeT(0);
-	wxWindow *page = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t index = arg.GetSizeT(0);
+	wxWindow *page = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(2));
 	bool select = false;
-	if (args.IsValid(3)) select = args.GetBoolean(3);
+	if (arg.IsValid(3)) select = arg.GetBoolean(3);
 	int imageId = -1;
-	if (args.IsValid(4)) imageId = args.GetInt(4);
+	if (arg.IsValid(4)) imageId = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->InsertPage(index, page, text, select, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 #if 0
@@ -418,15 +438,16 @@ Gura_DeclareMethod(wx_Notebook, OnSelChange)
 
 Gura_ImplementMethod(wx_Notebook, OnSelChange)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxNotebookEvent *event = Object_wx_NotebookEvent::GetObject(args, 0)->GetEntity();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxNotebookEvent *event = Object_wx_NotebookEvent::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnSelChange(*event);
-	return Value::Null;
+	return Value::Nil;
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 #endif
@@ -440,11 +461,12 @@ Gura_DeclareMethod(wx_Notebook, RemovePage)
 
 Gura_ImplementMethod(wx_Notebook, RemovePage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->RemovePage(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, SetImageList)
@@ -455,12 +477,13 @@ Gura_DeclareMethod(wx_Notebook, SetImageList)
 
 Gura_ImplementMethod(wx_Notebook, SetImageList)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxImageList *imageList = NULL;
-	if (args.IsValid(0)) imageList = Object_wx_ImageList::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxImageList *imageList = nullptr;
+	if (arg.IsValid(0)) imageList = Object_wx_ImageList::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetImageList(imageList);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Notebook, SetPadding)
@@ -471,11 +494,12 @@ Gura_DeclareMethod(wx_Notebook, SetPadding)
 
 Gura_ImplementMethod(wx_Notebook, SetPadding)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *padding = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *padding = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPadding(*padding);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Notebook, SetPageSize)
@@ -486,11 +510,12 @@ Gura_DeclareMethod(wx_Notebook, SetPageSize)
 
 Gura_ImplementMethod(wx_Notebook, SetPageSize)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPageSize(*size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Notebook, SetPageImage)
@@ -503,12 +528,13 @@ Gura_DeclareMethod(wx_Notebook, SetPageImage)
 
 Gura_ImplementMethod(wx_Notebook, SetPageImage)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	int image = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	int image = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->SetPageImage(page, image);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, SetPageText)
@@ -521,12 +547,13 @@ Gura_DeclareMethod(wx_Notebook, SetPageText)
 
 Gura_ImplementMethod(wx_Notebook, SetPageText)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->SetPageText(page, text);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Notebook, SetSelection)
@@ -538,11 +565,12 @@ Gura_DeclareMethod(wx_Notebook, SetSelection)
 
 Gura_ImplementMethod(wx_Notebook, SetSelection)
 {
-	Object_wx_Notebook *pThis = Object_wx_Notebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Notebook *pThis = Object_wx_Notebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->SetSelection(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -554,13 +582,13 @@ Object_wx_Notebook::~Object_wx_Notebook()
 
 Object *Object_wx_Notebook::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Notebook::ToString(bool exprFlag)
 {
 	String rtn("<wx.Notebook:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -609,7 +637,7 @@ Gura_ImplementUserInheritableClass(wx_Notebook)
 
 Gura_ImplementDescendantCreator(wx_Notebook)
 {
-	return new Object_wx_Notebook((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Notebook((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
