@@ -11,15 +11,15 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_PageSetupDialogData: public wxPageSetupDialogData, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_PageSetupDialogData *_pObj;
 public:
-	inline wx_PageSetupDialogData() : wxPageSetupDialogData(), _sig(NULL), _pObj(NULL) {}
-	inline wx_PageSetupDialogData(wxPageSetupDialogData& data) : wxPageSetupDialogData(data), _sig(NULL), _pObj(NULL) {}
-	inline wx_PageSetupDialogData(wxPrintData& printData) : wxPageSetupDialogData(printData), _sig(NULL), _pObj(NULL) {}
+	inline wx_PageSetupDialogData() : wxPageSetupDialogData(), _pObj(nullptr) {}
+	inline wx_PageSetupDialogData(wxPageSetupDialogData& data) : wxPageSetupDialogData(data), _pObj(nullptr) {}
+	inline wx_PageSetupDialogData(wxPrintData& printData) : wxPageSetupDialogData(printData), _pObj(nullptr) {}
 	~wx_PageSetupDialogData();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_PageSetupDialogData *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_PageSetupDialogData *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -27,12 +27,12 @@ public:
 
 wx_PageSetupDialogData::~wx_PageSetupDialogData()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_PageSetupDialogData::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,17 +47,18 @@ Gura_DeclareFunction(PageSetupDialogDataEmpty)
 
 Gura_ImplementFunction(PageSetupDialogDataEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_PageSetupDialogData *pEntity = new wx_PageSetupDialogData();
-	Object_wx_PageSetupDialogData *pObj = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PageSetupDialogData *pObj = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PageSetupDialogData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(PageSetupDialogData)
@@ -70,18 +71,19 @@ Gura_DeclareFunction(PageSetupDialogData)
 
 Gura_ImplementFunction(PageSetupDialogData)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPageSetupDialogData *data = Object_wx_PageSetupDialogData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPageSetupDialogData *data = Object_wx_PageSetupDialogData::GetObject(arg, 0)->GetEntity();
 	wx_PageSetupDialogData *pEntity = new wx_PageSetupDialogData(*data);
-	Object_wx_PageSetupDialogData *pObj = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PageSetupDialogData *pObj = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PageSetupDialogData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(PageSetupDialogData_1)
@@ -94,18 +96,19 @@ Gura_DeclareFunction(PageSetupDialogData_1)
 
 Gura_ImplementFunction(PageSetupDialogData_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPrintData *printData = Object_wx_PrintData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPrintData *printData = Object_wx_PrintData::GetObject(arg, 0)->GetEntity();
 	wx_PageSetupDialogData *pEntity = new wx_PageSetupDialogData(*printData);
-	Object_wx_PageSetupDialogData *pObj = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PageSetupDialogData *pObj = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PageSetupDialogData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, EnableHelp)
@@ -116,11 +119,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, EnableHelp)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, EnableHelp)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableHelp(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, EnableMargins)
@@ -131,11 +135,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, EnableMargins)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, EnableMargins)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableMargins(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, EnableOrientation)
@@ -146,11 +151,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, EnableOrientation)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, EnableOrientation)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableOrientation(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, EnablePaper)
@@ -161,11 +167,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, EnablePaper)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, EnablePaper)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnablePaper(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, EnablePrinter)
@@ -176,11 +183,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, EnablePrinter)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, EnablePrinter)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnablePrinter(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetDefaultMinMargins)
@@ -191,10 +199,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetDefaultMinMargins)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetDefaultMinMargins)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetDefaultMinMargins();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetEnableMargins)
@@ -205,10 +214,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetEnableMargins)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetEnableMargins)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetEnableMargins();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetEnableOrientation)
@@ -219,10 +229,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetEnableOrientation)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetEnableOrientation)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetEnableOrientation();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetEnablePaper)
@@ -233,10 +244,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetEnablePaper)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetEnablePaper)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetEnablePaper();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetEnablePrinter)
@@ -247,10 +259,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetEnablePrinter)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetEnablePrinter)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetEnablePrinter();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetEnableHelp)
@@ -261,10 +274,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetEnableHelp)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetEnableHelp)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetEnableHelp();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetDefaultInfo)
@@ -275,10 +289,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetDefaultInfo)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetDefaultInfo)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetDefaultInfo();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetMarginTopLeft)
@@ -289,10 +304,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetMarginTopLeft)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetMarginTopLeft)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetMarginTopLeft();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetMarginBottomRight)
@@ -303,10 +319,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetMarginBottomRight)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetMarginBottomRight)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetMarginBottomRight();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetMinMarginTopLeft)
@@ -317,10 +334,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetMinMarginTopLeft)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetMinMarginTopLeft)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetMinMarginTopLeft();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetMinMarginBottomRight)
@@ -331,10 +349,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetMinMarginBottomRight)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetMinMarginBottomRight)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetMinMarginBottomRight();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetPaperId)
@@ -345,10 +364,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetPaperId)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetPaperId)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPaperSize rtn = pThis->GetEntity()->GetPaperId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetPaperSize)
@@ -359,10 +379,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetPaperSize)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetPaperSize)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetPaperSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, GetPrintData)
@@ -373,10 +394,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, GetPrintData)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, GetPrintData)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPrintData &rtn = pThis->GetEntity()->GetPrintData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_PrintData(new wxPrintData(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_PrintData(new wxPrintData(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, IsOk)
@@ -387,10 +409,11 @@ Gura_DeclareMethod(wx_PageSetupDialogData, IsOk)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, IsOk)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetDefaultInfo)
@@ -401,11 +424,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetDefaultInfo)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetDefaultInfo)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetDefaultInfo(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetDefaultMinMargins)
@@ -416,11 +440,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetDefaultMinMargins)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetDefaultMinMargins)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetDefaultMinMargins(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetMarginTopLeft)
@@ -431,11 +456,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetMarginTopLeft)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetMarginTopLeft)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMarginTopLeft(*pt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetMarginBottomRight)
@@ -446,11 +472,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetMarginBottomRight)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetMarginBottomRight)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMarginBottomRight(*pt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetMinMarginTopLeft)
@@ -461,11 +488,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetMinMarginTopLeft)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetMinMarginTopLeft)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMinMarginTopLeft(*pt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetMinMarginBottomRight)
@@ -476,11 +504,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetMinMarginBottomRight)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetMinMarginBottomRight)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMinMarginBottomRight(*pt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetPaperId)
@@ -491,11 +520,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetPaperId)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetPaperId)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPaperSize id = static_cast<wxPaperSize>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPaperSize id = static_cast<wxPaperSize>(arg.GetInt(0));
 	pThis->GetEntity()->SetPaperId(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetPaperSize)
@@ -506,11 +536,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetPaperSize)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetPaperSize)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPaperSize(*size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PageSetupDialogData, SetPrintData)
@@ -521,11 +552,12 @@ Gura_DeclareMethod(wx_PageSetupDialogData, SetPrintData)
 
 Gura_ImplementMethod(wx_PageSetupDialogData, SetPrintData)
 {
-	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPrintData *printData = Object_wx_PrintData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PageSetupDialogData *pThis = Object_wx_PageSetupDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPrintData *printData = Object_wx_PrintData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPrintData(*printData);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -537,13 +569,13 @@ Object_wx_PageSetupDialogData::~Object_wx_PageSetupDialogData()
 
 Object *Object_wx_PageSetupDialogData::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_PageSetupDialogData::ToString(bool exprFlag)
 {
 	String rtn("<wx.PageSetupDialogData:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -594,7 +626,7 @@ Gura_ImplementUserInheritableClass(wx_PageSetupDialogData)
 
 Gura_ImplementDescendantCreator(wx_PageSetupDialogData)
 {
-	return new Object_wx_PageSetupDialogData((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_PageSetupDialogData((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
