@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_PlatformInfo: public wxPlatformInfo, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_PlatformInfo *_pObj;
 public:
-	inline wx_PlatformInfo() : wxPlatformInfo(), _sig(NULL), _pObj(NULL) {}
-	inline wx_PlatformInfo(wxPortId pid, int tkMajor, int tkMinor, wxOperatingSystemId id, int osMajor, int osMinor, wxArchitecture arch, wxEndianness endian) : wxPlatformInfo(pid, tkMajor, tkMinor, id, osMajor, osMinor, arch, endian), _sig(NULL), _pObj(NULL) {}
+	inline wx_PlatformInfo() : wxPlatformInfo(), _pObj(nullptr) {}
+	inline wx_PlatformInfo(wxPortId pid, int tkMajor, int tkMinor, wxOperatingSystemId id, int osMajor, int osMinor, wxArchitecture arch, wxEndianness endian) : wxPlatformInfo(pid, tkMajor, tkMinor, id, osMajor, osMinor, arch, endian), _pObj(nullptr) {}
 	~wx_PlatformInfo();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_PlatformInfo *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_PlatformInfo *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_PlatformInfo::~wx_PlatformInfo()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_PlatformInfo::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(PlatformInfoEmpty)
 
 Gura_ImplementFunction(PlatformInfoEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_PlatformInfo *pEntity = new wx_PlatformInfo();
-	Object_wx_PlatformInfo *pObj = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PlatformInfo *pObj = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PlatformInfo(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(PlatformInfo)
@@ -76,33 +77,34 @@ Gura_DeclareFunction(PlatformInfo)
 
 Gura_ImplementFunction(PlatformInfo)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxPortId pid = wxPORT_UNKNOWN;
-	if (args.IsValid(0)) pid = static_cast<wxPortId>(args.GetInt(0));
+	if (arg.IsValid(0)) pid = static_cast<wxPortId>(arg.GetInt(0));
 	int tkMajor = -1;
-	if (args.IsValid(1)) tkMajor = args.GetInt(1);
+	if (arg.IsValid(1)) tkMajor = arg.GetInt(1);
 	int tkMinor = -1;
-	if (args.IsValid(2)) tkMinor = args.GetInt(2);
+	if (arg.IsValid(2)) tkMinor = arg.GetInt(2);
 	wxOperatingSystemId id = wxOS_UNKNOWN;
-	if (args.IsValid(3)) id = static_cast<wxOperatingSystemId>(args.GetInt(3));
+	if (arg.IsValid(3)) id = static_cast<wxOperatingSystemId>(arg.GetInt(3));
 	int osMajor = -1;
-	if (args.IsValid(4)) osMajor = args.GetInt(4);
+	if (arg.IsValid(4)) osMajor = arg.GetInt(4);
 	int osMinor = -1;
-	if (args.IsValid(5)) osMinor = args.GetInt(5);
+	if (arg.IsValid(5)) osMinor = arg.GetInt(5);
 	wxArchitecture arch = wxARCH_INVALID;
-	if (args.IsValid(6)) arch = static_cast<wxArchitecture>(args.GetInt(6));
+	if (arg.IsValid(6)) arch = static_cast<wxArchitecture>(arg.GetInt(6));
 	wxEndianness endian = wxENDIAN_INVALID;
-	if (args.IsValid(7)) endian = static_cast<wxEndianness>(args.GetInt(7));
+	if (arg.IsValid(7)) endian = static_cast<wxEndianness>(arg.GetInt(7));
 	wx_PlatformInfo *pEntity = new wx_PlatformInfo(pid, tkMajor, tkMinor, id, osMajor, osMinor, arch, endian);
-	Object_wx_PlatformInfo *pObj = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PlatformInfo *pObj = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PlatformInfo(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, CheckOSVersion)
@@ -115,12 +117,13 @@ Gura_DeclareMethod(wx_PlatformInfo, CheckOSVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, CheckOSVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int major = args.GetInt(0);
-	int minor = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int major = arg.GetInt(0);
+	int minor = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->CheckOSVersion(major, minor);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, CheckToolkitVersion)
@@ -133,12 +136,13 @@ Gura_DeclareMethod(wx_PlatformInfo, CheckToolkitVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, CheckToolkitVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int major = args.GetInt(0);
-	int minor = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int major = arg.GetInt(0);
+	int minor = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->CheckToolkitVersion(major, minor);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, Get)
@@ -149,9 +153,10 @@ Gura_DeclareClassMethod(wx_PlatformInfo, Get)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, Get)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	const wxPlatformInfo &rtn = wxPlatformInfo::Get();
-	return ReturnValue(env, sig, args, Value(new Object_wx_PlatformInfo(new wxPlatformInfo(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_PlatformInfo(new wxPlatformInfo(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetArch)
@@ -163,10 +168,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetArch)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetArch)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString arch = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString arch = wxString::FromUTF8(arg.GetString(0));
 	wxArchitecture rtn = wxPlatformInfo::GetArch(arch);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetArchName)
@@ -178,10 +184,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetArchName)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetArchName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxArchitecture arch = static_cast<wxArchitecture>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxArchitecture arch = static_cast<wxArchitecture>(arg.GetInt(0));
 	wxString rtn = wxPlatformInfo::GetArchName(arch);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetArchName_1)
@@ -192,10 +199,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetArchName_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetArchName_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetArchName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetArchitecture)
@@ -206,10 +214,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetArchitecture)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetArchitecture)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxArchitecture rtn = pThis->GetEntity()->GetArchitecture();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetEndianness)
@@ -221,10 +230,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetEndianness)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetEndianness)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString end = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString end = wxString::FromUTF8(arg.GetString(0));
 	wxEndianness rtn = wxPlatformInfo::GetEndianness(end);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetEndianness_1)
@@ -235,10 +245,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetEndianness_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetEndianness_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxEndianness rtn = pThis->GetEntity()->GetEndianness();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetEndiannessName)
@@ -250,10 +261,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetEndiannessName)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetEndiannessName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxEndianness end = static_cast<wxEndianness>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxEndianness end = static_cast<wxEndianness>(arg.GetInt(0));
 	wxString rtn = wxPlatformInfo::GetEndiannessName(end);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetEndiannessName_1)
@@ -264,10 +276,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetEndiannessName_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetEndiannessName_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetEndiannessName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetOSMajorVersion)
@@ -278,10 +291,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetOSMajorVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetOSMajorVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetOSMajorVersion();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetOSMinorVersion)
@@ -292,10 +306,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetOSMinorVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetOSMinorVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetOSMinorVersion();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetOperatingSystemFamilyName)
@@ -307,10 +322,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetOperatingSystemFamilyName)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetOperatingSystemFamilyName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxOperatingSystemId os = static_cast<wxOperatingSystemId>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxOperatingSystemId os = static_cast<wxOperatingSystemId>(arg.GetInt(0));
 	wxString rtn = wxPlatformInfo::GetOperatingSystemFamilyName(os);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetOperatingSystemFamilyName_1)
@@ -321,10 +337,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetOperatingSystemFamilyName_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetOperatingSystemFamilyName_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetOperatingSystemFamilyName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetOperatingSystemId)
@@ -336,10 +353,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetOperatingSystemId)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetOperatingSystemId)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxOperatingSystemId rtn = wxPlatformInfo::GetOperatingSystemId(name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetOperatingSystemId_1)
@@ -350,10 +368,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetOperatingSystemId_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetOperatingSystemId_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxOperatingSystemId rtn = pThis->GetEntity()->GetOperatingSystemId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetOperatingSystemIdName)
@@ -365,10 +384,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetOperatingSystemIdName)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetOperatingSystemIdName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxOperatingSystemId os = static_cast<wxOperatingSystemId>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxOperatingSystemId os = static_cast<wxOperatingSystemId>(arg.GetInt(0));
 	wxString rtn = wxPlatformInfo::GetOperatingSystemIdName(os);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetOperatingSystemIdName_1)
@@ -379,10 +399,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetOperatingSystemIdName_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetOperatingSystemIdName_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetOperatingSystemIdName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetPortId)
@@ -394,10 +415,11 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetPortId)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetPortId)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString portname = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString portname = wxString::FromUTF8(arg.GetString(0));
 	wxPortId rtn = wxPlatformInfo::GetPortId(portname);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetPortId_1)
@@ -408,10 +430,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetPortId_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetPortId_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPortId rtn = pThis->GetEntity()->GetPortId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetPortIdName)
@@ -424,11 +447,12 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetPortIdName)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetPortIdName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPortId port = static_cast<wxPortId>(args.GetInt(0));
-	bool usingUniversal = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPortId port = static_cast<wxPortId>(arg.GetInt(0));
+	bool usingUniversal = arg.GetBoolean(1);
 	wxString rtn = wxPlatformInfo::GetPortIdName(port, usingUniversal);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetPortIdName_1)
@@ -439,10 +463,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetPortIdName_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetPortIdName_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetPortIdName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareClassMethod(wx_PlatformInfo, GetPortIdShortName)
@@ -455,11 +480,12 @@ Gura_DeclareClassMethod(wx_PlatformInfo, GetPortIdShortName)
 
 Gura_ImplementClassMethod(wx_PlatformInfo, GetPortIdShortName)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPortId port = static_cast<wxPortId>(args.GetInt(0));
-	bool usingUniversal = args.GetBoolean(1);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPortId port = static_cast<wxPortId>(arg.GetInt(0));
+	bool usingUniversal = arg.GetBoolean(1);
 	wxString rtn = wxPlatformInfo::GetPortIdShortName(port, usingUniversal);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetPortIdShortName_1)
@@ -470,10 +496,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetPortIdShortName_1)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetPortIdShortName_1)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetPortIdShortName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetToolkitMajorVersion)
@@ -484,10 +511,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetToolkitMajorVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetToolkitMajorVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetToolkitMajorVersion();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, GetToolkitMinorVersion)
@@ -498,10 +526,11 @@ Gura_DeclareMethod(wx_PlatformInfo, GetToolkitMinorVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, GetToolkitMinorVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetToolkitMinorVersion();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, IsOk)
@@ -512,10 +541,11 @@ Gura_DeclareMethod(wx_PlatformInfo, IsOk)
 
 Gura_ImplementMethod(wx_PlatformInfo, IsOk)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, IsUsingUniversalWidgets)
@@ -526,10 +556,11 @@ Gura_DeclareMethod(wx_PlatformInfo, IsUsingUniversalWidgets)
 
 Gura_ImplementMethod(wx_PlatformInfo, IsUsingUniversalWidgets)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsUsingUniversalWidgets();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, SetArchitecture)
@@ -540,11 +571,12 @@ Gura_DeclareMethod(wx_PlatformInfo, SetArchitecture)
 
 Gura_ImplementMethod(wx_PlatformInfo, SetArchitecture)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxArchitecture n = static_cast<wxArchitecture>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxArchitecture n = static_cast<wxArchitecture>(arg.GetInt(0));
 	pThis->GetEntity()->SetArchitecture(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, SetEndianness)
@@ -555,11 +587,12 @@ Gura_DeclareMethod(wx_PlatformInfo, SetEndianness)
 
 Gura_ImplementMethod(wx_PlatformInfo, SetEndianness)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEndianness n = static_cast<wxEndianness>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEndianness n = static_cast<wxEndianness>(arg.GetInt(0));
 	pThis->GetEntity()->SetEndianness(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, SetOSVersion)
@@ -571,12 +604,13 @@ Gura_DeclareMethod(wx_PlatformInfo, SetOSVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, SetOSVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int major = args.GetInt(0);
-	int minor = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int major = arg.GetInt(0);
+	int minor = arg.GetInt(1);
 	pThis->GetEntity()->SetOSVersion(major, minor);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, SetOperatingSystemId)
@@ -587,11 +621,12 @@ Gura_DeclareMethod(wx_PlatformInfo, SetOperatingSystemId)
 
 Gura_ImplementMethod(wx_PlatformInfo, SetOperatingSystemId)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxOperatingSystemId n = static_cast<wxOperatingSystemId>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxOperatingSystemId n = static_cast<wxOperatingSystemId>(arg.GetInt(0));
 	pThis->GetEntity()->SetOperatingSystemId(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, SetPortId)
@@ -602,11 +637,12 @@ Gura_DeclareMethod(wx_PlatformInfo, SetPortId)
 
 Gura_ImplementMethod(wx_PlatformInfo, SetPortId)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPortId n = static_cast<wxPortId>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPortId n = static_cast<wxPortId>(arg.GetInt(0));
 	pThis->GetEntity()->SetPortId(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PlatformInfo, SetToolkitVersion)
@@ -618,12 +654,13 @@ Gura_DeclareMethod(wx_PlatformInfo, SetToolkitVersion)
 
 Gura_ImplementMethod(wx_PlatformInfo, SetToolkitVersion)
 {
-	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int major = args.GetInt(0);
-	int minor = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_PlatformInfo *pThis = Object_wx_PlatformInfo::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int major = arg.GetInt(0);
+	int minor = arg.GetInt(1);
 	pThis->GetEntity()->SetToolkitVersion(major, minor);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -631,20 +668,20 @@ Gura_ImplementMethod(wx_PlatformInfo, SetToolkitVersion)
 //----------------------------------------------------------------------------
 Object_wx_PlatformInfo::~Object_wx_PlatformInfo()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_PlatformInfo::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_PlatformInfo::ToString(bool exprFlag)
 {
 	String rtn("<wx.PlatformInfo:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -700,7 +737,7 @@ Gura_ImplementUserInheritableClass(wx_PlatformInfo)
 
 Gura_ImplementDescendantCreator(wx_PlatformInfo)
 {
-	return new Object_wx_PlatformInfo((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_PlatformInfo((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
