@@ -11,15 +11,15 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_PrintDialogData: public wxPrintDialogData, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_PrintDialogData *_pObj;
 public:
-	inline wx_PrintDialogData() : wxPrintDialogData(), _sig(NULL), _pObj(NULL) {}
-	inline wx_PrintDialogData(wxPrintDialogData& dialogData) : wxPrintDialogData(dialogData), _sig(NULL), _pObj(NULL) {}
-	inline wx_PrintDialogData(wxPrintData& printData) : wxPrintDialogData(printData), _sig(NULL), _pObj(NULL) {}
+	inline wx_PrintDialogData() : wxPrintDialogData(), _pObj(nullptr) {}
+	inline wx_PrintDialogData(wxPrintDialogData& dialogData) : wxPrintDialogData(dialogData), _pObj(nullptr) {}
+	inline wx_PrintDialogData(wxPrintData& printData) : wxPrintDialogData(printData), _pObj(nullptr) {}
 	~wx_PrintDialogData();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_PrintDialogData *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_PrintDialogData *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -27,12 +27,12 @@ public:
 
 wx_PrintDialogData::~wx_PrintDialogData()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_PrintDialogData::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,17 +47,18 @@ Gura_DeclareFunction(PrintDialogDataEmpty)
 
 Gura_ImplementFunction(PrintDialogDataEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_PrintDialogData *pEntity = new wx_PrintDialogData();
-	Object_wx_PrintDialogData *pObj = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PrintDialogData *pObj = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PrintDialogData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(PrintDialogData)
@@ -70,18 +71,19 @@ Gura_DeclareFunction(PrintDialogData)
 
 Gura_ImplementFunction(PrintDialogData)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPrintDialogData *dialogData = Object_wx_PrintDialogData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPrintDialogData *dialogData = Object_wx_PrintDialogData::GetObject(arg, 0)->GetEntity();
 	wx_PrintDialogData *pEntity = new wx_PrintDialogData(*dialogData);
-	Object_wx_PrintDialogData *pObj = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PrintDialogData *pObj = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PrintDialogData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(PrintDialogData_1)
@@ -94,18 +96,19 @@ Gura_DeclareFunction(PrintDialogData_1)
 
 Gura_ImplementFunction(PrintDialogData_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPrintData *printData = Object_wx_PrintData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPrintData *printData = Object_wx_PrintData::GetObject(arg, 0)->GetEntity();
 	wx_PrintDialogData *pEntity = new wx_PrintDialogData(*printData);
-	Object_wx_PrintDialogData *pObj = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_PrintDialogData *pObj = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_PrintDialogData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, EnableHelp)
@@ -116,11 +119,12 @@ Gura_DeclareMethod(wx_PrintDialogData, EnableHelp)
 
 Gura_ImplementMethod(wx_PrintDialogData, EnableHelp)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableHelp(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, EnablePageNumbers)
@@ -131,11 +135,12 @@ Gura_DeclareMethod(wx_PrintDialogData, EnablePageNumbers)
 
 Gura_ImplementMethod(wx_PrintDialogData, EnablePageNumbers)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnablePageNumbers(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, EnablePrintToFile)
@@ -146,11 +151,12 @@ Gura_DeclareMethod(wx_PrintDialogData, EnablePrintToFile)
 
 Gura_ImplementMethod(wx_PrintDialogData, EnablePrintToFile)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnablePrintToFile(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, EnableSelection)
@@ -161,11 +167,12 @@ Gura_DeclareMethod(wx_PrintDialogData, EnableSelection)
 
 Gura_ImplementMethod(wx_PrintDialogData, EnableSelection)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->EnableSelection(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetAllPages)
@@ -176,10 +183,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetAllPages)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetAllPages)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetAllPages();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetCollate)
@@ -190,10 +198,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetCollate)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetCollate)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetCollate();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetFromPage)
@@ -204,10 +213,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetFromPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetFromPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFromPage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetMaxPage)
@@ -218,10 +228,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetMaxPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetMaxPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMaxPage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetMinPage)
@@ -232,10 +243,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetMinPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetMinPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMinPage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetNoCopies)
@@ -246,10 +258,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetNoCopies)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetNoCopies)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetNoCopies();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetPrintData)
@@ -260,10 +273,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetPrintData)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetPrintData)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPrintData &rtn = pThis->GetEntity()->GetPrintData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_PrintData(new wxPrintData(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_PrintData(new wxPrintData(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetPrintToFile)
@@ -274,10 +288,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetPrintToFile)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetPrintToFile)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetPrintToFile();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetSelection)
@@ -288,10 +303,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetSelection)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetSelection)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, GetToPage)
@@ -302,10 +318,11 @@ Gura_DeclareMethod(wx_PrintDialogData, GetToPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, GetToPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetToPage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, IsOk)
@@ -316,10 +333,11 @@ Gura_DeclareMethod(wx_PrintDialogData, IsOk)
 
 Gura_ImplementMethod(wx_PrintDialogData, IsOk)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetCollate)
@@ -330,11 +348,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetCollate)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetCollate)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetCollate(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetFromPage)
@@ -345,11 +364,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetFromPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetFromPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int page = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int page = arg.GetInt(0);
 	pThis->GetEntity()->SetFromPage(page);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetMaxPage)
@@ -360,11 +380,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetMaxPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetMaxPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int page = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int page = arg.GetInt(0);
 	pThis->GetEntity()->SetMaxPage(page);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetMinPage)
@@ -375,11 +396,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetMinPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetMinPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int page = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int page = arg.GetInt(0);
 	pThis->GetEntity()->SetMinPage(page);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetNoCopies)
@@ -390,11 +412,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetNoCopies)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetNoCopies)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->SetNoCopies(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetPrintData)
@@ -405,11 +428,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetPrintData)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetPrintData)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPrintData *printData = Object_wx_PrintData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPrintData *printData = Object_wx_PrintData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPrintData(*printData);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetPrintToFile)
@@ -420,11 +444,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetPrintToFile)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetPrintToFile)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetPrintToFile(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetSelection)
@@ -435,11 +460,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetSelection)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetSelection)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetSelection(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetSetupDialog)
@@ -452,15 +478,16 @@ Gura_DeclareMethod(wx_PrintDialogData, SetSetupDialog)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetSetupDialog)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flag = args.GetBoolean(0);
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flag = arg.GetBoolean(0);
 	pThis->GetEntity()->SetSetupDialog(flag);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_PrintDialogData, SetToPage)
@@ -471,11 +498,12 @@ Gura_DeclareMethod(wx_PrintDialogData, SetToPage)
 
 Gura_ImplementMethod(wx_PrintDialogData, SetToPage)
 {
-	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int page = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_PrintDialogData *pThis = Object_wx_PrintDialogData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int page = arg.GetInt(0);
 	pThis->GetEntity()->SetToPage(page);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -487,13 +515,13 @@ Object_wx_PrintDialogData::~Object_wx_PrintDialogData()
 
 Object *Object_wx_PrintDialogData::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_PrintDialogData::ToString(bool exprFlag)
 {
 	String rtn("<wx.PrintDialogData:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -540,7 +568,7 @@ Gura_ImplementUserInheritableClass(wx_PrintDialogData)
 
 Gura_ImplementDescendantCreator(wx_PrintDialogData)
 {
-	return new Object_wx_PrintDialogData((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_PrintDialogData((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
