@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Printout: public wxPrintout, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Printout *_pObj;
 public:
-	//inline wx_Printout(const wxString& title) : wxPrintout(title), _sig(NULL), _pObj(NULL) {}
+	//inline wx_Printout(const wxString& title) : wxPrintout(title), _pObj(nullptr) {}
 	~wx_Printout();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Printout *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Printout *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_Printout::~wx_Printout()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Printout::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -48,23 +48,24 @@ Gura_DeclareFunction(Printout)
 
 Gura_ImplementFunction(Printout)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxString title = wxT("Printout");
-	if (args.IsValid(0)) title = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) title = wxString::FromUTF8(arg.GetString(0));
 	wx_Printout *pEntity = new wx_Printout(title);
-	Object_wx_Printout *pObj = Object_wx_Printout::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Printout *pObj = Object_wx_Printout::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Printout(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetDC)
@@ -75,10 +76,11 @@ Gura_DeclareMethod(wx_Printout, GetDC)
 
 Gura_ImplementMethod(wx_Printout, GetDC)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDC *rtn = (wxDC *)pThis->GetEntity()->GetDC();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DC(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_DC(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Printout, GetPageInfo)
@@ -94,18 +96,19 @@ Gura_DeclareMethod(wx_Printout, GetPageInfo)
 
 Gura_ImplementMethod(wx_Printout, GetPageInfo)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int minPage = args.GetInt(0);
-	int maxPage = args.GetInt(1);
-	int pageFrom = args.GetInt(2);
-	int pageTo = args.GetInt(3);
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int minPage = arg.GetInt(0);
+	int maxPage = arg.GetInt(1);
+	int pageFrom = arg.GetInt(2);
+	int pageTo = arg.GetInt(3);
 	pThis->GetEntity()->GetPageInfo(minPage, maxPage, pageFrom, pageTo);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetPageSizeMM)
@@ -119,16 +122,17 @@ Gura_DeclareMethod(wx_Printout, GetPageSizeMM)
 
 Gura_ImplementMethod(wx_Printout, GetPageSizeMM)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int w = args.GetInt(0);
-	int h = args.GetInt(1);
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int w = arg.GetInt(0);
+	int h = arg.GetInt(1);
 	pThis->GetEntity()->GetPageSizeMM(w, h);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetPageSizePixels)
@@ -142,16 +146,17 @@ Gura_DeclareMethod(wx_Printout, GetPageSizePixels)
 
 Gura_ImplementMethod(wx_Printout, GetPageSizePixels)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int w = args.GetInt(0);
-	int h = args.GetInt(1);
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int w = arg.GetInt(0);
+	int h = arg.GetInt(1);
 	pThis->GetEntity()->GetPageSizePixels(w, h);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetPaperRectPixels)
@@ -162,10 +167,11 @@ Gura_DeclareMethod(wx_Printout, GetPaperRectPixels)
 
 Gura_ImplementMethod(wx_Printout, GetPaperRectPixels)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRect rtn = pThis->GetEntity()->GetPaperRectPixels();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Printout, GetPPIPrinter)
@@ -179,16 +185,17 @@ Gura_DeclareMethod(wx_Printout, GetPPIPrinter)
 
 Gura_ImplementMethod(wx_Printout, GetPPIPrinter)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int w = args.GetInt(0);
-	int h = args.GetInt(1);
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int w = arg.GetInt(0);
+	int h = arg.GetInt(1);
 	pThis->GetEntity()->GetPPIPrinter(w, h);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetPPIScreen)
@@ -202,16 +209,17 @@ Gura_DeclareMethod(wx_Printout, GetPPIScreen)
 
 Gura_ImplementMethod(wx_Printout, GetPPIScreen)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int w = args.GetInt(0);
-	int h = args.GetInt(1);
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int w = arg.GetInt(0);
+	int h = arg.GetInt(1);
 	pThis->GetEntity()->GetPPIScreen(w, h);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetTitle)
@@ -222,10 +230,11 @@ Gura_DeclareMethod(wx_Printout, GetTitle)
 
 Gura_ImplementMethod(wx_Printout, GetTitle)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetTitle();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Printout, HasPage)
@@ -237,11 +246,12 @@ Gura_DeclareMethod(wx_Printout, HasPage)
 
 Gura_ImplementMethod(wx_Printout, HasPage)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pageNum = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pageNum = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->HasPage(pageNum);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Printout, IsPreview)
@@ -252,10 +262,11 @@ Gura_DeclareMethod(wx_Printout, IsPreview)
 
 Gura_ImplementMethod(wx_Printout, IsPreview)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsPreview();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Printout, FitThisSizeToPaper)
@@ -266,11 +277,12 @@ Gura_DeclareMethod(wx_Printout, FitThisSizeToPaper)
 
 Gura_ImplementMethod(wx_Printout, FitThisSizeToPaper)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *imageSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *imageSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FitThisSizeToPaper(*imageSize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, FitThisSizeToPage)
@@ -281,11 +293,12 @@ Gura_DeclareMethod(wx_Printout, FitThisSizeToPage)
 
 Gura_ImplementMethod(wx_Printout, FitThisSizeToPage)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *imageSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *imageSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->FitThisSizeToPage(*imageSize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, FitThisSizeToPageMargins)
@@ -297,12 +310,13 @@ Gura_DeclareMethod(wx_Printout, FitThisSizeToPageMargins)
 
 Gura_ImplementMethod(wx_Printout, FitThisSizeToPageMargins)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *imageSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
-	wxPageSetupDialogData *pageSetupData = Object_wx_PageSetupDialogData::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *imageSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
+	wxPageSetupDialogData *pageSetupData = Object_wx_PageSetupDialogData::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->FitThisSizeToPageMargins(*imageSize, *pageSetupData);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, MapScreenSizeToPaper)
@@ -312,10 +326,11 @@ Gura_DeclareMethod(wx_Printout, MapScreenSizeToPaper)
 
 Gura_ImplementMethod(wx_Printout, MapScreenSizeToPaper)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->MapScreenSizeToPaper();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, MapScreenSizeToPage)
@@ -325,10 +340,11 @@ Gura_DeclareMethod(wx_Printout, MapScreenSizeToPage)
 
 Gura_ImplementMethod(wx_Printout, MapScreenSizeToPage)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->MapScreenSizeToPage();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, MapScreenSizeToPageMargins)
@@ -339,11 +355,12 @@ Gura_DeclareMethod(wx_Printout, MapScreenSizeToPageMargins)
 
 Gura_ImplementMethod(wx_Printout, MapScreenSizeToPageMargins)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPageSetupDialogData *pageSetupData = Object_wx_PageSetupDialogData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPageSetupDialogData *pageSetupData = Object_wx_PageSetupDialogData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->MapScreenSizeToPageMargins(*pageSetupData);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, MapScreenSizeToDevice)
@@ -353,10 +370,11 @@ Gura_DeclareMethod(wx_Printout, MapScreenSizeToDevice)
 
 Gura_ImplementMethod(wx_Printout, MapScreenSizeToDevice)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->MapScreenSizeToDevice();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, GetLogicalPaperRect)
@@ -367,10 +385,11 @@ Gura_DeclareMethod(wx_Printout, GetLogicalPaperRect)
 
 Gura_ImplementMethod(wx_Printout, GetLogicalPaperRect)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRect rtn = pThis->GetEntity()->GetLogicalPaperRect();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Printout, GetLogicalPageRect)
@@ -381,10 +400,11 @@ Gura_DeclareMethod(wx_Printout, GetLogicalPageRect)
 
 Gura_ImplementMethod(wx_Printout, GetLogicalPageRect)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRect rtn = pThis->GetEntity()->GetLogicalPageRect();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Printout, GetLogicalPageMarginsRect)
@@ -396,11 +416,12 @@ Gura_DeclareMethod(wx_Printout, GetLogicalPageMarginsRect)
 
 Gura_ImplementMethod(wx_Printout, GetLogicalPageMarginsRect)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPageSetupDialogData *pageSetupData = Object_wx_PageSetupDialogData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPageSetupDialogData *pageSetupData = Object_wx_PageSetupDialogData::GetObject(arg, 0)->GetEntity();
 	wxRect rtn = pThis->GetEntity()->GetLogicalPageMarginsRect(*pageSetupData);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Printout, SetLogicalOrigin)
@@ -412,12 +433,13 @@ Gura_DeclareMethod(wx_Printout, SetLogicalOrigin)
 
 Gura_ImplementMethod(wx_Printout, SetLogicalOrigin)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->SetLogicalOrigin(x, y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, OffsetLogicalOrigin)
@@ -429,12 +451,13 @@ Gura_DeclareMethod(wx_Printout, OffsetLogicalOrigin)
 
 Gura_ImplementMethod(wx_Printout, OffsetLogicalOrigin)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord xoff = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord yoff = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord xoff = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord yoff = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->OffsetLogicalOrigin(xoff, yoff);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, OnBeginDocument)
@@ -447,12 +470,13 @@ Gura_DeclareMethod(wx_Printout, OnBeginDocument)
 
 Gura_ImplementMethod(wx_Printout, OnBeginDocument)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int startPage = args.GetInt(0);
-	int endPage = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int startPage = arg.GetInt(0);
+	int endPage = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->OnBeginDocument(startPage, endPage);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Printout, OnEndDocument)
@@ -462,10 +486,11 @@ Gura_DeclareMethod(wx_Printout, OnEndDocument)
 
 Gura_ImplementMethod(wx_Printout, OnEndDocument)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnEndDocument();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, OnBeginPrinting)
@@ -475,10 +500,11 @@ Gura_DeclareMethod(wx_Printout, OnBeginPrinting)
 
 Gura_ImplementMethod(wx_Printout, OnBeginPrinting)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnBeginPrinting();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, OnEndPrinting)
@@ -488,10 +514,11 @@ Gura_DeclareMethod(wx_Printout, OnEndPrinting)
 
 Gura_ImplementMethod(wx_Printout, OnEndPrinting)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnEndPrinting();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, OnPreparePrinting)
@@ -501,10 +528,11 @@ Gura_DeclareMethod(wx_Printout, OnPreparePrinting)
 
 Gura_ImplementMethod(wx_Printout, OnPreparePrinting)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->OnPreparePrinting();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Printout, OnPrintPage)
@@ -516,11 +544,12 @@ Gura_DeclareMethod(wx_Printout, OnPrintPage)
 
 Gura_ImplementMethod(wx_Printout, OnPrintPage)
 {
-	Object_wx_Printout *pThis = Object_wx_Printout::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pageNum = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Printout *pThis = Object_wx_Printout::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pageNum = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->OnPrintPage(pageNum);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -532,13 +561,13 @@ Object_wx_Printout::~Object_wx_Printout()
 
 Object *Object_wx_Printout::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Printout::ToString(bool exprFlag)
 {
 	String rtn("<wx.Printout:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -586,7 +615,7 @@ Gura_ImplementUserInheritableClass(wx_Printout)
 
 Gura_ImplementDescendantCreator(wx_Printout)
 {
-	return new Object_wx_Printout((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Printout((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
