@@ -16,19 +16,19 @@ Gura_DeclarePrivUserSymbol(ShowItem);
 //----------------------------------------------------------------------------
 class wx_RadioBox: public wxRadioBox, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_RadioBox *_pObj;
 public:
-	inline wx_RadioBox() : wxRadioBox(), _sig(NULL), _pObj(NULL) {}
-	//inline wx_RadioBox(wxWindow* parent, wxWindowID id, const wxString& label, const wxPoint& point, const wxSize& size, int n, const wxString choices[], int majorDimension, long style, const wxValidator& validator, const wxString& name) : wxRadioBox(parent, id, label, point, size, n, choices[], majorDimension, style, validator, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_RadioBox(wxWindow* parent, wxWindowID id, const wxString& label, const wxPoint& point, const wxSize& size, const wxArrayString& choices, int majorDimension, long style, const wxValidator& validator, const wxString& name) : wxRadioBox(parent, id, label, point, size, choices, majorDimension, style, validator, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_RadioBox() : wxRadioBox(), _pObj(nullptr) {}
+	//inline wx_RadioBox(wxWindow* parent, wxWindowID id, const wxString& label, const wxPoint& point, const wxSize& size, int n, const wxString choices[], int majorDimension, long style, const wxValidator& validator, const wxString& name) : wxRadioBox(parent, id, label, point, size, n, choices[], majorDimension, style, validator, name), _pObj(nullptr) {}
+	inline wx_RadioBox(wxWindow* parent, wxWindowID id, const wxString& label, const wxPoint& point, const wxSize& size, const wxArrayString& choices, int majorDimension, long style, const wxValidator& validator, const wxString& name) : wxRadioBox(parent, id, label, point, size, choices, majorDimension, style, validator, name), _pObj(nullptr) {}
 	//virtual bool Enable(bool enable);
 	//virtual bool Enable(unsigned int n, bool enable);
 	//virtual bool Show(const bool show);
 	//virtual bool Show(unsigned int item, const bool show);
 	~wx_RadioBox();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_RadioBox *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_RadioBox *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -36,12 +36,12 @@ public:
 
 wx_RadioBox::~wx_RadioBox()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RadioBox::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -56,17 +56,18 @@ Gura_DeclareFunction(RadioBoxEmpty)
 
 Gura_ImplementFunction(RadioBoxEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_RadioBox *pEntity = new wx_RadioBox();
-	Object_wx_RadioBox *pObj = Object_wx_RadioBox::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RadioBox *pObj = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RadioBox(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RadioBox)
@@ -78,7 +79,7 @@ Gura_DeclareFunction(RadioBox)
 	DeclareArg(env, "label", VTYPE_string, OCCUR_Once);
 	DeclareArg(env, "point", VTYPE_wx_Point, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "size", VTYPE_wx_Size, OCCUR_ZeroOrOnce);
-	DeclareArg(env, "choices", VTYPE_string, OCCUR_ZeroOrOnce, FLAG_List);
+	DeclareArg(env, "choices", VTYPE_string, OCCUR_ZeroOrOnce, FLAG_ListVar);
 	DeclareArg(env, "majorDimension", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "style", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "validator", VTYPE_wx_Validator, OCCUR_ZeroOrOnce);
@@ -88,38 +89,39 @@ Gura_DeclareFunction(RadioBox)
 
 Gura_ImplementFunction(RadioBox)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString label = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString label = wxString::FromUTF8(arg.GetString(2));
 	wxPoint *point = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(3)) point = Object_wx_Point::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) point = Object_wx_Point::GetObject(arg, 3)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(4)) size = Object_wx_Size::GetObject(args, 4)->GetEntity();
-	std::auto_ptr<wxArrayString> choices;
-	if (args.IsValid(5)) {
-		choices.reset(CreateArrayString(args.GetList(5)));
+	if (arg.IsValid(4)) size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
+	std::unique_ptr<wxArrayString> choices;
+	if (arg.IsValid(5)) {
+		choices.reset(CreateArrayString(arg.GetList(5)));
 	} else {
 		choices.reset(new wxArrayString());
 	}
 	int majorDimension = 0;
-	if (args.IsValid(6)) majorDimension = args.GetInt(6);
+	if (arg.IsValid(6)) majorDimension = arg.GetInt(6);
 	long style = wxRA_SPECIFY_COLS;
-	if (args.IsValid(7)) style = args.GetLong(7);
+	if (arg.IsValid(7)) style = arg.GetLong(7);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(8)) validator = Object_wx_Validator::GetObject(args, 8)->GetEntity();
+	if (arg.IsValid(8)) validator = Object_wx_Validator::GetObject(arg, 8)->GetEntity();
 	wxString name = wxT("radioBox");
-	if (args.IsValid(9)) name = wxString::FromUTF8(args.GetString(9));
+	if (arg.IsValid(9)) name = wxString::FromUTF8(arg.GetString(9));
 	wx_RadioBox *pEntity = new wx_RadioBox(parent, id, label, *point, *size, *choices, majorDimension, style, *validator, name);
-	Object_wx_RadioBox *pObj = Object_wx_RadioBox::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RadioBox *pObj = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RadioBox(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_RadioBox, Create)
@@ -130,7 +132,7 @@ Gura_DeclareMethod(wx_RadioBox, Create)
 	DeclareArg(env, "label", VTYPE_string, OCCUR_Once);
 	DeclareArg(env, "point", VTYPE_wx_Point, OCCUR_Once);
 	DeclareArg(env, "size", VTYPE_wx_Size, OCCUR_Once);
-	DeclareArg(env, "choices", VTYPE_string, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "choices", VTYPE_string, OCCUR_Once, FLAG_ListVar);
 	DeclareArg(env, "majorDimension", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "style", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "validator", VTYPE_wx_Validator, OCCUR_ZeroOrOnce);
@@ -140,24 +142,25 @@ Gura_DeclareMethod(wx_RadioBox, Create)
 
 Gura_ImplementMethod(wx_RadioBox, Create)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
-	wxString label = wxString::FromUTF8(args.GetString(2));
-	wxPoint *point = Object_wx_Point::GetObject(args, 3)->GetEntity();
-	wxSize *size = Object_wx_Size::GetObject(args, 4)->GetEntity();
-	std::auto_ptr<wxArrayString> choices(CreateArrayString(args.GetList(5)));
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
+	wxString label = wxString::FromUTF8(arg.GetString(2));
+	wxPoint *point = Object_wx_Point::GetObject(arg, 3)->GetEntity();
+	wxSize *size = Object_wx_Size::GetObject(arg, 4)->GetEntity();
+	std::unique_ptr<wxArrayString> choices(CreateArrayString(arg.GetList(5)));
 	int majorDimension = 0;
-	if (args.IsValid(6)) majorDimension = args.GetInt(6);
+	if (arg.IsValid(6)) majorDimension = arg.GetInt(6);
 	long style = wxRA_SPECIFY_COLS;
-	if (args.IsValid(7)) style = args.GetLong(7);
+	if (arg.IsValid(7)) style = arg.GetLong(7);
 	wxValidator *validator = (wxValidator *)(&wxDefaultValidator);
-	if (args.IsValid(8)) validator = Object_wx_Validator::GetObject(args, 8)->GetEntity();
+	if (arg.IsValid(8)) validator = Object_wx_Validator::GetObject(arg, 8)->GetEntity();
 	wxString name = wxT("radioBox");
-	if (args.IsValid(9)) name = wxString::FromUTF8(args.GetString(9));
+	if (arg.IsValid(9)) name = wxString::FromUTF8(arg.GetString(9));
 	bool rtn = pThis->GetEntity()->Create(parent, id, label, *point, *size, *choices, majorDimension, style, *validator, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, Enable)
@@ -169,12 +172,13 @@ Gura_DeclareMethod(wx_RadioBox, Enable)
 
 Gura_ImplementMethod(wx_RadioBox, Enable)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Enable(enable);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, EnableItem)
@@ -187,13 +191,14 @@ Gura_DeclareMethod(wx_RadioBox, EnableItem)
 
 Gura_ImplementMethod(wx_RadioBox, EnableItem)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	bool enable = true;
-	if (args.IsValid(1)) enable = args.GetBoolean(1);
+	if (arg.IsValid(1)) enable = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->Enable(n, enable);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, FindString)
@@ -205,11 +210,12 @@ Gura_DeclareMethod(wx_RadioBox, FindString)
 
 Gura_ImplementMethod(wx_RadioBox, FindString)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString string = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString string = wxString::FromUTF8(arg.GetString(0));
 	int rtn = pThis->GetEntity()->FindString(string);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetColumnCount)
@@ -220,10 +226,11 @@ Gura_DeclareMethod(wx_RadioBox, GetColumnCount)
 
 Gura_ImplementMethod(wx_RadioBox, GetColumnCount)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	unsigned rtn = pThis->GetEntity()->GetColumnCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetItemHelpText)
@@ -235,11 +242,12 @@ Gura_DeclareMethod(wx_RadioBox, GetItemHelpText)
 
 Gura_ImplementMethod(wx_RadioBox, GetItemHelpText)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned item = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned item = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetItemHelpText(item);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetItemToolTip)
@@ -251,11 +259,12 @@ Gura_DeclareMethod(wx_RadioBox, GetItemToolTip)
 
 Gura_ImplementMethod(wx_RadioBox, GetItemToolTip)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned item = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned item = arg.GetInt(0);
 	wxToolTip *rtn = (wxToolTip *)pThis->GetEntity()->GetItemToolTip(item);
-	return ReturnValue(env, sig, args, Value(new Object_wx_ToolTip(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ToolTip(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetItemFromPoint)
@@ -267,11 +276,12 @@ Gura_DeclareMethod(wx_RadioBox, GetItemFromPoint)
 
 Gura_ImplementMethod(wx_RadioBox, GetItemFromPoint)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	int rtn = pThis->GetEntity()->GetItemFromPoint(*pt);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetLabel)
@@ -282,10 +292,11 @@ Gura_DeclareMethod(wx_RadioBox, GetLabel)
 
 Gura_ImplementMethod(wx_RadioBox, GetLabel)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetLabel();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetRowCount)
@@ -296,10 +307,11 @@ Gura_DeclareMethod(wx_RadioBox, GetRowCount)
 
 Gura_ImplementMethod(wx_RadioBox, GetRowCount)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	unsigned rtn = pThis->GetEntity()->GetRowCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetSelection)
@@ -310,10 +322,11 @@ Gura_DeclareMethod(wx_RadioBox, GetSelection)
 
 Gura_ImplementMethod(wx_RadioBox, GetSelection)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetStringSelection)
@@ -324,10 +337,11 @@ Gura_DeclareMethod(wx_RadioBox, GetStringSelection)
 
 Gura_ImplementMethod(wx_RadioBox, GetStringSelection)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetStringSelection();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RadioBox, GetString)
@@ -339,11 +353,12 @@ Gura_DeclareMethod(wx_RadioBox, GetString)
 
 Gura_ImplementMethod(wx_RadioBox, GetString)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	wxString rtn = pThis->GetEntity()->GetString(n);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RadioBox, IsItemEnabled)
@@ -355,11 +370,12 @@ Gura_DeclareMethod(wx_RadioBox, IsItemEnabled)
 
 Gura_ImplementMethod(wx_RadioBox, IsItemEnabled)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsItemEnabled(n);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, IsItemShown)
@@ -371,11 +387,12 @@ Gura_DeclareMethod(wx_RadioBox, IsItemShown)
 
 Gura_ImplementMethod(wx_RadioBox, IsItemShown)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned n = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->IsItemShown(n);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, SetItemHelpText)
@@ -387,12 +404,13 @@ Gura_DeclareMethod(wx_RadioBox, SetItemHelpText)
 
 Gura_ImplementMethod(wx_RadioBox, SetItemHelpText)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned item = args.GetInt(0);
-	wxString helptext = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned item = arg.GetInt(0);
+	wxString helptext = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetItemHelpText(item, helptext);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RadioBox, SetLabel)
@@ -403,11 +421,12 @@ Gura_DeclareMethod(wx_RadioBox, SetLabel)
 
 Gura_ImplementMethod(wx_RadioBox, SetLabel)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString label = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString label = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetLabel(label);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RadioBox, SetSelection)
@@ -418,11 +437,12 @@ Gura_DeclareMethod(wx_RadioBox, SetSelection)
 
 Gura_ImplementMethod(wx_RadioBox, SetSelection)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->SetSelection(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RadioBox, SetStringSelection)
@@ -433,11 +453,12 @@ Gura_DeclareMethod(wx_RadioBox, SetStringSelection)
 
 Gura_ImplementMethod(wx_RadioBox, SetStringSelection)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString string = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString string = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetStringSelection(string);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RadioBox, SetItemToolTip)
@@ -449,12 +470,13 @@ Gura_DeclareMethod(wx_RadioBox, SetItemToolTip)
 
 Gura_ImplementMethod(wx_RadioBox, SetItemToolTip)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned item = args.GetInt(0);
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned item = arg.GetInt(0);
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	pThis->GetEntity()->SetItemToolTip(item, text);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RadioBox, Show)
@@ -466,12 +488,13 @@ Gura_DeclareMethod(wx_RadioBox, Show)
 
 Gura_ImplementMethod(wx_RadioBox, Show)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool show = true;
-	if (args.IsValid(0)) show = args.GetBoolean(0);
+	if (arg.IsValid(0)) show = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Show(show);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RadioBox, ShowItem)
@@ -484,13 +507,14 @@ Gura_DeclareMethod(wx_RadioBox, ShowItem)
 
 Gura_ImplementMethod(wx_RadioBox, ShowItem)
 {
-	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned item = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RadioBox *pThis = Object_wx_RadioBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned item = arg.GetInt(0);
 	bool show = true;
-	if (args.IsValid(1)) show = args.GetBoolean(1);
+	if (arg.IsValid(1)) show = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->Show(item, show);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -502,13 +526,13 @@ Object_wx_RadioBox::~Object_wx_RadioBox()
 
 Object *Object_wx_RadioBox::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_RadioBox::ToString(bool exprFlag)
 {
 	String rtn("<wx.RadioBox:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -556,7 +580,7 @@ Gura_ImplementUserInheritableClass(wx_RadioBox)
 
 Gura_ImplementDescendantCreator(wx_RadioBox)
 {
-	return new Object_wx_RadioBox((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RadioBox((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
