@@ -11,17 +11,17 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Rect: public wxRect, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Rect *_pObj;
 public:
-	inline wx_Rect() : wxRect(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Rect(int x, int y, int width, int height) : wxRect(x, y, width, height), _sig(NULL), _pObj(NULL) {}
-	inline wx_Rect(const wxPoint& topLeft, const wxPoint& bottomRight) : wxRect(topLeft, bottomRight), _sig(NULL), _pObj(NULL) {}
-	inline wx_Rect(const wxPoint& pos, const wxSize& size) : wxRect(pos, size), _sig(NULL), _pObj(NULL) {}
-	inline wx_Rect(const wxSize& size) : wxRect(size), _sig(NULL), _pObj(NULL) {}
+	inline wx_Rect() : wxRect(), _pObj(nullptr) {}
+	inline wx_Rect(int x, int y, int width, int height) : wxRect(x, y, width, height), _pObj(nullptr) {}
+	inline wx_Rect(const wxPoint& topLeft, const wxPoint& bottomRight) : wxRect(topLeft, bottomRight), _pObj(nullptr) {}
+	inline wx_Rect(const wxPoint& pos, const wxSize& size) : wxRect(pos, size), _pObj(nullptr) {}
+	inline wx_Rect(const wxSize& size) : wxRect(size), _pObj(nullptr) {}
 	~wx_Rect();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Rect *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Rect *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -29,12 +29,12 @@ public:
 
 wx_Rect::~wx_Rect()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Rect::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,17 +49,18 @@ Gura_DeclareFunction(RectEmpty)
 
 Gura_ImplementFunction(RectEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Rect *pEntity = new wx_Rect();
-	Object_wx_Rect *pObj = Object_wx_Rect::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Rect *pObj = Object_wx_Rect::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Rect(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Rect)
@@ -75,21 +76,22 @@ Gura_DeclareFunction(Rect)
 
 Gura_ImplementFunction(Rect)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
-	int width = args.GetInt(2);
-	int height = args.GetInt(3);
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
+	int y = arg.GetInt(1);
+	int width = arg.GetInt(2);
+	int height = arg.GetInt(3);
 	wx_Rect *pEntity = new wx_Rect(x, y, width, height);
-	Object_wx_Rect *pObj = Object_wx_Rect::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Rect *pObj = Object_wx_Rect::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Rect(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Rect_1)
@@ -103,19 +105,20 @@ Gura_DeclareFunction(Rect_1)
 
 Gura_ImplementFunction(Rect_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPoint *topLeft = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxPoint *bottomRight = Object_wx_Point::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPoint *topLeft = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxPoint *bottomRight = Object_wx_Point::GetObject(arg, 1)->GetEntity();
 	wx_Rect *pEntity = new wx_Rect(*topLeft, *bottomRight);
-	Object_wx_Rect *pObj = Object_wx_Rect::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Rect *pObj = Object_wx_Rect::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Rect(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Rect_2)
@@ -129,19 +132,20 @@ Gura_DeclareFunction(Rect_2)
 
 Gura_ImplementFunction(Rect_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPoint *pos = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxSize *size = Object_wx_Size::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxSize *size = Object_wx_Size::GetObject(arg, 1)->GetEntity();
 	wx_Rect *pEntity = new wx_Rect(*pos, *size);
-	Object_wx_Rect *pObj = Object_wx_Rect::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Rect *pObj = Object_wx_Rect::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Rect(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Rect_3)
@@ -154,18 +158,19 @@ Gura_DeclareFunction(Rect_3)
 
 Gura_ImplementFunction(Rect_3)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	wx_Rect *pEntity = new wx_Rect(*size);
-	Object_wx_Rect *pObj = Object_wx_Rect::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Rect *pObj = Object_wx_Rect::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Rect(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Rect, CentreIn)
@@ -178,13 +183,14 @@ Gura_DeclareMethod(wx_Rect, CentreIn)
 
 Gura_ImplementMethod(wx_Rect, CentreIn)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *r = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *r = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	int dir = wxBOTH;
-	if (args.IsValid(1)) dir = args.GetInt(1);
+	if (arg.IsValid(1)) dir = arg.GetInt(1);
 	wxRect rtn = pThis->GetEntity()->CentreIn(*r, dir);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, CenterIn)
@@ -197,13 +203,14 @@ Gura_DeclareMethod(wx_Rect, CenterIn)
 
 Gura_ImplementMethod(wx_Rect, CenterIn)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *r = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *r = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	int dir = wxBOTH;
-	if (args.IsValid(1)) dir = args.GetInt(1);
+	if (arg.IsValid(1)) dir = arg.GetInt(1);
 	wxRect rtn = pThis->GetEntity()->CenterIn(*r, dir);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, ContainsXY)
@@ -216,12 +223,13 @@ Gura_DeclareMethod(wx_Rect, ContainsXY)
 
 Gura_ImplementMethod(wx_Rect, ContainsXY)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
+	int y = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->Contains(x, y);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, Contains)
@@ -233,11 +241,12 @@ Gura_DeclareMethod(wx_Rect, Contains)
 
 Gura_ImplementMethod(wx_Rect, Contains)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Contains(*pt);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, ContainsRect)
@@ -249,11 +258,12 @@ Gura_DeclareMethod(wx_Rect, ContainsRect)
 
 Gura_ImplementMethod(wx_Rect, ContainsRect)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Contains(*rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, Deflate)
@@ -265,12 +275,13 @@ Gura_DeclareMethod(wx_Rect, Deflate)
 
 Gura_ImplementMethod(wx_Rect, Deflate)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord dx = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord dy = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord dx = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord dy = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->Deflate(dx, dy);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Deflate_1)
@@ -281,11 +292,12 @@ Gura_DeclareMethod(wx_Rect, Deflate_1)
 
 Gura_ImplementMethod(wx_Rect, Deflate_1)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *diff = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *diff = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Deflate(*diff);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Deflate_2)
@@ -296,11 +308,12 @@ Gura_DeclareMethod(wx_Rect, Deflate_2)
 
 Gura_ImplementMethod(wx_Rect, Deflate_2)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord diff = static_cast<wxCoord>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord diff = static_cast<wxCoord>(arg.GetInt(0));
 	pThis->GetEntity()->Deflate(diff);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Deflate_3)
@@ -313,12 +326,13 @@ Gura_DeclareMethod(wx_Rect, Deflate_3)
 
 Gura_ImplementMethod(wx_Rect, Deflate_3)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord dx = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord dy = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord dx = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord dy = static_cast<wxCoord>(arg.GetInt(1));
 	wxRect rtn = pThis->GetEntity()->Deflate(dx, dy);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetBottom)
@@ -329,10 +343,11 @@ Gura_DeclareMethod(wx_Rect, GetBottom)
 
 Gura_ImplementMethod(wx_Rect, GetBottom)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetBottom();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetHeight)
@@ -343,10 +358,11 @@ Gura_DeclareMethod(wx_Rect, GetHeight)
 
 Gura_ImplementMethod(wx_Rect, GetHeight)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetHeight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetLeft)
@@ -357,10 +373,11 @@ Gura_DeclareMethod(wx_Rect, GetLeft)
 
 Gura_ImplementMethod(wx_Rect, GetLeft)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLeft();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetPosition)
@@ -371,10 +388,11 @@ Gura_DeclareMethod(wx_Rect, GetPosition)
 
 Gura_ImplementMethod(wx_Rect, GetPosition)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetPosition();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetTopLeft)
@@ -385,10 +403,11 @@ Gura_DeclareMethod(wx_Rect, GetTopLeft)
 
 Gura_ImplementMethod(wx_Rect, GetTopLeft)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetTopLeft();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetTopRight)
@@ -399,10 +418,11 @@ Gura_DeclareMethod(wx_Rect, GetTopRight)
 
 Gura_ImplementMethod(wx_Rect, GetTopRight)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetTopRight();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetBottomLeft)
@@ -413,10 +433,11 @@ Gura_DeclareMethod(wx_Rect, GetBottomLeft)
 
 Gura_ImplementMethod(wx_Rect, GetBottomLeft)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetBottomLeft();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetBottomRight)
@@ -427,10 +448,11 @@ Gura_DeclareMethod(wx_Rect, GetBottomRight)
 
 Gura_ImplementMethod(wx_Rect, GetBottomRight)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetBottomRight();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetRight)
@@ -441,10 +463,11 @@ Gura_DeclareMethod(wx_Rect, GetRight)
 
 Gura_ImplementMethod(wx_Rect, GetRight)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetRight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetSize)
@@ -455,10 +478,11 @@ Gura_DeclareMethod(wx_Rect, GetSize)
 
 Gura_ImplementMethod(wx_Rect, GetSize)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, GetTop)
@@ -469,10 +493,11 @@ Gura_DeclareMethod(wx_Rect, GetTop)
 
 Gura_ImplementMethod(wx_Rect, GetTop)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetTop();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetWidth)
@@ -483,10 +508,11 @@ Gura_DeclareMethod(wx_Rect, GetWidth)
 
 Gura_ImplementMethod(wx_Rect, GetWidth)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWidth();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetX)
@@ -497,10 +523,11 @@ Gura_DeclareMethod(wx_Rect, GetX)
 
 Gura_ImplementMethod(wx_Rect, GetX)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetX();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, GetY)
@@ -511,10 +538,11 @@ Gura_DeclareMethod(wx_Rect, GetY)
 
 Gura_ImplementMethod(wx_Rect, GetY)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetY();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, Inflate)
@@ -526,12 +554,13 @@ Gura_DeclareMethod(wx_Rect, Inflate)
 
 Gura_ImplementMethod(wx_Rect, Inflate)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord dx = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord dy = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord dx = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord dy = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->Inflate(dx, dy);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Inflate_1)
@@ -542,11 +571,12 @@ Gura_DeclareMethod(wx_Rect, Inflate_1)
 
 Gura_ImplementMethod(wx_Rect, Inflate_1)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *diff = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *diff = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Inflate(*diff);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Inflate_2)
@@ -557,11 +587,12 @@ Gura_DeclareMethod(wx_Rect, Inflate_2)
 
 Gura_ImplementMethod(wx_Rect, Inflate_2)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord diff = static_cast<wxCoord>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord diff = static_cast<wxCoord>(arg.GetInt(0));
 	pThis->GetEntity()->Inflate(diff);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Inflate_3)
@@ -574,12 +605,13 @@ Gura_DeclareMethod(wx_Rect, Inflate_3)
 
 Gura_ImplementMethod(wx_Rect, Inflate_3)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord dx = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord dy = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord dx = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord dy = static_cast<wxCoord>(arg.GetInt(1));
 	wxRect rtn = pThis->GetEntity()->Inflate(dx, dy);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, Intersect)
@@ -591,11 +623,12 @@ Gura_DeclareMethod(wx_Rect, Intersect)
 
 Gura_ImplementMethod(wx_Rect, Intersect)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wxRect rtn = pThis->GetEntity()->Intersect(*rect);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, Intersect_1)
@@ -607,11 +640,12 @@ Gura_DeclareMethod(wx_Rect, Intersect_1)
 
 Gura_ImplementMethod(wx_Rect, Intersect_1)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wxRect &rtn = pThis->GetEntity()->Intersect(*rect);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, Intersects)
@@ -623,11 +657,12 @@ Gura_DeclareMethod(wx_Rect, Intersects)
 
 Gura_ImplementMethod(wx_Rect, Intersects)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Intersects(*rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, IsEmpty)
@@ -638,10 +673,11 @@ Gura_DeclareMethod(wx_Rect, IsEmpty)
 
 Gura_ImplementMethod(wx_Rect, IsEmpty)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsEmpty();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Rect, Offset)
@@ -653,12 +689,13 @@ Gura_DeclareMethod(wx_Rect, Offset)
 
 Gura_ImplementMethod(wx_Rect, Offset)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord dx = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord dy = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord dx = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord dy = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->Offset(dx, dy);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Offset_1)
@@ -669,11 +706,12 @@ Gura_DeclareMethod(wx_Rect, Offset_1)
 
 Gura_ImplementMethod(wx_Rect, Offset_1)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Offset(*pt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, SetHeight)
@@ -684,11 +722,12 @@ Gura_DeclareMethod(wx_Rect, SetHeight)
 
 Gura_ImplementMethod(wx_Rect, SetHeight)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int height = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int height = arg.GetInt(0);
 	pThis->GetEntity()->SetHeight(height);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, SetSize)
@@ -699,11 +738,12 @@ Gura_DeclareMethod(wx_Rect, SetSize)
 
 Gura_ImplementMethod(wx_Rect, SetSize)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *s = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *s = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetSize(*s);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, SetWidth)
@@ -714,11 +754,12 @@ Gura_DeclareMethod(wx_Rect, SetWidth)
 
 Gura_ImplementMethod(wx_Rect, SetWidth)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
 	pThis->GetEntity()->SetWidth(width);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, SetX)
@@ -729,11 +770,12 @@ Gura_DeclareMethod(wx_Rect, SetX)
 
 Gura_ImplementMethod(wx_Rect, SetX)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
 	pThis->GetEntity()->SetX(x);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, SetY)
@@ -744,11 +786,12 @@ Gura_DeclareMethod(wx_Rect, SetY)
 
 Gura_ImplementMethod(wx_Rect, SetY)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int y = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int y = arg.GetInt(0);
 	pThis->GetEntity()->SetY(y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Rect, Union)
@@ -760,11 +803,12 @@ Gura_DeclareMethod(wx_Rect, Union)
 
 Gura_ImplementMethod(wx_Rect, Union)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wxRect rtn = pThis->GetEntity()->Union(*rect);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Rect, Union_1)
@@ -776,11 +820,12 @@ Gura_DeclareMethod(wx_Rect, Union_1)
 
 Gura_ImplementMethod(wx_Rect, Union_1)
 {
-	Object_wx_Rect *pThis = Object_wx_Rect::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Rect *pThis = Object_wx_Rect::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wxRect &rtn = pThis->GetEntity()->Union(*rect);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 // operator ==
@@ -799,75 +844,120 @@ Gura_ImplementBinaryOperator(Ne, wx_Rect, wx_Rect)
 	return *item1 != *item2;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// wx.Rect#height
+Gura_DeclareProperty_RW(wx_Rect, height)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(wx_Rect, height)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	return Value(pObjThis->GetEntity()->height);
+}
+
+Gura_ImplementPropertySetter(wx_Rect, height)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	pObjThis->GetEntity()->height = value.GetInt();
+	return value;
+}
+
+// wx.Rect#width
+Gura_DeclareProperty_RW(wx_Rect, width)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(wx_Rect, width)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	return Value(pObjThis->GetEntity()->width);
+}
+
+Gura_ImplementPropertySetter(wx_Rect, width)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	pObjThis->GetEntity()->width = value.GetInt();
+	return value;
+}
+
+// wx.Rect#x
+Gura_DeclareProperty_RW(wx_Rect, x)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(wx_Rect, x)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	return Value(pObjThis->GetEntity()->x);
+}
+
+Gura_ImplementPropertySetter(wx_Rect, x)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	pObjThis->GetEntity()->x = value.GetInt();
+	return value;
+}
+
+// wx.Rect#y
+Gura_DeclareProperty_RW(wx_Rect, y)
+{
+	SetPropAttr(VTYPE_number);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(wx_Rect, y)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	return Value(pObjThis->GetEntity()->y);
+}
+
+Gura_ImplementPropertySetter(wx_Rect, y)
+{
+	Object_wx_Rect *pObjThis = Object_wx_Rect::GetObject(valueThis);
+	pObjThis->GetEntity()->y = value.GetInt();
+	return value;
+}
+
 //----------------------------------------------------------------------------
 // Object implementation for wxRect
 //----------------------------------------------------------------------------
 Object_wx_Rect::~Object_wx_Rect()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_Rect::Clone() const
 {
-	return new Object_wx_Rect(new wxRect(*dynamic_cast<wxRect *>(_pEntity)), NULL, OwnerTrue);
-}
-
-bool Object_wx_Rect::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_Symbol(x));
-	symbols.insert(Gura_Symbol(y));
-	symbols.insert(Gura_Symbol(width));
-	symbols.insert(Gura_Symbol(height));
-	return true;
-}
-
-Value Object_wx_Rect::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-						const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_Symbol(x))) {
-		return Value(GetEntity()->x);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(y))) {
-		return Value(GetEntity()->y);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(width))) {
-		return Value(GetEntity()->width);
-	} else if (pSymbol->IsIdentical(Gura_Symbol(height))) {
-		return Value(GetEntity()->height);
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_wx_Rect::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-						const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	if (pSymbol->IsIdentical(Gura_Symbol(x))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		GetEntity()->x = value.GetInt();
-		return value;
-	} else if (pSymbol->IsIdentical(Gura_Symbol(y))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		GetEntity()->y = value.GetInt();
-		return value;
-	} else if (pSymbol->IsIdentical(Gura_Symbol(width))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		GetEntity()->width = value.GetInt();
-		return value;
-	} else if (pSymbol->IsIdentical(Gura_Symbol(height))) {
-		if (!value.MustBe_number(sig)) return Value::Null;
-		GetEntity()->height = value.GetInt();
-		return value;
-	}
-	return Value::Null;
+	return new Object_wx_Rect(new wxRect(*dynamic_cast<wxRect *>(_pEntity)), nullptr, OwnerTrue);
 }
 
 String Object_wx_Rect::ToString(bool exprFlag)
 {
 	String rtn("<wx.Rect:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -882,13 +972,21 @@ String Object_wx_Rect::ToString(bool exprFlag)
 //----------------------------------------------------------------------------
 Gura_ImplementUserInheritableClass(wx_Rect)
 {
+	// Assignment of properties
+	Gura_AssignProperty(wx_Rect, height);
+	Gura_AssignProperty(wx_Rect, width);
+	Gura_AssignProperty(wx_Rect, x);
+	Gura_AssignProperty(wx_Rect, y);
+	// Assignment of functions
 	Gura_AssignFunction(RectEmpty);
 	Gura_AssignFunction(Rect);
 	Gura_AssignFunction(Rect_1);
 	Gura_AssignFunction(Rect_2);
 	Gura_AssignFunction(Rect_3);
+	// Assignment of operators
 	Gura_AssignBinaryOperator(Eq, wx_Rect, wx_Rect);
 	Gura_AssignBinaryOperator(Ne, wx_Rect, wx_Rect);
+	// Assignment of methods
 	Gura_AssignMethod(wx_Rect, CentreIn);
 	Gura_AssignMethod(wx_Rect, CenterIn);
 	Gura_AssignMethod(wx_Rect, ContainsXY);
@@ -933,7 +1031,7 @@ Gura_ImplementUserInheritableClass(wx_Rect)
 
 Gura_ImplementDescendantCreator(wx_Rect)
 {
-	return new Object_wx_Rect((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Rect((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
