@@ -11,15 +11,15 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_RegKey: public wxRegKey, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_RegKey *_pObj;
 public:
-	inline wx_RegKey() : wxRegKey(), _sig(NULL), _pObj(NULL) {}
-	inline wx_RegKey(const wxString& strKey) : wxRegKey(strKey), _sig(NULL), _pObj(NULL) {}
-	inline wx_RegKey(const wxRegKey& keyParent, const wxString& strKey) : wxRegKey(keyParent, strKey), _sig(NULL), _pObj(NULL) {}
+	inline wx_RegKey() : wxRegKey(), _pObj(nullptr) {}
+	inline wx_RegKey(const wxString& strKey) : wxRegKey(strKey), _pObj(nullptr) {}
+	inline wx_RegKey(const wxRegKey& keyParent, const wxString& strKey) : wxRegKey(keyParent, strKey), _pObj(nullptr) {}
 	~wx_RegKey();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_RegKey *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_RegKey *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -27,12 +27,12 @@ public:
 
 wx_RegKey::~wx_RegKey()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RegKey::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,17 +47,18 @@ Gura_DeclareFunction(RegKeyEmpty)
 
 Gura_ImplementFunction(RegKeyEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_RegKey *pEntity = new wx_RegKey();
-	Object_wx_RegKey *pObj = Object_wx_RegKey::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RegKey *pObj = Object_wx_RegKey::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RegKey(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RegKey)
@@ -70,18 +71,19 @@ Gura_DeclareFunction(RegKey)
 
 Gura_ImplementFunction(RegKey)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString strKey = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString strKey = wxString::FromUTF8(arg.GetString(0));
 	wx_RegKey *pEntity = new wx_RegKey(strKey);
-	Object_wx_RegKey *pObj = Object_wx_RegKey::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RegKey *pObj = Object_wx_RegKey::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RegKey(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RegKey_1)
@@ -95,19 +97,20 @@ Gura_DeclareFunction(RegKey_1)
 
 Gura_ImplementFunction(RegKey_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxRegKey *keyParent = Object_wx_RegKey::GetObject(args, 0)->GetEntity();
-	wxString strKey = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxRegKey *keyParent = Object_wx_RegKey::GetObject(arg, 0)->GetEntity();
+	wxString strKey = wxString::FromUTF8(arg.GetString(1));
 	wx_RegKey *pEntity = new wx_RegKey(*keyParent, strKey);
-	Object_wx_RegKey *pObj = Object_wx_RegKey::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RegKey *pObj = Object_wx_RegKey::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RegKey(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_RegKey, Close)
@@ -117,10 +120,11 @@ Gura_DeclareMethod(wx_RegKey, Close)
 
 Gura_ImplementMethod(wx_RegKey, Close)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Close();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, Create)
@@ -132,12 +136,13 @@ Gura_DeclareMethod(wx_RegKey, Create)
 
 Gura_ImplementMethod(wx_RegKey, Create)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bOkIfExists = true;
-	if (args.IsValid(0)) bOkIfExists = args.GetBoolean(0);
+	if (arg.IsValid(0)) bOkIfExists = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Create(bOkIfExists);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, DeleteSelf)
@@ -147,10 +152,11 @@ Gura_DeclareMethod(wx_RegKey, DeleteSelf)
 
 Gura_ImplementMethod(wx_RegKey, DeleteSelf)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DeleteSelf();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, DeleteKey)
@@ -161,11 +167,12 @@ Gura_DeclareMethod(wx_RegKey, DeleteKey)
 
 Gura_ImplementMethod(wx_RegKey, DeleteKey)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szKey = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szKey = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->DeleteKey(szKey);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, DeleteValue)
@@ -176,11 +183,12 @@ Gura_DeclareMethod(wx_RegKey, DeleteValue)
 
 Gura_ImplementMethod(wx_RegKey, DeleteValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szKey = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szKey = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->DeleteValue(szKey);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_RegKey, Exists)
@@ -191,13 +199,14 @@ Gura_DeclareClassMethod(wx_RegKey, Exists)
 
 Gura_ImplementClassMethod(wx_RegKey, Exists)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	bool rtn = wxRegKey::Exists();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, GetName)
@@ -209,12 +218,13 @@ Gura_DeclareMethod(wx_RegKey, GetName)
 
 Gura_ImplementMethod(wx_RegKey, GetName)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool bShortPrefix = true;
-	if (args.IsValid(0)) bShortPrefix = args.GetBoolean(0);
+	if (arg.IsValid(0)) bShortPrefix = arg.GetBoolean(0);
 	wxString rtn = pThis->GetEntity()->GetName(bShortPrefix);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RegKey, GetFirstKey)
@@ -227,12 +237,13 @@ Gura_DeclareMethod(wx_RegKey, GetFirstKey)
 
 Gura_ImplementMethod(wx_RegKey, GetFirstKey)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strKeyName = wxString::FromUTF8(args.GetString(0));
-	long lIndex = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strKeyName = wxString::FromUTF8(arg.GetString(0));
+	long lIndex = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetFirstKey(strKeyName, lIndex);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, GetFirstValue)
@@ -245,12 +256,13 @@ Gura_DeclareMethod(wx_RegKey, GetFirstValue)
 
 Gura_ImplementMethod(wx_RegKey, GetFirstValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strValueName = wxString::FromUTF8(args.GetString(0));
-	long lIndex = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strValueName = wxString::FromUTF8(arg.GetString(0));
+	long lIndex = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetFirstValue(strValueName, lIndex);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, Exists_1)
@@ -266,17 +278,18 @@ Gura_DeclareMethod(wx_RegKey, Exists_1)
 
 Gura_ImplementMethod(wx_RegKey, Exists_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pnSubKeys = args.GetSizeT(0);
-	size_t pnValues = args.GetSizeT(1);
-	size_t pnMaxValueLen = args.GetSizeT(2);
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pnSubKeys = arg.GetSizeT(0);
+	size_t pnValues = arg.GetSizeT(1);
+	size_t pnMaxValueLen = arg.GetSizeT(2);
 	bool rtn = pThis->GetEntity()->Exists(pnSubKeys, pnValues, pnMaxValueLen);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, GetNextKey)
@@ -289,12 +302,13 @@ Gura_DeclareMethod(wx_RegKey, GetNextKey)
 
 Gura_ImplementMethod(wx_RegKey, GetNextKey)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strKeyName = wxString::FromUTF8(args.GetString(0));
-	long lIndex = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strKeyName = wxString::FromUTF8(arg.GetString(0));
+	long lIndex = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetNextKey(strKeyName, lIndex);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, GetNextValue)
@@ -307,12 +321,13 @@ Gura_DeclareMethod(wx_RegKey, GetNextValue)
 
 Gura_ImplementMethod(wx_RegKey, GetNextValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strValueName = wxString::FromUTF8(args.GetString(0));
-	long lIndex = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strValueName = wxString::FromUTF8(arg.GetString(0));
+	long lIndex = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->GetNextValue(strValueName, lIndex);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, HasValue)
@@ -324,11 +339,12 @@ Gura_DeclareMethod(wx_RegKey, HasValue)
 
 Gura_ImplementMethod(wx_RegKey, HasValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValue = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValue = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->HasValue(szValue);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, HasValues)
@@ -339,10 +355,11 @@ Gura_DeclareMethod(wx_RegKey, HasValues)
 
 Gura_ImplementMethod(wx_RegKey, HasValues)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasValues();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, HasSubKey)
@@ -354,11 +371,12 @@ Gura_DeclareMethod(wx_RegKey, HasSubKey)
 
 Gura_ImplementMethod(wx_RegKey, HasSubKey)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szKey = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szKey = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->HasSubKey(szKey);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, HasSubKeys)
@@ -369,14 +387,15 @@ Gura_DeclareMethod(wx_RegKey, HasSubKeys)
 
 Gura_ImplementMethod(wx_RegKey, HasSubKeys)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasSubKeys();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, IsEmpty)
@@ -387,10 +406,11 @@ Gura_DeclareMethod(wx_RegKey, IsEmpty)
 
 Gura_ImplementMethod(wx_RegKey, IsEmpty)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsEmpty();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, IsOpened)
@@ -401,10 +421,11 @@ Gura_DeclareMethod(wx_RegKey, IsOpened)
 
 Gura_ImplementMethod(wx_RegKey, IsOpened)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOpened();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, Open)
@@ -418,16 +439,17 @@ Gura_DeclareMethod(wx_RegKey, Open)
 
 Gura_ImplementMethod(wx_RegKey, Open)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRegKey::AccessMode mode = Write;
-	if (args.IsValid(0)) mode = static_cast<wxRegKey::AccessMode>(args.GetInt(0));
+	if (arg.IsValid(0)) mode = static_cast<wxRegKey::AccessMode>(arg.GetInt(0));
 	bool rtn = pThis->GetEntity()->Open(mode);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, QueryValue)
@@ -440,12 +462,13 @@ Gura_DeclareMethod(wx_RegKey, QueryValue)
 
 Gura_ImplementMethod(wx_RegKey, QueryValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValue = wxString::FromUTF8(args.GetString(0));
-	wxString strValue = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValue = wxString::FromUTF8(arg.GetString(0));
+	wxString strValue = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->QueryValue(szValue, strValue);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, QueryValue_1)
@@ -460,16 +483,17 @@ Gura_DeclareMethod(wx_RegKey, QueryValue_1)
 
 Gura_ImplementMethod(wx_RegKey, QueryValue_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValue = wxString::FromUTF8(args.GetString(0));
-	long plValue = args.GetLong(1);
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValue = wxString::FromUTF8(arg.GetString(0));
+	long plValue = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->QueryValue(szValue, plValue);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RegKey, Rename)
@@ -481,11 +505,12 @@ Gura_DeclareMethod(wx_RegKey, Rename)
 
 Gura_ImplementMethod(wx_RegKey, Rename)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szNewName = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szNewName = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Rename(szNewName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, RenameValue)
@@ -498,12 +523,13 @@ Gura_DeclareMethod(wx_RegKey, RenameValue)
 
 Gura_ImplementMethod(wx_RegKey, RenameValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValueOld = wxString::FromUTF8(args.GetString(0));
-	wxString szValueNew = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValueOld = wxString::FromUTF8(arg.GetString(0));
+	wxString szValueNew = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->RenameValue(szValueOld, szValueNew);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, SetValue)
@@ -516,12 +542,13 @@ Gura_DeclareMethod(wx_RegKey, SetValue)
 
 Gura_ImplementMethod(wx_RegKey, SetValue)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValue = wxString::FromUTF8(args.GetString(0));
-	long lValue = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValue = wxString::FromUTF8(arg.GetString(0));
+	long lValue = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->SetValue(szValue, lValue);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, SetValue_1)
@@ -534,12 +561,13 @@ Gura_DeclareMethod(wx_RegKey, SetValue_1)
 
 Gura_ImplementMethod(wx_RegKey, SetValue_1)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValue = wxString::FromUTF8(args.GetString(0));
-	wxString strValue = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValue = wxString::FromUTF8(arg.GetString(0));
+	wxString strValue = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->SetValue(szValue, strValue);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RegKey, SetValue_2)
@@ -552,12 +580,13 @@ Gura_DeclareMethod(wx_RegKey, SetValue_2)
 
 Gura_ImplementMethod(wx_RegKey, SetValue_2)
 {
-	Object_wx_RegKey *pThis = Object_wx_RegKey::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString szValue = wxString::FromUTF8(args.GetString(0));
-	wxMemoryBuffer *buf = Object_wx_MemoryBuffer::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RegKey *pThis = Object_wx_RegKey::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString szValue = wxString::FromUTF8(arg.GetString(0));
+	wxMemoryBuffer *buf = Object_wx_MemoryBuffer::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->SetValue(szValue, *buf);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -565,20 +594,20 @@ Gura_ImplementMethod(wx_RegKey, SetValue_2)
 //----------------------------------------------------------------------------
 Object_wx_RegKey::~Object_wx_RegKey()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_RegKey::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_RegKey::ToString(bool exprFlag)
 {
 	String rtn("<wx.RegKey:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -626,7 +655,7 @@ Gura_ImplementUserInheritableClass(wx_RegKey)
 
 Gura_ImplementDescendantCreator(wx_RegKey)
 {
-	return new Object_wx_RegKey((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RegKey((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
