@@ -11,20 +11,20 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Region: public wxRegion, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Region *_pObj;
 public:
-	inline wx_Region() : wxRegion(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(wxCoord x, wxCoord y, wxCoord width, wxCoord height) : wxRegion(x, y, width, height), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(const wxPoint& topLeft, const wxPoint& bottomRight) : wxRegion(topLeft, bottomRight), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(const wxRect& rect) : wxRegion(rect), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(const wxRegion& region) : wxRegion(region), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(size_t n, const wxPoint *points, wxPolygonFillMode fillStyle) : wxRegion(n, points, fillStyle), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(const wxBitmap& bmp) : wxRegion(bmp), _sig(NULL), _pObj(NULL) {}
-	inline wx_Region(const wxBitmap& bmp, const wxColour& transColour, int tolerance) : wxRegion(bmp, transColour, tolerance), _sig(NULL), _pObj(NULL) {}
+	inline wx_Region() : wxRegion(), _pObj(nullptr) {}
+	inline wx_Region(wxCoord x, wxCoord y, wxCoord width, wxCoord height) : wxRegion(x, y, width, height), _pObj(nullptr) {}
+	inline wx_Region(const wxPoint& topLeft, const wxPoint& bottomRight) : wxRegion(topLeft, bottomRight), _pObj(nullptr) {}
+	inline wx_Region(const wxRect& rect) : wxRegion(rect), _pObj(nullptr) {}
+	inline wx_Region(const wxRegion& region) : wxRegion(region), _pObj(nullptr) {}
+	inline wx_Region(size_t n, const wxPoint *points, wxPolygonFillMode fillStyle) : wxRegion(n, points, fillStyle), _pObj(nullptr) {}
+	inline wx_Region(const wxBitmap& bmp) : wxRegion(bmp), _pObj(nullptr) {}
+	inline wx_Region(const wxBitmap& bmp, const wxColour& transColour, int tolerance) : wxRegion(bmp, transColour, tolerance), _pObj(nullptr) {}
 	~wx_Region();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Region *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Region *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -32,12 +32,12 @@ public:
 
 wx_Region::~wx_Region()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Region::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -52,17 +52,18 @@ Gura_DeclareFunction(RegionEmpty)
 
 Gura_ImplementFunction(RegionEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Region *pEntity = new wx_Region();
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Region)
@@ -78,21 +79,22 @@ Gura_DeclareFunction(Region)
 
 Gura_ImplementFunction(Region)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
-	wxCoord width = static_cast<wxCoord>(args.GetInt(2));
-	wxCoord height = static_cast<wxCoord>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
+	wxCoord width = static_cast<wxCoord>(arg.GetInt(2));
+	wxCoord height = static_cast<wxCoord>(arg.GetInt(3));
 	wx_Region *pEntity = new wx_Region(x, y, width, height);
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Region_1)
@@ -106,19 +108,20 @@ Gura_DeclareFunction(Region_1)
 
 Gura_ImplementFunction(Region_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxPoint *topLeft = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxPoint *bottomRight = Object_wx_Point::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxPoint *topLeft = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxPoint *bottomRight = Object_wx_Point::GetObject(arg, 1)->GetEntity();
 	wx_Region *pEntity = new wx_Region(*topLeft, *bottomRight);
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RegionRect)
@@ -131,51 +134,53 @@ Gura_DeclareFunction(RegionRect)
 
 Gura_ImplementFunction(RegionRect)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wx_Region *pEntity = new wx_Region(*rect);
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RegionPoints)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	SetClassToConstruct(Gura_UserClass(wx_Region));
-	DeclareArg(env, "points", VTYPE_wx_Point, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "points", VTYPE_wx_Point, OCCUR_Once, FLAG_ListVar);
 	DeclareArg(env, "fillStyle", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 Gura_ImplementFunction(RegionPoints)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	size_t n = args.GetList(0).size();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	size_t n = arg.GetList(0).size();
 	wxPoint *points = new wxPoint[n];
 	size_t i = 0;
-	foreach_const (ValueList, pValue, args.GetList(0)) {
+	foreach_const (ValueList, pValue, arg.GetList(0)) {
 		points[i++] = *Object_wx_Point::GetObject(*pValue)->GetEntity();
 	}
 	wxPolygonFillMode fillStyle = wxWINDING_RULE;
-	if (args.IsValid(1)) fillStyle = static_cast<wxPolygonFillMode>(args.GetInt(1));
+	if (arg.IsValid(1)) fillStyle = static_cast<wxPolygonFillMode>(arg.GetInt(1));
 	wx_Region *pEntity = new wx_Region(n, points, fillStyle);
 	delete[] points;
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RegionFromBitmap)
@@ -190,26 +195,27 @@ Gura_DeclareFunction(RegionFromBitmap)
 
 Gura_ImplementFunction(RegionFromBitmap)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxBitmap *bmp = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	wx_Region *pEntity = NULL;
-	if (args.IsValid(1)) {
-		wxColour *transColour = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxBitmap *bmp = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	wx_Region *pEntity = nullptr;
+	if (arg.IsValid(1)) {
+		wxColour *transColour = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 		int tolerance = 0;
-		if (args.IsValid(2)) tolerance = args.GetInt(2);
+		if (arg.IsValid(2)) tolerance = arg.GetInt(2);
 		pEntity = new wx_Region(*bmp, *transColour, tolerance);
 	} else {
 		pEntity = new wx_Region(*bmp);
 	}
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 #if 0
@@ -225,21 +231,22 @@ Gura_DeclareFunction(Region_6)
 
 Gura_ImplementFunction(Region_6)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxBitmap *bmp = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	wxColour *transColour = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxBitmap *bmp = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	wxColour *transColour = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	int tolerance = 0;
-	if (args.IsValid(2)) tolerance = args.GetInt(2);
+	if (arg.IsValid(2)) tolerance = arg.GetInt(2);
 	wx_Region *pEntity = new wx_Region(*bmp, *transColour, tolerance);
-	Object_wx_Region *pObj = Object_wx_Region::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Region *pObj = Object_wx_Region::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Region(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 #endif
 
@@ -250,10 +257,11 @@ Gura_DeclareMethod(wx_Region, Clear)
 
 Gura_ImplementMethod(wx_Region, Clear)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Region, Contains)
@@ -266,12 +274,13 @@ Gura_DeclareMethod(wx_Region, Contains)
 
 Gura_ImplementMethod(wx_Region, Contains)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long x = args.GetLong(0);
-	long y = args.GetLong(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long x = arg.GetLong(0);
+	long y = arg.GetLong(1);
 	wxRegionContain rtn = pThis->GetEntity()->Contains(x, y);
-	return ReturnValue(env, sig, args, Value(rtn != wxOutRegion));
+	return ReturnValue(env, arg, Value(rtn != wxOutRegion));
 }
 
 Gura_DeclareMethod(wx_Region, ContainsPoint)
@@ -283,11 +292,12 @@ Gura_DeclareMethod(wx_Region, ContainsPoint)
 
 Gura_ImplementMethod(wx_Region, ContainsPoint)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	wxRegionContain rtn = pThis->GetEntity()->Contains(*pt);
-	return ReturnValue(env, sig, args, Value(rtn != wxOutRegion));
+	return ReturnValue(env, arg, Value(rtn != wxOutRegion));
 }
 
 Gura_DeclareMethod(wx_Region, ContainsRectDim)
@@ -302,14 +312,15 @@ Gura_DeclareMethod(wx_Region, ContainsRectDim)
 
 Gura_ImplementMethod(wx_Region, ContainsRectDim)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long x = args.GetLong(0);
-	long y = args.GetLong(1);
-	long width = args.GetLong(2);
-	long height = args.GetLong(3);
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long x = arg.GetLong(0);
+	long y = arg.GetLong(1);
+	long width = arg.GetLong(2);
+	long height = arg.GetLong(3);
 	wxRegionContain rtn = pThis->GetEntity()->Contains(x, y, width, height);
-	return ReturnValue(env, sig, args, Value(rtn != wxOutRegion));
+	return ReturnValue(env, arg, Value(rtn != wxOutRegion));
 }
 
 Gura_DeclareMethod(wx_Region, ContainsRect)
@@ -321,11 +332,12 @@ Gura_DeclareMethod(wx_Region, ContainsRect)
 
 Gura_ImplementMethod(wx_Region, ContainsRect)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	wxRegionContain rtn = pThis->GetEntity()->Contains(*rect);
-	return ReturnValue(env, sig, args, Value(rtn != wxOutRegion));
+	return ReturnValue(env, arg, Value(rtn != wxOutRegion));
 }
 
 Gura_DeclareMethod(wx_Region, ConvertToBitmap)
@@ -336,10 +348,11 @@ Gura_DeclareMethod(wx_Region, ConvertToBitmap)
 
 Gura_ImplementMethod(wx_Region, ConvertToBitmap)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxBitmap rtn = pThis->GetEntity()->ConvertToBitmap();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Region, GetBoxRectDim)
@@ -350,14 +363,15 @@ Gura_DeclareMethod(wx_Region, GetBoxRectDim)
 
 Gura_ImplementMethod(wx_Region, GetBoxRectDim)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxCoord x;
 	wxCoord y;
 	wxCoord width;
 	wxCoord height;
 	pThis->GetEntity()->GetBox(x, y, width, height);
-	return ReturnValue(env, sig, args, Value::CreateList(env,
+	return ReturnValue(env, arg, Value::CreateList(env,
 						Value(x), Value(y), Value(width), Value(height)));
 }
 
@@ -369,10 +383,11 @@ Gura_DeclareMethod(wx_Region, GetBox)
 
 Gura_ImplementMethod(wx_Region, GetBox)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRect rtn = pThis->GetEntity()->GetBox();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Region, Intersect)
@@ -387,14 +402,15 @@ Gura_DeclareMethod(wx_Region, Intersect)
 
 Gura_ImplementMethod(wx_Region, Intersect)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
-	wxCoord width = static_cast<wxCoord>(args.GetInt(2));
-	wxCoord height = static_cast<wxCoord>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
+	wxCoord width = static_cast<wxCoord>(arg.GetInt(2));
+	wxCoord height = static_cast<wxCoord>(arg.GetInt(3));
 	bool rtn = pThis->GetEntity()->Intersect(x, y, width, height);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, IntersectRect)
@@ -406,11 +422,12 @@ Gura_DeclareMethod(wx_Region, IntersectRect)
 
 Gura_ImplementMethod(wx_Region, IntersectRect)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Intersect(*rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, IntersectRegion)
@@ -422,11 +439,12 @@ Gura_DeclareMethod(wx_Region, IntersectRegion)
 
 Gura_ImplementMethod(wx_Region, IntersectRegion)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRegion *region = Object_wx_Region::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRegion *region = Object_wx_Region::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Intersect(*region);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, IsEmpty)
@@ -437,10 +455,11 @@ Gura_DeclareMethod(wx_Region, IsEmpty)
 
 Gura_ImplementMethod(wx_Region, IsEmpty)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsEmpty();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, IsEqual)
@@ -452,11 +471,12 @@ Gura_DeclareMethod(wx_Region, IsEqual)
 
 Gura_ImplementMethod(wx_Region, IsEqual)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRegion *region = Object_wx_Region::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRegion *region = Object_wx_Region::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->IsEqual(*region);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, SubtractRect)
@@ -468,11 +488,12 @@ Gura_DeclareMethod(wx_Region, SubtractRect)
 
 Gura_ImplementMethod(wx_Region, SubtractRect)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Subtract(*rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, SubtractRegion)
@@ -484,11 +505,12 @@ Gura_DeclareMethod(wx_Region, SubtractRegion)
 
 Gura_ImplementMethod(wx_Region, SubtractRegion)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRegion *region = Object_wx_Region::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRegion *region = Object_wx_Region::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Subtract(*region);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, Offset)
@@ -501,12 +523,13 @@ Gura_DeclareMethod(wx_Region, Offset)
 
 Gura_ImplementMethod(wx_Region, Offset)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
 	bool rtn = pThis->GetEntity()->Offset(x, y);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, OffsetPoint)
@@ -518,11 +541,12 @@ Gura_DeclareMethod(wx_Region, OffsetPoint)
 
 Gura_ImplementMethod(wx_Region, OffsetPoint)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Offset(*pt);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, Union)
@@ -537,14 +561,15 @@ Gura_DeclareMethod(wx_Region, Union)
 
 Gura_ImplementMethod(wx_Region, Union)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
-	wxCoord width = static_cast<wxCoord>(args.GetInt(2));
-	wxCoord height = static_cast<wxCoord>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
+	wxCoord width = static_cast<wxCoord>(arg.GetInt(2));
+	wxCoord height = static_cast<wxCoord>(arg.GetInt(3));
 	bool rtn = pThis->GetEntity()->Union(x, y, width, height);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, UnionRect)
@@ -556,11 +581,12 @@ Gura_DeclareMethod(wx_Region, UnionRect)
 
 Gura_ImplementMethod(wx_Region, UnionRect)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Union(*rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, UnionRegion)
@@ -572,11 +598,12 @@ Gura_DeclareMethod(wx_Region, UnionRegion)
 
 Gura_ImplementMethod(wx_Region, UnionRegion)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRegion *region = Object_wx_Region::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRegion *region = Object_wx_Region::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Union(*region);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, UnionBitmap)
@@ -588,11 +615,12 @@ Gura_DeclareMethod(wx_Region, UnionBitmap)
 
 Gura_ImplementMethod(wx_Region, UnionBitmap)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *bmp = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *bmp = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Union(*bmp);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, UnionBitmapColour)
@@ -606,14 +634,15 @@ Gura_DeclareMethod(wx_Region, UnionBitmapColour)
 
 Gura_ImplementMethod(wx_Region, UnionBitmapColour)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxBitmap *bmp = Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	wxColour *transColour = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxBitmap *bmp = Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	wxColour *transColour = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	int tolerance = 0;
-	if (args.IsValid(2)) tolerance = args.GetInt(2);
+	if (arg.IsValid(2)) tolerance = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->Union(*bmp, *transColour, tolerance);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, Xor)
@@ -628,14 +657,15 @@ Gura_DeclareMethod(wx_Region, Xor)
 
 Gura_ImplementMethod(wx_Region, Xor)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
-	wxCoord width = static_cast<wxCoord>(args.GetInt(2));
-	wxCoord height = static_cast<wxCoord>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
+	wxCoord width = static_cast<wxCoord>(arg.GetInt(2));
+	wxCoord height = static_cast<wxCoord>(arg.GetInt(3));
 	bool rtn = pThis->GetEntity()->Xor(x, y, width, height);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, XorRect)
@@ -647,11 +677,12 @@ Gura_DeclareMethod(wx_Region, XorRect)
 
 Gura_ImplementMethod(wx_Region, XorRect)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Xor(*rect);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Region, XorRegion)
@@ -663,11 +694,12 @@ Gura_DeclareMethod(wx_Region, XorRegion)
 
 Gura_ImplementMethod(wx_Region, XorRegion)
 {
-	Object_wx_Region *pThis = Object_wx_Region::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRegion *region = Object_wx_Region::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Region *pThis = Object_wx_Region::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRegion *region = Object_wx_Region::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Xor(*region);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -679,13 +711,13 @@ Object_wx_Region::~Object_wx_Region()
 
 Object *Object_wx_Region::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Region::ToString(bool exprFlag)
 {
 	String rtn("<wx.Region:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -736,7 +768,7 @@ Gura_ImplementUserInheritableClass(wx_Region)
 
 Gura_ImplementDescendantCreator(wx_Region)
 {
-	return new Object_wx_Region((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Region((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
