@@ -11,12 +11,12 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_RendererNative: public wxRendererNative, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_RendererNative *_pObj;
 public:
 	~wx_RendererNative();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_RendererNative *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_RendererNative *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -24,12 +24,12 @@ public:
 
 wx_RendererNative::~wx_RendererNative()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RendererNative::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,18 +49,19 @@ Gura_DeclareMethod(wx_RendererNative, DrawCheckBox)
 
 Gura_ImplementMethod(wx_RendererNative, DrawCheckBox)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
-	int flags = args.GetInt(3);
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
+	int flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawCheckBox(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawComboBoxDropButton)
@@ -76,18 +77,19 @@ Gura_DeclareMethod(wx_RendererNative, DrawComboBoxDropButton)
 
 Gura_ImplementMethod(wx_RendererNative, DrawComboBoxDropButton)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
-	int flags = args.GetInt(3);
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
+	int flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawComboBoxDropButton(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawDropArrow)
@@ -103,18 +105,19 @@ Gura_DeclareMethod(wx_RendererNative, DrawDropArrow)
 
 Gura_ImplementMethod(wx_RendererNative, DrawDropArrow)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
-	int flags = args.GetInt(3);
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
+	int flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawDropArrow(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawHeaderButton)
@@ -133,23 +136,24 @@ Gura_DeclareMethod(wx_RendererNative, DrawHeaderButton)
 
 Gura_ImplementMethod(wx_RendererNative, DrawHeaderButton)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
 	int flags = 0;
-	if (args.IsValid(3)) flags = args.GetInt(3);
+	if (arg.IsValid(3)) flags = arg.GetInt(3);
 	wxHeaderSortIconType *sortArrow = (wxHeaderSortIconType *)(&wxHDR_SORT_ICON_NONE);
-	if (args.IsValid(4)) sortArrow = Object_wx_HeaderSortIconType::GetObject(args, 4)->GetEntity();
-	wxHeaderButtonParams *params = (wxHeaderButtonParams *)(NULL);
-	if (args.IsValid(5)) params = Object_wx_HeaderButtonParams::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(4)) sortArrow = Object_wx_HeaderSortIconType::GetObject(arg, 4)->GetEntity();
+	wxHeaderButtonParams *params = (wxHeaderButtonParams *)(nullptr);
+	if (arg.IsValid(5)) params = Object_wx_HeaderButtonParams::GetObject(arg, 5)->GetEntity();
 	int rtn = pThis->GetEntity()->DrawHeaderButton(win, *dc, *rect, flags, *sortArrow, params);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawItemSelectionRect)
@@ -165,19 +169,20 @@ Gura_DeclareMethod(wx_RendererNative, DrawItemSelectionRect)
 
 Gura_ImplementMethod(wx_RendererNative, DrawItemSelectionRect)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
 	int flags = 0;
-	if (args.IsValid(3)) flags = args.GetInt(3);
+	if (arg.IsValid(3)) flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawItemSelectionRect(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawPushButton)
@@ -193,18 +198,19 @@ Gura_DeclareMethod(wx_RendererNative, DrawPushButton)
 
 Gura_ImplementMethod(wx_RendererNative, DrawPushButton)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
-	int flags = args.GetInt(3);
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
+	int flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawPushButton(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawSplitterBorder)
@@ -220,19 +226,20 @@ Gura_DeclareMethod(wx_RendererNative, DrawSplitterBorder)
 
 Gura_ImplementMethod(wx_RendererNative, DrawSplitterBorder)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
 	int flags = 0;
-	if (args.IsValid(3)) flags = args.GetInt(3);
+	if (arg.IsValid(3)) flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawSplitterBorder(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawSplitterSash)
@@ -250,21 +257,22 @@ Gura_DeclareMethod(wx_RendererNative, DrawSplitterSash)
 
 Gura_ImplementMethod(wx_RendererNative, DrawSplitterSash)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxSize *size = Object_wx_Size::GetObject(args, 2)->GetEntity();
-	wxCoord position = static_cast<wxCoord>(args.GetInt(3));
-	wxOrientation orient = static_cast<wxOrientation>(args.GetInt(4));
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxSize *size = Object_wx_Size::GetObject(arg, 2)->GetEntity();
+	wxCoord position = static_cast<wxCoord>(arg.GetInt(3));
+	wxOrientation orient = static_cast<wxOrientation>(arg.GetInt(4));
 	int flags = 0;
-	if (args.IsValid(5)) flags = args.GetInt(5);
+	if (arg.IsValid(5)) flags = arg.GetInt(5);
 	pThis->GetEntity()->DrawSplitterSash(win, *dc, *size, position, orient, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, DrawTreeItemButton)
@@ -280,19 +288,20 @@ Gura_DeclareMethod(wx_RendererNative, DrawTreeItemButton)
 
 Gura_ImplementMethod(wx_RendererNative, DrawTreeItemButton)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxDC *dc = Object_wx_DC::GetObject(args, 1)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 2)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxDC *dc = Object_wx_DC::GetObject(arg, 1)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 2)->GetEntity();
 	int flags = 0;
-	if (args.IsValid(3)) flags = args.GetInt(3);
+	if (arg.IsValid(3)) flags = arg.GetInt(3);
 	pThis->GetEntity()->DrawTreeItemButton(win, *dc, *rect, flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, Get)
@@ -303,14 +312,15 @@ Gura_DeclareMethod(wx_RendererNative, Get)
 
 Gura_ImplementMethod(wx_RendererNative, Get)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRendererNative &rtn = pThis->GetEntity()->Get();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RendererNative(new wxRendererNative(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_RendererNative(new wxRendererNative(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, GetDefault)
@@ -321,14 +331,15 @@ Gura_DeclareMethod(wx_RendererNative, GetDefault)
 
 Gura_ImplementMethod(wx_RendererNative, GetDefault)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRendererNative &rtn = pThis->GetEntity()->GetDefault();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RendererNative(new wxRendererNative(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_RendererNative(new wxRendererNative(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, GetGeneric)
@@ -339,14 +350,15 @@ Gura_DeclareMethod(wx_RendererNative, GetGeneric)
 
 Gura_ImplementMethod(wx_RendererNative, GetGeneric)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRendererNative &rtn = pThis->GetEntity()->GetGeneric();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RendererNative(new wxRendererNative(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_RendererNative(new wxRendererNative(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, GetHeaderButtonHeight)
@@ -360,15 +372,16 @@ Gura_DeclareMethod(wx_RendererNative, GetHeaderButtonHeight)
 
 Gura_ImplementMethod(wx_RendererNative, GetHeaderButtonHeight)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	int rtn = pThis->GetEntity()->GetHeaderButtonHeight(win);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, GetSplitterParams)
@@ -382,15 +395,16 @@ Gura_DeclareMethod(wx_RendererNative, GetSplitterParams)
 
 Gura_ImplementMethod(wx_RendererNative, GetSplitterParams)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxSplitterRenderParams rtn = pThis->GetEntity()->GetSplitterParams(win);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SplitterRenderParams(new wxSplitterRenderParams(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SplitterRenderParams(new wxSplitterRenderParams(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, GetVersion)
@@ -401,10 +415,11 @@ Gura_DeclareMethod(wx_RendererNative, GetVersion)
 
 Gura_ImplementMethod(wx_RendererNative, GetVersion)
 {
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRendererVersion rtn = pThis->GetEntity()->GetVersion();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RendererVersion(new wxRendererVersion(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_RendererVersion(new wxRendererVersion(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RendererNative, Load)
@@ -418,15 +433,16 @@ Gura_DeclareMethod(wx_RendererNative, Load)
 
 Gura_ImplementMethod(wx_RendererNative, Load)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxRendererNative *rtn = (wxRendererNative *)pThis->GetEntity()->Load(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RendererNative(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RendererNative(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RendererNative, Set)
@@ -440,15 +456,16 @@ Gura_DeclareMethod(wx_RendererNative, Set)
 
 Gura_ImplementMethod(wx_RendererNative, Set)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRendererNative *renderer = Object_wx_RendererNative::GetObject(args, 0)->GetEntity();
+	Object_wx_RendererNative *pThis = Object_wx_RendererNative::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRendererNative *renderer = Object_wx_RendererNative::GetObject(arg, 0)->GetEntity();
 	wxRendererNative *rtn = (wxRendererNative *)pThis->GetEntity()->Set(renderer);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RendererNative(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RendererNative(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -456,20 +473,20 @@ Gura_ImplementMethod(wx_RendererNative, Set)
 //----------------------------------------------------------------------------
 Object_wx_RendererNative::~Object_wx_RendererNative()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_RendererNative::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_RendererNative::ToString(bool exprFlag)
 {
 	String rtn("<wx.RendererNative:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -505,7 +522,7 @@ Gura_ImplementUserInheritableClass(wx_RendererNative)
 
 Gura_ImplementDescendantCreator(wx_RendererNative)
 {
-	return new Object_wx_RendererNative((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RendererNative((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
