@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_RichTextFormattingDialog: public wxRichTextFormattingDialog, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_RichTextFormattingDialog *_pObj;
 public:
-	inline wx_RichTextFormattingDialog(long flags, wxWindow* parent, const wxString& title, wxWindowID id, const wxPoint& pos, const wxSize& sz, long style) : wxRichTextFormattingDialog(flags, parent, title, id, pos, sz, style), _sig(NULL), _pObj(NULL) {}
-	inline wx_RichTextFormattingDialog() : wxRichTextFormattingDialog(), _sig(NULL), _pObj(NULL) {}
+	inline wx_RichTextFormattingDialog(long flags, wxWindow* parent, const wxString& title, wxWindowID id, const wxPoint& pos, const wxSize& sz, long style) : wxRichTextFormattingDialog(flags, parent, title, id, pos, sz, style), _pObj(nullptr) {}
+	inline wx_RichTextFormattingDialog() : wxRichTextFormattingDialog(), _pObj(nullptr) {}
 	~wx_RichTextFormattingDialog();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_RichTextFormattingDialog *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_RichTextFormattingDialog *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_RichTextFormattingDialog::~wx_RichTextFormattingDialog()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RichTextFormattingDialog::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -53,29 +53,30 @@ Gura_DeclareFunction(RichTextFormattingDialog)
 
 Gura_ImplementFunction(RichTextFormattingDialog)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	long flags = args.GetLong(0);
-	wxWindow *parent = Object_wx_Window::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	long flags = arg.GetLong(0);
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 1)->GetEntity();
 	wxString title = _("Formatting");
-	if (args.IsValid(2)) title = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) title = wxString::FromUTF8(arg.GetString(2));
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(3)) id = static_cast<wxWindowID>(args.GetInt(3));
+	if (arg.IsValid(3)) id = static_cast<wxWindowID>(arg.GetInt(3));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(4)) pos = Object_wx_Point::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) pos = Object_wx_Point::GetObject(arg, 4)->GetEntity();
 	wxSize *sz = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(5)) sz = Object_wx_Size::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(5)) sz = Object_wx_Size::GetObject(arg, 5)->GetEntity();
 	long style = wxDEFAULT_DIALOG_STYLE;
-	if (args.IsValid(6)) style = args.GetLong(6);
+	if (arg.IsValid(6)) style = arg.GetLong(6);
 	wx_RichTextFormattingDialog *pEntity = new wx_RichTextFormattingDialog(flags, parent, title, id, *pos, *sz, style);
-	Object_wx_RichTextFormattingDialog *pObj = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RichTextFormattingDialog *pObj = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RichTextFormattingDialog(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RichTextFormattingDialogEmpty)
@@ -87,17 +88,18 @@ Gura_DeclareFunction(RichTextFormattingDialogEmpty)
 
 Gura_ImplementFunction(RichTextFormattingDialogEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_RichTextFormattingDialog *pEntity = new wx_RichTextFormattingDialog();
-	Object_wx_RichTextFormattingDialog *pObj = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RichTextFormattingDialog *pObj = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RichTextFormattingDialog(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, ApplyStyle)
@@ -111,14 +113,15 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, ApplyStyle)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, ApplyStyle)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextCtrl *ctrl = Object_wx_RichTextCtrl::GetObject(args, 0)->GetEntity();
-	wxRichTextRange *range = Object_wx_RichTextRange::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextCtrl *ctrl = Object_wx_RichTextCtrl::GetObject(arg, 0)->GetEntity();
+	wxRichTextRange *range = Object_wx_RichTextRange::GetObject(arg, 1)->GetEntity();
 	int flags = wxRICHTEXT_SETSTYLE_WITH_UNDO|wxRICHTEXT_SETSTYLE_OPTIMIZE;
-	if (args.IsValid(2)) flags = args.GetInt(2);
+	if (arg.IsValid(2)) flags = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->ApplyStyle(ctrl, *range, flags);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, Create)
@@ -136,20 +139,21 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, Create)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, Create)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long flags = args.GetLong(0);
-	wxWindow *parent = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString title = wxString::FromUTF8(args.GetString(2));
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long flags = arg.GetLong(0);
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString title = wxString::FromUTF8(arg.GetString(2));
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(3));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(4)) pos = Object_wx_Point::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(4)) pos = Object_wx_Point::GetObject(arg, 4)->GetEntity();
 	wxSize *sz = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(5)) sz = Object_wx_Size::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(5)) sz = Object_wx_Size::GetObject(arg, 5)->GetEntity();
 	long style = wxDEFAULT_DIALOG_STYLE;
-	if (args.IsValid(6)) style = args.GetLong(6);
+	if (arg.IsValid(6)) style = arg.GetLong(6);
 	bool rtn = pThis->GetEntity()->Create(flags, parent, title, id, *pos, *sz, style);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetAttributes)
@@ -160,10 +164,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetAttributes)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetAttributes)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxTextAttrEx &rtn = pThis->GetEntity()->GetAttributes();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextAttrEx(new wxTextAttrEx(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextAttrEx(new wxTextAttrEx(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetAttributes_1)
@@ -174,10 +179,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetAttributes_1)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetAttributes_1)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTextAttrEx &rtn = pThis->GetEntity()->GetAttributes();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextAttrEx(new wxTextAttrEx(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextAttrEx(new wxTextAttrEx(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetDialog)
@@ -189,11 +195,12 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetDialog)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetDialog)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxRichTextFormattingDialog *rtn = (wxRichTextFormattingDialog *)pThis->GetEntity()->GetDialog(win);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextFormattingDialog(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextFormattingDialog(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetDialogAttributes)
@@ -205,11 +212,12 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetDialogAttributes)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetDialogAttributes)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxTextAttrEx *rtn = (wxTextAttrEx *)pThis->GetEntity()->GetDialogAttributes(win);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextAttrEx(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextAttrEx(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetDialogStyleDefinition)
@@ -221,11 +229,12 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetDialogStyleDefinition)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetDialogStyleDefinition)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxRichTextStyleDefinition *rtn = (wxRichTextStyleDefinition *)pThis->GetEntity()->GetDialogStyleDefinition(win);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetFormattingDialogFactory)
@@ -236,10 +245,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetFormattingDialogFactory)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetFormattingDialogFactory)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextFormattingDialogFactory *rtn = (wxRichTextFormattingDialogFactory *)pThis->GetEntity()->GetFormattingDialogFactory();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextFormattingDialogFactory(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextFormattingDialogFactory(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetImageList)
@@ -250,10 +260,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetImageList)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetImageList)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxImageList *rtn = (wxImageList *)pThis->GetEntity()->GetImageList();
-	return ReturnValue(env, sig, args, Value(new Object_wx_ImageList(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ImageList(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetStyle)
@@ -266,12 +277,13 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetStyle)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetStyle)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextCtrl *ctrl = Object_wx_RichTextCtrl::GetObject(args, 0)->GetEntity();
-	wxRichTextRange *range = Object_wx_RichTextRange::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextCtrl *ctrl = Object_wx_RichTextCtrl::GetObject(arg, 0)->GetEntity();
+	wxRichTextRange *range = Object_wx_RichTextRange::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->GetStyle(ctrl, *range);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetStyleDefinition)
@@ -282,10 +294,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetStyleDefinition)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetStyleDefinition)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextStyleDefinition *rtn = (wxRichTextStyleDefinition *)pThis->GetEntity()->GetStyleDefinition();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, GetStyleSheet)
@@ -296,10 +309,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, GetStyleSheet)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, GetStyleSheet)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextStyleSheet *rtn = (wxRichTextStyleSheet *)pThis->GetEntity()->GetStyleSheet();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextStyleSheet(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextStyleSheet(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, SetAttributes)
@@ -310,11 +324,12 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, SetAttributes)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, SetAttributes)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTextAttrEx *attr = Object_wx_TextAttrEx::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTextAttrEx *attr = Object_wx_TextAttrEx::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetAttributes(*attr);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, SetFormattingDialogFactory)
@@ -325,11 +340,12 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, SetFormattingDialogFactory)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, SetFormattingDialogFactory)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextFormattingDialogFactory *factory = Object_wx_RichTextFormattingDialogFactory::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextFormattingDialogFactory *factory = Object_wx_RichTextFormattingDialogFactory::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetFormattingDialogFactory(factory);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, SetImageList)
@@ -340,12 +356,13 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, SetImageList)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, SetImageList)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxImageList *imageList = NULL;
-	if (args.IsValid(0)) imageList = Object_wx_ImageList::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxImageList *imageList = nullptr;
+	if (arg.IsValid(0)) imageList = Object_wx_ImageList::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetImageList(imageList);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, SetStyle)
@@ -358,13 +375,14 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, SetStyle)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, SetStyle)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTextAttrEx *style = Object_wx_TextAttrEx::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTextAttrEx *style = Object_wx_TextAttrEx::GetObject(arg, 0)->GetEntity();
 	bool update = true;
-	if (args.IsValid(1)) update = args.GetBoolean(1);
+	if (arg.IsValid(1)) update = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->SetStyle(*style, update);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, SetStyleDefinition)
@@ -378,14 +396,15 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, SetStyleDefinition)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, SetStyleDefinition)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextStyleDefinition *styleDef = Object_wx_RichTextStyleDefinition::GetObject(args, 0)->GetEntity();
-	wxRichTextStyleSheet *sheet = Object_wx_RichTextStyleSheet::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextStyleDefinition *styleDef = Object_wx_RichTextStyleDefinition::GetObject(arg, 0)->GetEntity();
+	wxRichTextStyleSheet *sheet = Object_wx_RichTextStyleSheet::GetObject(arg, 1)->GetEntity();
 	bool update = true;
-	if (args.IsValid(2)) update = args.GetBoolean(2);
+	if (arg.IsValid(2)) update = arg.GetBoolean(2);
 	bool rtn = pThis->GetEntity()->SetStyleDefinition(*styleDef, sheet, update);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextFormattingDialog, UpdateDisplay)
@@ -396,10 +415,11 @@ Gura_DeclareMethod(wx_RichTextFormattingDialog, UpdateDisplay)
 
 Gura_ImplementMethod(wx_RichTextFormattingDialog, UpdateDisplay)
 {
-	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextFormattingDialog *pThis = Object_wx_RichTextFormattingDialog::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->UpdateDisplay();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -411,13 +431,13 @@ Object_wx_RichTextFormattingDialog::~Object_wx_RichTextFormattingDialog()
 
 Object *Object_wx_RichTextFormattingDialog::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_RichTextFormattingDialog::ToString(bool exprFlag)
 {
 	String rtn("<wx.RichTextFormattingDialog:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -456,7 +476,7 @@ Gura_ImplementUserInheritableClass(wx_RichTextFormattingDialog)
 
 Gura_ImplementDescendantCreator(wx_RichTextFormattingDialog)
 {
-	return new Object_wx_RichTextFormattingDialog((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RichTextFormattingDialog((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
