@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_RichTextHeaderFooterData: public wxRichTextHeaderFooterData, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_RichTextHeaderFooterData *_pObj;
 public:
-	inline wx_RichTextHeaderFooterData() : wxRichTextHeaderFooterData(), _sig(NULL), _pObj(NULL) {}
-	inline wx_RichTextHeaderFooterData(const wxRichTextHeaderFooterData& data) : wxRichTextHeaderFooterData(data), _sig(NULL), _pObj(NULL) {}
+	inline wx_RichTextHeaderFooterData() : wxRichTextHeaderFooterData(), _pObj(nullptr) {}
+	inline wx_RichTextHeaderFooterData(const wxRichTextHeaderFooterData& data) : wxRichTextHeaderFooterData(data), _pObj(nullptr) {}
 	~wx_RichTextHeaderFooterData();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_RichTextHeaderFooterData *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_RichTextHeaderFooterData *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_RichTextHeaderFooterData::~wx_RichTextHeaderFooterData()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RichTextHeaderFooterData::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(RichTextHeaderFooterDataEmpty)
 
 Gura_ImplementFunction(RichTextHeaderFooterDataEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_RichTextHeaderFooterData *pEntity = new wx_RichTextHeaderFooterData();
-	Object_wx_RichTextHeaderFooterData *pObj = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RichTextHeaderFooterData *pObj = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RichTextHeaderFooterData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(RichTextHeaderFooterData)
@@ -69,18 +70,19 @@ Gura_DeclareFunction(RichTextHeaderFooterData)
 
 Gura_ImplementFunction(RichTextHeaderFooterData)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxRichTextHeaderFooterData *data = Object_wx_RichTextHeaderFooterData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxRichTextHeaderFooterData *data = Object_wx_RichTextHeaderFooterData::GetObject(arg, 0)->GetEntity();
 	wx_RichTextHeaderFooterData *pEntity = new wx_RichTextHeaderFooterData(*data);
-	Object_wx_RichTextHeaderFooterData *pObj = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RichTextHeaderFooterData *pObj = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RichTextHeaderFooterData(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, Clear)
@@ -90,10 +92,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, Clear)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, Clear)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, Copy)
@@ -104,11 +107,12 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, Copy)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, Copy)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextHeaderFooterData *data = Object_wx_RichTextHeaderFooterData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextHeaderFooterData *data = Object_wx_RichTextHeaderFooterData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Copy(*data);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetFont)
@@ -119,10 +123,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetFont)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetFont)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxFont &rtn = pThis->GetEntity()->GetFont();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(new wxFont(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(new wxFont(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetFooterMargin)
@@ -133,10 +138,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetFooterMargin)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetFooterMargin)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFooterMargin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetFooterText)
@@ -149,14 +155,15 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetFooterText)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetFooterText)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_EVEN;
-	if (args.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(0));
+	if (arg.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(0));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(1)) location = static_cast<wxRichTextPageLocation>(args.GetInt(1));
+	if (arg.IsValid(1)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(1));
 	wxString rtn = pThis->GetEntity()->GetFooterText(page, location);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetHeaderMargin)
@@ -167,10 +174,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetHeaderMargin)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetHeaderMargin)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetHeaderMargin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetHeaderText)
@@ -183,14 +191,15 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetHeaderText)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetHeaderText)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_EVEN;
-	if (args.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(0));
+	if (arg.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(0));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(1)) location = static_cast<wxRichTextPageLocation>(args.GetInt(1));
+	if (arg.IsValid(1)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(1));
 	wxString rtn = pThis->GetEntity()->GetHeaderText(page, location);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetShowOnFirstPage)
@@ -201,10 +210,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetShowOnFirstPage)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetShowOnFirstPage)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetShowOnFirstPage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetText)
@@ -218,13 +228,14 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetText)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetText)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int headerFooter = args.GetInt(0);
-	wxRichTextOddEvenPage page = static_cast<wxRichTextOddEvenPage>(args.GetInt(1));
-	wxRichTextPageLocation location = static_cast<wxRichTextPageLocation>(args.GetInt(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int headerFooter = arg.GetInt(0);
+	wxRichTextOddEvenPage page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(1));
+	wxRichTextPageLocation location = static_cast<wxRichTextPageLocation>(arg.GetInt(2));
 	wxString rtn = pThis->GetEntity()->GetText(headerFooter, page, location);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetTextColour)
@@ -235,10 +246,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, GetTextColour)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, GetTextColour)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetTextColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, Init)
@@ -248,10 +260,11 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, Init)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, Init)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Init();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetFont)
@@ -262,11 +275,12 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetFont)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetFont)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetFooterText)
@@ -279,15 +293,16 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetFooterText)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetFooterText)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_ALL;
-	if (args.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(1));
+	if (arg.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(1));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(2)) location = static_cast<wxRichTextPageLocation>(args.GetInt(2));
+	if (arg.IsValid(2)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(2));
 	pThis->GetEntity()->SetFooterText(text, page, location);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetHeaderText)
@@ -300,15 +315,16 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetHeaderText)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetHeaderText)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_ALL;
-	if (args.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(1));
+	if (arg.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(1));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(2)) location = static_cast<wxRichTextPageLocation>(args.GetInt(2));
+	if (arg.IsValid(2)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(2));
 	pThis->GetEntity()->SetHeaderText(text, page, location);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetMargins)
@@ -320,12 +336,13 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetMargins)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetMargins)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int headerMargin = args.GetInt(0);
-	int footerMargin = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int headerMargin = arg.GetInt(0);
+	int footerMargin = arg.GetInt(1);
 	pThis->GetEntity()->SetMargins(headerMargin, footerMargin);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetShowOnFirstPage)
@@ -336,11 +353,12 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetShowOnFirstPage)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetShowOnFirstPage)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool showOnFirstPage = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool showOnFirstPage = arg.GetBoolean(0);
 	pThis->GetEntity()->SetShowOnFirstPage(showOnFirstPage);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetText)
@@ -354,14 +372,15 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetText)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetText)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
-	int headerFooter = args.GetInt(1);
-	wxRichTextOddEvenPage page = static_cast<wxRichTextOddEvenPage>(args.GetInt(2));
-	wxRichTextPageLocation location = static_cast<wxRichTextPageLocation>(args.GetInt(3));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
+	int headerFooter = arg.GetInt(1);
+	wxRichTextOddEvenPage page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(2));
+	wxRichTextPageLocation location = static_cast<wxRichTextPageLocation>(arg.GetInt(3));
 	pThis->GetEntity()->SetText(text, headerFooter, page, location);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetTextColour)
@@ -372,11 +391,12 @@ Gura_DeclareMethod(wx_RichTextHeaderFooterData, SetTextColour)
 
 Gura_ImplementMethod(wx_RichTextHeaderFooterData, SetTextColour)
 {
-	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *col = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextHeaderFooterData *pThis = Object_wx_RichTextHeaderFooterData::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *col = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetTextColour(*col);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -388,13 +408,13 @@ Object_wx_RichTextHeaderFooterData::~Object_wx_RichTextHeaderFooterData()
 
 Object *Object_wx_RichTextHeaderFooterData::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_RichTextHeaderFooterData::ToString(bool exprFlag)
 {
 	String rtn("<wx.RichTextHeaderFooterData:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -433,7 +453,7 @@ Gura_ImplementUserInheritableClass(wx_RichTextHeaderFooterData)
 
 Gura_ImplementDescendantCreator(wx_RichTextHeaderFooterData)
 {
-	return new Object_wx_RichTextHeaderFooterData((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RichTextHeaderFooterData((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
