@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_RichTextPrinting: public wxRichTextPrinting, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_RichTextPrinting *_pObj;
 public:
-	inline wx_RichTextPrinting(const wxString& name, wxWindow* parentWindow) : wxRichTextPrinting(name, parentWindow), _sig(NULL), _pObj(NULL) {}
+	inline wx_RichTextPrinting(const wxString& name, wxWindow* parentWindow) : wxRichTextPrinting(name, parentWindow), _pObj(nullptr) {}
 	~wx_RichTextPrinting();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_RichTextPrinting *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_RichTextPrinting *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_RichTextPrinting::~wx_RichTextPrinting()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RichTextPrinting::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,21 +47,22 @@ Gura_DeclareFunction(RichTextPrinting)
 
 Gura_ImplementFunction(RichTextPrinting)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxString name = wxT("Printing");
-	if (args.IsValid(0)) name = wxString::FromUTF8(args.GetString(0));
-	wxWindow *parentWindow = (wxWindow *)(NULL);
-	if (args.IsValid(1)) parentWindow = Object_wx_Window::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(0)) name = wxString::FromUTF8(arg.GetString(0));
+	wxWindow *parentWindow = (wxWindow *)(nullptr);
+	if (arg.IsValid(1)) parentWindow = Object_wx_Window::GetObject(arg, 1)->GetEntity();
 	wx_RichTextPrinting *pEntity = new wx_RichTextPrinting(name, parentWindow);
-	Object_wx_RichTextPrinting *pObj = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RichTextPrinting *pObj = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RichTextPrinting(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetFooterText)
@@ -74,14 +75,15 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetFooterText)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetFooterText)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_EVEN;
-	if (args.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(0));
+	if (arg.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(0));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(1)) location = static_cast<wxRichTextPageLocation>(args.GetInt(1));
+	if (arg.IsValid(1)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(1));
 	wxString rtn = pThis->GetEntity()->GetFooterText(page, location);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetHeaderFooterData)
@@ -92,10 +94,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetHeaderFooterData)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetHeaderFooterData)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxRichTextHeaderFooterData &rtn = pThis->GetEntity()->GetHeaderFooterData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextHeaderFooterData(new wxRichTextHeaderFooterData(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextHeaderFooterData(new wxRichTextHeaderFooterData(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetHeaderText)
@@ -108,14 +111,15 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetHeaderText)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetHeaderText)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_EVEN;
-	if (args.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(0));
+	if (arg.IsValid(0)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(0));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(1)) location = static_cast<wxRichTextPageLocation>(args.GetInt(1));
+	if (arg.IsValid(1)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(1));
 	wxString rtn = pThis->GetEntity()->GetHeaderText(page, location);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetPageSetupData)
@@ -126,10 +130,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetPageSetupData)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetPageSetupData)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPageSetupDialogData *rtn = (wxPageSetupDialogData *)pThis->GetEntity()->GetPageSetupData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_PageSetupDialogData(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_PageSetupDialogData(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetParentWindow)
@@ -140,10 +145,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetParentWindow)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetParentWindow)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetParentWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetPreviewRect)
@@ -154,10 +160,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetPreviewRect)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetPreviewRect)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxRect &rtn = pThis->GetEntity()->GetPreviewRect();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetPrintData)
@@ -168,10 +175,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetPrintData)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetPrintData)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPrintData *rtn = (wxPrintData *)pThis->GetEntity()->GetPrintData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_PrintData(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_PrintData(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, GetTitle)
@@ -182,10 +190,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, GetTitle)
 
 Gura_ImplementMethod(wx_RichTextPrinting, GetTitle)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetTitle();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, PageSetup)
@@ -195,10 +204,11 @@ Gura_DeclareMethod(wx_RichTextPrinting, PageSetup)
 
 Gura_ImplementMethod(wx_RichTextPrinting, PageSetup)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->PageSetup();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, PreviewBuffer)
@@ -210,11 +220,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, PreviewBuffer)
 
 Gura_ImplementMethod(wx_RichTextPrinting, PreviewBuffer)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextBuffer *buffer = Object_wx_RichTextBuffer::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextBuffer *buffer = Object_wx_RichTextBuffer::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->PreviewBuffer(*buffer);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, PreviewFile)
@@ -226,11 +237,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, PreviewFile)
 
 Gura_ImplementMethod(wx_RichTextPrinting, PreviewFile)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString richTextFile = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString richTextFile = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->PreviewFile(richTextFile);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, PrintBuffer)
@@ -242,11 +254,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, PrintBuffer)
 
 Gura_ImplementMethod(wx_RichTextPrinting, PrintBuffer)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextBuffer *buffer = Object_wx_RichTextBuffer::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextBuffer *buffer = Object_wx_RichTextBuffer::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->PrintBuffer(*buffer);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, PrintFile)
@@ -258,11 +271,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, PrintFile)
 
 Gura_ImplementMethod(wx_RichTextPrinting, PrintFile)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString richTextFile = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString richTextFile = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->PrintFile(richTextFile);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetFooterText)
@@ -275,15 +289,16 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetFooterText)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetFooterText)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_ALL;
-	if (args.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(1));
+	if (arg.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(1));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(2)) location = static_cast<wxRichTextPageLocation>(args.GetInt(2));
+	if (arg.IsValid(2)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(2));
 	pThis->GetEntity()->SetFooterText(text, page, location);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderFooterData)
@@ -294,11 +309,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderFooterData)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetHeaderFooterData)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextHeaderFooterData *data = Object_wx_RichTextHeaderFooterData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextHeaderFooterData *data = Object_wx_RichTextHeaderFooterData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetHeaderFooterData(*data);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderFooterFont)
@@ -309,11 +325,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderFooterFont)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetHeaderFooterFont)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetHeaderFooterFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderFooterTextColour)
@@ -324,11 +341,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderFooterTextColour)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetHeaderFooterTextColour)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colour = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colour = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetHeaderFooterTextColour(*colour);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderText)
@@ -341,15 +359,16 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetHeaderText)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetHeaderText)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextOddEvenPage page = wxRICHTEXT_PAGE_ALL;
-	if (args.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(args.GetInt(1));
+	if (arg.IsValid(1)) page = static_cast<wxRichTextOddEvenPage>(arg.GetInt(1));
 	wxRichTextPageLocation location = wxRICHTEXT_PAGE_CENTRE;
-	if (args.IsValid(2)) location = static_cast<wxRichTextPageLocation>(args.GetInt(2));
+	if (arg.IsValid(2)) location = static_cast<wxRichTextPageLocation>(arg.GetInt(2));
 	pThis->GetEntity()->SetHeaderText(text, page, location);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetPageSetupData)
@@ -360,11 +379,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetPageSetupData)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetPageSetupData)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPageSetupData *pageSetupData = Object_wx_PageSetupData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPageSetupData *pageSetupData = Object_wx_PageSetupData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPageSetupData(*pageSetupData);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetParentWindow)
@@ -375,11 +395,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetParentWindow)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetParentWindow)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetParentWindow(parent);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetPreviewRect)
@@ -390,11 +411,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetPreviewRect)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetPreviewRect)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRect *rect = Object_wx_Rect::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPreviewRect(*rect);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetPrintData)
@@ -405,11 +427,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetPrintData)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetPrintData)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPrintData *printData = Object_wx_PrintData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPrintData *printData = Object_wx_PrintData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetPrintData(*printData);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetShowOnFirstPage)
@@ -420,11 +443,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetShowOnFirstPage)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetShowOnFirstPage)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool show = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool show = arg.GetBoolean(0);
 	pThis->GetEntity()->SetShowOnFirstPage(show);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextPrinting, SetTitle)
@@ -435,11 +459,12 @@ Gura_DeclareMethod(wx_RichTextPrinting, SetTitle)
 
 Gura_ImplementMethod(wx_RichTextPrinting, SetTitle)
 {
-	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextPrinting *pThis = Object_wx_RichTextPrinting::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetTitle(title);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -451,13 +476,13 @@ Object_wx_RichTextPrinting::~Object_wx_RichTextPrinting()
 
 Object *Object_wx_RichTextPrinting::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_RichTextPrinting::ToString(bool exprFlag)
 {
 	String rtn("<wx.RichTextPrinting:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -501,7 +526,7 @@ Gura_ImplementUserInheritableClass(wx_RichTextPrinting)
 
 Gura_ImplementDescendantCreator(wx_RichTextPrinting)
 {
-	return new Object_wx_RichTextPrinting((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RichTextPrinting((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
