@@ -13,8 +13,8 @@ class wx_RichTextStyleSheet: public wxRichTextStyleSheet, public GuraObjectObser
 private:
 	Object_wx_RichTextStyleSheet *_pObj;
 public:
-	inline wx_RichTextStyleSheet(const wxRichTextStyleSheet& sheet) : wxRichTextStyleSheet(sheet), _pObj(NULL) {}
-	inline wx_RichTextStyleSheet() : wxRichTextStyleSheet(), _pObj(NULL) {}
+	inline wx_RichTextStyleSheet(const wxRichTextStyleSheet& sheet) : wxRichTextStyleSheet(sheet), _pObj(nullptr) {}
+	inline wx_RichTextStyleSheet() : wxRichTextStyleSheet(), _pObj(nullptr) {}
 	~wx_RichTextStyleSheet();
 	inline void AssocWithGura(Object_wx_RichTextStyleSheet *pObj) {
 		_pObj = pObj;
@@ -25,12 +25,12 @@ public:
 
 wx_RichTextStyleSheet::~wx_RichTextStyleSheet()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_RichTextStyleSheet::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -45,17 +45,18 @@ Gura_DeclareFunction(RichTextStyleSheet)
 
 Gura_ImplementFunction(RichTextStyleSheet)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_RichTextStyleSheet *pEntity = new wx_RichTextStyleSheet();
-	Object_wx_RichTextStyleSheet *pObj = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_RichTextStyleSheet *pObj = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_RichTextStyleSheet(pEntity, pEntity, OwnerFalse);
 		pEntity->AssocWithGura(pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
 	pEntity->AssocWithGura(pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, AddCharacterStyle)
@@ -67,11 +68,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, AddCharacterStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, AddCharacterStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextCharacterStyleDefinition *def = Object_wx_RichTextCharacterStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextCharacterStyleDefinition *def = Object_wx_RichTextCharacterStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddCharacterStyle(def);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, AddListStyle)
@@ -83,11 +85,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, AddListStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, AddListStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextListStyleDefinition *def = Object_wx_RichTextListStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextListStyleDefinition *def = Object_wx_RichTextListStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddListStyle(def);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, AddParagraphStyle)
@@ -99,11 +102,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, AddParagraphStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, AddParagraphStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextParagraphStyleDefinition *def = Object_wx_RichTextParagraphStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextParagraphStyleDefinition *def = Object_wx_RichTextParagraphStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddParagraphStyle(def);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, AddStyle)
@@ -115,11 +119,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, AddStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, AddStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->AddStyle(def);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, DeleteStyles)
@@ -129,10 +134,11 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, DeleteStyles)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, DeleteStyles)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DeleteStyles();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, FindCharacterStyle)
@@ -144,11 +150,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, FindCharacterStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, FindCharacterStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextCharacterStyleDefinition *rtn = (wxRichTextCharacterStyleDefinition *)pThis->GetEntity()->FindCharacterStyle(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextCharacterStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextCharacterStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, FindListStyle)
@@ -160,11 +167,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, FindListStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, FindListStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextListStyleDefinition *rtn = (wxRichTextListStyleDefinition *)pThis->GetEntity()->FindListStyle(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextListStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextListStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, FindParagraphStyle)
@@ -176,11 +184,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, FindParagraphStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, FindParagraphStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextParagraphStyleDefinition *rtn = (wxRichTextParagraphStyleDefinition *)pThis->GetEntity()->FindParagraphStyle(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextParagraphStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextParagraphStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, FindStyle)
@@ -192,11 +201,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, FindStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, FindStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxRichTextStyleDefinition *rtn = (wxRichTextStyleDefinition *)pThis->GetEntity()->FindStyle(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetCharacterStyle)
@@ -208,11 +218,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetCharacterStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetCharacterStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxRichTextCharacterStyleDefinition *rtn = (wxRichTextCharacterStyleDefinition *)pThis->GetEntity()->GetCharacterStyle(n);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextCharacterStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextCharacterStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetCharacterStyleCount)
@@ -223,10 +234,11 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetCharacterStyleCount)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetCharacterStyleCount)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetCharacterStyleCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetDescription)
@@ -237,10 +249,11 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetDescription)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetDescription)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetDescription();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetListStyle)
@@ -252,11 +265,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetListStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetListStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxRichTextListStyleDefinition *rtn = (wxRichTextListStyleDefinition *)pThis->GetEntity()->GetListStyle(n);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextListStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextListStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetListStyleCount)
@@ -267,10 +281,11 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetListStyleCount)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetListStyleCount)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetListStyleCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetName)
@@ -281,10 +296,11 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetName)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetName)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetParagraphStyle)
@@ -296,11 +312,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetParagraphStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetParagraphStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxRichTextParagraphStyleDefinition *rtn = (wxRichTextParagraphStyleDefinition *)pThis->GetEntity()->GetParagraphStyle(n);
-	return ReturnValue(env, sig, args, Value(new Object_wx_RichTextParagraphStyleDefinition(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_RichTextParagraphStyleDefinition(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, GetParagraphStyleCount)
@@ -311,10 +328,11 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, GetParagraphStyleCount)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, GetParagraphStyleCount)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetParagraphStyleCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveCharacterStyle)
@@ -327,13 +345,14 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveCharacterStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, RemoveCharacterStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool deleteStyle = false;
-	if (args.IsValid(1)) deleteStyle = args.GetBoolean(1);
+	if (arg.IsValid(1)) deleteStyle = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->RemoveCharacterStyle(def, deleteStyle);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveListStyle)
@@ -346,13 +365,14 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveListStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, RemoveListStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool deleteStyle = false;
-	if (args.IsValid(1)) deleteStyle = args.GetBoolean(1);
+	if (arg.IsValid(1)) deleteStyle = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->RemoveListStyle(def, deleteStyle);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveParagraphStyle)
@@ -365,13 +385,14 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveParagraphStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, RemoveParagraphStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool deleteStyle = false;
-	if (args.IsValid(1)) deleteStyle = args.GetBoolean(1);
+	if (arg.IsValid(1)) deleteStyle = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->RemoveParagraphStyle(def, deleteStyle);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveStyle)
@@ -384,13 +405,14 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, RemoveStyle)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, RemoveStyle)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRichTextStyleDefinition *def = Object_wx_RichTextStyleDefinition::GetObject(arg, 0)->GetEntity();
 	bool deleteStyle = false;
-	if (args.IsValid(1)) deleteStyle = args.GetBoolean(1);
+	if (arg.IsValid(1)) deleteStyle = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->RemoveStyle(def, deleteStyle);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, SetDescription)
@@ -401,11 +423,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, SetDescription)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, SetDescription)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString descr = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString descr = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetDescription(descr);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_RichTextStyleSheet, SetName)
@@ -416,11 +439,12 @@ Gura_DeclareMethod(wx_RichTextStyleSheet, SetName)
 
 Gura_ImplementMethod(wx_RichTextStyleSheet, SetName)
 {
-	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_RichTextStyleSheet *pThis = Object_wx_RichTextStyleSheet::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -441,7 +465,7 @@ Object *Object_wx_RichTextStyleSheet::Clone() const
 String Object_wx_RichTextStyleSheet::ToString(bool exprFlag)
 {
 	String rtn("<wx.RichTextStyleSheet:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -484,7 +508,7 @@ Gura_ImplementUserInheritableClass(wx_RichTextStyleSheet)
 
 Gura_ImplementDescendantCreator(wx_RichTextStyleSheet)
 {
-	return new Object_wx_RichTextStyleSheet((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_RichTextStyleSheet((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
