@@ -11,17 +11,17 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_SizerItem: public wxSizerItem, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_SizerItem *_pObj;
 public:
-	inline wx_SizerItem(int width, int height, int proportion, int flag, int border, wxObject* userData) : wxSizerItem(width, height, proportion, flag, border, userData), _sig(NULL), _pObj(NULL) {}
-	inline wx_SizerItem(wxWindow* window, const wxSizerFlags& flags) : wxSizerItem(window, flags), _sig(NULL), _pObj(NULL) {}
-	inline wx_SizerItem(wxWindow* window, int proportion, int flag, int border, wxObject* userData) : wxSizerItem(window, proportion, flag, border, userData), _sig(NULL), _pObj(NULL) {}
-	inline wx_SizerItem(wxSizer* window, const wxSizerFlags& flags) : wxSizerItem(window, flags), _sig(NULL), _pObj(NULL) {}
-	inline wx_SizerItem(wxSizer* sizer, int proportion, int flag, int border, wxObject* userData) : wxSizerItem(sizer, proportion, flag, border, userData), _sig(NULL), _pObj(NULL) {}
+	inline wx_SizerItem(int width, int height, int proportion, int flag, int border, wxObject* userData) : wxSizerItem(width, height, proportion, flag, border, userData), _pObj(nullptr) {}
+	inline wx_SizerItem(wxWindow* window, const wxSizerFlags& flags) : wxSizerItem(window, flags), _pObj(nullptr) {}
+	inline wx_SizerItem(wxWindow* window, int proportion, int flag, int border, wxObject* userData) : wxSizerItem(window, proportion, flag, border, userData), _pObj(nullptr) {}
+	inline wx_SizerItem(wxSizer* window, const wxSizerFlags& flags) : wxSizerItem(window, flags), _pObj(nullptr) {}
+	inline wx_SizerItem(wxSizer* sizer, int proportion, int flag, int border, wxObject* userData) : wxSizerItem(sizer, proportion, flag, border, userData), _pObj(nullptr) {}
 	~wx_SizerItem();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_SizerItem *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_SizerItem *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -29,12 +29,12 @@ public:
 
 wx_SizerItem::~wx_SizerItem()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_SizerItem::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -55,23 +55,24 @@ Gura_DeclareFunction(SizerItem)
 
 Gura_ImplementFunction(SizerItem)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	int width = args.GetInt(0);
-	int height = args.GetInt(1);
-	int proportion = args.GetInt(2);
-	int flag = args.GetInt(3);
-	int border = args.GetInt(4);
-	wxObject *userData = Object_wx_Object::GetObject(args, 5)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
+	int height = arg.GetInt(1);
+	int proportion = arg.GetInt(2);
+	int flag = arg.GetInt(3);
+	int border = arg.GetInt(4);
+	wxObject *userData = Object_wx_Object::GetObject(arg, 5)->GetEntity();
 	wx_SizerItem *pEntity = new wx_SizerItem(width, height, proportion, flag, border, userData);
-	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SizerItem(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(SizerItem_1)
@@ -85,19 +86,20 @@ Gura_DeclareFunction(SizerItem_1)
 
 Gura_ImplementFunction(SizerItem_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxSizerFlags *flags = Object_wx_SizerFlags::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxSizerFlags *flags = Object_wx_SizerFlags::GetObject(arg, 1)->GetEntity();
 	wx_SizerItem *pEntity = new wx_SizerItem(window, *flags);
-	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SizerItem(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(SizerItem_2)
@@ -114,22 +116,23 @@ Gura_DeclareFunction(SizerItem_2)
 
 Gura_ImplementFunction(SizerItem_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	int proportion = args.GetInt(1);
-	int flag = args.GetInt(2);
-	int border = args.GetInt(3);
-	wxObject *userData = Object_wx_Object::GetObject(args, 4)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	int proportion = arg.GetInt(1);
+	int flag = arg.GetInt(2);
+	int border = arg.GetInt(3);
+	wxObject *userData = Object_wx_Object::GetObject(arg, 4)->GetEntity();
 	wx_SizerItem *pEntity = new wx_SizerItem(window, proportion, flag, border, userData);
-	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SizerItem(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(SizerItem_3)
@@ -143,19 +146,20 @@ Gura_DeclareFunction(SizerItem_3)
 
 Gura_ImplementFunction(SizerItem_3)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxSizer *window = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
-	wxSizerFlags *flags = Object_wx_SizerFlags::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxSizer *window = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
+	wxSizerFlags *flags = Object_wx_SizerFlags::GetObject(arg, 1)->GetEntity();
 	wx_SizerItem *pEntity = new wx_SizerItem(window, *flags);
-	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SizerItem(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(SizerItem_4)
@@ -172,22 +176,23 @@ Gura_DeclareFunction(SizerItem_4)
 
 Gura_ImplementFunction(SizerItem_4)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
-	int proportion = args.GetInt(1);
-	int flag = args.GetInt(2);
-	int border = args.GetInt(3);
-	wxObject *userData = Object_wx_Object::GetObject(args, 4)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
+	int proportion = arg.GetInt(1);
+	int flag = arg.GetInt(2);
+	int border = arg.GetInt(3);
+	wxObject *userData = Object_wx_Object::GetObject(arg, 4)->GetEntity();
 	wx_SizerItem *pEntity = new wx_SizerItem(sizer, proportion, flag, border, userData);
-	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SizerItem *pObj = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SizerItem(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_SizerItem, CalcMin)
@@ -198,10 +203,11 @@ Gura_DeclareMethod(wx_SizerItem, CalcMin)
 
 Gura_ImplementMethod(wx_SizerItem, CalcMin)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->CalcMin();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, DeleteWindows)
@@ -211,10 +217,11 @@ Gura_DeclareMethod(wx_SizerItem, DeleteWindows)
 
 Gura_ImplementMethod(wx_SizerItem, DeleteWindows)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DeleteWindows();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, DetachSizer)
@@ -224,10 +231,11 @@ Gura_DeclareMethod(wx_SizerItem, DetachSizer)
 
 Gura_ImplementMethod(wx_SizerItem, DetachSizer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->DetachSizer();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetBorder)
@@ -238,10 +246,11 @@ Gura_DeclareMethod(wx_SizerItem, GetBorder)
 
 Gura_ImplementMethod(wx_SizerItem, GetBorder)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetBorder();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetFlag)
@@ -252,10 +261,11 @@ Gura_DeclareMethod(wx_SizerItem, GetFlag)
 
 Gura_ImplementMethod(wx_SizerItem, GetFlag)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFlag();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetMinSize)
@@ -266,10 +276,11 @@ Gura_DeclareMethod(wx_SizerItem, GetMinSize)
 
 Gura_ImplementMethod(wx_SizerItem, GetMinSize)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetMinSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetPosition)
@@ -280,10 +291,11 @@ Gura_DeclareMethod(wx_SizerItem, GetPosition)
 
 Gura_ImplementMethod(wx_SizerItem, GetPosition)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetPosition();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetProportion)
@@ -294,10 +306,11 @@ Gura_DeclareMethod(wx_SizerItem, GetProportion)
 
 Gura_ImplementMethod(wx_SizerItem, GetProportion)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetProportion();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetRatio)
@@ -308,10 +321,11 @@ Gura_DeclareMethod(wx_SizerItem, GetRatio)
 
 Gura_ImplementMethod(wx_SizerItem, GetRatio)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	float rtn = pThis->GetEntity()->GetRatio();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetRect)
@@ -322,10 +336,11 @@ Gura_DeclareMethod(wx_SizerItem, GetRect)
 
 Gura_ImplementMethod(wx_SizerItem, GetRect)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxRect rtn = pThis->GetEntity()->GetRect();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Rect(new wxRect(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Rect(new wxRect(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetSize)
@@ -336,10 +351,11 @@ Gura_DeclareMethod(wx_SizerItem, GetSize)
 
 Gura_ImplementMethod(wx_SizerItem, GetSize)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSize rtn = pThis->GetEntity()->GetSize();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetSizer)
@@ -350,10 +366,11 @@ Gura_DeclareMethod(wx_SizerItem, GetSizer)
 
 Gura_ImplementMethod(wx_SizerItem, GetSizer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSizer *rtn = (wxSizer *)pThis->GetEntity()->GetSizer();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Sizer(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Sizer(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetSpacer)
@@ -364,10 +381,11 @@ Gura_DeclareMethod(wx_SizerItem, GetSpacer)
 
 Gura_ImplementMethod(wx_SizerItem, GetSpacer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxSize &rtn = pThis->GetEntity()->GetSpacer();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetUserData)
@@ -378,10 +396,11 @@ Gura_DeclareMethod(wx_SizerItem, GetUserData)
 
 Gura_ImplementMethod(wx_SizerItem, GetUserData)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxObject *rtn = (wxObject *)pThis->GetEntity()->GetUserData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Object(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Object(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, GetWindow)
@@ -392,10 +411,11 @@ Gura_DeclareMethod(wx_SizerItem, GetWindow)
 
 Gura_ImplementMethod(wx_SizerItem, GetWindow)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetWindow();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_SizerItem, IsSizer)
@@ -406,10 +426,11 @@ Gura_DeclareMethod(wx_SizerItem, IsSizer)
 
 Gura_ImplementMethod(wx_SizerItem, IsSizer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsSizer();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, IsShown)
@@ -420,10 +441,11 @@ Gura_DeclareMethod(wx_SizerItem, IsShown)
 
 Gura_ImplementMethod(wx_SizerItem, IsShown)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsShown();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, IsSpacer)
@@ -434,10 +456,11 @@ Gura_DeclareMethod(wx_SizerItem, IsSpacer)
 
 Gura_ImplementMethod(wx_SizerItem, IsSpacer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsSpacer();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, IsWindow)
@@ -448,10 +471,11 @@ Gura_DeclareMethod(wx_SizerItem, IsWindow)
 
 Gura_ImplementMethod(wx_SizerItem, IsWindow)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsWindow();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetBorder)
@@ -462,11 +486,12 @@ Gura_DeclareMethod(wx_SizerItem, SetBorder)
 
 Gura_ImplementMethod(wx_SizerItem, SetBorder)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int border = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int border = arg.GetInt(0);
 	pThis->GetEntity()->SetBorder(border);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetDimension)
@@ -478,12 +503,13 @@ Gura_DeclareMethod(wx_SizerItem, SetDimension)
 
 Gura_ImplementMethod(wx_SizerItem, SetDimension)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pos = Object_wx_Point::GetObject(args, 0)->GetEntity();
-	wxSize *size = Object_wx_Size::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pos = Object_wx_Point::GetObject(arg, 0)->GetEntity();
+	wxSize *size = Object_wx_Size::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->SetDimension(*pos, *size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetFlag)
@@ -494,11 +520,12 @@ Gura_DeclareMethod(wx_SizerItem, SetFlag)
 
 Gura_ImplementMethod(wx_SizerItem, SetFlag)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int flag = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int flag = arg.GetInt(0);
 	pThis->GetEntity()->SetFlag(flag);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetInitSize)
@@ -510,12 +537,13 @@ Gura_DeclareMethod(wx_SizerItem, SetInitSize)
 
 Gura_ImplementMethod(wx_SizerItem, SetInitSize)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
+	int y = arg.GetInt(1);
 	pThis->GetEntity()->SetInitSize(x, y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetProportion)
@@ -526,11 +554,12 @@ Gura_DeclareMethod(wx_SizerItem, SetProportion)
 
 Gura_ImplementMethod(wx_SizerItem, SetProportion)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int proportion = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int proportion = arg.GetInt(0);
 	pThis->GetEntity()->SetProportion(proportion);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetRatio)
@@ -542,12 +571,13 @@ Gura_DeclareMethod(wx_SizerItem, SetRatio)
 
 Gura_ImplementMethod(wx_SizerItem, SetRatio)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int width = args.GetInt(0);
-	int height = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int width = arg.GetInt(0);
+	int height = arg.GetInt(1);
 	pThis->GetEntity()->SetRatio(width, height);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetRatio_1)
@@ -558,11 +588,12 @@ Gura_DeclareMethod(wx_SizerItem, SetRatio_1)
 
 Gura_ImplementMethod(wx_SizerItem, SetRatio_1)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetRatio(*size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, SetRatio_2)
@@ -573,56 +604,60 @@ Gura_DeclareMethod(wx_SizerItem, SetRatio_2)
 
 Gura_ImplementMethod(wx_SizerItem, SetRatio_2)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	float ratio = args.GetFloat(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	float ratio = arg.GetFloat(0);
 	pThis->GetEntity()->SetRatio(ratio);
-	return Value::Null;
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_SizerItem, SetSizer)
+Gura_DeclareMethod(wx_SizerItem, AssignSizer)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "sizer", VTYPE_wx_Sizer, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_SizerItem, SetSizer)
+Gura_ImplementMethod(wx_SizerItem, AssignSizer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSizer *sizer = Object_wx_Sizer::GetObject(args, 0)->GetEntity();
-	pThis->GetEntity()->SetSizer(sizer);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSizer *sizer = Object_wx_Sizer::GetObject(arg, 0)->GetEntity();
+	pThis->GetEntity()->AssignSizer(sizer);
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_SizerItem, SetSpacer)
+Gura_DeclareMethod(wx_SizerItem, AssignSpacer)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "size", VTYPE_wx_Size, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_SizerItem, SetSpacer)
+Gura_ImplementMethod(wx_SizerItem, AssignSpacer)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
-	pThis->GetEntity()->SetSpacer(*size);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
+	pThis->GetEntity()->AssignSpacer(*size);
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_SizerItem, SetWindow)
+Gura_DeclareMethod(wx_SizerItem, AssignWindow)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "window", VTYPE_wx_Window, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_SizerItem, SetWindow)
+Gura_ImplementMethod(wx_SizerItem, AssignWindow)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	pThis->GetEntity()->SetWindow(window);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	pThis->GetEntity()->AssignWindow(window);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SizerItem, Show)
@@ -633,11 +668,12 @@ Gura_DeclareMethod(wx_SizerItem, Show)
 
 Gura_ImplementMethod(wx_SizerItem, Show)
 {
-	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool show = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SizerItem *pThis = Object_wx_SizerItem::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool show = arg.GetBoolean(0);
 	pThis->GetEntity()->Show(show);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -649,13 +685,13 @@ Object_wx_SizerItem::~Object_wx_SizerItem()
 
 Object *Object_wx_SizerItem::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_SizerItem::ToString(bool exprFlag)
 {
 	String rtn("<wx.SizerItem:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -702,15 +738,15 @@ Gura_ImplementUserInheritableClass(wx_SizerItem)
 	Gura_AssignMethod(wx_SizerItem, SetRatio);
 	Gura_AssignMethod(wx_SizerItem, SetRatio_1);
 	Gura_AssignMethod(wx_SizerItem, SetRatio_2);
-	Gura_AssignMethod(wx_SizerItem, SetSizer);
-	Gura_AssignMethod(wx_SizerItem, SetSpacer);
-	Gura_AssignMethod(wx_SizerItem, SetWindow);
+	Gura_AssignMethod(wx_SizerItem, AssignSizer);
+	Gura_AssignMethod(wx_SizerItem, AssignSpacer);
+	Gura_AssignMethod(wx_SizerItem, AssignWindow);
 	Gura_AssignMethod(wx_SizerItem, Show);
 }
 
 Gura_ImplementDescendantCreator(wx_SizerItem)
 {
-	return new Object_wx_SizerItem((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_SizerItem((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
