@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_SocketBase: public wxSocketBase, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_SocketBase *_pObj;
 public:
-	//inline wx_SocketBase() : wxSocketBase(), _sig(NULL), _pObj(NULL) {}
+	//inline wx_SocketBase() : wxSocketBase(), _pObj(nullptr) {}
 	~wx_SocketBase();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_SocketBase *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_SocketBase *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_SocketBase::~wx_SocketBase()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_SocketBase::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,21 +47,22 @@ Gura_DeclareFunction(SocketBaseEmpty)
 
 Gura_ImplementFunction(SocketBaseEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_SocketBase *pEntity = new wx_SocketBase();
-	Object_wx_SocketBase *pObj = Object_wx_SocketBase::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SocketBase *pObj = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SocketBase(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Close)
@@ -71,14 +72,15 @@ Gura_DeclareMethod(wx_SocketBase, Close)
 
 Gura_ImplementMethod(wx_SocketBase, Close)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Close();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Destroy)
@@ -89,14 +91,15 @@ Gura_DeclareMethod(wx_SocketBase, Destroy)
 
 Gura_ImplementMethod(wx_SocketBase, Destroy)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Destroy();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Discard)
@@ -107,14 +110,15 @@ Gura_DeclareMethod(wx_SocketBase, Discard)
 
 Gura_ImplementMethod(wx_SocketBase, Discard)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSocketBase &rtn = pThis->GetEntity()->Discard();
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Error)
@@ -125,10 +129,11 @@ Gura_DeclareMethod(wx_SocketBase, Error)
 
 Gura_ImplementMethod(wx_SocketBase, Error)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Error();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, GetClientData)
@@ -138,10 +143,11 @@ Gura_DeclareMethod(wx_SocketBase, GetClientData)
 
 Gura_ImplementMethod(wx_SocketBase, GetClientData)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetClientData();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, GetLocal)
@@ -153,11 +159,12 @@ Gura_DeclareMethod(wx_SocketBase, GetLocal)
 
 Gura_ImplementMethod(wx_SocketBase, GetLocal)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSockAddress *addr = Object_wx_SockAddress::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSockAddress *addr = Object_wx_SockAddress::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->GetLocal(*addr);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, GetFlags)
@@ -168,10 +175,11 @@ Gura_DeclareMethod(wx_SocketBase, GetFlags)
 
 Gura_ImplementMethod(wx_SocketBase, GetFlags)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSocketFlags rtn = pThis->GetEntity()->GetFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, GetPeer)
@@ -183,11 +191,12 @@ Gura_DeclareMethod(wx_SocketBase, GetPeer)
 
 Gura_ImplementMethod(wx_SocketBase, GetPeer)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSockAddress *addr = Object_wx_SockAddress::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSockAddress *addr = Object_wx_SockAddress::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->GetPeer(*addr);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, InterruptWait)
@@ -197,14 +206,15 @@ Gura_DeclareMethod(wx_SocketBase, InterruptWait)
 
 Gura_ImplementMethod(wx_SocketBase, InterruptWait)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->InterruptWait();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, IsConnected)
@@ -215,10 +225,11 @@ Gura_DeclareMethod(wx_SocketBase, IsConnected)
 
 Gura_ImplementMethod(wx_SocketBase, IsConnected)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsConnected();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, IsData)
@@ -229,10 +240,11 @@ Gura_DeclareMethod(wx_SocketBase, IsData)
 
 Gura_ImplementMethod(wx_SocketBase, IsData)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsData();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, IsDisconnected)
@@ -243,10 +255,11 @@ Gura_DeclareMethod(wx_SocketBase, IsDisconnected)
 
 Gura_ImplementMethod(wx_SocketBase, IsDisconnected)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsDisconnected();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, LastCount)
@@ -257,10 +270,11 @@ Gura_DeclareMethod(wx_SocketBase, LastCount)
 
 Gura_ImplementMethod(wx_SocketBase, LastCount)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxUint32 rtn = pThis->GetEntity()->LastCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, LastError)
@@ -271,14 +285,15 @@ Gura_DeclareMethod(wx_SocketBase, LastError)
 
 Gura_ImplementMethod(wx_SocketBase, LastError)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxSocketError rtn = pThis->GetEntity()->LastError();
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketError(new wxSocketError(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketError(new wxSocketError(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Notify)
@@ -291,15 +306,16 @@ Gura_DeclareMethod(wx_SocketBase, Notify)
 
 Gura_ImplementMethod(wx_SocketBase, Notify)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool notify = args.GetBoolean(0);
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool notify = arg.GetBoolean(0);
 	pThis->GetEntity()->Notify(notify);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, IsOk)
@@ -310,10 +326,11 @@ Gura_DeclareMethod(wx_SocketBase, IsOk)
 
 Gura_ImplementMethod(wx_SocketBase, IsOk)
 {
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOk();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SocketBase, RestoreState)
@@ -323,14 +340,15 @@ Gura_DeclareMethod(wx_SocketBase, RestoreState)
 
 Gura_ImplementMethod(wx_SocketBase, RestoreState)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->RestoreState();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SaveState)
@@ -340,14 +358,15 @@ Gura_DeclareMethod(wx_SocketBase, SaveState)
 
 Gura_ImplementMethod(wx_SocketBase, SaveState)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->SaveState();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SetClientData)
@@ -360,15 +379,16 @@ Gura_DeclareMethod(wx_SocketBase, SetClientData)
 
 Gura_ImplementMethod(wx_SocketBase, SetClientData)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int data = args.GetInt(0);
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int data = arg.GetInt(0);
 	pThis->GetEntity()->SetClientData(data);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SetEventHandler)
@@ -382,17 +402,18 @@ Gura_DeclareMethod(wx_SocketBase, SetEventHandler)
 
 Gura_ImplementMethod(wx_SocketBase, SetEventHandler)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxEvtHandler *handler = Object_wx_EvtHandler::GetObject(args, 0)->GetEntity();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxEvtHandler *handler = Object_wx_EvtHandler::GetObject(arg, 0)->GetEntity();
 	int id = -1;
-	if (args.IsValid(1)) id = args.GetInt(1);
+	if (arg.IsValid(1)) id = arg.GetInt(1);
 	pThis->GetEntity()->SetEventHandler(*handler, id);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SetFlags)
@@ -405,15 +426,16 @@ Gura_DeclareMethod(wx_SocketBase, SetFlags)
 
 Gura_ImplementMethod(wx_SocketBase, SetFlags)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSocketFlags flags = static_cast<wxSocketFlags>(args.GetInt(0));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSocketFlags flags = static_cast<wxSocketFlags>(arg.GetInt(0));
 	pThis->GetEntity()->SetFlags(flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SetLocal)
@@ -427,15 +449,16 @@ Gura_DeclareMethod(wx_SocketBase, SetLocal)
 
 Gura_ImplementMethod(wx_SocketBase, SetLocal)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIPV4address *local = Object_wx_IPV4address::GetObject(args, 0)->GetEntity();
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIPV4address *local = Object_wx_IPV4address::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->SetLocal(*local);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SetNotify)
@@ -448,15 +471,16 @@ Gura_DeclareMethod(wx_SocketBase, SetNotify)
 
 Gura_ImplementMethod(wx_SocketBase, SetNotify)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSocketEventFlags flags = static_cast<wxSocketEventFlags>(args.GetInt(0));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSocketEventFlags flags = static_cast<wxSocketEventFlags>(arg.GetInt(0));
 	pThis->GetEntity()->SetNotify(flags);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, SetTimeout)
@@ -469,15 +493,16 @@ Gura_DeclareMethod(wx_SocketBase, SetTimeout)
 
 Gura_ImplementMethod(wx_SocketBase, SetTimeout)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int seconds = args.GetInt(0);
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int seconds = arg.GetInt(0);
 	pThis->GetEntity()->SetTimeout(seconds);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Peek)
@@ -492,16 +517,17 @@ Gura_DeclareMethod(wx_SocketBase, Peek)
 
 Gura_ImplementMethod(wx_SocketBase, Peek)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	wxUint32 nbytes = static_cast<wxUint32>(args.GetULong(1));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	wxUint32 nbytes = static_cast<wxUint32>(arg.GetULong(1));
 	wxSocketBase &rtn = pThis->GetEntity()->Peek(buffer, nbytes);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Read)
@@ -516,16 +542,17 @@ Gura_DeclareMethod(wx_SocketBase, Read)
 
 Gura_ImplementMethod(wx_SocketBase, Read)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	wxUint32 nbytes = static_cast<wxUint32>(args.GetULong(1));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	wxUint32 nbytes = static_cast<wxUint32>(arg.GetULong(1));
 	wxSocketBase &rtn = pThis->GetEntity()->Read(buffer, nbytes);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, ReadMsg)
@@ -540,16 +567,17 @@ Gura_DeclareMethod(wx_SocketBase, ReadMsg)
 
 Gura_ImplementMethod(wx_SocketBase, ReadMsg)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	wxUint32 nbytes = static_cast<wxUint32>(args.GetULong(1));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	wxUint32 nbytes = static_cast<wxUint32>(arg.GetULong(1));
 	wxSocketBase &rtn = pThis->GetEntity()->ReadMsg(buffer, nbytes);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Unread)
@@ -564,16 +592,17 @@ Gura_DeclareMethod(wx_SocketBase, Unread)
 
 Gura_ImplementMethod(wx_SocketBase, Unread)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	wxUint32 nbytes = static_cast<wxUint32>(args.GetULong(1));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	wxUint32 nbytes = static_cast<wxUint32>(arg.GetULong(1));
 	wxSocketBase &rtn = pThis->GetEntity()->Unread(buffer, nbytes);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Wait)
@@ -588,18 +617,19 @@ Gura_DeclareMethod(wx_SocketBase, Wait)
 
 Gura_ImplementMethod(wx_SocketBase, Wait)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long seconds = -1;
-	if (args.IsValid(0)) seconds = args.GetLong(0);
+	if (arg.IsValid(0)) seconds = arg.GetLong(0);
 	long millisecond = 0;
-	if (args.IsValid(1)) millisecond = args.GetLong(1);
+	if (arg.IsValid(1)) millisecond = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->Wait(seconds, millisecond);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Wait_1)
@@ -614,18 +644,19 @@ Gura_DeclareMethod(wx_SocketBase, Wait_1)
 
 Gura_ImplementMethod(wx_SocketBase, Wait_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long seconds = -1;
-	if (args.IsValid(0)) seconds = args.GetLong(0);
+	if (arg.IsValid(0)) seconds = arg.GetLong(0);
 	long millisecond = 0;
-	if (args.IsValid(1)) millisecond = args.GetLong(1);
+	if (arg.IsValid(1)) millisecond = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->Wait(seconds, millisecond);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, WaitForRead)
@@ -640,18 +671,19 @@ Gura_DeclareMethod(wx_SocketBase, WaitForRead)
 
 Gura_ImplementMethod(wx_SocketBase, WaitForRead)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long seconds = -1;
-	if (args.IsValid(0)) seconds = args.GetLong(0);
+	if (arg.IsValid(0)) seconds = arg.GetLong(0);
 	long millisecond = 0;
-	if (args.IsValid(1)) millisecond = args.GetLong(1);
+	if (arg.IsValid(1)) millisecond = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->WaitForRead(seconds, millisecond);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, WaitForWrite)
@@ -666,18 +698,19 @@ Gura_DeclareMethod(wx_SocketBase, WaitForWrite)
 
 Gura_ImplementMethod(wx_SocketBase, WaitForWrite)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long seconds = -1;
-	if (args.IsValid(0)) seconds = args.GetLong(0);
+	if (arg.IsValid(0)) seconds = arg.GetLong(0);
 	long millisecond = 0;
-	if (args.IsValid(1)) millisecond = args.GetLong(1);
+	if (arg.IsValid(1)) millisecond = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->WaitForWrite(seconds, millisecond);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, Write)
@@ -692,16 +725,17 @@ Gura_DeclareMethod(wx_SocketBase, Write)
 
 Gura_ImplementMethod(wx_SocketBase, Write)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	wxUint32 nbytes = static_cast<wxUint32>(args.GetULong(1));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	wxUint32 nbytes = static_cast<wxUint32>(arg.GetULong(1));
 	wxSocketBase &rtn = pThis->GetEntity()->Write(buffer, nbytes);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SocketBase, WriteMsg)
@@ -716,16 +750,17 @@ Gura_DeclareMethod(wx_SocketBase, WriteMsg)
 
 Gura_ImplementMethod(wx_SocketBase, WriteMsg)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	wxUint32 nbytes = static_cast<wxUint32>(args.GetULong(1));
+	Object_wx_SocketBase *pThis = Object_wx_SocketBase::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	wxUint32 nbytes = static_cast<wxUint32>(arg.GetULong(1));
 	wxSocketBase &rtn = pThis->GetEntity()->WriteMsg(buffer, nbytes);
-	return ReturnValue(env, sig, args, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_SocketBase(new wxSocketBase(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -737,13 +772,13 @@ Object_wx_SocketBase::~Object_wx_SocketBase()
 
 Object *Object_wx_SocketBase::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_SocketBase::ToString(bool exprFlag)
 {
 	String rtn("<wx.SocketBase:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -797,7 +832,7 @@ Gura_ImplementUserInheritableClass(wx_SocketBase)
 
 Gura_ImplementDescendantCreator(wx_SocketBase)
 {
-	return new Object_wx_SocketBase((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_SocketBase((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
