@@ -15,17 +15,17 @@ Gura_DeclarePrivUserSymbol(OnSashPositionChange);
 //----------------------------------------------------------------------------
 class wx_SplitterWindow: public wxSplitterWindow, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_SplitterWindow *_pObj;
 public:
-	inline wx_SplitterWindow() : wxSplitterWindow(), _sig(NULL), _pObj(NULL) {}
-	inline wx_SplitterWindow(wxWindow* parent, wxWindowID id, const wxPoint& point, const wxSize& size, long style, const wxString& name) : wxSplitterWindow(parent, id, point, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_SplitterWindow() : wxSplitterWindow(), _pObj(nullptr) {}
+	inline wx_SplitterWindow(wxWindow* parent, wxWindowID id, const wxPoint& point, const wxSize& size, long style, const wxString& name) : wxSplitterWindow(parent, id, point, size, style, name), _pObj(nullptr) {}
 	//virtual void OnDoubleClickSash(int x, int y);
 	//virtual void OnUnsplit(wxWindow* removed);
 	//virtual bool OnSashPositionChange(int newSashPosition);
 	~wx_SplitterWindow();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_SplitterWindow *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_SplitterWindow *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -33,12 +33,12 @@ public:
 
 wx_SplitterWindow::~wx_SplitterWindow()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_SplitterWindow::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -53,17 +53,18 @@ Gura_DeclareFunction(SplitterWindowEmpty)
 
 Gura_ImplementFunction(SplitterWindowEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_SplitterWindow *pEntity = new wx_SplitterWindow();
-	Object_wx_SplitterWindow *pObj = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SplitterWindow *pObj = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SplitterWindow(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(SplitterWindow)
@@ -81,28 +82,29 @@ Gura_DeclareFunction(SplitterWindow)
 
 Gura_ImplementFunction(SplitterWindow)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *point = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) point = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) point = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = wxSP_3D;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxT("splitterWindow");
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	wx_SplitterWindow *pEntity = new wx_SplitterWindow(parent, id, *point, *size, style, name);
-	Object_wx_SplitterWindow *pObj = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_SplitterWindow *pObj = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_SplitterWindow(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, Create)
@@ -119,20 +121,21 @@ Gura_DeclareMethod(wx_SplitterWindow, Create)
 
 Gura_ImplementMethod(wx_SplitterWindow, Create)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *point = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) point = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) point = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = wxSP_3D;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxT("splitterWindow");
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	bool rtn = pThis->GetEntity()->Create(parent, id, *point, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, GetMinimumPaneSize)
@@ -143,10 +146,11 @@ Gura_DeclareMethod(wx_SplitterWindow, GetMinimumPaneSize)
 
 Gura_ImplementMethod(wx_SplitterWindow, GetMinimumPaneSize)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMinimumPaneSize();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, GetSashGravity)
@@ -157,10 +161,11 @@ Gura_DeclareMethod(wx_SplitterWindow, GetSashGravity)
 
 Gura_ImplementMethod(wx_SplitterWindow, GetSashGravity)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	double rtn = pThis->GetEntity()->GetSashGravity();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, GetSashPosition)
@@ -171,10 +176,11 @@ Gura_DeclareMethod(wx_SplitterWindow, GetSashPosition)
 
 Gura_ImplementMethod(wx_SplitterWindow, GetSashPosition)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSashPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, GetSplitMode)
@@ -185,10 +191,11 @@ Gura_DeclareMethod(wx_SplitterWindow, GetSplitMode)
 
 Gura_ImplementMethod(wx_SplitterWindow, GetSplitMode)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSplitMode();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, GetWindow1)
@@ -199,10 +206,11 @@ Gura_DeclareMethod(wx_SplitterWindow, GetWindow1)
 
 Gura_ImplementMethod(wx_SplitterWindow, GetWindow1)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetWindow1();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, GetWindow2)
@@ -213,10 +221,11 @@ Gura_DeclareMethod(wx_SplitterWindow, GetWindow2)
 
 Gura_ImplementMethod(wx_SplitterWindow, GetWindow2)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetWindow2();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, Initialize)
@@ -227,11 +236,12 @@ Gura_DeclareMethod(wx_SplitterWindow, Initialize)
 
 Gura_ImplementMethod(wx_SplitterWindow, Initialize)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Initialize(window);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, IsSplit)
@@ -242,10 +252,11 @@ Gura_DeclareMethod(wx_SplitterWindow, IsSplit)
 
 Gura_ImplementMethod(wx_SplitterWindow, IsSplit)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsSplit();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, OnDoubleClickSash)
@@ -257,12 +268,13 @@ Gura_DeclareMethod(wx_SplitterWindow, OnDoubleClickSash)
 
 Gura_ImplementMethod(wx_SplitterWindow, OnDoubleClickSash)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int x = args.GetInt(0);
-	int y = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int x = arg.GetInt(0);
+	int y = arg.GetInt(1);
 	pThis->GetEntity()->OnDoubleClickSash(x, y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, OnUnsplit)
@@ -273,11 +285,12 @@ Gura_DeclareMethod(wx_SplitterWindow, OnUnsplit)
 
 Gura_ImplementMethod(wx_SplitterWindow, OnUnsplit)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *removed = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *removed = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->OnUnsplit(removed);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, OnSashPositionChange)
@@ -289,11 +302,12 @@ Gura_DeclareMethod(wx_SplitterWindow, OnSashPositionChange)
 
 Gura_ImplementMethod(wx_SplitterWindow, OnSashPositionChange)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int newSashPosition = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int newSashPosition = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->OnSashPositionChange(newSashPosition);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, ReplaceWindow)
@@ -306,12 +320,13 @@ Gura_DeclareMethod(wx_SplitterWindow, ReplaceWindow)
 
 Gura_ImplementMethod(wx_SplitterWindow, ReplaceWindow)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *winOld = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindow *winNew = Object_wx_Window::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *winOld = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindow *winNew = Object_wx_Window::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->ReplaceWindow(winOld, winNew);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SetSashGravity)
@@ -322,11 +337,12 @@ Gura_DeclareMethod(wx_SplitterWindow, SetSashGravity)
 
 Gura_ImplementMethod(wx_SplitterWindow, SetSashGravity)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	double gravity = args.GetDouble(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	double gravity = arg.GetDouble(0);
 	pThis->GetEntity()->SetSashGravity(gravity);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SetSashPosition)
@@ -338,13 +354,14 @@ Gura_DeclareMethod(wx_SplitterWindow, SetSashPosition)
 
 Gura_ImplementMethod(wx_SplitterWindow, SetSashPosition)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int position = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int position = arg.GetInt(0);
 	bool redraw = true;
-	if (args.IsValid(1)) redraw = args.GetBoolean(1);
+	if (arg.IsValid(1)) redraw = arg.GetBoolean(1);
 	pThis->GetEntity()->SetSashPosition(position, redraw);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SetSashSize)
@@ -355,11 +372,12 @@ Gura_DeclareMethod(wx_SplitterWindow, SetSashSize)
 
 Gura_ImplementMethod(wx_SplitterWindow, SetSashSize)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int size = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int size = arg.GetInt(0);
 	pThis->GetEntity()->SetSashSize(size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SetMinimumPaneSize)
@@ -370,11 +388,12 @@ Gura_DeclareMethod(wx_SplitterWindow, SetMinimumPaneSize)
 
 Gura_ImplementMethod(wx_SplitterWindow, SetMinimumPaneSize)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int paneSize = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int paneSize = arg.GetInt(0);
 	pThis->GetEntity()->SetMinimumPaneSize(paneSize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SetSplitMode)
@@ -385,11 +404,12 @@ Gura_DeclareMethod(wx_SplitterWindow, SetSplitMode)
 
 Gura_ImplementMethod(wx_SplitterWindow, SetSplitMode)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int mode = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int mode = arg.GetInt(0);
 	pThis->GetEntity()->SetSplitMode(mode);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SplitHorizontally)
@@ -403,14 +423,15 @@ Gura_DeclareMethod(wx_SplitterWindow, SplitHorizontally)
 
 Gura_ImplementMethod(wx_SplitterWindow, SplitHorizontally)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window1 = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindow *window2 = Object_wx_Window::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window1 = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindow *window2 = Object_wx_Window::GetObject(arg, 1)->GetEntity();
 	int sashPosition = 0;
-	if (args.IsValid(2)) sashPosition = args.GetInt(2);
+	if (arg.IsValid(2)) sashPosition = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->SplitHorizontally(window1, window2, sashPosition);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, SplitVertically)
@@ -424,14 +445,15 @@ Gura_DeclareMethod(wx_SplitterWindow, SplitVertically)
 
 Gura_ImplementMethod(wx_SplitterWindow, SplitVertically)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *window1 = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindow *window2 = Object_wx_Window::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *window1 = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindow *window2 = Object_wx_Window::GetObject(arg, 1)->GetEntity();
 	int sashPosition = 0;
-	if (args.IsValid(2)) sashPosition = args.GetInt(2);
+	if (arg.IsValid(2)) sashPosition = arg.GetInt(2);
 	bool rtn = pThis->GetEntity()->SplitVertically(window1, window2, sashPosition);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, Unsplit)
@@ -443,12 +465,13 @@ Gura_DeclareMethod(wx_SplitterWindow, Unsplit)
 
 Gura_ImplementMethod(wx_SplitterWindow, Unsplit)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *toRemove = (wxWindow *)(NULL);
-	if (args.IsValid(0)) toRemove = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *toRemove = (wxWindow *)(nullptr);
+	if (arg.IsValid(0)) toRemove = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Unsplit(toRemove);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_SplitterWindow, UpdateSize)
@@ -458,10 +481,11 @@ Gura_DeclareMethod(wx_SplitterWindow, UpdateSize)
 
 Gura_ImplementMethod(wx_SplitterWindow, UpdateSize)
 {
-	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_SplitterWindow *pThis = Object_wx_SplitterWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->UpdateSize();
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -473,13 +497,13 @@ Object_wx_SplitterWindow::~Object_wx_SplitterWindow()
 
 Object *Object_wx_SplitterWindow::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_SplitterWindow::ToString(bool exprFlag)
 {
 	String rtn("<wx.SplitterWindow:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -525,7 +549,7 @@ Gura_ImplementUserInheritableClass(wx_SplitterWindow)
 
 Gura_ImplementDescendantCreator(wx_SplitterWindow)
 {
-	return new Object_wx_SplitterWindow((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_SplitterWindow((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
