@@ -11,16 +11,16 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_StreamBuffer: public wxStreamBuffer, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_StreamBuffer *_pObj;
 public:
-	inline wx_StreamBuffer(wxStreamBase& stream, BufMode mode) : wxStreamBuffer(stream, mode), _sig(NULL), _pObj(NULL) {}
-	inline wx_StreamBuffer(BufMode mode) : wxStreamBuffer(mode), _sig(NULL), _pObj(NULL) {}
-	inline wx_StreamBuffer(const wxStreamBuffer& buffer) : wxStreamBuffer(buffer), _sig(NULL), _pObj(NULL) {}
-	//inline wx_StreamBuffer() : wxStreamBuffer(), _sig(NULL), _pObj(NULL) {}
+	inline wx_StreamBuffer(wxStreamBase& stream, BufMode mode) : wxStreamBuffer(stream, mode), _pObj(nullptr) {}
+	inline wx_StreamBuffer(BufMode mode) : wxStreamBuffer(mode), _pObj(nullptr) {}
+	inline wx_StreamBuffer(const wxStreamBuffer& buffer) : wxStreamBuffer(buffer), _pObj(nullptr) {}
+	//inline wx_StreamBuffer() : wxStreamBuffer(), _pObj(nullptr) {}
 	~wx_StreamBuffer();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_StreamBuffer *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_StreamBuffer *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -28,12 +28,12 @@ public:
 
 wx_StreamBuffer::~wx_StreamBuffer()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_StreamBuffer::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -50,19 +50,20 @@ Gura_DeclareFunction(StreamBuffer)
 
 Gura_ImplementFunction(StreamBuffer)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxStreamBase *stream = Object_wx_StreamBase::GetObject(args, 0)->GetEntity();
-	wxStreamBuffer::BufMode mode = static_cast<wxStreamBuffer::BufMode>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxStreamBase *stream = Object_wx_StreamBase::GetObject(arg, 0)->GetEntity();
+	wxStreamBuffer::BufMode mode = static_cast<wxStreamBuffer::BufMode>(arg.GetInt(1));
 	wx_StreamBuffer *pEntity = new wx_StreamBuffer(*stream, mode);
-	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_StreamBuffer(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(StreamBuffer_1)
@@ -75,18 +76,19 @@ Gura_DeclareFunction(StreamBuffer_1)
 
 Gura_ImplementFunction(StreamBuffer_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxStreamBuffer::BufMode mode = static_cast<wxStreamBuffer::BufMode>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxStreamBuffer::BufMode mode = static_cast<wxStreamBuffer::BufMode>(arg.GetInt(0));
 	wx_StreamBuffer *pEntity = new wx_StreamBuffer(mode);
-	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_StreamBuffer(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(StreamBuffer_2)
@@ -99,18 +101,19 @@ Gura_DeclareFunction(StreamBuffer_2)
 
 Gura_ImplementFunction(StreamBuffer_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxStreamBuffer *buffer = Object_wx_StreamBuffer::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxStreamBuffer *buffer = Object_wx_StreamBuffer::GetObject(arg, 0)->GetEntity();
 	wx_StreamBuffer *pEntity = new wx_StreamBuffer(*buffer);
-	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_StreamBuffer(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(StreamBufferEmpty)
@@ -124,21 +127,22 @@ Gura_DeclareFunction(StreamBufferEmpty)
 
 Gura_ImplementFunction(StreamBufferEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_StreamBuffer *pEntity = new wx_StreamBuffer();
-	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_StreamBuffer *pObj = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_StreamBuffer(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Read)
@@ -153,16 +157,17 @@ Gura_DeclareMethod(wx_StreamBuffer, Read)
 
 Gura_ImplementMethod(wx_StreamBuffer, Read)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	size_t size = args.GetSizeT(1);
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	size_t size = arg.GetSizeT(1);
 	size_t rtn = pThis->GetEntity()->Read(buffer, size);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Read_1)
@@ -174,11 +179,12 @@ Gura_DeclareMethod(wx_StreamBuffer, Read_1)
 
 Gura_ImplementMethod(wx_StreamBuffer, Read_1)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxStreamBuffer *buffer = Object_wx_StreamBuffer::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxStreamBuffer *buffer = Object_wx_StreamBuffer::GetObject(arg, 0)->GetEntity();
 	size_t rtn = pThis->GetEntity()->Read(buffer);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Write)
@@ -193,16 +199,17 @@ Gura_DeclareMethod(wx_StreamBuffer, Write)
 
 Gura_ImplementMethod(wx_StreamBuffer, Write)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int buffer = args.GetInt(0);
-	size_t size = args.GetSizeT(1);
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int buffer = arg.GetInt(0);
+	size_t size = arg.GetSizeT(1);
 	size_t rtn = pThis->GetEntity()->Write(buffer, size);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Write_1)
@@ -214,11 +221,12 @@ Gura_DeclareMethod(wx_StreamBuffer, Write_1)
 
 Gura_ImplementMethod(wx_StreamBuffer, Write_1)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxStreamBuffer *buffer = Object_wx_StreamBuffer::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxStreamBuffer *buffer = Object_wx_StreamBuffer::GetObject(arg, 0)->GetEntity();
 	size_t rtn = pThis->GetEntity()->Write(buffer);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetChar)
@@ -229,10 +237,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetChar)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetChar)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	char rtn = pThis->GetEntity()->GetChar();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, PutChar)
@@ -243,11 +252,12 @@ Gura_DeclareMethod(wx_StreamBuffer, PutChar)
 
 Gura_ImplementMethod(wx_StreamBuffer, PutChar)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char c = args.GetChar(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char c = arg.GetChar(0);
 	pThis->GetEntity()->PutChar(c);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Tell)
@@ -258,10 +268,11 @@ Gura_DeclareMethod(wx_StreamBuffer, Tell)
 
 Gura_ImplementMethod(wx_StreamBuffer, Tell)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	off_t rtn = pThis->GetEntity()->Tell();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Seek)
@@ -274,12 +285,13 @@ Gura_DeclareMethod(wx_StreamBuffer, Seek)
 
 Gura_ImplementMethod(wx_StreamBuffer, Seek)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	off_t pos = static_cast<off_t>(args.GetLong(0));
-	wxSeekMode mode = static_cast<wxSeekMode>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	off_t pos = static_cast<off_t>(arg.GetLong(0));
+	wxSeekMode mode = static_cast<wxSeekMode>(arg.GetInt(1));
 	off_t rtn = pThis->GetEntity()->Seek(pos, mode);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, ResetBuffer)
@@ -289,10 +301,11 @@ Gura_DeclareMethod(wx_StreamBuffer, ResetBuffer)
 
 Gura_ImplementMethod(wx_StreamBuffer, ResetBuffer)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ResetBuffer();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, SetBufferIO)
@@ -306,16 +319,17 @@ Gura_DeclareMethod(wx_StreamBuffer, SetBufferIO)
 
 Gura_ImplementMethod(wx_StreamBuffer, SetBufferIO)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char buffer_start = args.GetChar(0);
-	char buffer_end = args.GetChar(1);
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char buffer_start = arg.GetChar(0);
+	char buffer_end = arg.GetChar(1);
 	pThis->GetEntity()->SetBufferIO(buffer_start, buffer_end);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, SetBufferIO_1)
@@ -326,11 +340,12 @@ Gura_DeclareMethod(wx_StreamBuffer, SetBufferIO_1)
 
 Gura_ImplementMethod(wx_StreamBuffer, SetBufferIO_1)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t bufsize = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t bufsize = arg.GetSizeT(0);
 	pThis->GetEntity()->SetBufferIO(bufsize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetBufferStart)
@@ -340,10 +355,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetBufferStart)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetBufferStart)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetBufferStart();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetBufferEnd)
@@ -353,10 +369,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetBufferEnd)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetBufferEnd)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetBufferEnd();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetBufferPos)
@@ -366,10 +383,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetBufferPos)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetBufferPos)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetBufferPos();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetIntPosition)
@@ -380,10 +398,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetIntPosition)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetIntPosition)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	off_t rtn = pThis->GetEntity()->GetIntPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, SetIntPosition)
@@ -394,11 +413,12 @@ Gura_DeclareMethod(wx_StreamBuffer, SetIntPosition)
 
 Gura_ImplementMethod(wx_StreamBuffer, SetIntPosition)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pos = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pos = arg.GetSizeT(0);
 	pThis->GetEntity()->SetIntPosition(pos);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetLastAccess)
@@ -409,10 +429,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetLastAccess)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetLastAccess)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetLastAccess();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Fixed)
@@ -423,11 +444,12 @@ Gura_DeclareMethod(wx_StreamBuffer, Fixed)
 
 Gura_ImplementMethod(wx_StreamBuffer, Fixed)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool fixed = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool fixed = arg.GetBoolean(0);
 	pThis->GetEntity()->Fixed(fixed);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, Flushable)
@@ -438,11 +460,12 @@ Gura_DeclareMethod(wx_StreamBuffer, Flushable)
 
 Gura_ImplementMethod(wx_StreamBuffer, Flushable)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool flushable = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool flushable = arg.GetBoolean(0);
 	pThis->GetEntity()->Flushable(flushable);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, FlushBuffer)
@@ -453,10 +476,11 @@ Gura_DeclareMethod(wx_StreamBuffer, FlushBuffer)
 
 Gura_ImplementMethod(wx_StreamBuffer, FlushBuffer)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->FlushBuffer();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, FillBuffer)
@@ -467,10 +491,11 @@ Gura_DeclareMethod(wx_StreamBuffer, FillBuffer)
 
 Gura_ImplementMethod(wx_StreamBuffer, FillBuffer)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->FillBuffer();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StreamBuffer, GetDataLeft)
@@ -481,10 +506,11 @@ Gura_DeclareMethod(wx_StreamBuffer, GetDataLeft)
 
 Gura_ImplementMethod(wx_StreamBuffer, GetDataLeft)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetDataLeft();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 #if 0
@@ -496,10 +522,11 @@ Gura_DeclareMethod(wx_StreamBuffer, Stream)
 
 Gura_ImplementMethod(wx_StreamBuffer, Stream)
 {
-	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StreamBuffer *pThis = Object_wx_StreamBuffer::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxStreamBase *rtn = (wxStreamBase *)pThis->GetEntity()->Stream();
-	return ReturnValue(env, sig, args, Value(new Object_wx_StreamBase(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_StreamBase(rtn, nullptr, OwnerFalse)));
 }
 #endif
 
@@ -508,20 +535,20 @@ Gura_ImplementMethod(wx_StreamBuffer, Stream)
 //----------------------------------------------------------------------------
 Object_wx_StreamBuffer::~Object_wx_StreamBuffer()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_StreamBuffer::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_StreamBuffer::ToString(bool exprFlag)
 {
 	String rtn("<wx.StreamBuffer:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -567,7 +594,7 @@ Gura_ImplementUserInheritableClass(wx_StreamBuffer)
 
 Gura_ImplementDescendantCreator(wx_StreamBuffer)
 {
-	return new Object_wx_StreamBuffer((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_StreamBuffer((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
