@@ -10,13 +10,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_StyledTextEvent: public wxStyledTextEvent, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_StyledTextEvent *_pObj;
 public:
-	inline wx_StyledTextEvent(WXTYPE commandType, int id) : wxStyledTextEvent(commandType, id), _sig(NULL), _pObj(NULL) {}
+	inline wx_StyledTextEvent(WXTYPE commandType, int id) : wxStyledTextEvent(commandType, id), _pObj(nullptr) {}
 	~wx_StyledTextEvent();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_StyledTextEvent *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_StyledTextEvent *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -24,12 +24,12 @@ public:
 
 wx_StyledTextEvent::~wx_StyledTextEvent()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_StyledTextEvent::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,21 +46,22 @@ Gura_DeclareFunction(StyledTextEvent)
 
 Gura_ImplementFunction(StyledTextEvent)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	WXTYPE commandType = 0;
-	if (args.IsValid(0)) commandType = static_cast<WXTYPE>(args.GetInt(0));
+	if (arg.IsValid(0)) commandType = static_cast<WXTYPE>(arg.GetInt(0));
 	int id = 0;
-	if (args.IsValid(1)) id = args.GetInt(1);
+	if (arg.IsValid(1)) id = arg.GetInt(1);
 	wx_StyledTextEvent *pEntity = new wx_StyledTextEvent(commandType, id);
-	Object_wx_StyledTextEvent *pObj = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_StyledTextEvent *pObj = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_StyledTextEvent(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 //----------------------------------------------------------------------------
@@ -74,11 +75,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetPosition)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetPosition)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pos = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pos = arg.GetInt(0);
 	pThis->GetEntity()->SetPosition(pos);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetKey)
@@ -89,11 +91,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetKey)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetKey)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int k = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int k = arg.GetInt(0);
 	pThis->GetEntity()->SetKey(k);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetModifiers)
@@ -104,11 +107,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetModifiers)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetModifiers)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int m = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int m = arg.GetInt(0);
 	pThis->GetEntity()->SetModifiers(m);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetModificationType)
@@ -119,11 +123,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetModificationType)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetModificationType)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int t = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int t = arg.GetInt(0);
 	pThis->GetEntity()->SetModificationType(t);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetText)
@@ -134,11 +139,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetText)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetText)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString t = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString t = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetText(t);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetLength)
@@ -149,11 +155,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetLength)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetLength)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int len = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int len = arg.GetInt(0);
 	pThis->GetEntity()->SetLength(len);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetLinesAdded)
@@ -164,11 +171,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetLinesAdded)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetLinesAdded)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int num = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int num = arg.GetInt(0);
 	pThis->GetEntity()->SetLinesAdded(num);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetLine)
@@ -179,11 +187,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetLine)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetLine)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetLine(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetFoldLevelNow)
@@ -194,11 +203,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetFoldLevelNow)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetFoldLevelNow)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetFoldLevelNow(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetFoldLevelPrev)
@@ -209,11 +219,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetFoldLevelPrev)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetFoldLevelPrev)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetFoldLevelPrev(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetMargin)
@@ -224,11 +235,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetMargin)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetMargin)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetMargin(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetMessage)
@@ -239,11 +251,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetMessage)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetMessage)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetMessage(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetWParam)
@@ -254,11 +267,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetWParam)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetWParam)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetWParam(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetLParam)
@@ -269,11 +283,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetLParam)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetLParam)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetLParam(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetListType)
@@ -284,11 +299,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetListType)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetListType)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetListType(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetX)
@@ -299,11 +315,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetX)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetX)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetX(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetY)
@@ -314,11 +331,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetY)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetY)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetY(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetToken)
@@ -329,11 +347,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetToken)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetToken)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetToken(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetAnnotationLinesAdded)
@@ -344,11 +363,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetAnnotationLinesAdded)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetAnnotationLinesAdded)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetAnnotationLinesAdded(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetUpdated)
@@ -359,11 +379,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetUpdated)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetUpdated)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int val = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int val = arg.GetInt(0);
 	pThis->GetEntity()->SetUpdated(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetDragText)
@@ -374,11 +395,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetDragText)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetDragText)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString val = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString val = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetDragText(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetDragFlags)
@@ -389,11 +411,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetDragFlags)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetDragFlags)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int flags = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int flags = arg.GetInt(0);
 	pThis->GetEntity()->SetDragFlags(flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, SetDragResult)
@@ -404,11 +427,12 @@ Gura_DeclareMethod(wx_StyledTextEvent, SetDragResult)
 
 Gura_ImplementMethod(wx_StyledTextEvent, SetDragResult)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDragResult val = static_cast<wxDragResult>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDragResult val = static_cast<wxDragResult>(arg.GetInt(0));
 	pThis->GetEntity()->SetDragResult(val);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetPosition)
@@ -418,10 +442,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetPosition)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetPosition)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetPosition();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetKey)
@@ -431,10 +456,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetKey)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetKey)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetKey();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetModifiers)
@@ -444,10 +470,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetModifiers)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetModifiers)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetModifiers();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetModificationType)
@@ -457,10 +484,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetModificationType)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetModificationType)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetModificationType();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetText)
@@ -470,10 +498,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetText)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetText)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetLength)
@@ -483,10 +512,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetLength)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetLength)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLength();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetLinesAdded)
@@ -496,10 +526,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetLinesAdded)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetLinesAdded)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLinesAdded();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetLine)
@@ -509,10 +540,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetLine)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetLine)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLine();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetFoldLevelNow)
@@ -522,10 +554,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetFoldLevelNow)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetFoldLevelNow)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFoldLevelNow();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetFoldLevelPrev)
@@ -535,10 +568,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetFoldLevelPrev)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetFoldLevelPrev)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFoldLevelPrev();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetMargin)
@@ -548,10 +582,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetMargin)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetMargin)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMargin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetMessage)
@@ -561,10 +596,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetMessage)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetMessage)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMessage();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetWParam)
@@ -574,10 +610,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetWParam)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetWParam)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWParam();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetLParam)
@@ -587,10 +624,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetLParam)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetLParam)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLParam();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetListType)
@@ -600,10 +638,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetListType)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetListType)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetListType();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetX)
@@ -613,10 +652,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetX)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetX)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetX();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetY)
@@ -626,10 +666,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetY)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetY)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetY();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetToken)
@@ -639,10 +680,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetToken)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetToken)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetToken();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetAnnotationsLinesAdded)
@@ -652,10 +694,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetAnnotationsLinesAdded)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetAnnotationsLinesAdded)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetAnnotationsLinesAdded();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetUpdated)
@@ -665,10 +708,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetUpdated)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetUpdated)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetUpdated();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetDragText)
@@ -678,10 +722,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetDragText)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetDragText)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetDragText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetDragFlags)
@@ -691,10 +736,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetDragFlags)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetDragFlags)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetDragFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetDragResult)
@@ -704,10 +750,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetDragResult)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetDragResult)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDragResult rtn = pThis->GetEntity()->GetDragResult();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetShift)
@@ -717,10 +764,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetShift)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetShift)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetShift();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetControl)
@@ -730,10 +778,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetControl)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetControl)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetControl();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_StyledTextEvent, GetAlt)
@@ -743,10 +792,11 @@ Gura_DeclareMethod(wx_StyledTextEvent, GetAlt)
 
 Gura_ImplementMethod(wx_StyledTextEvent, GetAlt)
 {
-	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_StyledTextEvent *pThis = Object_wx_StyledTextEvent::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetAlt();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -758,13 +808,13 @@ Object_wx_StyledTextEvent::~Object_wx_StyledTextEvent()
 
 Object *Object_wx_StyledTextEvent::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_StyledTextEvent::ToString(bool exprFlag)
 {
 	String rtn("<wx.StyledTextEvent:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -833,7 +883,7 @@ Gura_ImplementUserInheritableClass(wx_StyledTextEvent)
 
 Gura_ImplementDescendantCreator(wx_StyledTextEvent)
 {
-	return new Object_wx_StyledTextEvent((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_StyledTextEvent((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
