@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_TarEntry: public wxTarEntry, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_TarEntry *_pObj;
 public:
-	inline wx_TarEntry(const wxString& name, const wxDateTime& dt, wxFileOffset size) : wxTarEntry(name, dt, size), _sig(NULL), _pObj(NULL) {}
-	inline wx_TarEntry(const wxTarEntry& entry) : wxTarEntry(entry), _sig(NULL), _pObj(NULL) {}
+	inline wx_TarEntry(const wxString& name, const wxDateTime& dt, wxFileOffset size) : wxTarEntry(name, dt, size), _pObj(nullptr) {}
+	inline wx_TarEntry(const wxTarEntry& entry) : wxTarEntry(entry), _pObj(nullptr) {}
 	~wx_TarEntry();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_TarEntry *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_TarEntry *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_TarEntry::~wx_TarEntry()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_TarEntry::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,23 +49,24 @@ Gura_DeclareFunction(TarEntry)
 
 Gura_ImplementFunction(TarEntry)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxString name = wxEmptyString;
-	if (args.IsValid(0)) name = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) name = wxString::FromUTF8(arg.GetString(0));
 	wxDateTime dt = wxDateTime::Now();
-	if (args.IsValid(1)) dt = *Object_wx_DateTime::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) dt = *Object_wx_DateTime::GetObject(arg, 1)->GetEntity();
 	wxFileOffset size = wxInvalidOffset;
-	if (args.IsValid(2)) size = static_cast<wxFileOffset>(args.GetInt64(2));
+	if (arg.IsValid(2)) size = static_cast<wxFileOffset>(arg.GetInt64(2));
 	wx_TarEntry *pEntity = new wx_TarEntry(name, dt, size);
-	Object_wx_TarEntry *pObj = Object_wx_TarEntry::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TarEntry *pObj = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TarEntry(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(TarEntry_1)
@@ -78,18 +79,19 @@ Gura_DeclareFunction(TarEntry_1)
 
 Gura_ImplementFunction(TarEntry_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxTarEntry *entry = Object_wx_TarEntry::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxTarEntry *entry = Object_wx_TarEntry::GetObject(arg, 0)->GetEntity();
 	wx_TarEntry *pEntity = new wx_TarEntry(*entry);
-	Object_wx_TarEntry *pObj = Object_wx_TarEntry::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TarEntry *pObj = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TarEntry(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetAccessTime)
@@ -100,10 +102,11 @@ Gura_DeclareMethod(wx_TarEntry, GetAccessTime)
 
 Gura_ImplementMethod(wx_TarEntry, GetAccessTime)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDateTime rtn = pThis->GetEntity()->GetAccessTime();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DateTime(new wxDateTime(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_DateTime(new wxDateTime(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetAccessTime)
@@ -114,11 +117,12 @@ Gura_DeclareMethod(wx_TarEntry, SetAccessTime)
 
 Gura_ImplementMethod(wx_TarEntry, SetAccessTime)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDateTime *dt = Object_wx_DateTime::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDateTime *dt = Object_wx_DateTime::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetAccessTime(*dt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetCreateTime)
@@ -129,10 +133,11 @@ Gura_DeclareMethod(wx_TarEntry, GetCreateTime)
 
 Gura_ImplementMethod(wx_TarEntry, GetCreateTime)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDateTime rtn = pThis->GetEntity()->GetCreateTime();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DateTime(new wxDateTime(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_DateTime(new wxDateTime(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetCreateTime)
@@ -143,11 +148,12 @@ Gura_DeclareMethod(wx_TarEntry, SetCreateTime)
 
 Gura_ImplementMethod(wx_TarEntry, SetCreateTime)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDateTime *dt = Object_wx_DateTime::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDateTime *dt = Object_wx_DateTime::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetCreateTime(*dt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetDevMajor)
@@ -158,10 +164,11 @@ Gura_DeclareMethod(wx_TarEntry, GetDevMajor)
 
 Gura_ImplementMethod(wx_TarEntry, GetDevMajor)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetDevMajor();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetDevMinor)
@@ -172,10 +179,11 @@ Gura_DeclareMethod(wx_TarEntry, GetDevMinor)
 
 Gura_ImplementMethod(wx_TarEntry, GetDevMinor)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetDevMinor();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetDevMajor)
@@ -186,11 +194,12 @@ Gura_DeclareMethod(wx_TarEntry, SetDevMajor)
 
 Gura_ImplementMethod(wx_TarEntry, SetDevMajor)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int dev = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int dev = arg.GetInt(0);
 	pThis->GetEntity()->SetDevMajor(dev);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetDevMinor)
@@ -201,11 +210,12 @@ Gura_DeclareMethod(wx_TarEntry, SetDevMinor)
 
 Gura_ImplementMethod(wx_TarEntry, SetDevMinor)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int dev = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int dev = arg.GetInt(0);
 	pThis->GetEntity()->SetDevMinor(dev);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetGroupId)
@@ -216,10 +226,11 @@ Gura_DeclareMethod(wx_TarEntry, GetGroupId)
 
 Gura_ImplementMethod(wx_TarEntry, GetGroupId)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetGroupId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetUserId)
@@ -230,10 +241,11 @@ Gura_DeclareMethod(wx_TarEntry, GetUserId)
 
 Gura_ImplementMethod(wx_TarEntry, GetUserId)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetUserId();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetGroupId)
@@ -244,11 +256,12 @@ Gura_DeclareMethod(wx_TarEntry, SetGroupId)
 
 Gura_ImplementMethod(wx_TarEntry, SetGroupId)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->SetGroupId(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetUserId)
@@ -259,11 +272,12 @@ Gura_DeclareMethod(wx_TarEntry, SetUserId)
 
 Gura_ImplementMethod(wx_TarEntry, SetUserId)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int id = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int id = arg.GetInt(0);
 	pThis->GetEntity()->SetUserId(id);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetGroupName)
@@ -274,10 +288,11 @@ Gura_DeclareMethod(wx_TarEntry, GetGroupName)
 
 Gura_ImplementMethod(wx_TarEntry, GetGroupName)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetGroupName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethodAlias(wx_TarEntry, GetUserName_, "GetUserName")
@@ -288,10 +303,11 @@ Gura_DeclareMethodAlias(wx_TarEntry, GetUserName_, "GetUserName")
 
 Gura_ImplementMethod(wx_TarEntry, GetUserName_)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetUserName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetGroupName)
@@ -302,11 +318,12 @@ Gura_DeclareMethod(wx_TarEntry, SetGroupName)
 
 Gura_ImplementMethod(wx_TarEntry, SetGroupName)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString group = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString group = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetGroupName(group);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetUserName)
@@ -317,11 +334,12 @@ Gura_DeclareMethod(wx_TarEntry, SetUserName)
 
 Gura_ImplementMethod(wx_TarEntry, SetUserName)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString user = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString user = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetUserName(user);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetInternalName)
@@ -332,14 +350,15 @@ Gura_DeclareMethod(wx_TarEntry, GetInternalName)
 
 Gura_ImplementMethod(wx_TarEntry, GetInternalName)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetInternalName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetInternalName_1)
@@ -355,19 +374,20 @@ Gura_DeclareMethod(wx_TarEntry, GetInternalName_1)
 
 Gura_ImplementMethod(wx_TarEntry, GetInternalName_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxPathFormat format = wxPATH_NATIVE;
-	if (args.IsValid(1)) format = static_cast<wxPathFormat>(args.GetInt(1));
-	bool pIsDir = NULL;
-	if (args.IsValid(2)) pIsDir = args.GetBoolean(2);
+	if (arg.IsValid(1)) format = static_cast<wxPathFormat>(arg.GetInt(1));
+	bool pIsDir = nullptr;
+	if (arg.IsValid(2)) pIsDir = arg.GetBoolean(2);
 	wxString rtn = pThis->GetEntity()->GetInternalName(name, format, pIsDir);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetLinkName)
@@ -378,10 +398,11 @@ Gura_DeclareMethod(wx_TarEntry, GetLinkName)
 
 Gura_ImplementMethod(wx_TarEntry, GetLinkName)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetLinkName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetLinkName)
@@ -394,15 +415,16 @@ Gura_DeclareMethod(wx_TarEntry, SetLinkName)
 
 Gura_ImplementMethod(wx_TarEntry, SetLinkName)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString link = wxString::FromUTF8(args.GetString(0));
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString link = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetLinkName(link);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetMode)
@@ -413,10 +435,11 @@ Gura_DeclareMethod(wx_TarEntry, GetMode)
 
 Gura_ImplementMethod(wx_TarEntry, GetMode)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMode();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethodAlias(wx_TarEntry, SetMode_, "SetMode")
@@ -427,11 +450,12 @@ Gura_DeclareMethodAlias(wx_TarEntry, SetMode_, "SetMode")
 
 Gura_ImplementMethod(wx_TarEntry, SetMode_)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int mode = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int mode = arg.GetInt(0);
 	pThis->GetEntity()->SetMode(mode);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetSize)
@@ -442,11 +466,12 @@ Gura_DeclareMethod(wx_TarEntry, SetSize)
 
 Gura_ImplementMethod(wx_TarEntry, SetSize)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFileOffset size = static_cast<wxFileOffset>(args.GetInt64(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFileOffset size = static_cast<wxFileOffset>(arg.GetInt64(0));
 	pThis->GetEntity()->SetSize(size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetSize)
@@ -457,10 +482,11 @@ Gura_DeclareMethod(wx_TarEntry, GetSize)
 
 Gura_ImplementMethod(wx_TarEntry, GetSize)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFileOffset rtn = pThis->GetEntity()->GetSize();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TarEntry, GetTypeFlag)
@@ -471,10 +497,11 @@ Gura_DeclareMethod(wx_TarEntry, GetTypeFlag)
 
 Gura_ImplementMethod(wx_TarEntry, GetTypeFlag)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetTypeFlag();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TarEntry, SetTypeFlag)
@@ -485,11 +512,12 @@ Gura_DeclareMethod(wx_TarEntry, SetTypeFlag)
 
 Gura_ImplementMethod(wx_TarEntry, SetTypeFlag)
 {
-	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int type = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TarEntry *pThis = Object_wx_TarEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int type = arg.GetInt(0);
 	pThis->GetEntity()->SetTypeFlag(type);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -501,13 +529,13 @@ Object_wx_TarEntry::~Object_wx_TarEntry()
 
 Object *Object_wx_TarEntry::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_TarEntry::ToString(bool exprFlag)
 {
 	String rtn("<wx.TarEntry:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -554,7 +582,7 @@ Gura_ImplementUserInheritableClass(wx_TarEntry)
 
 Gura_ImplementDescendantCreator(wx_TarEntry)
 {
-	return new Object_wx_TarEntry((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_TarEntry((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
