@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_TextAttr: public wxTextAttr, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_TextAttr *_pObj;
 public:
-	inline wx_TextAttr() : wxTextAttr(), _sig(NULL), _pObj(NULL) {}
-	inline wx_TextAttr(const wxColour& colText, const wxColour& colBack, const wxFont& font, wxTextAttrAlignment alignment) : wxTextAttr(colText, colBack, font, alignment), _sig(NULL), _pObj(NULL) {}
+	inline wx_TextAttr() : wxTextAttr(), _pObj(nullptr) {}
+	inline wx_TextAttr(const wxColour& colText, const wxColour& colBack, const wxFont& font, wxTextAttrAlignment alignment) : wxTextAttr(colText, colBack, font, alignment), _pObj(nullptr) {}
 	~wx_TextAttr();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_TextAttr *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_TextAttr *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_TextAttr::~wx_TextAttr()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_TextAttr::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(TextAttr)
 
 Gura_ImplementFunction(TextAttr)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_TextAttr *pEntity = new wx_TextAttr();
-	Object_wx_TextAttr *pObj = Object_wx_TextAttr::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TextAttr *pObj = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TextAttr(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(TextAttr_1)
@@ -72,24 +73,25 @@ Gura_DeclareFunction(TextAttr_1)
 
 Gura_ImplementFunction(TextAttr_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxColour *colText = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxColour *colText = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	wxColour *colBack = (wxColour *)(&wxNullColour);
-	if (args.IsValid(1)) colBack = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) colBack = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	wxFont *font = (wxFont *)(&wxNullFont);
-	if (args.IsValid(2)) font = Object_wx_Font::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) font = Object_wx_Font::GetObject(arg, 2)->GetEntity();
 	wxTextAttrAlignment alignment = wxTEXT_ALIGNMENT_DEFAULT;
-	if (args.IsValid(3)) alignment = static_cast<wxTextAttrAlignment>(args.GetInt(3));
+	if (arg.IsValid(3)) alignment = static_cast<wxTextAttrAlignment>(arg.GetInt(3));
 	wx_TextAttr *pEntity = new wx_TextAttr(*colText, *colBack, *font, alignment);
-	Object_wx_TextAttr *pObj = Object_wx_TextAttr::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TextAttr *pObj = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TextAttr(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetAlignment)
@@ -100,10 +102,11 @@ Gura_DeclareMethod(wx_TextAttr, GetAlignment)
 
 Gura_ImplementMethod(wx_TextAttr, GetAlignment)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTextAttrAlignment rtn = pThis->GetEntity()->GetAlignment();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetBackgroundColour)
@@ -114,10 +117,11 @@ Gura_DeclareMethod(wx_TextAttr, GetBackgroundColour)
 
 Gura_ImplementMethod(wx_TextAttr, GetBackgroundColour)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetBackgroundColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetFont)
@@ -128,10 +132,11 @@ Gura_DeclareMethod(wx_TextAttr, GetFont)
 
 Gura_ImplementMethod(wx_TextAttr, GetFont)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxFont &rtn = pThis->GetEntity()->GetFont();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(new wxFont(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(new wxFont(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetLeftIndent)
@@ -142,10 +147,11 @@ Gura_DeclareMethod(wx_TextAttr, GetLeftIndent)
 
 Gura_ImplementMethod(wx_TextAttr, GetLeftIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLeftIndent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetLeftSubIndent)
@@ -156,10 +162,11 @@ Gura_DeclareMethod(wx_TextAttr, GetLeftSubIndent)
 
 Gura_ImplementMethod(wx_TextAttr, GetLeftSubIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLeftSubIndent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetRightIndent)
@@ -170,10 +177,11 @@ Gura_DeclareMethod(wx_TextAttr, GetRightIndent)
 
 Gura_ImplementMethod(wx_TextAttr, GetRightIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetRightIndent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetTabs)
@@ -184,10 +192,11 @@ Gura_DeclareMethod(wx_TextAttr, GetTabs)
 
 Gura_ImplementMethod(wx_TextAttr, GetTabs)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxArrayInt rtn = pThis->GetEntity()->GetTabs();
-	return ReturnValue(env, sig, args, ArrayIntToValue(env, rtn));
+	return ReturnValue(env, arg, ArrayIntToValue(env, rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetTextColour)
@@ -198,10 +207,11 @@ Gura_DeclareMethod(wx_TextAttr, GetTextColour)
 
 Gura_ImplementMethod(wx_TextAttr, GetTextColour)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetTextColour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasAlignment)
@@ -212,10 +222,11 @@ Gura_DeclareMethod(wx_TextAttr, HasAlignment)
 
 Gura_ImplementMethod(wx_TextAttr, HasAlignment)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasAlignment();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasBackgroundColour)
@@ -226,10 +237,11 @@ Gura_DeclareMethod(wx_TextAttr, HasBackgroundColour)
 
 Gura_ImplementMethod(wx_TextAttr, HasBackgroundColour)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasBackgroundColour();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasFont)
@@ -240,10 +252,11 @@ Gura_DeclareMethod(wx_TextAttr, HasFont)
 
 Gura_ImplementMethod(wx_TextAttr, HasFont)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasFont();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasLeftIndent)
@@ -254,10 +267,11 @@ Gura_DeclareMethod(wx_TextAttr, HasLeftIndent)
 
 Gura_ImplementMethod(wx_TextAttr, HasLeftIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasLeftIndent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasRightIndent)
@@ -268,10 +282,11 @@ Gura_DeclareMethod(wx_TextAttr, HasRightIndent)
 
 Gura_ImplementMethod(wx_TextAttr, HasRightIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasRightIndent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasTabs)
@@ -282,10 +297,11 @@ Gura_DeclareMethod(wx_TextAttr, HasTabs)
 
 Gura_ImplementMethod(wx_TextAttr, HasTabs)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasTabs();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, HasTextColour)
@@ -296,10 +312,11 @@ Gura_DeclareMethod(wx_TextAttr, HasTextColour)
 
 Gura_ImplementMethod(wx_TextAttr, HasTextColour)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasTextColour();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, GetFlags)
@@ -310,10 +327,11 @@ Gura_DeclareMethod(wx_TextAttr, GetFlags)
 
 Gura_ImplementMethod(wx_TextAttr, GetFlags)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, IsDefault)
@@ -324,10 +342,11 @@ Gura_DeclareMethod(wx_TextAttr, IsDefault)
 
 Gura_ImplementMethod(wx_TextAttr, IsDefault)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsDefault();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttr, Merge)
@@ -338,11 +357,12 @@ Gura_DeclareMethod(wx_TextAttr, Merge)
 
 Gura_ImplementMethod(wx_TextAttr, Merge)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTextAttr *overlay = Object_wx_TextAttr::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTextAttr *overlay = Object_wx_TextAttr::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Merge(*overlay);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TextAttr, Merge_1)
@@ -355,11 +375,12 @@ Gura_DeclareClassMethod(wx_TextAttr, Merge_1)
 
 Gura_ImplementClassMethod(wx_TextAttr, Merge_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxTextAttr *base = Object_wx_TextAttr::GetObject(args, 0)->GetEntity();
-	wxTextAttr *overlay = Object_wx_TextAttr::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxTextAttr *base = Object_wx_TextAttr::GetObject(arg, 0)->GetEntity();
+	wxTextAttr *overlay = Object_wx_TextAttr::GetObject(arg, 1)->GetEntity();
 	wxTextAttr rtn = wxTextAttr::Merge(*base, *overlay);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextAttr(new wxTextAttr(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextAttr(new wxTextAttr(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetAlignment)
@@ -370,11 +391,12 @@ Gura_DeclareMethod(wx_TextAttr, SetAlignment)
 
 Gura_ImplementMethod(wx_TextAttr, SetAlignment)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTextAttrAlignment alignment = static_cast<wxTextAttrAlignment>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTextAttrAlignment alignment = static_cast<wxTextAttrAlignment>(arg.GetInt(0));
 	pThis->GetEntity()->SetAlignment(alignment);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetBackgroundColour)
@@ -385,11 +407,12 @@ Gura_DeclareMethod(wx_TextAttr, SetBackgroundColour)
 
 Gura_ImplementMethod(wx_TextAttr, SetBackgroundColour)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colour = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colour = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetBackgroundColour(*colour);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetFlags)
@@ -400,11 +423,12 @@ Gura_DeclareMethod(wx_TextAttr, SetFlags)
 
 Gura_ImplementMethod(wx_TextAttr, SetFlags)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long flags = args.GetLong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long flags = arg.GetLong(0);
 	pThis->GetEntity()->SetFlags(flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetFont)
@@ -415,11 +439,12 @@ Gura_DeclareMethod(wx_TextAttr, SetFont)
 
 Gura_ImplementMethod(wx_TextAttr, SetFont)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFont *font = Object_wx_Font::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFont *font = Object_wx_Font::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetFont(*font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetLeftIndent)
@@ -431,13 +456,14 @@ Gura_DeclareMethod(wx_TextAttr, SetLeftIndent)
 
 Gura_ImplementMethod(wx_TextAttr, SetLeftIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int indent = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int indent = arg.GetInt(0);
 	int subIndent = 0;
-	if (args.IsValid(1)) subIndent = args.GetInt(1);
+	if (arg.IsValid(1)) subIndent = arg.GetInt(1);
 	pThis->GetEntity()->SetLeftIndent(indent, subIndent);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetRightIndent)
@@ -448,26 +474,28 @@ Gura_DeclareMethod(wx_TextAttr, SetRightIndent)
 
 Gura_ImplementMethod(wx_TextAttr, SetRightIndent)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int indent = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int indent = arg.GetInt(0);
 	pThis->GetEntity()->SetRightIndent(indent);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetTabs)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
-	DeclareArg(env, "tabs", VTYPE_number, OCCUR_Once, FLAG_List);
+	DeclareArg(env, "tabs", VTYPE_number, OCCUR_Once, FLAG_ListVar);
 }
 
 Gura_ImplementMethod(wx_TextAttr, SetTabs)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	std::auto_ptr<wxArrayInt> tabs(CreateArrayInt(args.GetList(0)));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	std::unique_ptr<wxArrayInt> tabs(CreateArrayInt(arg.GetList(0)));
 	pThis->GetEntity()->SetTabs(*tabs);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttr, SetTextColour)
@@ -478,11 +506,12 @@ Gura_DeclareMethod(wx_TextAttr, SetTextColour)
 
 Gura_ImplementMethod(wx_TextAttr, SetTextColour)
 {
-	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *colour = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttr *pThis = Object_wx_TextAttr::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *colour = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetTextColour(*colour);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -490,20 +519,20 @@ Gura_ImplementMethod(wx_TextAttr, SetTextColour)
 //----------------------------------------------------------------------------
 Object_wx_TextAttr::~Object_wx_TextAttr()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_TextAttr::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_TextAttr::ToString(bool exprFlag)
 {
 	String rtn("<wx.TextAttr:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -551,7 +580,7 @@ Gura_ImplementUserInheritableClass(wx_TextAttr)
 
 Gura_ImplementDescendantCreator(wx_TextAttr)
 {
-	return new Object_wx_TextAttr((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_TextAttr((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
