@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_TextAttrEx: public wxTextAttrEx, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_TextAttrEx *_pObj;
 public:
-	inline wx_TextAttrEx() : wxTextAttrEx(), _sig(NULL), _pObj(NULL) {}
-	inline wx_TextAttrEx(const wxTextAttrEx& attr) : wxTextAttrEx(attr), _sig(NULL), _pObj(NULL) {}
+	inline wx_TextAttrEx() : wxTextAttrEx(), _pObj(nullptr) {}
+	inline wx_TextAttrEx(const wxTextAttrEx& attr) : wxTextAttrEx(attr), _pObj(nullptr) {}
 	~wx_TextAttrEx();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_TextAttrEx *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_TextAttrEx *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_TextAttrEx::~wx_TextAttrEx()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_TextAttrEx::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(TextAttrEx)
 
 Gura_ImplementFunction(TextAttrEx)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_TextAttrEx *pEntity = new wx_TextAttrEx();
-	Object_wx_TextAttrEx *pObj = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TextAttrEx *pObj = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TextAttrEx(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetBulletFont)
@@ -67,10 +68,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetBulletFont)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetBulletFont)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetBulletFont();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetBulletName)
@@ -81,10 +83,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetBulletName)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetBulletName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetBulletName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetBulletNumber)
@@ -95,10 +98,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetBulletNumber)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetBulletNumber)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetBulletNumber();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetBulletStyle)
@@ -109,10 +113,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetBulletStyle)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetBulletStyle)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetBulletStyle();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetBulletText)
@@ -123,10 +128,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetBulletText)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetBulletText)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetBulletText();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetCharacterStyleName)
@@ -137,10 +143,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetCharacterStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetCharacterStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetCharacterStyleName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetLineSpacing)
@@ -151,10 +158,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetLineSpacing)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetLineSpacing)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetLineSpacing();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetListStyleName)
@@ -165,10 +173,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetListStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetListStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetListStyleName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetOutlineLevel)
@@ -179,10 +188,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetOutlineLevel)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetOutlineLevel)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetOutlineLevel();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetParagraphSpacingAfter)
@@ -193,10 +203,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetParagraphSpacingAfter)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetParagraphSpacingAfter)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetParagraphSpacingAfter();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetParagraphSpacingBefore)
@@ -207,10 +218,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetParagraphSpacingBefore)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetParagraphSpacingBefore)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetParagraphSpacingBefore();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetParagraphStyleName)
@@ -221,10 +233,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetParagraphStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetParagraphStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetParagraphStyleName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetTextEffectFlags)
@@ -235,10 +248,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetTextEffectFlags)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetTextEffectFlags)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetTextEffectFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetTextEffects)
@@ -249,10 +263,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetTextEffects)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetTextEffects)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetTextEffects();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, GetURL)
@@ -263,10 +278,11 @@ Gura_DeclareMethod(wx_TextAttrEx, GetURL)
 
 Gura_ImplementMethod(wx_TextAttrEx, GetURL)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetURL();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasBulletName)
@@ -277,10 +293,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasBulletName)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasBulletName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasBulletName();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasBulletNumber)
@@ -291,10 +308,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasBulletNumber)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasBulletNumber)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasBulletNumber();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasBulletStyle)
@@ -305,10 +323,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasBulletStyle)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasBulletStyle)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasBulletStyle();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasBulletText)
@@ -319,10 +338,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasBulletText)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasBulletText)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasBulletText();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasCharacterStyleName)
@@ -333,10 +353,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasCharacterStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasCharacterStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasCharacterStyleName();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasLineSpacing)
@@ -347,10 +368,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasLineSpacing)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasLineSpacing)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasLineSpacing();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasListStyleName)
@@ -361,10 +383,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasListStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasListStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasListStyleName();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasOutlineLevel)
@@ -375,10 +398,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasOutlineLevel)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasOutlineLevel)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasOutlineLevel();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasPageBreak)
@@ -389,10 +413,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasPageBreak)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasPageBreak)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasPageBreak();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasParagraphSpacingAfter)
@@ -403,10 +428,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasParagraphSpacingAfter)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasParagraphSpacingAfter)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasParagraphSpacingAfter();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasParagraphSpacingBefore)
@@ -417,10 +443,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasParagraphSpacingBefore)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasParagraphSpacingBefore)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasParagraphSpacingBefore();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasParagraphStyleName)
@@ -431,10 +458,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasParagraphStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasParagraphStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasParagraphStyleName();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasTextEffects)
@@ -445,10 +473,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasTextEffects)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasTextEffects)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasTextEffects();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, HasURL)
@@ -459,10 +488,11 @@ Gura_DeclareMethod(wx_TextAttrEx, HasURL)
 
 Gura_ImplementMethod(wx_TextAttrEx, HasURL)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasURL();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, Init)
@@ -472,10 +502,11 @@ Gura_DeclareMethod(wx_TextAttrEx, Init)
 
 Gura_ImplementMethod(wx_TextAttrEx, Init)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Init();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, IsCharacterStyle)
@@ -486,10 +517,11 @@ Gura_DeclareMethod(wx_TextAttrEx, IsCharacterStyle)
 
 Gura_ImplementMethod(wx_TextAttrEx, IsCharacterStyle)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsCharacterStyle();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, IsDefault)
@@ -500,10 +532,11 @@ Gura_DeclareMethod(wx_TextAttrEx, IsDefault)
 
 Gura_ImplementMethod(wx_TextAttrEx, IsDefault)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsDefault();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, IsParagraphStyle)
@@ -514,10 +547,11 @@ Gura_DeclareMethod(wx_TextAttrEx, IsParagraphStyle)
 
 Gura_ImplementMethod(wx_TextAttrEx, IsParagraphStyle)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsParagraphStyle();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetBulletFont)
@@ -528,11 +562,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetBulletFont)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetBulletFont)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString font = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString font = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetBulletFont(font);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetBulletNumber)
@@ -543,11 +578,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetBulletNumber)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetBulletNumber)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	pThis->GetEntity()->SetBulletNumber(n);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetBulletName)
@@ -558,11 +594,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetBulletName)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetBulletName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetBulletName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetBulletStyle)
@@ -573,11 +610,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetBulletStyle)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetBulletStyle)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int style = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int style = arg.GetInt(0);
 	pThis->GetEntity()->SetBulletStyle(style);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetBulletText)
@@ -588,11 +626,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetBulletText)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetBulletText)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString text = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString text = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetBulletText(text);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetCharacterStyleName)
@@ -603,11 +642,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetCharacterStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetCharacterStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetCharacterStyleName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetLineSpacing)
@@ -618,11 +658,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetLineSpacing)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetLineSpacing)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int spacing = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int spacing = arg.GetInt(0);
 	pThis->GetEntity()->SetLineSpacing(spacing);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetListStyleName)
@@ -633,11 +674,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetListStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetListStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetListStyleName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetOutlineLevel)
@@ -648,11 +690,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetOutlineLevel)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetOutlineLevel)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int level = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int level = arg.GetInt(0);
 	pThis->GetEntity()->SetOutlineLevel(level);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetPageBreak)
@@ -663,12 +706,13 @@ Gura_DeclareMethod(wx_TextAttrEx, SetPageBreak)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetPageBreak)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool pageBreak = true;
-	if (args.IsValid(0)) pageBreak = args.GetBoolean(0);
+	if (arg.IsValid(0)) pageBreak = arg.GetBoolean(0);
 	pThis->GetEntity()->SetPageBreak(pageBreak);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetParagraphSpacingAfter)
@@ -679,11 +723,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetParagraphSpacingAfter)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetParagraphSpacingAfter)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int spacing = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int spacing = arg.GetInt(0);
 	pThis->GetEntity()->SetParagraphSpacingAfter(spacing);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetParagraphSpacingBefore)
@@ -694,11 +739,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetParagraphSpacingBefore)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetParagraphSpacingBefore)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int spacing = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int spacing = arg.GetInt(0);
 	pThis->GetEntity()->SetParagraphSpacingBefore(spacing);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetParagraphStyleName)
@@ -709,11 +755,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetParagraphStyleName)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetParagraphStyleName)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetParagraphStyleName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetTextEffectFlags)
@@ -724,11 +771,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetTextEffectFlags)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetTextEffectFlags)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int flags = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int flags = arg.GetInt(0);
 	pThis->GetEntity()->SetTextEffectFlags(flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetTextEffects)
@@ -739,11 +787,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetTextEffects)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetTextEffects)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int effects = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int effects = arg.GetInt(0);
 	pThis->GetEntity()->SetTextEffects(effects);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextAttrEx, SetURL)
@@ -754,11 +803,12 @@ Gura_DeclareMethod(wx_TextAttrEx, SetURL)
 
 Gura_ImplementMethod(wx_TextAttrEx, SetURL)
 {
-	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString url = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TextAttrEx *pThis = Object_wx_TextAttrEx::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString url = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetURL(url);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -770,13 +820,13 @@ Object_wx_TextAttrEx::~Object_wx_TextAttrEx()
 
 Object *Object_wx_TextAttrEx::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_TextAttrEx::ToString(bool exprFlag)
 {
 	String rtn("<wx.TextAttrEx:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -845,7 +895,7 @@ Gura_ImplementUserInheritableClass(wx_TextAttrEx)
 
 Gura_ImplementDescendantCreator(wx_TextAttrEx)
 {
-	return new Object_wx_TextAttrEx((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_TextAttrEx((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
