@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_TextFile: public wxTextFile, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_TextFile *_pObj;
 public:
-	inline wx_TextFile() : wxTextFile(), _sig(NULL), _pObj(NULL) {}
-	inline wx_TextFile(const wxString& strFile) : wxTextFile(strFile), _sig(NULL), _pObj(NULL) {}
+	inline wx_TextFile() : wxTextFile(), _pObj(nullptr) {}
+	inline wx_TextFile(const wxString& strFile) : wxTextFile(strFile), _pObj(nullptr) {}
 	~wx_TextFile();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_TextFile *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_TextFile *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_TextFile::~wx_TextFile()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_TextFile::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(TextFileEmpty)
 
 Gura_ImplementFunction(TextFileEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_TextFile *pEntity = new wx_TextFile();
-	Object_wx_TextFile *pObj = Object_wx_TextFile::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TextFile *pObj = Object_wx_TextFile::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TextFile(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(TextFile)
@@ -69,18 +70,19 @@ Gura_DeclareFunction(TextFile)
 
 Gura_ImplementFunction(TextFile)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString strFile = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString strFile = wxString::FromUTF8(arg.GetString(0));
 	wx_TextFile *pEntity = new wx_TextFile(strFile);
-	Object_wx_TextFile *pObj = Object_wx_TextFile::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TextFile *pObj = Object_wx_TextFile::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TextFile(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_TextFile, AddLine)
@@ -94,17 +96,18 @@ Gura_DeclareMethod(wx_TextFile, AddLine)
 
 Gura_ImplementMethod(wx_TextFile, AddLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str = wxString::FromUTF8(args.GetString(0));
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str = wxString::FromUTF8(arg.GetString(0));
 	wxTextFileType *type = (wxTextFileType *)(&typeDefault);
-	if (args.IsValid(1)) type = Object_wx_TextFileType::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) type = Object_wx_TextFileType::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->AddLine(str, *type);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Close)
@@ -115,14 +118,15 @@ Gura_DeclareMethod(wx_TextFile, Close)
 
 Gura_ImplementMethod(wx_TextFile, Close)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Close();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Create)
@@ -133,14 +137,15 @@ Gura_DeclareMethod(wx_TextFile, Create)
 
 Gura_ImplementMethod(wx_TextFile, Create)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Create();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Create_1)
@@ -154,15 +159,16 @@ Gura_DeclareMethod(wx_TextFile, Create_1)
 
 Gura_ImplementMethod(wx_TextFile, Create_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strFile = wxString::FromUTF8(args.GetString(0));
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strFile = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Create(strFile);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Exists)
@@ -173,14 +179,15 @@ Gura_DeclareMethod(wx_TextFile, Exists)
 
 Gura_ImplementMethod(wx_TextFile, Exists)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Exists();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, IsOpened)
@@ -191,14 +198,15 @@ Gura_DeclareMethod(wx_TextFile, IsOpened)
 
 Gura_ImplementMethod(wx_TextFile, IsOpened)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsOpened();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetLineCount)
@@ -209,14 +217,15 @@ Gura_DeclareMethod(wx_TextFile, GetLineCount)
 
 Gura_ImplementMethod(wx_TextFile, GetLineCount)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetLineCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetLine)
@@ -230,15 +239,16 @@ Gura_DeclareMethod(wx_TextFile, GetLine)
 
 Gura_ImplementMethod(wx_TextFile, GetLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxString rtn = pThis->GetEntity()->GetLine(n);
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetCurrentLine)
@@ -249,14 +259,15 @@ Gura_DeclareMethod(wx_TextFile, GetCurrentLine)
 
 Gura_ImplementMethod(wx_TextFile, GetCurrentLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetCurrentLine();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GoToLine)
@@ -269,15 +280,16 @@ Gura_DeclareMethod(wx_TextFile, GoToLine)
 
 Gura_ImplementMethod(wx_TextFile, GoToLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	pThis->GetEntity()->GoToLine(n);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Eof)
@@ -288,14 +300,15 @@ Gura_DeclareMethod(wx_TextFile, Eof)
 
 Gura_ImplementMethod(wx_TextFile, Eof)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->Eof();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TextFile, GetEOL)
@@ -309,15 +322,16 @@ Gura_DeclareClassMethod(wx_TextFile, GetEOL)
 
 Gura_ImplementClassMethod(wx_TextFile, GetEOL)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTextFileType *type = (wxTextFileType *)(&typeDefault);
-	if (args.IsValid(0)) type = Object_wx_TextFileType::GetObject(args, 0)->GetEntity();
+	if (arg.IsValid(0)) type = Object_wx_TextFileType::GetObject(arg, 0)->GetEntity();
 	char rtn = wxTextFile::GetEOL(*type);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetFirstLine)
@@ -328,14 +342,15 @@ Gura_DeclareMethod(wx_TextFile, GetFirstLine)
 
 Gura_ImplementMethod(wx_TextFile, GetFirstLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetFirstLine();
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetNextLine)
@@ -346,14 +361,15 @@ Gura_DeclareMethod(wx_TextFile, GetNextLine)
 
 Gura_ImplementMethod(wx_TextFile, GetNextLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetNextLine();
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetPrevLine)
@@ -364,14 +380,15 @@ Gura_DeclareMethod(wx_TextFile, GetPrevLine)
 
 Gura_ImplementMethod(wx_TextFile, GetPrevLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetPrevLine();
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetLastLine)
@@ -382,14 +399,15 @@ Gura_DeclareMethod(wx_TextFile, GetLastLine)
 
 Gura_ImplementMethod(wx_TextFile, GetLastLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetLastLine();
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetLineType)
@@ -403,15 +421,16 @@ Gura_DeclareMethod(wx_TextFile, GetLineType)
 
 Gura_ImplementMethod(wx_TextFile, GetLineType)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxTextFileType rtn = pThis->GetEntity()->GetLineType(n);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextFileType(new wxTextFileType(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextFileType(new wxTextFileType(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GuessType)
@@ -422,14 +441,15 @@ Gura_DeclareMethod(wx_TextFile, GuessType)
 
 Gura_ImplementMethod(wx_TextFile, GuessType)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTextFileType rtn = pThis->GetEntity()->GuessType();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TextFileType(new wxTextFileType(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TextFileType(new wxTextFileType(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, GetName)
@@ -440,14 +460,15 @@ Gura_DeclareMethod(wx_TextFile, GetName)
 
 Gura_ImplementMethod(wx_TextFile, GetName)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	char rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, InsertLine)
@@ -462,18 +483,19 @@ Gura_DeclareMethod(wx_TextFile, InsertLine)
 
 Gura_ImplementMethod(wx_TextFile, InsertLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str = wxString::FromUTF8(args.GetString(0));
-	size_t n = args.GetSizeT(1);
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str = wxString::FromUTF8(arg.GetString(0));
+	size_t n = arg.GetSizeT(1);
 	wxTextFileType *type = (wxTextFileType *)(&typeDefault);
-	if (args.IsValid(2)) type = Object_wx_TextFileType::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) type = Object_wx_TextFileType::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->InsertLine(str, n, *type);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Open)
@@ -487,16 +509,17 @@ Gura_DeclareMethod(wx_TextFile, Open)
 
 Gura_ImplementMethod(wx_TextFile, Open)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxMBConv *conv = (wxMBConv *)(&wxConvUTF8);
-	if (args.IsValid(0)) conv = Object_wx_MBConv::GetObject(args, 0)->GetEntity();
+	if (arg.IsValid(0)) conv = Object_wx_MBConv::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Open(*conv);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Open_1)
@@ -511,17 +534,18 @@ Gura_DeclareMethod(wx_TextFile, Open_1)
 
 Gura_ImplementMethod(wx_TextFile, Open_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString strFile = wxString::FromUTF8(args.GetString(0));
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString strFile = wxString::FromUTF8(arg.GetString(0));
 	wxMBConv *conv = (wxMBConv *)(&wxConvUTF8);
-	if (args.IsValid(1)) conv = Object_wx_MBConv::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) conv = Object_wx_MBConv::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->Open(strFile, *conv);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, RemoveLine)
@@ -534,15 +558,16 @@ Gura_DeclareMethod(wx_TextFile, RemoveLine)
 
 Gura_ImplementMethod(wx_TextFile, RemoveLine)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	pThis->GetEntity()->RemoveLine(n);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Clear)
@@ -552,14 +577,15 @@ Gura_DeclareMethod(wx_TextFile, Clear)
 
 Gura_ImplementMethod(wx_TextFile, Clear)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TextFile, Write)
@@ -574,18 +600,19 @@ Gura_DeclareMethod(wx_TextFile, Write)
 
 Gura_ImplementMethod(wx_TextFile, Write)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TextFile *pThis = Object_wx_TextFile::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TextFile *pThis = Object_wx_TextFile::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTextFileType *typeNew = (wxTextFileType *)(&wxTextFileType_None);
-	if (args.IsValid(0)) typeNew = Object_wx_TextFileType::GetObject(args, 0)->GetEntity();
+	if (arg.IsValid(0)) typeNew = Object_wx_TextFileType::GetObject(arg, 0)->GetEntity();
 	wxMBConv *conv = (wxMBConv *)(&wxConvUTF8);
-	if (args.IsValid(1)) conv = Object_wx_MBConv::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) conv = Object_wx_MBConv::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->Write(*typeNew, *conv);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -593,20 +620,20 @@ Gura_ImplementMethod(wx_TextFile, Write)
 //----------------------------------------------------------------------------
 Object_wx_TextFile::~Object_wx_TextFile()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_TextFile::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_TextFile::ToString(bool exprFlag)
 {
 	String rtn("<wx.TextFile:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -652,7 +679,7 @@ Gura_ImplementUserInheritableClass(wx_TextFile)
 
 Gura_ImplementDescendantCreator(wx_TextFile)
 {
-	return new Object_wx_TextFile((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_TextFile((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
