@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_TimeSpan: public wxTimeSpan, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_TimeSpan *_pObj;
 public:
-	//inline wx_TimeSpan() : wxTimeSpan(), _sig(NULL), _pObj(NULL) {}
-	//inline wx_TimeSpan(long hours, long min, long sec, long msec) : wxTimeSpan(hours, min, sec, msec), _sig(NULL), _pObj(NULL) {}
+	//inline wx_TimeSpan() : wxTimeSpan(), _pObj(nullptr) {}
+	//inline wx_TimeSpan(long hours, long min, long sec, long msec) : wxTimeSpan(hours, min, sec, msec), _pObj(nullptr) {}
 	~wx_TimeSpan();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_TimeSpan *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_TimeSpan *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_TimeSpan::~wx_TimeSpan()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_TimeSpan::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -45,10 +45,11 @@ Gura_DeclareMethod(wx_TimeSpan, Abs)
 
 Gura_ImplementMethod(wx_TimeSpan, Abs)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTimeSpan rtn = pThis->GetEntity()->Abs();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Add)
@@ -62,15 +63,16 @@ Gura_DeclareMethod(wx_TimeSpan, Add)
 
 Gura_ImplementMethod(wx_TimeSpan, Add)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	wxTimeSpan rtn = pThis->GetEntity()->Add(*diff);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Add_1)
@@ -82,11 +84,12 @@ Gura_DeclareMethod(wx_TimeSpan, Add_1)
 
 Gura_ImplementMethod(wx_TimeSpan, Add_1)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	wxTimeSpan &rtn = pThis->GetEntity()->Add(*diff);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Days)
@@ -100,14 +103,15 @@ Gura_DeclareClassMethod(wx_TimeSpan, Days)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Days)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long days = args.GetLong(0);
+	long days = arg.GetLong(0);
 	wxTimespan rtn = wxTimeSpan::Days(days);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Day)
@@ -118,13 +122,14 @@ Gura_DeclareClassMethod(wx_TimeSpan, Day)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Day)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTimespan rtn = wxTimeSpan::Day();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Format)
@@ -138,20 +143,21 @@ Gura_DeclareMethod(wx_TimeSpan, Format)
 
 Gura_ImplementMethod(wx_TimeSpan, Format)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString _format;
 	const wxChar *format = wxDefaultTimeSpanFormat;
-	if (args.IsValid(0)) {
-		_format = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) {
+		_format = wxString::FromUTF8(arg.GetString(0));
 		format = _format;
 	}
 	wxString rtn = pThis->GetEntity()->Format(format);
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetDays)
@@ -162,10 +168,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetDays)
 
 Gura_ImplementMethod(wx_TimeSpan, GetDays)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetDays();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetHours)
@@ -176,10 +183,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetHours)
 
 Gura_ImplementMethod(wx_TimeSpan, GetHours)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetHours();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetMilliseconds)
@@ -190,10 +198,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetMilliseconds)
 
 Gura_ImplementMethod(wx_TimeSpan, GetMilliseconds)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxLongLong rtn = pThis->GetEntity()->GetMilliseconds();
-	return ReturnValue(env, sig, args, Value(new Object_wx_LongLong(new wxLongLong(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_LongLong(new wxLongLong(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetMinutes)
@@ -204,10 +213,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetMinutes)
 
 Gura_ImplementMethod(wx_TimeSpan, GetMinutes)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMinutes();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetSeconds)
@@ -218,10 +228,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetSeconds)
 
 Gura_ImplementMethod(wx_TimeSpan, GetSeconds)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxLongLong rtn = pThis->GetEntity()->GetSeconds();
-	return ReturnValue(env, sig, args, Value(new Object_wx_LongLong(new wxLongLong(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_LongLong(new wxLongLong(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetValue)
@@ -232,10 +243,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetValue)
 
 Gura_ImplementMethod(wx_TimeSpan, GetValue)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxLongLong rtn = pThis->GetEntity()->GetValue();
-	return ReturnValue(env, sig, args, Value(new Object_wx_LongLong(new wxLongLong(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_LongLong(new wxLongLong(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, GetWeeks)
@@ -246,10 +258,11 @@ Gura_DeclareMethod(wx_TimeSpan, GetWeeks)
 
 Gura_ImplementMethod(wx_TimeSpan, GetWeeks)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetWeeks();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Hours)
@@ -263,14 +276,15 @@ Gura_DeclareClassMethod(wx_TimeSpan, Hours)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Hours)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long hours = args.GetLong(0);
+	long hours = arg.GetLong(0);
 	wxTimespan rtn = wxTimeSpan::Hours(hours);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Hour)
@@ -281,13 +295,14 @@ Gura_DeclareClassMethod(wx_TimeSpan, Hour)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Hour)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTimespan rtn = wxTimeSpan::Hour();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, IsEqualTo)
@@ -299,11 +314,12 @@ Gura_DeclareMethod(wx_TimeSpan, IsEqualTo)
 
 Gura_ImplementMethod(wx_TimeSpan, IsEqualTo)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *ts = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *ts = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->IsEqualTo(*ts);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, IsLongerThan)
@@ -315,11 +331,12 @@ Gura_DeclareMethod(wx_TimeSpan, IsLongerThan)
 
 Gura_ImplementMethod(wx_TimeSpan, IsLongerThan)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *ts = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *ts = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->IsLongerThan(*ts);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, IsNegative)
@@ -330,10 +347,11 @@ Gura_DeclareMethod(wx_TimeSpan, IsNegative)
 
 Gura_ImplementMethod(wx_TimeSpan, IsNegative)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsNegative();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, IsNull)
@@ -344,10 +362,11 @@ Gura_DeclareMethod(wx_TimeSpan, IsNull)
 
 Gura_ImplementMethod(wx_TimeSpan, IsNull)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsNull();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, IsPositive)
@@ -358,10 +377,11 @@ Gura_DeclareMethod(wx_TimeSpan, IsPositive)
 
 Gura_ImplementMethod(wx_TimeSpan, IsPositive)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsPositive();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, IsShorterThan)
@@ -373,11 +393,12 @@ Gura_DeclareMethod(wx_TimeSpan, IsShorterThan)
 
 Gura_ImplementMethod(wx_TimeSpan, IsShorterThan)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *ts = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *ts = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->IsShorterThan(*ts);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Minutes)
@@ -391,14 +412,15 @@ Gura_DeclareClassMethod(wx_TimeSpan, Minutes)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Minutes)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long min = args.GetLong(0);
+	long min = arg.GetLong(0);
 	wxTimespan rtn = wxTimeSpan::Minutes(min);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Minute)
@@ -409,13 +431,14 @@ Gura_DeclareClassMethod(wx_TimeSpan, Minute)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Minute)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTimespan rtn = wxTimeSpan::Minute();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Multiply)
@@ -429,15 +452,16 @@ Gura_DeclareMethod(wx_TimeSpan, Multiply)
 
 Gura_ImplementMethod(wx_TimeSpan, Multiply)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	wxTimeSpan rtn = pThis->GetEntity()->Multiply(n);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Multiply_1)
@@ -449,11 +473,12 @@ Gura_DeclareMethod(wx_TimeSpan, Multiply_1)
 
 Gura_ImplementMethod(wx_TimeSpan, Multiply_1)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int n = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int n = arg.GetInt(0);
 	wxTimeSpan &rtn = pThis->GetEntity()->Multiply(n);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Negate)
@@ -464,10 +489,11 @@ Gura_DeclareMethod(wx_TimeSpan, Negate)
 
 Gura_ImplementMethod(wx_TimeSpan, Negate)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTimeSpan rtn = pThis->GetEntity()->Negate();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Neg)
@@ -478,14 +504,15 @@ Gura_DeclareMethod(wx_TimeSpan, Neg)
 
 Gura_ImplementMethod(wx_TimeSpan, Neg)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxTimeSpan &rtn = pThis->GetEntity()->Neg();
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Milliseconds)
@@ -499,14 +526,15 @@ Gura_DeclareClassMethod(wx_TimeSpan, Milliseconds)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Milliseconds)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long ms = args.GetLong(0);
+	long ms = arg.GetLong(0);
 	wxTimespan rtn = wxTimeSpan::Milliseconds(ms);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Millisecond)
@@ -517,13 +545,14 @@ Gura_DeclareClassMethod(wx_TimeSpan, Millisecond)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Millisecond)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTimespan rtn = wxTimeSpan::Millisecond();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Seconds)
@@ -537,14 +566,15 @@ Gura_DeclareClassMethod(wx_TimeSpan, Seconds)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Seconds)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long sec = args.GetLong(0);
+	long sec = arg.GetLong(0);
 	wxTimespan rtn = wxTimeSpan::Seconds(sec);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Second)
@@ -555,13 +585,14 @@ Gura_DeclareClassMethod(wx_TimeSpan, Second)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Second)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTimespan rtn = wxTimeSpan::Second();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Subtract)
@@ -575,15 +606,16 @@ Gura_DeclareMethod(wx_TimeSpan, Subtract)
 
 Gura_ImplementMethod(wx_TimeSpan, Subtract)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	wxTimeSpan rtn = pThis->GetEntity()->Subtract(*diff);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TimeSpan, Subtract_1)
@@ -595,11 +627,12 @@ Gura_DeclareMethod(wx_TimeSpan, Subtract_1)
 
 Gura_ImplementMethod(wx_TimeSpan, Subtract_1)
 {
-	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TimeSpan *pThis = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxTimeSpan *diff = Object_wx_TimeSpan::GetObject(arg, 0)->GetEntity();
 	wxTimeSpan &rtn = pThis->GetEntity()->Subtract(*diff);
-	return ReturnValue(env, sig, args, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_TimeSpan(new wxTimeSpan(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Weeks)
@@ -613,14 +646,15 @@ Gura_DeclareClassMethod(wx_TimeSpan, Weeks)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Weeks)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long weeks = args.GetLong(0);
+	long weeks = arg.GetLong(0);
 	wxTimespan rtn = wxTimeSpan::Weeks(weeks);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareClassMethod(wx_TimeSpan, Week)
@@ -631,13 +665,14 @@ Gura_DeclareClassMethod(wx_TimeSpan, Week)
 
 Gura_ImplementClassMethod(wx_TimeSpan, Week)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wxTimespan rtn = wxTimeSpan::Week();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Timespan(new wxTimespan(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Timespan(new wxTimespan(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(TimeSpanEmpty)
@@ -651,21 +686,22 @@ Gura_DeclareFunction(TimeSpanEmpty)
 
 Gura_ImplementFunction(TimeSpanEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_TimeSpan *pEntity = new wx_TimeSpan();
-	Object_wx_TimeSpan *pObj = Object_wx_TimeSpan::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TimeSpan *pObj = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TimeSpan(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(TimeSpan)
@@ -683,25 +719,26 @@ Gura_DeclareFunction(TimeSpan)
 
 Gura_ImplementFunction(TimeSpan)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	long hours = args.GetLong(0);
-	long min = args.GetLong(1);
-	long sec = args.GetLong(2);
-	long msec = args.GetLong(3);
+	long hours = arg.GetLong(0);
+	long min = arg.GetLong(1);
+	long sec = arg.GetLong(2);
+	long msec = arg.GetLong(3);
 	wx_TimeSpan *pEntity = new wx_TimeSpan(hours, min, sec, msec);
-	Object_wx_TimeSpan *pObj = Object_wx_TimeSpan::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_TimeSpan *pObj = Object_wx_TimeSpan::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_TimeSpan(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -709,20 +746,20 @@ Gura_ImplementFunction(TimeSpan)
 //----------------------------------------------------------------------------
 Object_wx_TimeSpan::~Object_wx_TimeSpan()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_TimeSpan::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_TimeSpan::ToString(bool exprFlag)
 {
 	String rtn("<wx.TimeSpan:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -778,7 +815,7 @@ Gura_ImplementUserInheritableClass(wx_TimeSpan)
 
 Gura_ImplementDescendantCreator(wx_TimeSpan)
 {
-	return new Object_wx_TimeSpan((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_TimeSpan((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
