@@ -19,7 +19,7 @@ Gura_DeclarePrivUserSymbol(ShouldPreventAppExit);
 //----------------------------------------------------------------------------
 class wx_TopLevelWindow: public wxTopLevelWindow, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_TopLevelWindow *_pObj;
 public:
 	//virtual bool CanSetTransparent();
@@ -30,8 +30,8 @@ public:
 	//virtual bool SetTransparent(int alpha);
 	//virtual bool ShouldPreventAppExit();
 	~wx_TopLevelWindow();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_TopLevelWindow *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_TopLevelWindow *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -39,12 +39,12 @@ public:
 
 wx_TopLevelWindow::~wx_TopLevelWindow()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_TopLevelWindow::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -58,10 +58,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, CanSetTransparent)
 
 Gura_ImplementMethod(wx_TopLevelWindow, CanSetTransparent)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->CanSetTransparent();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, CentreOnScreen)
@@ -72,12 +73,13 @@ Gura_DeclareMethod(wx_TopLevelWindow, CentreOnScreen)
 
 Gura_ImplementMethod(wx_TopLevelWindow, CentreOnScreen)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int direction = wxBOTH;
-	if (args.IsValid(0)) direction = args.GetInt(0);
+	if (arg.IsValid(0)) direction = arg.GetInt(0);
 	pThis->GetEntity()->CentreOnScreen(direction);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, EnableCloseButton)
@@ -89,12 +91,13 @@ Gura_DeclareMethod(wx_TopLevelWindow, EnableCloseButton)
 
 Gura_ImplementMethod(wx_TopLevelWindow, EnableCloseButton)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool enable = true;
-	if (args.IsValid(0)) enable = args.GetBoolean(0);
+	if (arg.IsValid(0)) enable = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->EnableCloseButton(enable);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, GetDefaultItem)
@@ -105,10 +108,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, GetDefaultItem)
 
 Gura_ImplementMethod(wx_TopLevelWindow, GetDefaultItem)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxWindow *rtn = (wxWindow *)pThis->GetEntity()->GetDefaultItem();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Window(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Window(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, GetIcon)
@@ -119,10 +123,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, GetIcon)
 
 Gura_ImplementMethod(wx_TopLevelWindow, GetIcon)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxIcon &rtn = pThis->GetEntity()->GetIcon();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Icon(new wxIcon(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Icon(new wxIcon(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, GetIcons)
@@ -133,10 +138,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, GetIcons)
 
 Gura_ImplementMethod(wx_TopLevelWindow, GetIcons)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxIconBundle &rtn = pThis->GetEntity()->GetIcons();
-	return ReturnValue(env, sig, args, Value(new Object_wx_IconBundle(new wxIconBundle(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_IconBundle(new wxIconBundle(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, GetTitle)
@@ -147,10 +153,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, GetTitle)
 
 Gura_ImplementMethod(wx_TopLevelWindow, GetTitle)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetTitle();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, HandleSettingChange)
@@ -163,16 +170,17 @@ Gura_DeclareMethod(wx_TopLevelWindow, HandleSettingChange)
 
 Gura_ImplementMethod(wx_TopLevelWindow, HandleSettingChange)
 {
+	Signal &sig = env.GetSignal();
 #if defined(__WXMSW__)
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	WXWPARAM wParam = static_cast<WXWPARAM>(args.GetULong(0));
-	WXLPARAM lParam = static_cast<WXLPARAM>(args.GetULong(1));
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	WXWPARAM wParam = static_cast<WXWPARAM>(arg.GetULong(0));
+	WXLPARAM lParam = static_cast<WXLPARAM>(arg.GetULong(1));
 	bool rtn = pThis->GetEntity()->HandleSettingChange(wParam, lParam);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #else
 	SetError_MSWOnly(sig);
-	return Value::Null;
+	return Value::Nil;
 #endif	
 }
 
@@ -184,10 +192,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, IsActive)
 
 Gura_ImplementMethod(wx_TopLevelWindow, IsActive)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsActive();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, IsAlwaysMaximized)
@@ -198,10 +207,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, IsAlwaysMaximized)
 
 Gura_ImplementMethod(wx_TopLevelWindow, IsAlwaysMaximized)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsAlwaysMaximized();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, Iconize)
@@ -212,11 +222,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, Iconize)
 
 Gura_ImplementMethod(wx_TopLevelWindow, Iconize)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool iconize = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool iconize = arg.GetBoolean(0);
 	pThis->GetEntity()->Iconize(iconize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, IsFullScreen)
@@ -227,10 +238,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, IsFullScreen)
 
 Gura_ImplementMethod(wx_TopLevelWindow, IsFullScreen)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsFullScreen();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, IsIconized)
@@ -241,10 +253,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, IsIconized)
 
 Gura_ImplementMethod(wx_TopLevelWindow, IsIconized)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsIconized();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, IsMaximized)
@@ -255,10 +268,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, IsMaximized)
 
 Gura_ImplementMethod(wx_TopLevelWindow, IsMaximized)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsMaximized();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, IsUsingNativeDecorations)
@@ -269,14 +283,15 @@ Gura_DeclareMethod(wx_TopLevelWindow, IsUsingNativeDecorations)
 
 Gura_ImplementMethod(wx_TopLevelWindow, IsUsingNativeDecorations)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsUsingNativeDecorations();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, Maximize)
@@ -287,11 +302,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, Maximize)
 
 Gura_ImplementMethod(wx_TopLevelWindow, Maximize)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool maximize = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool maximize = arg.GetBoolean(0);
 	pThis->GetEntity()->Maximize(maximize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, RequestUserAttention)
@@ -302,12 +318,13 @@ Gura_DeclareMethod(wx_TopLevelWindow, RequestUserAttention)
 
 Gura_ImplementMethod(wx_TopLevelWindow, RequestUserAttention)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int flags = wxUSER_ATTENTION_INFO;
-	if (args.IsValid(0)) flags = args.GetInt(0);
+	if (arg.IsValid(0)) flags = arg.GetInt(0);
 	pThis->GetEntity()->RequestUserAttention(flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetDefaultItem)
@@ -320,15 +337,16 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetDefaultItem)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetDefaultItem)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow **win = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow **win = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetDefaultItem(**win);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetIcon)
@@ -339,11 +357,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetIcon)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetIcon)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIcon *icon = Object_wx_Icon::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIcon *icon = Object_wx_Icon::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetIcon(*icon);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetIcons)
@@ -354,11 +373,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetIcons)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetIcons)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxIconBundle *icons = Object_wx_IconBundle::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxIconBundle *icons = Object_wx_IconBundle::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetIcons(*icons);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetLeftMenu)
@@ -373,20 +393,21 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetLeftMenu)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetLeftMenu)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int id = wxID_ANY;
-	if (args.IsValid(0)) id = args.GetInt(0);
+	if (arg.IsValid(0)) id = arg.GetInt(0);
 	wxString label = wxEmptyString;
-	if (args.IsValid(1)) label = wxString::FromUTF8(args.GetString(1));
-	wxMenu *subMenu = (wxMenu *)(NULL);
-	if (args.IsValid(2)) subMenu = Object_wx_Menu::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(1)) label = wxString::FromUTF8(arg.GetString(1));
+	wxMenu *subMenu = (wxMenu *)(nullptr);
+	if (arg.IsValid(2)) subMenu = Object_wx_Menu::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->SetLeftMenu(id, label, subMenu);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetMaxSize)
@@ -397,11 +418,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetMaxSize)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetMaxSize)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMaxSize(*size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetMinSize)
@@ -412,11 +434,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetMinSize)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetMinSize)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *size = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *size = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMinSize(*size);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetSizeHints)
@@ -432,20 +455,21 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetSizeHints)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetSizeHints)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int minW = args.GetInt(0);
-	int minH = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int minW = arg.GetInt(0);
+	int minH = arg.GetInt(1);
 	int maxW = -1;
-	if (args.IsValid(2)) maxW = args.GetInt(2);
+	if (arg.IsValid(2)) maxW = arg.GetInt(2);
 	int maxH = -1;
-	if (args.IsValid(3)) maxH = args.GetInt(3);
+	if (arg.IsValid(3)) maxH = arg.GetInt(3);
 	int incW = -1;
-	if (args.IsValid(4)) incW = args.GetInt(4);
+	if (arg.IsValid(4)) incW = arg.GetInt(4);
 	int incH = -1;
-	if (args.IsValid(5)) incH = args.GetInt(5);
+	if (arg.IsValid(5)) incH = arg.GetInt(5);
 	pThis->GetEntity()->SetSizeHints(minW, minH, maxW, maxH, incW, incH);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetSizeHints_1)
@@ -458,15 +482,16 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetSizeHints_1)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetSizeHints_1)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxSize *minSize = Object_wx_Size::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxSize *minSize = Object_wx_Size::GetObject(arg, 0)->GetEntity();
 	wxSize *maxSize = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(1)) maxSize = Object_wx_Size::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) maxSize = Object_wx_Size::GetObject(arg, 1)->GetEntity();
 	wxSize *incSize = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(2)) incSize = Object_wx_Size::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) incSize = Object_wx_Size::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->SetSizeHints(*minSize, *maxSize, *incSize);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetRightMenu)
@@ -481,20 +506,21 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetRightMenu)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetRightMenu)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int id = wxID_ANY;
-	if (args.IsValid(0)) id = args.GetInt(0);
+	if (arg.IsValid(0)) id = arg.GetInt(0);
 	wxString label = wxEmptyString;
-	if (args.IsValid(1)) label = wxString::FromUTF8(args.GetString(1));
-	wxMenu *subMenu = (wxMenu *)(NULL);
-	if (args.IsValid(2)) subMenu = Object_wx_Menu::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(1)) label = wxString::FromUTF8(arg.GetString(1));
+	wxMenu *subMenu = (wxMenu *)(nullptr);
+	if (arg.IsValid(2)) subMenu = Object_wx_Menu::GetObject(arg, 2)->GetEntity();
 	pThis->GetEntity()->SetRightMenu(id, label, subMenu);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetShape)
@@ -506,11 +532,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetShape)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetShape)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxRegion *region = Object_wx_Region::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxRegion *region = Object_wx_Region::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->SetShape(*region);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetTitle)
@@ -521,11 +548,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetTitle)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetTitle)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString title = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString title = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetTitle(title);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, SetTransparent)
@@ -537,11 +565,12 @@ Gura_DeclareMethod(wx_TopLevelWindow, SetTransparent)
 
 Gura_ImplementMethod(wx_TopLevelWindow, SetTransparent)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int alpha = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int alpha = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->SetTransparent(alpha);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, ShouldPreventAppExit)
@@ -552,10 +581,11 @@ Gura_DeclareMethod(wx_TopLevelWindow, ShouldPreventAppExit)
 
 Gura_ImplementMethod(wx_TopLevelWindow, ShouldPreventAppExit)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->ShouldPreventAppExit();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, ShowFullScreen)
@@ -568,13 +598,14 @@ Gura_DeclareMethod(wx_TopLevelWindow, ShowFullScreen)
 
 Gura_ImplementMethod(wx_TopLevelWindow, ShowFullScreen)
 {
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool show = args.GetBoolean(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool show = arg.GetBoolean(0);
 	long style = wxFULLSCREEN_ALL;
-	if (args.IsValid(1)) style = args.GetLong(1);
+	if (arg.IsValid(1)) style = arg.GetLong(1);
 	bool rtn = pThis->GetEntity()->ShowFullScreen(show, style);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, UseNativeDecorations)
@@ -587,16 +618,17 @@ Gura_DeclareMethod(wx_TopLevelWindow, UseNativeDecorations)
 
 Gura_ImplementMethod(wx_TopLevelWindow, UseNativeDecorations)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool native = ;
-	if (args.IsValid(0)) native = args.GetBoolean(0);
+	if (arg.IsValid(0)) native = arg.GetBoolean(0);
 	pThis->GetEntity()->UseNativeDecorations(native);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_TopLevelWindow, UseNativeDecorationsByDefault)
@@ -609,16 +641,17 @@ Gura_DeclareMethod(wx_TopLevelWindow, UseNativeDecorationsByDefault)
 
 Gura_ImplementMethod(wx_TopLevelWindow, UseNativeDecorationsByDefault)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_TopLevelWindow *pThis = Object_wx_TopLevelWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool native = ;
-	if (args.IsValid(0)) native = args.GetBoolean(0);
+	if (arg.IsValid(0)) native = arg.GetBoolean(0);
 	pThis->GetEntity()->UseNativeDecorationsByDefault(native);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -630,13 +663,13 @@ Object_wx_TopLevelWindow::~Object_wx_TopLevelWindow()
 
 Object *Object_wx_TopLevelWindow::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_TopLevelWindow::ToString(bool exprFlag)
 {
 	String rtn("<wx.TopLevelWindow:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -695,7 +728,7 @@ Gura_ImplementUserInheritableClass(wx_TopLevelWindow)
 
 Gura_ImplementDescendantCreator(wx_TopLevelWindow)
 {
-	return new Object_wx_TopLevelWindow((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_TopLevelWindow((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
