@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Treebook: public wxTreebook, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Treebook *_pObj;
 public:
-	inline wx_Treebook() : wxTreebook(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Treebook(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxTreebook(parent, id, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_Treebook() : wxTreebook(), _pObj(nullptr) {}
+	inline wx_Treebook(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxTreebook(parent, id, pos, size, style, name), _pObj(nullptr) {}
 	~wx_Treebook();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Treebook *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Treebook *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_Treebook::~wx_Treebook()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Treebook::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -46,17 +46,18 @@ Gura_DeclareFunction(TreebookEmpty)
 
 Gura_ImplementFunction(TreebookEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Treebook *pEntity = new wx_Treebook();
-	Object_wx_Treebook *pObj = Object_wx_Treebook::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Treebook *pObj = Object_wx_Treebook::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Treebook(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Treebook)
@@ -74,27 +75,28 @@ Gura_DeclareFunction(Treebook)
 
 Gura_ImplementFunction(Treebook)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = wxBK_DEFAULT;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxEmptyString;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	wx_Treebook *pEntity = new wx_Treebook(parent, id, *pos, *size, style, name);
-	Object_wx_Treebook *pObj = Object_wx_Treebook::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Treebook *pObj = Object_wx_Treebook::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Treebook(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Treebook, AddPage)
@@ -109,16 +111,17 @@ Gura_DeclareMethod(wx_Treebook, AddPage)
 
 Gura_ImplementMethod(wx_Treebook, AddPage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *page = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *page = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	bool bSelect = false;
-	if (args.IsValid(2)) bSelect = args.GetBoolean(2);
+	if (arg.IsValid(2)) bSelect = arg.GetBoolean(2);
 	int imageId = wxNOT_FOUND;
-	if (args.IsValid(3)) imageId = args.GetInt(3);
+	if (arg.IsValid(3)) imageId = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AddPage(page, text, bSelect, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, AddSubPage)
@@ -133,16 +136,17 @@ Gura_DeclareMethod(wx_Treebook, AddSubPage)
 
 Gura_ImplementMethod(wx_Treebook, AddSubPage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *page = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *page = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	bool bSelect = false;
-	if (args.IsValid(2)) bSelect = args.GetBoolean(2);
+	if (arg.IsValid(2)) bSelect = arg.GetBoolean(2);
 	int imageId = wxNOT_FOUND;
-	if (args.IsValid(3)) imageId = args.GetInt(3);
+	if (arg.IsValid(3)) imageId = arg.GetInt(3);
 	bool rtn = pThis->GetEntity()->AddSubPage(page, text, bSelect, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, AssignImageList)
@@ -153,11 +157,12 @@ Gura_DeclareMethod(wx_Treebook, AssignImageList)
 
 Gura_ImplementMethod(wx_Treebook, AssignImageList)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxImageList *imageList = Object_wx_ImageList::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxImageList *imageList = Object_wx_ImageList::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AssignImageList(imageList);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Treebook, ChangeSelection)
@@ -169,11 +174,12 @@ Gura_DeclareMethod(wx_Treebook, ChangeSelection)
 
 Gura_ImplementMethod(wx_Treebook, ChangeSelection)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->ChangeSelection(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, CollapseNode)
@@ -185,11 +191,12 @@ Gura_DeclareMethod(wx_Treebook, CollapseNode)
 
 Gura_ImplementMethod(wx_Treebook, CollapseNode)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pageId = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pageId = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->CollapseNode(pageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, Create)
@@ -206,20 +213,21 @@ Gura_DeclareMethod(wx_Treebook, Create)
 
 Gura_ImplementMethod(wx_Treebook, Create)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxWindowID id = static_cast<wxWindowID>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxWindowID id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = wxBK_DEFAULT;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxEmptyString;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	bool rtn = pThis->GetEntity()->Create(parent, id, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, DeleteAllPages)
@@ -230,10 +238,11 @@ Gura_DeclareMethod(wx_Treebook, DeleteAllPages)
 
 Gura_ImplementMethod(wx_Treebook, DeleteAllPages)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DeleteAllPages();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, DeletePage)
@@ -245,11 +254,12 @@ Gura_DeclareMethod(wx_Treebook, DeletePage)
 
 Gura_ImplementMethod(wx_Treebook, DeletePage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pagePos = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pagePos = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->DeletePage(pagePos);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, ExpandNode)
@@ -262,13 +272,14 @@ Gura_DeclareMethod(wx_Treebook, ExpandNode)
 
 Gura_ImplementMethod(wx_Treebook, ExpandNode)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pageId = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pageId = arg.GetSizeT(0);
 	bool expand = true;
-	if (args.IsValid(1)) expand = args.GetBoolean(1);
+	if (arg.IsValid(1)) expand = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->ExpandNode(pageId, expand);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, GetPageImage)
@@ -280,11 +291,12 @@ Gura_DeclareMethod(wx_Treebook, GetPageImage)
 
 Gura_ImplementMethod(wx_Treebook, GetPageImage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->GetPageImage(n);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, GetPageParent)
@@ -296,11 +308,12 @@ Gura_DeclareMethod(wx_Treebook, GetPageParent)
 
 Gura_ImplementMethod(wx_Treebook, GetPageParent)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->GetPageParent(page);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, GetPageText)
@@ -312,11 +325,12 @@ Gura_DeclareMethod(wx_Treebook, GetPageText)
 
 Gura_ImplementMethod(wx_Treebook, GetPageText)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxString rtn = pThis->GetEntity()->GetPageText(n);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Treebook, GetSelection)
@@ -327,10 +341,11 @@ Gura_DeclareMethod(wx_Treebook, GetSelection)
 
 Gura_ImplementMethod(wx_Treebook, GetSelection)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, InsertPage)
@@ -346,17 +361,18 @@ Gura_DeclareMethod(wx_Treebook, InsertPage)
 
 Gura_ImplementMethod(wx_Treebook, InsertPage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pagePos = args.GetSizeT(0);
-	wxWindow *page = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pagePos = arg.GetSizeT(0);
+	wxWindow *page = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(2));
 	bool bSelect = false;
-	if (args.IsValid(3)) bSelect = args.GetBoolean(3);
+	if (arg.IsValid(3)) bSelect = arg.GetBoolean(3);
 	int imageId = wxNOT_FOUND;
-	if (args.IsValid(4)) imageId = args.GetInt(4);
+	if (arg.IsValid(4)) imageId = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->InsertPage(pagePos, page, text, bSelect, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, InsertSubPage)
@@ -372,17 +388,18 @@ Gura_DeclareMethod(wx_Treebook, InsertSubPage)
 
 Gura_ImplementMethod(wx_Treebook, InsertSubPage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pagePos = args.GetSizeT(0);
-	wxWindow *page = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString text = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pagePos = arg.GetSizeT(0);
+	wxWindow *page = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString text = wxString::FromUTF8(arg.GetString(2));
 	bool bSelect = false;
-	if (args.IsValid(3)) bSelect = args.GetBoolean(3);
+	if (arg.IsValid(3)) bSelect = arg.GetBoolean(3);
 	int imageId = wxNOT_FOUND;
-	if (args.IsValid(4)) imageId = args.GetInt(4);
+	if (arg.IsValid(4)) imageId = arg.GetInt(4);
 	bool rtn = pThis->GetEntity()->InsertSubPage(pagePos, page, text, bSelect, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, IsNodeExpanded)
@@ -394,11 +411,12 @@ Gura_DeclareMethod(wx_Treebook, IsNodeExpanded)
 
 Gura_ImplementMethod(wx_Treebook, IsNodeExpanded)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t pageId = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t pageId = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->IsNodeExpanded(pageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, SetImageList)
@@ -409,12 +427,13 @@ Gura_DeclareMethod(wx_Treebook, SetImageList)
 
 Gura_ImplementMethod(wx_Treebook, SetImageList)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxImageList *imageList = NULL;
-	if (args.IsValid(0)) imageList = Object_wx_ImageList::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxImageList *imageList = nullptr;
+	if (arg.IsValid(0)) imageList = Object_wx_ImageList::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetImageList(imageList);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Treebook, SetPageImage)
@@ -427,12 +446,13 @@ Gura_DeclareMethod(wx_Treebook, SetPageImage)
 
 Gura_ImplementMethod(wx_Treebook, SetPageImage)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	int imageId = args.GetInt(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	int imageId = arg.GetInt(1);
 	bool rtn = pThis->GetEntity()->SetPageImage(page, imageId);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, SetPageText)
@@ -445,12 +465,13 @@ Gura_DeclareMethod(wx_Treebook, SetPageText)
 
 Gura_ImplementMethod(wx_Treebook, SetPageText)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t page = args.GetSizeT(0);
-	wxString text = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t page = arg.GetSizeT(0);
+	wxString text = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->SetPageText(page, text);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Treebook, SetSelection)
@@ -462,11 +483,12 @@ Gura_DeclareMethod(wx_Treebook, SetSelection)
 
 Gura_ImplementMethod(wx_Treebook, SetSelection)
 {
-	Object_wx_Treebook *pThis = Object_wx_Treebook::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Treebook *pThis = Object_wx_Treebook::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	int rtn = pThis->GetEntity()->SetSelection(n);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 //----------------------------------------------------------------------------
@@ -478,13 +500,13 @@ Object_wx_Treebook::~Object_wx_Treebook()
 
 Object *Object_wx_Treebook::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Treebook::ToString(bool exprFlag)
 {
 	String rtn("<wx.Treebook:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -525,7 +547,7 @@ Gura_ImplementUserInheritableClass(wx_Treebook)
 
 Gura_ImplementDescendantCreator(wx_Treebook)
 {
-	return new Object_wx_Treebook((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Treebook((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
