@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_VListBox: public wxVListBox, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_VListBox *_pObj;
 public:
-	//inline wx_VListBox(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxVListBox(parent, id, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
-	//inline wx_VListBox() : wxVListBox(), _sig(NULL), _pObj(NULL) {}
+	//inline wx_VListBox(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxVListBox(parent, id, pos, size, style, name), _pObj(nullptr) {}
+	//inline wx_VListBox() : wxVListBox(), _pObj(nullptr) {}
 	~wx_VListBox();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_VListBox *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_VListBox *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_VListBox::~wx_VListBox()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_VListBox::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -54,32 +54,33 @@ Gura_DeclareFunction(VListBox)
 
 Gura_ImplementFunction(VListBox)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxVListBoxNameStr;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	wx_VListBox *pEntity = new wx_VListBox(parent, id, *pos, *size, style, name);
-	Object_wx_VListBox *pObj = Object_wx_VListBox::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_VListBox *pObj = Object_wx_VListBox::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_VListBox(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(VListBoxEmpty)
@@ -93,21 +94,22 @@ Gura_DeclareFunction(VListBoxEmpty)
 
 Gura_ImplementFunction(VListBoxEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_VListBox *pEntity = new wx_VListBox();
-	Object_wx_VListBox *pObj = Object_wx_VListBox::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_VListBox *pObj = Object_wx_VListBox::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_VListBox(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, Clear)
@@ -117,10 +119,11 @@ Gura_DeclareMethod(wx_VListBox, Clear)
 
 Gura_ImplementMethod(wx_VListBox, Clear)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, Create)
@@ -137,21 +140,22 @@ Gura_DeclareMethod(wx_VListBox, Create)
 
 Gura_ImplementMethod(wx_VListBox, Create)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxVListBoxNameStr;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	bool rtn = pThis->GetEntity()->Create(parent, id, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, DeselectAll)
@@ -162,10 +166,11 @@ Gura_DeclareMethod(wx_VListBox, DeselectAll)
 
 Gura_ImplementMethod(wx_VListBox, DeselectAll)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->DeselectAll();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetFirstSelected)
@@ -177,11 +182,12 @@ Gura_DeclareMethod(wx_VListBox, GetFirstSelected)
 
 Gura_ImplementMethod(wx_VListBox, GetFirstSelected)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned long cookie = args.GetULong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned long cookie = arg.GetULong(0);
 	int rtn = pThis->GetEntity()->GetFirstSelected(cookie);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetItemCount)
@@ -192,10 +198,11 @@ Gura_DeclareMethod(wx_VListBox, GetItemCount)
 
 Gura_ImplementMethod(wx_VListBox, GetItemCount)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetItemCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetMargins)
@@ -206,10 +213,11 @@ Gura_DeclareMethod(wx_VListBox, GetMargins)
 
 Gura_ImplementMethod(wx_VListBox, GetMargins)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxPoint rtn = pThis->GetEntity()->GetMargins();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetNextSelected)
@@ -221,11 +229,12 @@ Gura_DeclareMethod(wx_VListBox, GetNextSelected)
 
 Gura_ImplementMethod(wx_VListBox, GetNextSelected)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	unsigned long cookie = args.GetULong(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	unsigned long cookie = arg.GetULong(0);
 	int rtn = pThis->GetEntity()->GetNextSelected(cookie);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetSelectedCount)
@@ -236,10 +245,11 @@ Gura_DeclareMethod(wx_VListBox, GetSelectedCount)
 
 Gura_ImplementMethod(wx_VListBox, GetSelectedCount)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetSelectedCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetSelection)
@@ -250,10 +260,11 @@ Gura_DeclareMethod(wx_VListBox, GetSelection)
 
 Gura_ImplementMethod(wx_VListBox, GetSelection)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, GetSelectionBackground)
@@ -264,10 +275,11 @@ Gura_DeclareMethod(wx_VListBox, GetSelectionBackground)
 
 Gura_ImplementMethod(wx_VListBox, GetSelectionBackground)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	const wxColour &rtn = pThis->GetEntity()->GetSelectionBackground();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_VListBox, HasMultipleSelection)
@@ -278,10 +290,11 @@ Gura_DeclareMethod(wx_VListBox, HasMultipleSelection)
 
 Gura_ImplementMethod(wx_VListBox, HasMultipleSelection)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->HasMultipleSelection();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, IsCurrent)
@@ -293,11 +306,12 @@ Gura_DeclareMethod(wx_VListBox, IsCurrent)
 
 Gura_ImplementMethod(wx_VListBox, IsCurrent)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t item = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t item = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->IsCurrent(item);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, IsSelected)
@@ -309,11 +323,12 @@ Gura_DeclareMethod(wx_VListBox, IsSelected)
 
 Gura_ImplementMethod(wx_VListBox, IsSelected)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t item = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t item = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->IsSelected(item);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, OnDrawBackground)
@@ -328,17 +343,18 @@ Gura_DeclareMethod(wx_VListBox, OnDrawBackground)
 
 Gura_ImplementMethod(wx_VListBox, OnDrawBackground)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC *dc = Object_wx_DC::GetObject(args, 0)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 1)->GetEntity();
-	size_t n = args.GetSizeT(2);
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC *dc = Object_wx_DC::GetObject(arg, 0)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 1)->GetEntity();
+	size_t n = arg.GetSizeT(2);
 	pThis->GetEntity()->OnDrawBackground(*dc, *rect, n);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, OnDrawItem)
@@ -353,17 +369,18 @@ Gura_DeclareMethod(wx_VListBox, OnDrawItem)
 
 Gura_ImplementMethod(wx_VListBox, OnDrawItem)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC *dc = Object_wx_DC::GetObject(args, 0)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 1)->GetEntity();
-	size_t n = args.GetSizeT(2);
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC *dc = Object_wx_DC::GetObject(arg, 0)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 1)->GetEntity();
+	size_t n = arg.GetSizeT(2);
 	pThis->GetEntity()->OnDrawItem(*dc, *rect, n);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, OnDrawSeparator)
@@ -378,17 +395,18 @@ Gura_DeclareMethod(wx_VListBox, OnDrawSeparator)
 
 Gura_ImplementMethod(wx_VListBox, OnDrawSeparator)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDC *dc = Object_wx_DC::GetObject(args, 0)->GetEntity();
-	wxRect *rect = Object_wx_Rect::GetObject(args, 1)->GetEntity();
-	size_t n = args.GetSizeT(2);
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDC *dc = Object_wx_DC::GetObject(arg, 0)->GetEntity();
+	wxRect *rect = Object_wx_Rect::GetObject(arg, 1)->GetEntity();
+	size_t n = arg.GetSizeT(2);
 	pThis->GetEntity()->OnDrawSeparator(*dc, *rect, n);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, OnMeasureItem)
@@ -402,15 +420,16 @@ Gura_DeclareMethod(wx_VListBox, OnMeasureItem)
 
 Gura_ImplementMethod(wx_VListBox, OnMeasureItem)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxCoord rtn = pThis->GetEntity()->OnMeasureItem(n);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, Select)
@@ -423,13 +442,14 @@ Gura_DeclareMethod(wx_VListBox, Select)
 
 Gura_ImplementMethod(wx_VListBox, Select)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t item = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t item = arg.GetSizeT(0);
 	bool select = true;
-	if (args.IsValid(1)) select = args.GetBoolean(1);
+	if (arg.IsValid(1)) select = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->Select(item, select);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, SelectAll)
@@ -440,10 +460,11 @@ Gura_DeclareMethod(wx_VListBox, SelectAll)
 
 Gura_ImplementMethod(wx_VListBox, SelectAll)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->SelectAll();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, SelectRange)
@@ -456,12 +477,13 @@ Gura_DeclareMethod(wx_VListBox, SelectRange)
 
 Gura_ImplementMethod(wx_VListBox, SelectRange)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t from = args.GetSizeT(0);
-	size_t to = args.GetSizeT(1);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t from = arg.GetSizeT(0);
+	size_t to = arg.GetSizeT(1);
 	bool rtn = pThis->GetEntity()->SelectRange(from, to);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VListBox, SetItemCount)
@@ -472,11 +494,12 @@ Gura_DeclareMethod(wx_VListBox, SetItemCount)
 
 Gura_ImplementMethod(wx_VListBox, SetItemCount)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t count = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t count = arg.GetSizeT(0);
 	pThis->GetEntity()->SetItemCount(count);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, SetMargins)
@@ -487,11 +510,12 @@ Gura_DeclareMethod(wx_VListBox, SetMargins)
 
 Gura_ImplementMethod(wx_VListBox, SetMargins)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetMargins(*pt);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, SetMargins_1)
@@ -503,12 +527,13 @@ Gura_DeclareMethod(wx_VListBox, SetMargins_1)
 
 Gura_ImplementMethod(wx_VListBox, SetMargins_1)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
 	pThis->GetEntity()->SetMargins(x, y);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, SetSelection)
@@ -519,11 +544,12 @@ Gura_DeclareMethod(wx_VListBox, SetSelection)
 
 Gura_ImplementMethod(wx_VListBox, SetSelection)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int selection = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int selection = arg.GetInt(0);
 	pThis->GetEntity()->SetSelection(selection);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, SetSelectionBackground)
@@ -534,11 +560,12 @@ Gura_DeclareMethod(wx_VListBox, SetSelectionBackground)
 
 Gura_ImplementMethod(wx_VListBox, SetSelectionBackground)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxColour *col = Object_wx_Colour::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxColour *col = Object_wx_Colour::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetSelectionBackground(*col);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VListBox, Toggle)
@@ -549,11 +576,12 @@ Gura_DeclareMethod(wx_VListBox, Toggle)
 
 Gura_ImplementMethod(wx_VListBox, Toggle)
 {
-	Object_wx_VListBox *pThis = Object_wx_VListBox::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t item = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VListBox *pThis = Object_wx_VListBox::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t item = arg.GetSizeT(0);
 	pThis->GetEntity()->Toggle(item);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -565,13 +593,13 @@ Object_wx_VListBox::~Object_wx_VListBox()
 
 Object *Object_wx_VListBox::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_VListBox::ToString(bool exprFlag)
 {
 	String rtn("<wx.VListBox:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -619,7 +647,7 @@ Gura_ImplementUserInheritableClass(wx_VListBox)
 
 Gura_ImplementDescendantCreator(wx_VListBox)
 {
-	return new Object_wx_VListBox((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_VListBox((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
