@@ -15,17 +15,17 @@ Gura_DeclarePrivUserSymbol(OnGetLinesHint);
 //----------------------------------------------------------------------------
 class wx_VScrolledWindow: public wxVScrolledWindow, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_VScrolledWindow *_pObj;
 public:
-	//inline wx_VScrolledWindow(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxVScrolledWindow(parent, id, pos, size, style, name), _sig(NULL), _pObj(NULL) {}
-	//inline wx_VScrolledWindow() : wxVScrolledWindow(), _sig(NULL), _pObj(NULL) {}
+	//inline wx_VScrolledWindow(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name) : wxVScrolledWindow(parent, id, pos, size, style, name), _pObj(nullptr) {}
+	//inline wx_VScrolledWindow() : wxVScrolledWindow(), _pObj(nullptr) {}
 	//virtual wxCoord EstimateTotalHeight();
 	//virtual wxCoord OnGetLineHeight(size_t n);
 	//virtual void OnGetLinesHint(size_t lineMin, size_t lineMax);
 	~wx_VScrolledWindow();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_VScrolledWindow *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_VScrolledWindow *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -33,12 +33,12 @@ public:
 
 wx_VScrolledWindow::~wx_VScrolledWindow()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_VScrolledWindow::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -61,32 +61,33 @@ Gura_DeclareFunction(VScrolledWindow)
 
 Gura_ImplementFunction(VScrolledWindow)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxPanelNameStr;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	wx_VScrolledWindow *pEntity = new wx_VScrolledWindow(parent, id, *pos, *size, style, name);
-	Object_wx_VScrolledWindow *pObj = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_VScrolledWindow *pObj = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_VScrolledWindow(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(VScrolledWindowEmpty)
@@ -100,21 +101,22 @@ Gura_DeclareFunction(VScrolledWindowEmpty)
 
 Gura_ImplementFunction(VScrolledWindowEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_VScrolledWindow *pEntity = new wx_VScrolledWindow();
-	Object_wx_VScrolledWindow *pObj = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_VScrolledWindow *pObj = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_VScrolledWindow(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, Create)
@@ -131,21 +133,22 @@ Gura_DeclareMethod(wx_VScrolledWindow, Create)
 
 Gura_ImplementMethod(wx_VScrolledWindow, Create)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	wxWindowID id = wxID_ANY;
-	if (args.IsValid(1)) id = static_cast<wxWindowID>(args.GetInt(1));
+	if (arg.IsValid(1)) id = static_cast<wxWindowID>(arg.GetInt(1));
 	wxPoint *pos = (wxPoint *)(&wxDefaultPosition);
-	if (args.IsValid(2)) pos = Object_wx_Point::GetObject(args, 2)->GetEntity();
+	if (arg.IsValid(2)) pos = Object_wx_Point::GetObject(arg, 2)->GetEntity();
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(3)) size = Object_wx_Size::GetObject(args, 3)->GetEntity();
+	if (arg.IsValid(3)) size = Object_wx_Size::GetObject(arg, 3)->GetEntity();
 	long style = 0;
-	if (args.IsValid(4)) style = args.GetLong(4);
+	if (arg.IsValid(4)) style = arg.GetLong(4);
 	wxString name = wxPanelNameStr;
-	if (args.IsValid(5)) name = wxString::FromUTF8(args.GetString(5));
+	if (arg.IsValid(5)) name = wxString::FromUTF8(arg.GetString(5));
 	bool rtn = pThis->GetEntity()->Create(parent, id, *pos, *size, style, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, EstimateTotalHeight)
@@ -156,56 +159,60 @@ Gura_DeclareMethod(wx_VScrolledWindow, EstimateTotalHeight)
 
 Gura_ImplementMethod(wx_VScrolledWindow, EstimateTotalHeight)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxCoord rtn = pThis->GetEntity()->EstimateTotalHeight();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_VScrolledWindow, GetFirstVisibleLine)
+Gura_DeclareMethod(wx_VScrolledWindow, GetVisibleRowsBegin)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, GetFirstVisibleLine)
+Gura_ImplementMethod(wx_VScrolledWindow, GetVisibleRowsBegin)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t rtn = pThis->GetEntity()->GetFirstVisibleLine();
-	return ReturnValue(env, sig, args, Value(rtn));
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t rtn = pThis->GetEntity()->GetVisibleRowsBegin();
+	return ReturnValue(env, arg, Value(rtn));
 }
 
-Gura_DeclareMethod(wx_VScrolledWindow, GetLastVisibleLine)
+Gura_DeclareMethod(wx_VScrolledWindow, GetVisibleRowsEnd)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, GetLastVisibleLine)
+Gura_ImplementMethod(wx_VScrolledWindow, GetVisibleRowsEnd)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t rtn = pThis->GetEntity()->GetLastVisibleLine();
-	return ReturnValue(env, sig, args, Value(rtn));
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t rtn = pThis->GetEntity()->GetVisibleRowsEnd();
+	return ReturnValue(env, arg, Value(rtn));
 }
 
-Gura_DeclareMethod(wx_VScrolledWindow, GetLineCount)
+Gura_DeclareMethod(wx_VScrolledWindow, GetRowCount)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, GetLineCount)
+Gura_ImplementMethod(wx_VScrolledWindow, GetRowCount)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t rtn = pThis->GetEntity()->GetLineCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t rtn = pThis->GetEntity()->GetRowCount();
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, GetVisibleBegin)
@@ -216,10 +223,11 @@ Gura_DeclareMethod(wx_VScrolledWindow, GetVisibleBegin)
 
 Gura_ImplementMethod(wx_VScrolledWindow, GetVisibleBegin)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetVisibleBegin();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, GetVisibleEnd)
@@ -230,10 +238,11 @@ Gura_DeclareMethod(wx_VScrolledWindow, GetVisibleEnd)
 
 Gura_ImplementMethod(wx_VScrolledWindow, GetVisibleEnd)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetVisibleEnd();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, HitTest)
@@ -246,12 +255,13 @@ Gura_DeclareMethod(wx_VScrolledWindow, HitTest)
 
 Gura_ImplementMethod(wx_VScrolledWindow, HitTest)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxCoord x = static_cast<wxCoord>(args.GetInt(0));
-	wxCoord y = static_cast<wxCoord>(args.GetInt(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxCoord x = static_cast<wxCoord>(arg.GetInt(0));
+	wxCoord y = static_cast<wxCoord>(arg.GetInt(1));
 	int rtn = pThis->GetEntity()->HitTest(x, y);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, HitTest_1)
@@ -263,11 +273,12 @@ Gura_DeclareMethod(wx_VScrolledWindow, HitTest_1)
 
 Gura_ImplementMethod(wx_VScrolledWindow, HitTest_1)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPoint *pt = Object_wx_Point::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPoint *pt = Object_wx_Point::GetObject(arg, 0)->GetEntity();
 	int rtn = pThis->GetEntity()->HitTest(*pt);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, IsVisible)
@@ -279,11 +290,12 @@ Gura_DeclareMethod(wx_VScrolledWindow, IsVisible)
 
 Gura_ImplementMethod(wx_VScrolledWindow, IsVisible)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t line = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t line = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->IsVisible(line);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, OnGetLineHeight)
@@ -297,15 +309,16 @@ Gura_DeclareMethod(wx_VScrolledWindow, OnGetLineHeight)
 
 Gura_ImplementMethod(wx_VScrolledWindow, OnGetLineHeight)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t n = args.GetSizeT(0);
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t n = arg.GetSizeT(0);
 	wxCoord rtn = pThis->GetEntity()->OnGetLineHeight(n);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, OnGetLinesHint)
@@ -319,48 +332,51 @@ Gura_DeclareMethod(wx_VScrolledWindow, OnGetLinesHint)
 
 Gura_ImplementMethod(wx_VScrolledWindow, OnGetLinesHint)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t lineMin = args.GetSizeT(0);
-	size_t lineMax = args.GetSizeT(1);
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t lineMin = arg.GetSizeT(0);
+	size_t lineMax = arg.GetSizeT(1);
 	pThis->GetEntity()->OnGetLinesHint(lineMin, lineMax);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_VScrolledWindow, RefreshLine)
+Gura_DeclareMethod(wx_VScrolledWindow, RefreshRow)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "line", VTYPE_number, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, RefreshLine)
+Gura_ImplementMethod(wx_VScrolledWindow, RefreshRow)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t line = args.GetSizeT(0);
-	pThis->GetEntity()->RefreshLine(line);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t line = arg.GetSizeT(0);
+	pThis->GetEntity()->RefreshRow(line);
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_VScrolledWindow, RefreshLines)
+Gura_DeclareMethod(wx_VScrolledWindow, RefreshRows)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "from", VTYPE_number, OCCUR_Once);
 	DeclareArg(env, "to", VTYPE_number, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, RefreshLines)
+Gura_ImplementMethod(wx_VScrolledWindow, RefreshRows)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t from = args.GetSizeT(0);
-	size_t to = args.GetSizeT(1);
-	pThis->GetEntity()->RefreshLines(from, to);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t from = arg.GetSizeT(0);
+	size_t to = arg.GetSizeT(1);
+	pThis->GetEntity()->RefreshRows(from, to);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_VScrolledWindow, RefreshAll)
@@ -370,10 +386,11 @@ Gura_DeclareMethod(wx_VScrolledWindow, RefreshAll)
 
 Gura_ImplementMethod(wx_VScrolledWindow, RefreshAll)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->RefreshAll();
-	return Value::Null;
+	return Value::Nil;
 }
 
 #if 0
@@ -386,11 +403,12 @@ Gura_DeclareMethod(wx_VScrolledWindow, ScrollLines)
 
 Gura_ImplementMethod(wx_VScrolledWindow, ScrollLines)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int lines = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int lines = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->ScrollLines(lines);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 #endif
 
@@ -404,43 +422,46 @@ Gura_DeclareMethod(wx_VScrolledWindow, ScrollPages)
 
 Gura_ImplementMethod(wx_VScrolledWindow, ScrollPages)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int pages = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int pages = arg.GetInt(0);
 	bool rtn = pThis->GetEntity()->ScrollPages(pages);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 #endif
 
-Gura_DeclareMethod(wx_VScrolledWindow, ScrollToLine)
+Gura_DeclareMethod(wx_VScrolledWindow, ScrollToRow)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "line", VTYPE_number, OCCUR_Once);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, ScrollToLine)
+Gura_ImplementMethod(wx_VScrolledWindow, ScrollToRow)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t line = args.GetSizeT(0);
-	bool rtn = pThis->GetEntity()->ScrollToLine(line);
-	return ReturnValue(env, sig, args, Value(rtn));
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t line = arg.GetSizeT(0);
+	bool rtn = pThis->GetEntity()->ScrollToRow(line);
+	return ReturnValue(env, arg, Value(rtn));
 }
 
-Gura_DeclareMethod(wx_VScrolledWindow, SetLineCount)
+Gura_DeclareMethod(wx_VScrolledWindow, SetRowCount)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "count", VTYPE_number, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_VScrolledWindow, SetLineCount)
+Gura_ImplementMethod(wx_VScrolledWindow, SetRowCount)
 {
-	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t count = args.GetSizeT(0);
-	pThis->GetEntity()->SetLineCount(count);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_VScrolledWindow *pThis = Object_wx_VScrolledWindow::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t count = arg.GetSizeT(0);
+	pThis->GetEntity()->SetRowCount(count);
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -452,13 +473,13 @@ Object_wx_VScrolledWindow::~Object_wx_VScrolledWindow()
 
 Object *Object_wx_VScrolledWindow::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_VScrolledWindow::ToString(bool exprFlag)
 {
 	String rtn("<wx.VScrolledWindow:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -480,9 +501,9 @@ Gura_ImplementUserInheritableClass(wx_VScrolledWindow)
 	Gura_AssignFunction(VScrolledWindowEmpty);
 	Gura_AssignMethod(wx_VScrolledWindow, Create);
 	Gura_AssignMethod(wx_VScrolledWindow, EstimateTotalHeight);
-	Gura_AssignMethod(wx_VScrolledWindow, GetFirstVisibleLine);
-	Gura_AssignMethod(wx_VScrolledWindow, GetLastVisibleLine);
-	Gura_AssignMethod(wx_VScrolledWindow, GetLineCount);
+	Gura_AssignMethod(wx_VScrolledWindow, GetVisibleRowsBegin);
+	Gura_AssignMethod(wx_VScrolledWindow, GetVisibleRowsEnd);
+	Gura_AssignMethod(wx_VScrolledWindow, GetRowCount);
 	Gura_AssignMethod(wx_VScrolledWindow, GetVisibleBegin);
 	Gura_AssignMethod(wx_VScrolledWindow, GetVisibleEnd);
 	Gura_AssignMethod(wx_VScrolledWindow, HitTest);
@@ -490,18 +511,18 @@ Gura_ImplementUserInheritableClass(wx_VScrolledWindow)
 	Gura_AssignMethod(wx_VScrolledWindow, IsVisible);
 	Gura_AssignMethod(wx_VScrolledWindow, OnGetLineHeight);
 	Gura_AssignMethod(wx_VScrolledWindow, OnGetLinesHint);
-	Gura_AssignMethod(wx_VScrolledWindow, RefreshLine);
-	Gura_AssignMethod(wx_VScrolledWindow, RefreshLines);
+	Gura_AssignMethod(wx_VScrolledWindow, RefreshRow);
+	Gura_AssignMethod(wx_VScrolledWindow, RefreshRows);
 	Gura_AssignMethod(wx_VScrolledWindow, RefreshAll);
 	//Gura_AssignMethod(wx_VScrolledWindow, ScrollLines);
 	//Gura_AssignMethod(wx_VScrolledWindow, ScrollPages);
-	Gura_AssignMethod(wx_VScrolledWindow, ScrollToLine);
-	Gura_AssignMethod(wx_VScrolledWindow, SetLineCount);
+	Gura_AssignMethod(wx_VScrolledWindow, ScrollToRow);
+	Gura_AssignMethod(wx_VScrolledWindow, SetRowCount);
 }
 
 Gura_ImplementDescendantCreator(wx_VScrolledWindow)
 {
-	return new Object_wx_VScrolledWindow((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_VScrolledWindow((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
