@@ -11,29 +11,29 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_Variant: public wxVariant, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_Variant *_pObj;
 public:
-	inline wx_Variant() : wxVariant(), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(const wxVariant& variant) : wxVariant(variant), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(const wxChar* value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(const wxString& value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(wxChar value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(long value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(bool value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(double value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	//inline wx_Variant(const wxList& value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(void* value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(wxObject* value, const wxString& name) : wxVariant(value, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(wxVariantData* data, const wxString& name) : wxVariant(data, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(wxDateTime& val, const wxString& name) : wxVariant(val, name), _sig(NULL), _pObj(NULL) {}
-	inline wx_Variant(wxArrayString& val, const wxString& name) : wxVariant(val, name), _sig(NULL), _pObj(NULL) {}
-	//inline wx_Variant(DATE_STRUCT* val, const wxString& name) : wxVariant(val, name), _sig(NULL), _pObj(NULL) {}
-	//inline wx_Variant(TIME_STRUCT* val, const wxString& name) : wxVariant(val, name), _sig(NULL), _pObj(NULL) {}
-	//inline wx_Variant(TIMESTAMP_STRUCT* val, const wxString& name) : wxVariant(val, name), _sig(NULL), _pObj(NULL) {}
+	inline wx_Variant() : wxVariant(), _pObj(nullptr) {}
+	inline wx_Variant(const wxVariant& variant) : wxVariant(variant), _pObj(nullptr) {}
+	inline wx_Variant(const wxChar* value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(const wxString& value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(wxChar value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(long value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(bool value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(double value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	//inline wx_Variant(const wxList& value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(void* value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(wxObject* value, const wxString& name) : wxVariant(value, name), _pObj(nullptr) {}
+	inline wx_Variant(wxVariantData* data, const wxString& name) : wxVariant(data, name), _pObj(nullptr) {}
+	inline wx_Variant(wxDateTime& val, const wxString& name) : wxVariant(val, name), _pObj(nullptr) {}
+	inline wx_Variant(wxArrayString& val, const wxString& name) : wxVariant(val, name), _pObj(nullptr) {}
+	//inline wx_Variant(DATE_STRUCT* val, const wxString& name) : wxVariant(val, name), _pObj(nullptr) {}
+	//inline wx_Variant(TIME_STRUCT* val, const wxString& name) : wxVariant(val, name), _pObj(nullptr) {}
+	//inline wx_Variant(TIMESTAMP_STRUCT* val, const wxString& name) : wxVariant(val, name), _pObj(nullptr) {}
 	~wx_Variant();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_Variant *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_Variant *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -41,12 +41,12 @@ public:
 
 wx_Variant::~wx_Variant()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_Variant::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -61,17 +61,18 @@ Gura_DeclareFunction(VariantEmpty)
 
 Gura_ImplementFunction(VariantEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wx_Variant *pEntity = new wx_Variant();
-	Object_wx_Variant *pObj = Object_wx_Variant::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Variant *pObj = Object_wx_Variant::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Variant(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(Variant)
@@ -85,58 +86,59 @@ Gura_DeclareFunction(Variant)
 
 Gura_ImplementFunction(Variant)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wx_Variant *pEntity = NULL;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wx_Variant *pEntity = nullptr;
 	wxString name = wxEmptyString;
-	if (args.IsValid(1)) name = wxString::FromUTF8(args.GetString(1));
-	if (args.Is_string(0)) {
-		pEntity = new wx_Variant(args.GetString(0), name);
-	} else if (args.Is_number(0)) {
-		pEntity = new wx_Variant(args.GetLong(0), name);
-	} else if (args.Is_boolean(0)) {
-		pEntity = new wx_Variant(args.GetBoolean(0), name);
-	} else if (args.Is_list(0)) {
+	if (arg.IsValid(1)) name = wxString::FromUTF8(arg.GetString(1));
+	if (arg.Is_string(0)) {
+		pEntity = new wx_Variant(arg.GetString(0), name);
+	} else if (arg.Is_number(0)) {
+		pEntity = new wx_Variant(arg.GetLong(0), name);
+	} else if (arg.Is_boolean(0)) {
+		pEntity = new wx_Variant(arg.GetBoolean(0), name);
+	} else if (arg.Is_list(0)) {
 		wxArrayString val;
-		foreach_const (ValueList, pValue, args.GetList(0)) {
+		foreach_const (ValueList, pValue, arg.GetList(0)) {
 			const Value &value = *pValue;
 			if (!value.Is_string()) {
 				sig.SetError(ERR_TypeError, "elements in the list must be string");
-				return Value::Null;
+				return Value::Nil;
 			}
 			val.push_back(wxString::FromUTF8(value.GetString()));
 		}
 		pEntity = new wx_Variant(val, name);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_VariantData)) {
-		pEntity = new wx_Variant(Object_wx_VariantData::GetObject(args, 0)->GetEntity(), name);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_DateTime)) {
-		pEntity = new wx_Variant(*Object_wx_DateTime::GetObject(args, 0)->GetEntity(), name);
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Colour)) {
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_VariantData)) {
+		pEntity = new wx_Variant(Object_wx_VariantData::GetObject(arg, 0)->GetEntity(), name);
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_DateTime)) {
+		pEntity = new wx_Variant(*Object_wx_DateTime::GetObject(arg, 0)->GetEntity(), name);
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Colour)) {
 		pEntity = new wx_Variant();
-		(*pEntity) << *Object_wx_Colour::GetObject(args, 0)->GetEntity();
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Image)) {
+		(*pEntity) << *Object_wx_Colour::GetObject(arg, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Image)) {
 		pEntity = new wx_Variant();
-		(*pEntity) << *Object_wx_Image::GetObject(args, 0)->GetEntity();
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Icon)) {
+		(*pEntity) << *Object_wx_Image::GetObject(arg, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Icon)) {
 		pEntity = new wx_Variant();
-		(*pEntity) << *Object_wx_Icon::GetObject(args, 0)->GetEntity();
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Bitmap)) {
+		(*pEntity) << *Object_wx_Icon::GetObject(arg, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Bitmap)) {
 		pEntity = new wx_Variant();
-		(*pEntity) << *Object_wx_Bitmap::GetObject(args, 0)->GetEntity();
-	} else if (args.IsInstanceOf(0, VTYPE_wx_Object)) {
-		pEntity = new wx_Variant(new wxObject(*Object_wx_Object::GetObject(args, 0)->GetEntity()), name);
+		(*pEntity) << *Object_wx_Bitmap::GetObject(arg, 0)->GetEntity();
+	} else if (arg.IsInstanceOf(0, VTYPE_wx_Object)) {
+		pEntity = new wx_Variant(new wxObject(*Object_wx_Object::GetObject(arg, 0)->GetEntity()), name);
 	} else {
-		SetError_ArgumentTypeByIndex(sig, args, 0);
-		return Value::Null;
+		SetError_ArgumentTypeByIndex(env, arg, 0);
+		return Value::Nil;
 	}
-	Object_wx_Variant *pObj = Object_wx_Variant::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_Variant *pObj = Object_wx_Variant::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_Variant(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_Variant, Append)
@@ -147,11 +149,12 @@ Gura_DeclareMethod(wx_Variant, Append)
 
 Gura_ImplementMethod(wx_Variant, Append)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxVariant *value = Object_wx_Variant::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxVariant *value = Object_wx_Variant::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Append(*value);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Clear)
@@ -161,10 +164,11 @@ Gura_DeclareMethod(wx_Variant, Clear)
 
 Gura_ImplementMethod(wx_Variant, Clear)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->Clear();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, ClearList)
@@ -174,10 +178,11 @@ Gura_DeclareMethod(wx_Variant, ClearList)
 
 Gura_ImplementMethod(wx_Variant, ClearList)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ClearList();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Convert)
@@ -191,15 +196,16 @@ Gura_DeclareMethod(wx_Variant, Convert)
 
 Gura_ImplementMethod(wx_Variant, Convert)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	long value = args.GetLong(0);
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	long value = arg.GetLong(0);
 	bool rtn = pThis->GetEntity()->Convert(value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Convert_1)
@@ -213,15 +219,16 @@ Gura_DeclareMethod(wx_Variant, Convert_1)
 
 Gura_ImplementMethod(wx_Variant, Convert_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	bool value = args.GetBoolean(0);
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	bool value = arg.GetBoolean(0);
 	bool rtn = pThis->GetEntity()->Convert(value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Convert_2)
@@ -235,15 +242,16 @@ Gura_DeclareMethod(wx_Variant, Convert_2)
 
 Gura_ImplementMethod(wx_Variant, Convert_2)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	double value = args.GetDouble(0);
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	double value = arg.GetDouble(0);
 	bool rtn = pThis->GetEntity()->Convert(value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Convert_3)
@@ -257,15 +265,16 @@ Gura_DeclareMethod(wx_Variant, Convert_3)
 
 Gura_ImplementMethod(wx_Variant, Convert_3)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString value = wxString::FromUTF8(args.GetString(0));
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString value = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Convert(value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Convert_4)
@@ -279,15 +288,16 @@ Gura_DeclareMethod(wx_Variant, Convert_4)
 
 Gura_ImplementMethod(wx_Variant, Convert_4)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString value = wxString::FromUTF8(args.GetString(0));
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString value = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Convert(value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, Convert_5)
@@ -299,11 +309,12 @@ Gura_DeclareMethod(wx_Variant, Convert_5)
 
 Gura_ImplementMethod(wx_Variant, Convert_5)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDateTime *value = Object_wx_DateTime::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDateTime *value = Object_wx_DateTime::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Convert(value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetCount)
@@ -314,10 +325,11 @@ Gura_DeclareMethod(wx_Variant, GetCount)
 
 Gura_ImplementMethod(wx_Variant, GetCount)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetCount();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, Delete)
@@ -329,11 +341,12 @@ Gura_DeclareMethod(wx_Variant, Delete)
 
 Gura_ImplementMethod(wx_Variant, Delete)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	size_t item = args.GetSizeT(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	size_t item = arg.GetSizeT(0);
 	bool rtn = pThis->GetEntity()->Delete(item);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetArrayString)
@@ -344,10 +357,11 @@ Gura_DeclareMethod(wx_Variant, GetArrayString)
 
 Gura_ImplementMethod(wx_Variant, GetArrayString)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxArrayString rtn = pThis->GetEntity()->GetArrayString();
-	return ReturnValue(env, sig, args, ArrayStringToValue(env, rtn));
+	return ReturnValue(env, arg, ArrayStringToValue(env, rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetBool)
@@ -358,10 +372,11 @@ Gura_DeclareMethod(wx_Variant, GetBool)
 
 Gura_ImplementMethod(wx_Variant, GetBool)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->GetBool();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetChar)
@@ -372,10 +387,11 @@ Gura_DeclareMethod(wx_Variant, GetChar)
 
 Gura_ImplementMethod(wx_Variant, GetChar)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxChar rtn = pThis->GetEntity()->GetChar();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetData)
@@ -386,10 +402,11 @@ Gura_DeclareMethod(wx_Variant, GetData)
 
 Gura_ImplementMethod(wx_Variant, GetData)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxVariantData *rtn = (wxVariantData *)pThis->GetEntity()->GetData();
-	return ReturnValue(env, sig, args, Value(new Object_wx_VariantData(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_VariantData(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Variant, GetDateTime)
@@ -400,10 +417,11 @@ Gura_DeclareMethod(wx_Variant, GetDateTime)
 
 Gura_ImplementMethod(wx_Variant, GetDateTime)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxDateTime rtn = pThis->GetEntity()->GetDateTime();
-	return ReturnValue(env, sig, args, Value(new Object_wx_DateTime(new wxDateTime(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_DateTime(new wxDateTime(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_Variant, GetDouble)
@@ -414,10 +432,11 @@ Gura_DeclareMethod(wx_Variant, GetDouble)
 
 Gura_ImplementMethod(wx_Variant, GetDouble)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	double rtn = pThis->GetEntity()->GetDouble();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetLong)
@@ -428,10 +447,11 @@ Gura_DeclareMethod(wx_Variant, GetLong)
 
 Gura_ImplementMethod(wx_Variant, GetLong)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetLong();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, GetName)
@@ -442,10 +462,11 @@ Gura_DeclareMethod(wx_Variant, GetName)
 
 Gura_ImplementMethod(wx_Variant, GetName)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Variant, GetString)
@@ -456,10 +477,11 @@ Gura_DeclareMethod(wx_Variant, GetString)
 
 Gura_ImplementMethod(wx_Variant, GetString)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetString();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Variant, GetType)
@@ -470,10 +492,11 @@ Gura_DeclareMethod(wx_Variant, GetType)
 
 Gura_ImplementMethod(wx_Variant, GetType)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetType();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Variant, GetVoidPtr)
@@ -483,10 +506,11 @@ Gura_DeclareMethod(wx_Variant, GetVoidPtr)
 
 Gura_ImplementMethod(wx_Variant, GetVoidPtr)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->GetVoidPtr();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, GetWxObjectPtr)
@@ -497,10 +521,11 @@ Gura_DeclareMethod(wx_Variant, GetWxObjectPtr)
 
 Gura_ImplementMethod(wx_Variant, GetWxObjectPtr)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxObject *rtn = (wxObject *)pThis->GetEntity()->GetWxObjectPtr();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Object(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Object(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_Variant, Insert)
@@ -511,11 +536,12 @@ Gura_DeclareMethod(wx_Variant, Insert)
 
 Gura_ImplementMethod(wx_Variant, Insert)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxVariant *value = Object_wx_Variant::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxVariant *value = Object_wx_Variant::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->Insert(*value);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, IsNull)
@@ -526,10 +552,11 @@ Gura_DeclareMethod(wx_Variant, IsNull)
 
 Gura_ImplementMethod(wx_Variant, IsNull)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsNull();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, IsType)
@@ -541,11 +568,12 @@ Gura_DeclareMethod(wx_Variant, IsType)
 
 Gura_ImplementMethod(wx_Variant, IsType)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString type = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString type = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->IsType(type);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, IsValueKindOf)
@@ -559,15 +587,16 @@ Gura_DeclareMethod(wx_Variant, IsValueKindOf)
 
 Gura_ImplementMethod(wx_Variant, IsValueKindOf)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxClassInfo *type = Object_wx_ClassInfo::GetObject(args, 0)->GetEntity();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxClassInfo *type = Object_wx_ClassInfo::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->IsValueKindOf(*type);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, MakeNull)
@@ -577,10 +606,11 @@ Gura_DeclareMethod(wx_Variant, MakeNull)
 
 Gura_ImplementMethod(wx_Variant, MakeNull)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->MakeNull();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, MakeString)
@@ -591,10 +621,11 @@ Gura_DeclareMethod(wx_Variant, MakeString)
 
 Gura_ImplementMethod(wx_Variant, MakeString)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->MakeString();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_Variant, Member)
@@ -606,11 +637,12 @@ Gura_DeclareMethod(wx_Variant, Member)
 
 Gura_ImplementMethod(wx_Variant, Member)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxVariant *value = Object_wx_Variant::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxVariant *value = Object_wx_Variant::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->Member(*value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_Variant, NullList)
@@ -620,10 +652,11 @@ Gura_DeclareMethod(wx_Variant, NullList)
 
 Gura_ImplementMethod(wx_Variant, NullList)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->NullList();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_Variant, SetData)
@@ -634,11 +667,12 @@ Gura_DeclareMethod(wx_Variant, SetData)
 
 Gura_ImplementMethod(wx_Variant, SetData)
 {
-	Object_wx_Variant *pThis = Object_wx_Variant::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxVariantData *data = Object_wx_VariantData::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_Variant *pThis = Object_wx_Variant::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxVariantData *data = Object_wx_VariantData::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetData(data);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -650,13 +684,13 @@ Object_wx_Variant::~Object_wx_Variant()
 
 Object *Object_wx_Variant::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_Variant::ToString(bool exprFlag)
 {
 	String rtn("<wx.Variant:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -709,7 +743,7 @@ Gura_ImplementUserInheritableClass(wx_Variant)
 
 Gura_ImplementDescendantCreator(wx_Variant)
 {
-	return new Object_wx_Variant((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_Variant((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
