@@ -11,15 +11,15 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_XmlNode: public wxXmlNode, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_XmlNode *_pObj;
 public:
-	//inline wx_XmlNode(wxXmlNode* parent, wxXmlNodeType type, const wxString& name, const wxString& content, wxXmlProperty* props, wxXmlNode* next) : wxXmlNode(parent, type, name, content, props, next), _sig(NULL), _pObj(NULL) {}
-	inline wx_XmlNode(const wxXmlNode& node) : wxXmlNode(node), _sig(NULL), _pObj(NULL) {}
-	inline wx_XmlNode(wxXmlNodeType type, const wxString& name, const wxString& content) : wxXmlNode(type, name, content), _sig(NULL), _pObj(NULL) {}
+	//inline wx_XmlNode(wxXmlNode* parent, wxXmlNodeType type, const wxString& name, const wxString& content, wxXmlAttribute* props, wxXmlNode* next) : wxXmlNode(parent, type, name, content, props, next), _pObj(nullptr) {}
+	inline wx_XmlNode(const wxXmlNode& node) : wxXmlNode(node), _pObj(nullptr) {}
+	inline wx_XmlNode(wxXmlNodeType type, const wxString& name, const wxString& content) : wxXmlNode(type, name, content), _pObj(nullptr) {}
 	~wx_XmlNode();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_XmlNode *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_XmlNode *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -27,12 +27,12 @@ public:
 
 wx_XmlNode::~wx_XmlNode()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_XmlNode::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,7 +47,7 @@ Gura_DeclareFunction(XmlNode)
 	DeclareArg(env, "type", VTYPE_number, OCCUR_Once);
 	DeclareArg(env, "name", VTYPE_string, OCCUR_Once);
 	DeclareArg(env, "content", VTYPE_string, OCCUR_ZeroOrOnce);
-	DeclareArg(env, "props", VTYPE_wx_XmlProperty, OCCUR_ZeroOrOnce);
+	DeclareArg(env, "props", VTYPE_wx_XmlAttribute, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "next", VTYPE_wx_XmlNode, OCCUR_ZeroOrOnce);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 #endif
@@ -55,30 +55,31 @@ Gura_DeclareFunction(XmlNode)
 
 Gura_ImplementFunction(XmlNode)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
-	wxXmlNode *parent = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
-	wxXmlNodeType type = static_cast<wxXmlNodeType>(args.GetInt(1));
-	wxString name = wxString::FromUTF8(args.GetString(2));
+	wxXmlNode *parent = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
+	wxXmlNodeType type = static_cast<wxXmlNodeType>(arg.GetInt(1));
+	wxString name = wxString::FromUTF8(arg.GetString(2));
 	wxString content = wxEmptyString;
-	if (args.IsValid(3)) content = wxString::FromUTF8(args.GetString(3));
-	wxXmlProperty *props = (wxXmlProperty *)();
-	if (args.IsValid(4)) props = Object_wx_XmlProperty::GetObject(args, 4)->GetEntity();
+	if (arg.IsValid(3)) content = wxString::FromUTF8(arg.GetString(3));
+	wxXmlAttribute *props = (wxXmlAttribute *)();
+	if (arg.IsValid(4)) props = Object_wx_XmlAttribute::GetObject(arg, 4)->GetEntity();
 	wxXmlNode *next = (wxXmlNode *)();
-	if (args.IsValid(5)) next = Object_wx_XmlNode::GetObject(args, 5)->GetEntity();
+	if (arg.IsValid(5)) next = Object_wx_XmlNode::GetObject(arg, 5)->GetEntity();
 	wx_XmlNode *pEntity = new wx_XmlNode(parent, type, name, content, props, next);
-	Object_wx_XmlNode *pObj = Object_wx_XmlNode::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_XmlNode *pObj = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_XmlNode(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareFunction(XmlNode_1)
@@ -91,18 +92,19 @@ Gura_DeclareFunction(XmlNode_1)
 
 Gura_ImplementFunction(XmlNode_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxXmlNode *node = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxXmlNode *node = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	wx_XmlNode *pEntity = new wx_XmlNode(*node);
-	Object_wx_XmlNode *pObj = Object_wx_XmlNode::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_XmlNode *pObj = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_XmlNode(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(XmlNode_2)
@@ -117,21 +119,22 @@ Gura_DeclareFunction(XmlNode_2)
 
 Gura_ImplementFunction(XmlNode_2)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxXmlNodeType type = static_cast<wxXmlNodeType>(args.GetInt(0));
-	wxString name = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxXmlNodeType type = static_cast<wxXmlNodeType>(arg.GetInt(0));
+	wxString name = wxString::FromUTF8(arg.GetString(1));
 	wxString content = wxEmptyString;
-	if (args.IsValid(2)) content = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) content = wxString::FromUTF8(arg.GetString(2));
 	wx_XmlNode *pEntity = new wx_XmlNode(type, name, content);
-	Object_wx_XmlNode *pObj = Object_wx_XmlNode::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_XmlNode *pObj = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_XmlNode(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_XmlNode, AddChild)
@@ -142,59 +145,63 @@ Gura_DeclareMethod(wx_XmlNode, AddChild)
 
 Gura_ImplementMethod(wx_XmlNode, AddChild)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *child = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *child = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddChild(child);
-	return Value::Null;
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_XmlNode, AddProperty)
+Gura_DeclareMethod(wx_XmlNode, AddAttribute)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "name", VTYPE_string, OCCUR_Once);
 	DeclareArg(env, "value", VTYPE_string, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_XmlNode, AddProperty)
+Gura_ImplementMethod(wx_XmlNode, AddAttribute)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxString value = wxString::FromUTF8(args.GetString(1));
-	pThis->GetEntity()->AddProperty(name, value);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxString value = wxString::FromUTF8(arg.GetString(1));
+	pThis->GetEntity()->AddAttribute(name, value);
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_XmlNode, AddProperty_1)
+Gura_DeclareMethod(wx_XmlNode, AddAttribute_1)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
-	DeclareArg(env, "prop", VTYPE_wx_XmlProperty, OCCUR_Once);
+	DeclareArg(env, "prop", VTYPE_wx_XmlAttribute, OCCUR_Once);
 }
 
-Gura_ImplementMethod(wx_XmlNode, AddProperty_1)
+Gura_ImplementMethod(wx_XmlNode, AddAttribute_1)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlProperty *prop = Object_wx_XmlProperty::GetObject(args, 0)->GetEntity();
-	pThis->GetEntity()->AddProperty(prop);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlAttribute *prop = Object_wx_XmlAttribute::GetObject(arg, 0)->GetEntity();
+	pThis->GetEntity()->AddAttribute(prop);
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_XmlNode, DeleteProperty)
+Gura_DeclareMethod(wx_XmlNode, DeleteAttribute)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "name", VTYPE_string, OCCUR_Once);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_XmlNode, DeleteProperty)
+Gura_ImplementMethod(wx_XmlNode, DeleteAttribute)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	bool rtn = pThis->GetEntity()->DeleteProperty(name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	bool rtn = pThis->GetEntity()->DeleteAttribute(name);
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetChildren)
@@ -205,10 +212,11 @@ Gura_DeclareMethod(wx_XmlNode, GetChildren)
 
 Gura_ImplementMethod(wx_XmlNode, GetChildren)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxXmlNode *rtn = (wxXmlNode *)pThis->GetEntity()->GetChildren();
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlNode(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_XmlNode(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetContent)
@@ -219,10 +227,11 @@ Gura_DeclareMethod(wx_XmlNode, GetContent)
 
 Gura_ImplementMethod(wx_XmlNode, GetContent)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetContent();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetDepth)
@@ -234,12 +243,13 @@ Gura_DeclareMethod(wx_XmlNode, GetDepth)
 
 Gura_ImplementMethod(wx_XmlNode, GetDepth)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *grandparent = (wxXmlNode *)(NULL);
-	if (args.IsValid(0)) grandparent = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *grandparent = (wxXmlNode *)(nullptr);
+	if (arg.IsValid(0)) grandparent = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	int rtn = pThis->GetEntity()->GetDepth(grandparent);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetNodeContent)
@@ -250,10 +260,11 @@ Gura_DeclareMethod(wx_XmlNode, GetNodeContent)
 
 Gura_ImplementMethod(wx_XmlNode, GetNodeContent)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetNodeContent();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetName)
@@ -264,10 +275,11 @@ Gura_DeclareMethod(wx_XmlNode, GetName)
 
 Gura_ImplementMethod(wx_XmlNode, GetName)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetNext)
@@ -278,10 +290,11 @@ Gura_DeclareMethod(wx_XmlNode, GetNext)
 
 Gura_ImplementMethod(wx_XmlNode, GetNext)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxXmlNode *rtn = (wxXmlNode *)pThis->GetEntity()->GetNext();
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlNode(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_XmlNode(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetParent)
@@ -292,10 +305,11 @@ Gura_DeclareMethod(wx_XmlNode, GetParent)
 
 Gura_ImplementMethod(wx_XmlNode, GetParent)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxXmlNode *rtn = (wxXmlNode *)pThis->GetEntity()->GetParent();
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlNode(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_XmlNode(rtn, nullptr, OwnerFalse)));
 }
 
 #if 0
@@ -309,12 +323,13 @@ Gura_DeclareMethod(wx_XmlNode, GetPropVal)
 
 Gura_ImplementMethod(wx_XmlNode, GetPropVal)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString propName = wxString::FromUTF8(args.GetString(0));
-	wxString value = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString propName = wxString::FromUTF8(arg.GetString(0));
+	wxString value = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->GetPropVal(propName, value);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetPropVal_1)
@@ -327,27 +342,33 @@ Gura_DeclareMethod(wx_XmlNode, GetPropVal_1)
 
 Gura_ImplementMethod(wx_XmlNode, GetPropVal_1)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString propName = wxString::FromUTF8(args.GetString(0));
-	wxString defaultVal = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString propName = wxString::FromUTF8(arg.GetString(0));
+	wxString defaultVal = wxString::FromUTF8(arg.GetString(1));
 	wxString rtn = pThis->GetEntity()->GetPropVal(propName, defaultVal);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 #endif
 
-Gura_DeclareMethod(wx_XmlNode, GetProperties)
+Gura_DeclareMethod(wx_XmlNode, GetAttributes)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_XmlNode, GetProperties)
+Gura_ImplementMethod(wx_XmlNode, GetAttributes)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlProperty *rtn = (wxXmlProperty *)pThis->GetEntity()->GetProperties();
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlProperty(rtn, NULL, OwnerFalse)));
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlAttribute *rtn = (wxXmlAttribute *)pThis->GetEntity()->GetAttributes();
+	return ReturnValue(env, arg, Value(new Object_wx_XmlAttribute(rtn, nullptr, OwnerFalse)));
+#endif
+	SetError_Obsolete(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlNode, GetType)
@@ -358,26 +379,28 @@ Gura_DeclareMethod(wx_XmlNode, GetType)
 
 Gura_ImplementMethod(wx_XmlNode, GetType)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxXmlNodeType rtn = pThis->GetEntity()->GetType();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
-Gura_DeclareMethod(wx_XmlNode, HasProp)
+Gura_DeclareMethod(wx_XmlNode, HasAttribute)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "propName", VTYPE_string, OCCUR_Once);
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
-Gura_ImplementMethod(wx_XmlNode, HasProp)
+Gura_ImplementMethod(wx_XmlNode, HasAttribute)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString propName = wxString::FromUTF8(args.GetString(0));
-	bool rtn = pThis->GetEntity()->HasProp(propName);
-	return ReturnValue(env, sig, args, Value(rtn));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString propName = wxString::FromUTF8(arg.GetString(0));
+	bool rtn = pThis->GetEntity()->HasAttribute(propName);
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, InsertChild)
@@ -390,12 +413,13 @@ Gura_DeclareMethod(wx_XmlNode, InsertChild)
 
 Gura_ImplementMethod(wx_XmlNode, InsertChild)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *child = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
-	wxXmlNode *followingNode = Object_wx_XmlNode::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *child = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
+	wxXmlNode *followingNode = Object_wx_XmlNode::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->InsertChild(child, followingNode);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, InsertChildAfter)
@@ -408,12 +432,13 @@ Gura_DeclareMethod(wx_XmlNode, InsertChildAfter)
 
 Gura_ImplementMethod(wx_XmlNode, InsertChildAfter)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *child = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
-	wxXmlNode *precedingNode = Object_wx_XmlNode::GetObject(args, 1)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *child = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
+	wxXmlNode *precedingNode = Object_wx_XmlNode::GetObject(arg, 1)->GetEntity();
 	bool rtn = pThis->GetEntity()->InsertChildAfter(child, precedingNode);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, IsWhitespaceOnly)
@@ -424,10 +449,11 @@ Gura_DeclareMethod(wx_XmlNode, IsWhitespaceOnly)
 
 Gura_ImplementMethod(wx_XmlNode, IsWhitespaceOnly)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsWhitespaceOnly();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, RemoveChild)
@@ -439,11 +465,12 @@ Gura_DeclareMethod(wx_XmlNode, RemoveChild)
 
 Gura_ImplementMethod(wx_XmlNode, RemoveChild)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *child = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *child = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->RemoveChild(child);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlNode, SetChildren)
@@ -454,11 +481,12 @@ Gura_DeclareMethod(wx_XmlNode, SetChildren)
 
 Gura_ImplementMethod(wx_XmlNode, SetChildren)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *child = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *child = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetChildren(child);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlNode, SetContent)
@@ -469,11 +497,12 @@ Gura_DeclareMethod(wx_XmlNode, SetContent)
 
 Gura_ImplementMethod(wx_XmlNode, SetContent)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString con = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString con = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetContent(con);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlNode, SetName)
@@ -484,11 +513,12 @@ Gura_DeclareMethod(wx_XmlNode, SetName)
 
 Gura_ImplementMethod(wx_XmlNode, SetName)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetName(name);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlNode, SetNext)
@@ -499,11 +529,12 @@ Gura_DeclareMethod(wx_XmlNode, SetNext)
 
 Gura_ImplementMethod(wx_XmlNode, SetNext)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *next = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *next = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetNext(next);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlNode, SetParent)
@@ -514,26 +545,32 @@ Gura_DeclareMethod(wx_XmlNode, SetParent)
 
 Gura_ImplementMethod(wx_XmlNode, SetParent)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *parent = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *parent = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetParent(parent);
-	return Value::Null;
+	return Value::Nil;
 }
 
-Gura_DeclareMethod(wx_XmlNode, SetProperties)
+Gura_DeclareMethod(wx_XmlNode, SetAttributes)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
-	DeclareArg(env, "prop", VTYPE_wx_XmlProperty, OCCUR_Once);
+	DeclareArg(env, "attr", VTYPE_wx_XmlAttribute, OCCUR_Once, FLAG_ListVar);
 }
 
-Gura_ImplementMethod(wx_XmlNode, SetProperties)
+Gura_ImplementMethod(wx_XmlNode, SetAttributes)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlProperty *prop = Object_wx_XmlProperty::GetObject(args, 0)->GetEntity();
-	pThis->GetEntity()->SetProperties(prop);
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+#if 0
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlAttribute *prop = Object_wx_XmlAttribute::GetObject(arg, 0)->GetEntity();
+	pThis->GetEntity()->SetAttributes(prop);
+	return Value::Nil;
+#endif
+	SetError_NotImplemented(sig);
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlNode, SetType)
@@ -544,11 +581,12 @@ Gura_DeclareMethod(wx_XmlNode, SetType)
 
 Gura_ImplementMethod(wx_XmlNode, SetType)
 {
-	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNodeType type = static_cast<wxXmlNodeType>(args.GetInt(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlNode *pThis = Object_wx_XmlNode::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNodeType type = static_cast<wxXmlNodeType>(arg.GetInt(0));
 	pThis->GetEntity()->SetType(type);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -556,20 +594,20 @@ Gura_ImplementMethod(wx_XmlNode, SetType)
 //----------------------------------------------------------------------------
 Object_wx_XmlNode::~Object_wx_XmlNode()
 {
-	if (_pEntity != NULL) NotifyGuraObjectDeleted();
+	if (_pEntity != nullptr) NotifyGuraObjectDeleted();
 	if (_ownerFlag) delete _pEntity;
-	_pEntity = NULL;
+	_pEntity = nullptr;
 }
 
 Object *Object_wx_XmlNode::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_XmlNode::ToString(bool exprFlag)
 {
 	String rtn("<wx.XmlNode:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -588,9 +626,9 @@ Gura_ImplementUserInheritableClass(wx_XmlNode)
 	Gura_AssignFunction(XmlNode_1);
 	Gura_AssignFunction(XmlNode_2);
 	Gura_AssignMethod(wx_XmlNode, AddChild);
-	Gura_AssignMethod(wx_XmlNode, AddProperty);
-	Gura_AssignMethod(wx_XmlNode, AddProperty_1);
-	Gura_AssignMethod(wx_XmlNode, DeleteProperty);
+	Gura_AssignMethod(wx_XmlNode, AddAttribute);
+	Gura_AssignMethod(wx_XmlNode, AddAttribute_1);
+	Gura_AssignMethod(wx_XmlNode, DeleteAttribute);
 	Gura_AssignMethod(wx_XmlNode, GetChildren);
 	Gura_AssignMethod(wx_XmlNode, GetContent);
 	Gura_AssignMethod(wx_XmlNode, GetDepth);
@@ -600,9 +638,9 @@ Gura_ImplementUserInheritableClass(wx_XmlNode)
 	Gura_AssignMethod(wx_XmlNode, GetParent);
 	//Gura_AssignMethod(wx_XmlNode, GetPropVal);
 	//Gura_AssignMethod(wx_XmlNode, GetPropVal_1);
-	Gura_AssignMethod(wx_XmlNode, GetProperties);
+	Gura_AssignMethod(wx_XmlNode, GetAttributes);
 	Gura_AssignMethod(wx_XmlNode, GetType);
-	Gura_AssignMethod(wx_XmlNode, HasProp);
+	Gura_AssignMethod(wx_XmlNode, HasAttribute);
 	Gura_AssignMethod(wx_XmlNode, InsertChild);
 	Gura_AssignMethod(wx_XmlNode, InsertChildAfter);
 	Gura_AssignMethod(wx_XmlNode, IsWhitespaceOnly);
@@ -612,13 +650,13 @@ Gura_ImplementUserInheritableClass(wx_XmlNode)
 	Gura_AssignMethod(wx_XmlNode, SetName);
 	Gura_AssignMethod(wx_XmlNode, SetNext);
 	Gura_AssignMethod(wx_XmlNode, SetParent);
-	Gura_AssignMethod(wx_XmlNode, SetProperties);
+	Gura_AssignMethod(wx_XmlNode, SetAttributes);
 	Gura_AssignMethod(wx_XmlNode, SetType);
 }
 
 Gura_ImplementDescendantCreator(wx_XmlNode)
 {
-	return new Object_wx_XmlNode((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_XmlNode((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
