@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_XmlResource: public wxXmlResource, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_XmlResource *_pObj;
 public:
-	inline wx_XmlResource(const wxString& filemask, int flags, const wxString& domain) : wxXmlResource(filemask, flags, domain), _sig(NULL), _pObj(NULL) {}
-	inline wx_XmlResource(int flags, const wxString& domain) : wxXmlResource(flags, domain), _sig(NULL), _pObj(NULL) {}
+	inline wx_XmlResource(const wxString& filemask, int flags, const wxString& domain) : wxXmlResource(filemask, flags, domain), _pObj(nullptr) {}
+	inline wx_XmlResource(int flags, const wxString& domain) : wxXmlResource(flags, domain), _pObj(nullptr) {}
 	~wx_XmlResource();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_XmlResource *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_XmlResource *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_XmlResource::~wx_XmlResource()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_XmlResource::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,22 +49,23 @@ Gura_DeclareFunction(XmlResource)
 
 Gura_ImplementFunction(XmlResource)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxString filemask = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxString filemask = wxString::FromUTF8(arg.GetString(0));
 	int flags = wxXRC_USE_LOCALE;
-	if (args.IsValid(1)) flags = args.GetInt(1);
+	if (arg.IsValid(1)) flags = arg.GetInt(1);
 	wxString domain = wxEmptyString;
-	if (args.IsValid(2)) domain = wxString::FromUTF8(args.GetString(2));
+	if (arg.IsValid(2)) domain = wxString::FromUTF8(arg.GetString(2));
 	wx_XmlResource *pEntity = new wx_XmlResource(filemask, flags, domain);
-	Object_wx_XmlResource *pObj = Object_wx_XmlResource::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_XmlResource *pObj = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_XmlResource(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(XmlResource_1)
@@ -78,21 +79,22 @@ Gura_DeclareFunction(XmlResource_1)
 
 Gura_ImplementFunction(XmlResource_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	int flags = wxXRC_USE_LOCALE;
-	if (args.IsValid(0)) flags = args.GetInt(0);
+	if (arg.IsValid(0)) flags = arg.GetInt(0);
 	wxString domain = wxEmptyString;
-	if (args.IsValid(1)) domain = wxString::FromUTF8(args.GetString(1));
+	if (arg.IsValid(1)) domain = wxString::FromUTF8(arg.GetString(1));
 	wx_XmlResource *pEntity = new wx_XmlResource(flags, domain);
-	Object_wx_XmlResource *pObj = Object_wx_XmlResource::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_XmlResource *pObj = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_XmlResource(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_XmlResource, AddHandler)
@@ -103,11 +105,12 @@ Gura_DeclareMethod(wx_XmlResource, AddHandler)
 
 Gura_ImplementMethod(wx_XmlResource, AddHandler)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlResourceHandler *handler = Object_wx_XmlResourceHandler::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlResourceHandler *handler = Object_wx_XmlResourceHandler::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->AddHandler(handler);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResource, AttachUnknownControl)
@@ -121,14 +124,15 @@ Gura_DeclareMethod(wx_XmlResource, AttachUnknownControl)
 
 Gura_ImplementMethod(wx_XmlResource, AttachUnknownControl)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	wxWindow *control = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxWindow *parent = (wxWindow *)(NULL);
-	if (args.IsValid(2)) parent = Object_wx_Window::GetObject(args, 2)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	wxWindow *control = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxWindow *parent = (wxWindow *)(nullptr);
+	if (arg.IsValid(2)) parent = Object_wx_Window::GetObject(arg, 2)->GetEntity();
 	bool rtn = pThis->GetEntity()->AttachUnknownControl(name, control, parent);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, ClearHandlers)
@@ -138,10 +142,11 @@ Gura_DeclareMethod(wx_XmlResource, ClearHandlers)
 
 Gura_ImplementMethod(wx_XmlResource, ClearHandlers)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->ClearHandlers();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResource, CompareVersion)
@@ -156,14 +161,15 @@ Gura_DeclareMethod(wx_XmlResource, CompareVersion)
 
 Gura_ImplementMethod(wx_XmlResource, CompareVersion)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int major = args.GetInt(0);
-	int minor = args.GetInt(1);
-	int release = args.GetInt(2);
-	int revision = args.GetInt(3);
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int major = arg.GetInt(0);
+	int minor = arg.GetInt(1);
+	int release = arg.GetInt(2);
+	int revision = arg.GetInt(3);
 	int rtn = pThis->GetEntity()->CompareVersion(major, minor, release, revision);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, Get)
@@ -174,10 +180,11 @@ Gura_DeclareMethod(wx_XmlResource, Get)
 
 Gura_ImplementMethod(wx_XmlResource, Get)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxXmlResource *rtn = (wxXmlResource *)pThis->GetEntity()->Get();
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlResource(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_XmlResource(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, GetFlags)
@@ -188,10 +195,11 @@ Gura_DeclareMethod(wx_XmlResource, GetFlags)
 
 Gura_ImplementMethod(wx_XmlResource, GetFlags)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, GetVersion)
@@ -202,10 +210,11 @@ Gura_DeclareMethod(wx_XmlResource, GetVersion)
 
 Gura_ImplementMethod(wx_XmlResource, GetVersion)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	long rtn = pThis->GetEntity()->GetVersion();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, GetXRCID)
@@ -218,13 +227,14 @@ Gura_DeclareMethod(wx_XmlResource, GetXRCID)
 
 Gura_ImplementMethod(wx_XmlResource, GetXRCID)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString str_id = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString str_id = wxString::FromUTF8(arg.GetString(0));
 	int value_if_not_found = -2;
-	if (args.IsValid(1)) value_if_not_found = args.GetInt(1);
+	if (arg.IsValid(1)) value_if_not_found = arg.GetInt(1);
 	int rtn = pThis->GetEntity()->GetXRCID(str_id, value_if_not_found);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, InitAllHandlers)
@@ -234,10 +244,11 @@ Gura_DeclareMethod(wx_XmlResource, InitAllHandlers)
 
 Gura_ImplementMethod(wx_XmlResource, InitAllHandlers)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->InitAllHandlers();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResource, Load)
@@ -249,11 +260,12 @@ Gura_DeclareMethod(wx_XmlResource, Load)
 
 Gura_ImplementMethod(wx_XmlResource, Load)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString filemask = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString filemask = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Load(filemask);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadBitmap)
@@ -265,11 +277,12 @@ Gura_DeclareMethod(wx_XmlResource, LoadBitmap)
 
 Gura_ImplementMethod(wx_XmlResource, LoadBitmap)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxBitmap rtn = pThis->GetEntity()->LoadBitmap(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadDialog)
@@ -282,12 +295,13 @@ Gura_DeclareMethod(wx_XmlResource, LoadDialog)
 
 Gura_ImplementMethod(wx_XmlResource, LoadDialog)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(1));
 	wxDialog *rtn = (wxDialog *)pThis->GetEntity()->LoadDialog(parent, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Dialog(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Dialog(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadDialog_1)
@@ -301,13 +315,14 @@ Gura_DeclareMethod(wx_XmlResource, LoadDialog_1)
 
 Gura_ImplementMethod(wx_XmlResource, LoadDialog_1)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxDialog *dlg = Object_wx_Dialog::GetObject(args, 0)->GetEntity();
-	wxWindow *parent = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxDialog *dlg = Object_wx_Dialog::GetObject(arg, 0)->GetEntity();
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(2));
 	bool rtn = pThis->GetEntity()->LoadDialog(dlg, parent, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadFrame)
@@ -321,13 +336,14 @@ Gura_DeclareMethod(wx_XmlResource, LoadFrame)
 
 Gura_ImplementMethod(wx_XmlResource, LoadFrame)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxFrame *frame = Object_wx_Frame::GetObject(args, 0)->GetEntity();
-	wxWindow *parent = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxFrame *frame = Object_wx_Frame::GetObject(arg, 0)->GetEntity();
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(2));
 	bool rtn = pThis->GetEntity()->LoadFrame(frame, parent, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadIcon)
@@ -339,11 +355,12 @@ Gura_DeclareMethod(wx_XmlResource, LoadIcon)
 
 Gura_ImplementMethod(wx_XmlResource, LoadIcon)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxIcon rtn = pThis->GetEntity()->LoadIcon(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Icon(new wxIcon(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Icon(new wxIcon(rtn), nullptr, OwnerTrue)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadMenu)
@@ -355,11 +372,12 @@ Gura_DeclareMethod(wx_XmlResource, LoadMenu)
 
 Gura_ImplementMethod(wx_XmlResource, LoadMenu)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxMenu *rtn = (wxMenu *)pThis->GetEntity()->LoadMenu(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Menu(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Menu(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadMenuBar)
@@ -372,12 +390,13 @@ Gura_DeclareMethod(wx_XmlResource, LoadMenuBar)
 
 Gura_ImplementMethod(wx_XmlResource, LoadMenuBar)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(1));
 	wxMenuBar *rtn = (wxMenuBar *)pThis->GetEntity()->LoadMenuBar(parent, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadMenuBar_1)
@@ -389,11 +408,12 @@ Gura_DeclareMethod(wx_XmlResource, LoadMenuBar_1)
 
 Gura_ImplementMethod(wx_XmlResource, LoadMenuBar_1)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxMenuBar *rtn = (wxMenuBar *)pThis->GetEntity()->LoadMenuBar(name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_MenuBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_MenuBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadPanel)
@@ -406,12 +426,13 @@ Gura_DeclareMethod(wx_XmlResource, LoadPanel)
 
 Gura_ImplementMethod(wx_XmlResource, LoadPanel)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(1));
 	wxPanel *rtn = (wxPanel *)pThis->GetEntity()->LoadPanel(parent, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Panel(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Panel(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadPanel_1)
@@ -425,13 +446,14 @@ Gura_DeclareMethod(wx_XmlResource, LoadPanel_1)
 
 Gura_ImplementMethod(wx_XmlResource, LoadPanel_1)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxPanel *panel = Object_wx_Panel::GetObject(args, 0)->GetEntity();
-	wxWindow *parent = Object_wx_Window::GetObject(args, 1)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(2));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxPanel *panel = Object_wx_Panel::GetObject(arg, 0)->GetEntity();
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 1)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(2));
 	bool rtn = pThis->GetEntity()->LoadPanel(panel, parent, name);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, LoadToolBar)
@@ -444,12 +466,13 @@ Gura_DeclareMethod(wx_XmlResource, LoadToolBar)
 
 Gura_ImplementMethod(wx_XmlResource, LoadToolBar)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *parent = Object_wx_Window::GetObject(args, 0)->GetEntity();
-	wxString name = wxString::FromUTF8(args.GetString(1));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *parent = Object_wx_Window::GetObject(arg, 0)->GetEntity();
+	wxString name = wxString::FromUTF8(arg.GetString(1));
 	wxToolBar *rtn = (wxToolBar *)pThis->GetEntity()->LoadToolBar(parent, name);
-	return ReturnValue(env, sig, args, Value(new Object_wx_ToolBar(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ToolBar(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, Set)
@@ -461,11 +484,12 @@ Gura_DeclareMethod(wx_XmlResource, Set)
 
 Gura_ImplementMethod(wx_XmlResource, Set)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlResource *res = Object_wx_XmlResource::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlResource *res = Object_wx_XmlResource::GetObject(arg, 0)->GetEntity();
 	wxXmlResource *rtn = (wxXmlResource *)pThis->GetEntity()->Set(res);
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlResource(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_XmlResource(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_XmlResource, SetFlags)
@@ -476,11 +500,12 @@ Gura_DeclareMethod(wx_XmlResource, SetFlags)
 
 Gura_ImplementMethod(wx_XmlResource, SetFlags)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int flags = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int flags = arg.GetInt(0);
 	pThis->GetEntity()->SetFlags(flags);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResource, Unload)
@@ -492,11 +517,12 @@ Gura_DeclareMethod(wx_XmlResource, Unload)
 
 Gura_ImplementMethod(wx_XmlResource, Unload)
 {
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString filename = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString filename = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->Unload(filename);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_XmlResource, GetDomain)
@@ -507,14 +533,15 @@ Gura_DeclareMethod(wx_XmlResource, GetDomain)
 
 Gura_ImplementMethod(wx_XmlResource, GetDomain)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxChar rtn = pThis->GetEntity()->GetDomain();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResource, SetDomain)
@@ -528,15 +555,16 @@ Gura_DeclareMethod(wx_XmlResource, SetDomain)
 
 Gura_ImplementMethod(wx_XmlResource, SetDomain)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString domain = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResource *pThis = Object_wx_XmlResource::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString domain = wxString::FromUTF8(arg.GetString(0));
 	wxChar rtn = pThis->GetEntity()->SetDomain(domain);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -548,13 +576,13 @@ Object_wx_XmlResource::~Object_wx_XmlResource()
 
 Object *Object_wx_XmlResource::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_XmlResource::ToString(bool exprFlag)
 {
 	String rtn("<wx.XmlResource:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -601,7 +629,7 @@ Gura_ImplementUserInheritableClass(wx_XmlResource)
 
 Gura_ImplementDescendantCreator(wx_XmlResource)
 {
-	return new Object_wx_XmlResource((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_XmlResource((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
