@@ -11,13 +11,13 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_XmlResourceHandler: public wxXmlResourceHandler, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_XmlResourceHandler *_pObj;
 public:
-	//inline wx_XmlResourceHandler() : wxXmlResourceHandler(), _sig(NULL), _pObj(NULL) {}
+	//inline wx_XmlResourceHandler() : wxXmlResourceHandler(), _pObj(nullptr) {}
 	~wx_XmlResourceHandler();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_XmlResourceHandler *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_XmlResourceHandler *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -25,12 +25,12 @@ public:
 
 wx_XmlResourceHandler::~wx_XmlResourceHandler()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_XmlResourceHandler::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -47,21 +47,22 @@ Gura_DeclareFunction(XmlResourceHandlerEmpty)
 
 Gura_ImplementFunction(XmlResourceHandlerEmpty)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 #if 0
 	wx_XmlResourceHandler *pEntity = new wx_XmlResourceHandler();
-	Object_wx_XmlResourceHandler *pObj = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_XmlResourceHandler *pObj = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_XmlResourceHandler(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, AddStyle)
@@ -75,16 +76,17 @@ Gura_DeclareMethod(wx_XmlResourceHandler, AddStyle)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, AddStyle)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
-	int value = args.GetInt(1);
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
+	int value = arg.GetInt(1);
 	pThis->GetEntity()->AddStyle(name, value);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, AddWindowStyles)
@@ -94,14 +96,15 @@ Gura_DeclareMethod(wx_XmlResourceHandler, AddWindowStyles)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, AddWindowStyles)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->AddWindowStyles();
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, CanHandle)
@@ -115,15 +118,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, CanHandle)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, CanHandle)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *node = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *node = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	bool rtn = pThis->GetEntity()->CanHandle(node);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, CreateChildren)
@@ -137,17 +141,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, CreateChildren)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, CreateChildren)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxObject *parent = Object_wx_Object::GetObject(args, 0)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxObject *parent = Object_wx_Object::GetObject(arg, 0)->GetEntity();
 	bool this_hnd_only = false;
-	if (args.IsValid(1)) this_hnd_only = args.GetBoolean(1);
+	if (arg.IsValid(1)) this_hnd_only = arg.GetBoolean(1);
 	pThis->GetEntity()->CreateChildren(parent, this_hnd_only);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, CreateChildrenPrivately)
@@ -161,17 +166,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, CreateChildrenPrivately)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, CreateChildrenPrivately)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxObject *parent = Object_wx_Object::GetObject(args, 0)->GetEntity();
-	wxXmlNode *rootnode = (wxXmlNode *)(NULL);
-	if (args.IsValid(1)) rootnode = Object_wx_XmlNode::GetObject(args, 1)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxObject *parent = Object_wx_Object::GetObject(arg, 0)->GetEntity();
+	wxXmlNode *rootnode = (wxXmlNode *)(nullptr);
+	if (arg.IsValid(1)) rootnode = Object_wx_XmlNode::GetObject(arg, 1)->GetEntity();
 	pThis->GetEntity()->CreateChildrenPrivately(parent, rootnode);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, CreateResFromNode)
@@ -187,18 +193,19 @@ Gura_DeclareMethod(wx_XmlResourceHandler, CreateResFromNode)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, CreateResFromNode)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *node = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
-	wxObject *parent = Object_wx_Object::GetObject(args, 1)->GetEntity();
-	wxObject *instance = (wxObject *)(NULL);
-	if (args.IsValid(2)) instance = Object_wx_Object::GetObject(args, 2)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *node = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
+	wxObject *parent = Object_wx_Object::GetObject(arg, 1)->GetEntity();
+	wxObject *instance = (wxObject *)(nullptr);
+	if (arg.IsValid(2)) instance = Object_wx_Object::GetObject(arg, 2)->GetEntity();
 	wxObject *rtn = (wxObject *)pThis->GetEntity()->CreateResFromNode(node, parent, instance);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Object(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Object(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, CreateResource)
@@ -214,17 +221,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, CreateResource)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, CreateResource)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *node = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
-	wxObject *parent = Object_wx_Object::GetObject(args, 1)->GetEntity();
-	wxObject *instance = Object_wx_Object::GetObject(args, 2)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *node = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
+	wxObject *parent = Object_wx_Object::GetObject(arg, 1)->GetEntity();
+	wxObject *instance = Object_wx_Object::GetObject(arg, 2)->GetEntity();
 	wxObject *rtn = (wxObject *)pThis->GetEntity()->CreateResource(node, parent, instance);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Object(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Object(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, DoCreateResource)
@@ -235,14 +243,15 @@ Gura_DeclareMethod(wx_XmlResourceHandler, DoCreateResource)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, DoCreateResource)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxObject *rtn = (wxObject *)pThis->GetEntity()->DoCreateResource();
-	return ReturnValue(env, sig, args, Value(new Object_wx_Object(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_Object(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetBitmap)
@@ -257,18 +266,19 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetBitmap)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetBitmap)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString param = wxT("bitmap");
-	if (args.IsValid(0)) param = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) param = wxString::FromUTF8(arg.GetString(0));
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(1)) size = Object_wx_Size::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) size = Object_wx_Size::GetObject(arg, 1)->GetEntity();
 	wxBitmap rtn = pThis->GetEntity()->GetBitmap(param, *size);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Bitmap(new wxBitmap(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Bitmap(new wxBitmap(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetBool)
@@ -283,17 +293,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetBool)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetBool)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	bool defaultv = false;
-	if (args.IsValid(1)) defaultv = args.GetBoolean(1);
+	if (arg.IsValid(1)) defaultv = arg.GetBoolean(1);
 	bool rtn = pThis->GetEntity()->GetBool(param, defaultv);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetColour)
@@ -308,17 +319,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetColour)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetColour)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	wxColour *default = (wxColour *)(&wxNullColour);
-	if (args.IsValid(1)) default = Object_wx_Colour::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) default = Object_wx_Colour::GetObject(arg, 1)->GetEntity();
 	wxColour rtn = pThis->GetEntity()->GetColour(param, *default);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Colour(new wxColour(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Colour(new wxColour(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetCurFileSystem)
@@ -329,14 +341,15 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetCurFileSystem)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetCurFileSystem)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxFileSystem &rtn = pThis->GetEntity()->GetCurFileSystem();
-	return ReturnValue(env, sig, args, Value(new Object_wx_FileSystem(new wxFileSystem(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_FileSystem(new wxFileSystem(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetDimension)
@@ -351,17 +364,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetDimension)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetDimension)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	wxCoord defaultv = 0;
-	if (args.IsValid(1)) defaultv = static_cast<wxCoord>(args.GetInt(1));
+	if (arg.IsValid(1)) defaultv = static_cast<wxCoord>(arg.GetInt(1));
 	wxCoord rtn = pThis->GetEntity()->GetDimension(param, defaultv);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetFont)
@@ -375,16 +389,17 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetFont)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetFont)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString param = wxT("font");
-	if (args.IsValid(0)) param = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) param = wxString::FromUTF8(arg.GetString(0));
 	wxFont rtn = pThis->GetEntity()->GetFont(param);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Font(new wxFont(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Font(new wxFont(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetID)
@@ -395,14 +410,15 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetID)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetID)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetID();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetIcon)
@@ -417,18 +433,19 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetIcon)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetIcon)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString param = wxT("icon");
-	if (args.IsValid(0)) param = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) param = wxString::FromUTF8(arg.GetString(0));
 	wxSize *size = (wxSize *)(&wxDefaultSize);
-	if (args.IsValid(1)) size = Object_wx_Size::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) size = Object_wx_Size::GetObject(arg, 1)->GetEntity();
 	wxIcon rtn = pThis->GetEntity()->GetIcon(param, *size);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Icon(new wxIcon(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Icon(new wxIcon(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetLong)
@@ -443,17 +460,18 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetLong)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetLong)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	long defaultv = 0;
-	if (args.IsValid(1)) defaultv = args.GetLong(1);
+	if (arg.IsValid(1)) defaultv = arg.GetLong(1);
 	long rtn = pThis->GetEntity()->GetLong(param, defaultv);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetName)
@@ -464,14 +482,15 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetName)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetName)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetName();
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetNodeContent)
@@ -485,15 +504,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetNodeContent)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetNodeContent)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *node = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *node = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
 	wxString rtn = pThis->GetEntity()->GetNodeContent(node);
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetParamNode)
@@ -507,15 +527,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetParamNode)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetParamNode)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	wxXmlNode *rtn = (wxXmlNode *)pThis->GetEntity()->GetParamNode(param);
-	return ReturnValue(env, sig, args, Value(new Object_wx_XmlNode(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_XmlNode(rtn, nullptr, OwnerFalse)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetParamValue)
@@ -529,15 +550,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetParamValue)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetParamValue)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	wxString rtn = pThis->GetEntity()->GetParamValue(param);
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetPosition)
@@ -551,16 +573,17 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetPosition)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetPosition)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString param = wxT("pos");
-	if (args.IsValid(0)) param = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) param = wxString::FromUTF8(arg.GetString(0));
 	wxPoint rtn = pThis->GetEntity()->GetPosition(param);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Point(new wxPoint(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Point(new wxPoint(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetSize)
@@ -574,16 +597,17 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetSize)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetSize)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString param = wxT("size");
-	if (args.IsValid(0)) param = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) param = wxString::FromUTF8(arg.GetString(0));
 	wxSize rtn = pThis->GetEntity()->GetSize(param);
-	return ReturnValue(env, sig, args, Value(new Object_wx_Size(new wxSize(rtn), NULL, OwnerTrue)));
+	return ReturnValue(env, arg, Value(new Object_wx_Size(new wxSize(rtn), nullptr, OwnerTrue)));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetStyle)
@@ -598,18 +622,19 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetStyle)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetStyle)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString param = wxT("style");
-	if (args.IsValid(0)) param = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) param = wxString::FromUTF8(arg.GetString(0));
 	int defaults = 0;
-	if (args.IsValid(1)) defaults = args.GetInt(1);
+	if (arg.IsValid(1)) defaults = arg.GetInt(1);
 	int rtn = pThis->GetEntity()->GetStyle(param, defaults);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, GetText)
@@ -623,15 +648,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, GetText)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, GetText)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	wxString rtn = pThis->GetEntity()->GetText(param);
-	return ReturnValue(env, sig, args, Value(env, static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(env, static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, HasParam)
@@ -645,15 +671,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, HasParam)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, HasParam)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString param = wxString::FromUTF8(args.GetString(0));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString param = wxString::FromUTF8(arg.GetString(0));
 	bool rtn = pThis->GetEntity()->HasParam(param);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, IsOfClass)
@@ -668,16 +695,17 @@ Gura_DeclareMethod(wx_XmlResourceHandler, IsOfClass)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, IsOfClass)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlNode *node = Object_wx_XmlNode::GetObject(args, 0)->GetEntity();
-	wxString classname = wxString::FromUTF8(args.GetString(1));
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlNode *node = Object_wx_XmlNode::GetObject(arg, 0)->GetEntity();
+	wxString classname = wxString::FromUTF8(arg.GetString(1));
 	bool rtn = pThis->GetEntity()->IsOfClass(node, classname);
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, SetParentResource)
@@ -690,15 +718,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, SetParentResource)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, SetParentResource)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxXmlResource *res = Object_wx_XmlResource::GetObject(args, 0)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxXmlResource *res = Object_wx_XmlResource::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetParentResource(res);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_XmlResourceHandler, SetupWindow)
@@ -711,15 +740,16 @@ Gura_DeclareMethod(wx_XmlResourceHandler, SetupWindow)
 
 Gura_ImplementMethod(wx_XmlResourceHandler, SetupWindow)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxWindow *wnd = Object_wx_Window::GetObject(args, 0)->GetEntity();
+	Object_wx_XmlResourceHandler *pThis = Object_wx_XmlResourceHandler::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxWindow *wnd = Object_wx_Window::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetupWindow(wnd);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -731,13 +761,13 @@ Object_wx_XmlResourceHandler::~Object_wx_XmlResourceHandler()
 
 Object *Object_wx_XmlResourceHandler::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_XmlResourceHandler::ToString(bool exprFlag)
 {
 	String rtn("<wx.XmlResourceHandler:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -786,7 +816,7 @@ Gura_ImplementUserInheritableClass(wx_XmlResourceHandler)
 
 Gura_ImplementDescendantCreator(wx_XmlResourceHandler)
 {
-	return new Object_wx_XmlResourceHandler((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_XmlResourceHandler((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
