@@ -11,14 +11,14 @@ Gura_BeginModuleScope(wx)
 //----------------------------------------------------------------------------
 class wx_ZipEntry: public wxZipEntry, public GuraObjectObserver {
 private:
-	Gura::Signal _sig;
+	//Gura::Signal *_pSig;
 	Object_wx_ZipEntry *_pObj;
 public:
-	inline wx_ZipEntry(const wxString& name, const wxDateTime& dt, off_t size) : wxZipEntry(name, dt, size), _sig(NULL), _pObj(NULL) {}
-	inline wx_ZipEntry(const wxZipEntry& entry) : wxZipEntry(entry), _sig(NULL), _pObj(NULL) {}
+	inline wx_ZipEntry(const wxString& name, const wxDateTime& dt, off_t size) : wxZipEntry(name, dt, size), _pObj(nullptr) {}
+	inline wx_ZipEntry(const wxZipEntry& entry) : wxZipEntry(entry), _pObj(nullptr) {}
 	~wx_ZipEntry();
-	inline void AssocWithGura(Gura::Signal &sig, Object_wx_ZipEntry *pObj) {
-		_sig = sig, _pObj = pObj;
+	inline void AssocWithGura(Object_wx_ZipEntry *pObj) {
+		_pObj = pObj;
 	}
 	// virtual function of GuraObjectObserver
 	virtual void GuraObjectDeleted();
@@ -26,12 +26,12 @@ public:
 
 wx_ZipEntry::~wx_ZipEntry()
 {
-	if (_pObj != NULL) _pObj->InvalidateEntity();
+	if (_pObj != nullptr) _pObj->InvalidateEntity();
 }
 
 void wx_ZipEntry::GuraObjectDeleted()
 {
-	_pObj = NULL;
+	_pObj = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -49,23 +49,24 @@ Gura_DeclareFunction(ZipEntry)
 
 Gura_ImplementFunction(ZipEntry)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
 	wxString name = wxEmptyString;
-	if (args.IsValid(0)) name = wxString::FromUTF8(args.GetString(0));
+	if (arg.IsValid(0)) name = wxString::FromUTF8(arg.GetString(0));
 	wxDateTime dt = wxDateTime::Now();
-	if (args.IsValid(1)) dt = *Object_wx_DateTime::GetObject(args, 1)->GetEntity();
+	if (arg.IsValid(1)) dt = *Object_wx_DateTime::GetObject(arg, 1)->GetEntity();
 	off_t size = wxInvalidOffset;
-	if (args.IsValid(2)) size = static_cast<off_t>(args.GetLong(2));
+	if (arg.IsValid(2)) size = static_cast<off_t>(arg.GetLong(2));
 	wx_ZipEntry *pEntity = new wx_ZipEntry(name, dt, size);
-	Object_wx_ZipEntry *pObj = Object_wx_ZipEntry::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ZipEntry *pObj = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ZipEntry(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareFunction(ZipEntry_1)
@@ -78,18 +79,19 @@ Gura_DeclareFunction(ZipEntry_1)
 
 Gura_ImplementFunction(ZipEntry_1)
 {
-	if (!CheckWxReady(sig)) return Value::Null;
-	wxZipEntry *entry = Object_wx_ZipEntry::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	if (!CheckWxReady(sig)) return Value::Nil;
+	wxZipEntry *entry = Object_wx_ZipEntry::GetObject(arg, 0)->GetEntity();
 	wx_ZipEntry *pEntity = new wx_ZipEntry(*entry);
-	Object_wx_ZipEntry *pObj = Object_wx_ZipEntry::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_wx_ZipEntry *pObj = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_wx_ZipEntry(pEntity, pEntity, OwnerFalse);
-		pEntity->AssocWithGura(sig, pObj);
-		return ReturnValue(env, sig, args, Value(pObj));
+		pEntity->AssocWithGura(pObj);
+		return ReturnValue(env, arg, Value(pObj));
 	}
 	pObj->SetEntity(pEntity, pEntity, OwnerFalse);
-	pEntity->AssocWithGura(sig, pObj);
-	return ReturnValue(env, sig, args, args.GetThis());
+	pEntity->AssocWithGura(pObj);
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 Gura_DeclareMethod(wx_ZipEntry, Clone)
@@ -100,10 +102,11 @@ Gura_DeclareMethod(wx_ZipEntry, Clone)
 
 Gura_ImplementMethod(wx_ZipEntry, Clone)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxZipEntry *rtn = (wxZipEntry *)pThis->GetEntity()->Clone();
-	return ReturnValue(env, sig, args, Value(new Object_wx_ZipEntry(rtn, NULL, OwnerFalse)));
+	return ReturnValue(env, arg, Value(new Object_wx_ZipEntry(rtn, nullptr, OwnerFalse)));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetComment)
@@ -114,10 +117,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetComment)
 
 Gura_ImplementMethod(wx_ZipEntry, GetComment)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetComment();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetComment)
@@ -128,11 +132,12 @@ Gura_DeclareMethod(wx_ZipEntry, SetComment)
 
 Gura_ImplementMethod(wx_ZipEntry, SetComment)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString comment = wxString::FromUTF8(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString comment = wxString::FromUTF8(arg.GetString(0));
 	pThis->GetEntity()->SetComment(comment);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetCompressedSize)
@@ -143,10 +148,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetCompressedSize)
 
 Gura_ImplementMethod(wx_ZipEntry, GetCompressedSize)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	off_t rtn = pThis->GetEntity()->GetCompressedSize();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetCrc)
@@ -157,10 +163,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetCrc)
 
 Gura_ImplementMethod(wx_ZipEntry, GetCrc)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxUint32 rtn = pThis->GetEntity()->GetCrc();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetExternalAttributes)
@@ -171,10 +178,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetExternalAttributes)
 
 Gura_ImplementMethod(wx_ZipEntry, GetExternalAttributes)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxUint32 rtn = pThis->GetEntity()->GetExternalAttributes();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetExternalAttributes)
@@ -185,11 +193,12 @@ Gura_DeclareMethod(wx_ZipEntry, SetExternalAttributes)
 
 Gura_ImplementMethod(wx_ZipEntry, SetExternalAttributes)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxUint32 attr = static_cast<wxUint32>(args.GetULong(0));
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxUint32 attr = static_cast<wxUint32>(arg.GetULong(0));
 	pThis->GetEntity()->SetExternalAttributes(attr);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetExtra)
@@ -200,14 +209,15 @@ Gura_DeclareMethod(wx_ZipEntry, GetExtra)
 
 Gura_ImplementMethod(wx_ZipEntry, GetExtra)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	char rtn = pThis->GetEntity()->GetExtra();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetExtraLen)
@@ -218,10 +228,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetExtraLen)
 
 Gura_ImplementMethod(wx_ZipEntry, GetExtraLen)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetExtraLen();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetExtra)
@@ -235,16 +246,17 @@ Gura_DeclareMethod(wx_ZipEntry, SetExtra)
 
 Gura_ImplementMethod(wx_ZipEntry, SetExtra)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char extra = args.GetChar(0);
-	size_t len = args.GetSizeT(1);
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char extra = arg.GetChar(0);
+	size_t len = arg.GetSizeT(1);
 	pThis->GetEntity()->SetExtra(extra, len);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetFlags)
@@ -255,10 +267,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetFlags)
 
 Gura_ImplementMethod(wx_ZipEntry, GetFlags)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetFlags();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetInternalName)
@@ -269,14 +282,15 @@ Gura_DeclareMethod(wx_ZipEntry, GetInternalName)
 
 Gura_ImplementMethod(wx_ZipEntry, GetInternalName)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	wxString rtn = pThis->GetEntity()->GetInternalName();
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetInternalName_1)
@@ -292,19 +306,20 @@ Gura_DeclareMethod(wx_ZipEntry, GetInternalName_1)
 
 Gura_ImplementMethod(wx_ZipEntry, GetInternalName_1)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxString name = wxString::FromUTF8(args.GetString(0));
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxString name = wxString::FromUTF8(arg.GetString(0));
 	wxPathFormat format = wxPATH_NATIVE;
-	if (args.IsValid(1)) format = static_cast<wxPathFormat>(args.GetInt(1));
-	bool pIsDir = NULL;
-	if (args.IsValid(2)) pIsDir = args.GetBoolean(2);
+	if (arg.IsValid(1)) format = static_cast<wxPathFormat>(arg.GetInt(1));
+	bool pIsDir = nullptr;
+	if (arg.IsValid(2)) pIsDir = arg.GetBoolean(2);
 	wxString rtn = pThis->GetEntity()->GetInternalName(name, format, pIsDir);
-	return ReturnValue(env, sig, args, Value(static_cast<const char *>(rtn.ToUTF8())));
+	return ReturnValue(env, arg, Value(static_cast<const char *>(rtn.ToUTF8())));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetLocalExtra)
@@ -315,14 +330,15 @@ Gura_DeclareMethod(wx_ZipEntry, GetLocalExtra)
 
 Gura_ImplementMethod(wx_ZipEntry, GetLocalExtra)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	char rtn = pThis->GetEntity()->GetLocalExtra();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetLocalExtraLen)
@@ -333,10 +349,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetLocalExtraLen)
 
 Gura_ImplementMethod(wx_ZipEntry, GetLocalExtraLen)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	size_t rtn = pThis->GetEntity()->GetLocalExtraLen();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetLocalExtra)
@@ -350,16 +367,17 @@ Gura_DeclareMethod(wx_ZipEntry, SetLocalExtra)
 
 Gura_ImplementMethod(wx_ZipEntry, SetLocalExtra)
 {
+	Signal &sig = env.GetSignal();
 #if 0
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	char extra = args.GetChar(0);
-	size_t len = args.GetSizeT(1);
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	char extra = arg.GetChar(0);
+	size_t len = arg.GetSizeT(1);
 	pThis->GetEntity()->SetLocalExtra(extra, len);
-	return Value::Null;
+	return Value::Nil;
 #endif
 	SetError_NotImplemented(sig);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetMethod)
@@ -370,10 +388,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetMethod)
 
 Gura_ImplementMethod(wx_ZipEntry, GetMethod)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMethod();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetMethod)
@@ -384,11 +403,12 @@ Gura_DeclareMethod(wx_ZipEntry, SetMethod)
 
 Gura_ImplementMethod(wx_ZipEntry, SetMethod)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int method = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int method = arg.GetInt(0);
 	pThis->GetEntity()->SetMethod(method);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetMode)
@@ -399,10 +419,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetMode)
 
 Gura_ImplementMethod(wx_ZipEntry, GetMode)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetMode();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethodAlias(wx_ZipEntry, SetMode_, "SetMode")
@@ -413,11 +434,12 @@ Gura_DeclareMethodAlias(wx_ZipEntry, SetMode_, "SetMode")
 
 Gura_ImplementMethod(wx_ZipEntry, SetMode_)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int mode = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int mode = arg.GetInt(0);
 	pThis->GetEntity()->SetMode(mode);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetNotifier)
@@ -428,11 +450,12 @@ Gura_DeclareMethod(wx_ZipEntry, SetNotifier)
 
 Gura_ImplementMethod(wx_ZipEntry, SetNotifier)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	wxZipNotifier *notifier = Object_wx_ZipNotifier::GetObject(args, 0)->GetEntity();
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	wxZipNotifier *notifier = Object_wx_ZipNotifier::GetObject(arg, 0)->GetEntity();
 	pThis->GetEntity()->SetNotifier(*notifier);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, UnsetNotifier)
@@ -442,10 +465,11 @@ Gura_DeclareMethod(wx_ZipEntry, UnsetNotifier)
 
 Gura_ImplementMethod(wx_ZipEntry, UnsetNotifier)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	pThis->GetEntity()->UnsetNotifier();
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, GetSystemMadeBy)
@@ -456,10 +480,11 @@ Gura_DeclareMethod(wx_ZipEntry, GetSystemMadeBy)
 
 Gura_ImplementMethod(wx_ZipEntry, GetSystemMadeBy)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	int rtn = pThis->GetEntity()->GetSystemMadeBy();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetSystemMadeBy)
@@ -470,11 +495,12 @@ Gura_DeclareMethod(wx_ZipEntry, SetSystemMadeBy)
 
 Gura_ImplementMethod(wx_ZipEntry, SetSystemMadeBy)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
-	int system = args.GetInt(0);
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
+	int system = arg.GetInt(0);
 	pThis->GetEntity()->SetSystemMadeBy(system);
-	return Value::Null;
+	return Value::Nil;
 }
 
 Gura_DeclareMethod(wx_ZipEntry, IsMadeByUnix)
@@ -485,10 +511,11 @@ Gura_DeclareMethod(wx_ZipEntry, IsMadeByUnix)
 
 Gura_ImplementMethod(wx_ZipEntry, IsMadeByUnix)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsMadeByUnix();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, IsText)
@@ -499,10 +526,11 @@ Gura_DeclareMethod(wx_ZipEntry, IsText)
 
 Gura_ImplementMethod(wx_ZipEntry, IsText)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool rtn = pThis->GetEntity()->IsText();
-	return ReturnValue(env, sig, args, Value(rtn));
+	return ReturnValue(env, arg, Value(rtn));
 }
 
 Gura_DeclareMethod(wx_ZipEntry, SetIsText)
@@ -513,12 +541,13 @@ Gura_DeclareMethod(wx_ZipEntry, SetIsText)
 
 Gura_ImplementMethod(wx_ZipEntry, SetIsText)
 {
-	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetThisObj(args);
-	if (pThis->IsInvalid(sig)) return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_wx_ZipEntry *pThis = Object_wx_ZipEntry::GetObjectThis(arg);
+	if (pThis->IsInvalid(sig)) return Value::Nil;
 	bool isText = true;
-	if (args.IsValid(0)) isText = args.GetBoolean(0);
+	if (arg.IsValid(0)) isText = arg.GetBoolean(0);
 	pThis->GetEntity()->SetIsText(isText);
-	return Value::Null;
+	return Value::Nil;
 }
 
 //----------------------------------------------------------------------------
@@ -530,13 +559,13 @@ Object_wx_ZipEntry::~Object_wx_ZipEntry()
 
 Object *Object_wx_ZipEntry::Clone() const
 {
-	return NULL;
+	return nullptr;
 }
 
 String Object_wx_ZipEntry::ToString(bool exprFlag)
 {
 	String rtn("<wx.ZipEntry:");
-	if (GetEntity() == NULL) {
+	if (GetEntity() == nullptr) {
 		rtn += "invalid>";
 	} else {
 		char buff[64];
@@ -584,7 +613,7 @@ Gura_ImplementUserInheritableClass(wx_ZipEntry)
 
 Gura_ImplementDescendantCreator(wx_ZipEntry)
 {
-	return new Object_wx_ZipEntry((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
+	return new Object_wx_ZipEntry((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
 }
 
 Gura_EndModuleScope(wx)
