@@ -12,7 +12,7 @@ String MakeIndentUnit(int cntSpace);
 //-----------------------------------------------------------------------------
 Parser::Parser()
 {
-	_parser = ::XML_ParserCreate(NULL);
+	_parser = ::XML_ParserCreate(nullptr);
 	::XML_SetUserData(_parser, this);
 	::XML_SetStartElementHandler(_parser,			StartElementHandler);
 	::XML_SetEndElementHandler(_parser,				EndElementHandler);
@@ -43,7 +43,7 @@ Parser::~Parser()
 	::XML_ParserFree(_parser);
 }
 
-bool Parser::Parse(Signal sig, SimpleStream &stream)
+bool Parser::Parse(Signal &sig, SimpleStream &stream)
 {
 	const size_t bytesToRead = 1024 * 8;
 	for (;;) {
@@ -139,7 +139,7 @@ int XMLCALL Parser::ExternalEntityRefHandler(XML_Parser parser,
 {
 	// <!ENTITY>
 	//Parser *pParser = reinterpret_cast<Parser *>(userData);
-	//pParser->OnExternalEntityRef(args, base, systemId, publicId);
+	//pParser->OnExternalEntityRef(arg, base, systemId, publicId);
 	return 0;
 }
 
@@ -157,16 +157,16 @@ int XMLCALL Parser::UnknownEncodingHandler(void *encodingHandlerData,
 		for (int i = 0x81; i <= 0x9f; i++) info->map[i] = -2;
 		for (int i = 0xe0; i <= 0xee; i++) info->map[i] = -2;
 		for (int i = 0xfa; i <= 0xfc; i++) info->map[i] = -2;
-		info->data = NULL;
+		info->data = nullptr;
 		info->convert = Convert_shift_jis;
-		info->release = NULL;
+		info->release = nullptr;
 		return XML_STATUS_OK;
 	} else if (::strcasecmp(name, "euc-jp") == 0) {
 		for (int i = 0; i <= 0x7f; i++) info->map[i] = i;
 		for (int i = 0x81; i <= 0xff; i++) info->map[i] = -2;
-		info->data = NULL;
+		info->data = nullptr;
 		info->convert = Convert_euc_jp;
-		info->release = NULL;
+		info->release = nullptr;
 		return XML_STATUS_OK;
 	}
 	return XML_STATUS_ERROR;
@@ -292,7 +292,7 @@ const Attribute *AttributeList::FindByName(const char *name) const
 		const Attribute *pAttribute = *ppAttribute;
 		if (::strcmp(pAttribute->GetName(), name) == 0) return pAttribute;
 	}
-	return NULL;
+	return nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -319,15 +319,15 @@ Element::Element(Type type, const String &str, const char **atts) :
 										_cntRef(1), _type(type), _str(str)
 {
 	if (type == TYPE_Tag) _pAttributes.reset(new AttributeOwner());
-	if (atts != NULL) {
-		for (const char **p = atts; *p != NULL && *(p + 1) != NULL; p += 2) {
+	if (atts != nullptr) {
+		for (const char **p = atts; *p != nullptr && *(p + 1) != nullptr; p += 2) {
 			const char *name = *p, *value = *(p + 1);
 			GetAttributes()->push_back(new Attribute(name, value));
 		}
 	}
 }
 
-bool Element::Write(Signal sig, SimpleStream &stream,
+bool Element::Write(Signal &sig, SimpleStream &stream,
 				bool fancyFlag, int indentLevel, const char *indentUnit) const
 {
 	String indent;
@@ -352,7 +352,7 @@ bool Element::Write(Signal sig, SimpleStream &stream,
 			stream.PutChar(sig, '"');
 			if (sig.IsSignalled()) return false;
 		}
-		if (GetChildren() == NULL || GetChildren()->empty()) {
+		if (GetChildren() == nullptr || GetChildren()->empty()) {
 			stream.Print(sig, " />");
 			if (sig.IsSignalled()) return false;
 			if (fancyFlag) {
@@ -411,7 +411,7 @@ String Element::GatherText() const
 {
 	if (IsText()) return GetText();
 	String str;
-	if (GetChildren() != NULL) {
+	if (GetChildren() != nullptr) {
 		foreach_const (ElementOwner, ppChild, *GetChildren()) {
 			const Element *pChild = *ppChild;
 			str += pChild->GatherText();
@@ -422,11 +422,11 @@ String Element::GatherText() const
 
 void Element::AddChild(Element *pChild)
 {
-	if (_pChildren.get() == NULL) _pChildren.reset(new ElementOwner());
+	if (_pChildren.get() == nullptr) _pChildren.reset(new ElementOwner());
 	_pChildren->push_back(pChild);
 }
 
-bool Element::AddChild(Environment &env, Signal sig, const Value &value)
+bool Element::AddChild(Environment &env, Signal &sig, const Value &value)
 {
 	if (value.Is_string()) {
 		AutoPtr<Element> pChild(new Element(Element::TYPE_Text, value.GetStringSTL()));
@@ -442,7 +442,7 @@ bool Element::AddChild(Environment &env, Signal sig, const Value &value)
 			return false;
 		}
 		Value valueIter;
-		while (pIterator->Next(env, sig, valueIter)) {
+		while (pIterator->Next(env, valueIter)) {
 			if (!AddChild(env, sig, valueIter)) return false;
 		}
 		if (sig.IsSignalled()) return false;
@@ -453,6 +453,98 @@ bool Element::AddChild(Environment &env, Signal sig, const Value &value)
 	return true;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// xml.element#attrs
+Gura_DeclareProperty_R(element, attrs)
+{
+	SetPropAttr(VTYPE_iterator);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(element, attrs)
+{
+	const Element *pElement = Object_element::GetObject(valueThis)->GetElement();
+	const AttributeOwner *pAttrs = pElement->GetAttributes();
+	if (pAttrs == nullptr) return Value::Nil;
+	Iterator *pIterator = new Iterator_attribute(pAttrs->Reference());
+	return Value(new Object_iterator(env, pIterator));
+}
+
+// xml.element#children
+Gura_DeclareProperty_R(element, children)
+{
+	SetPropAttr(VTYPE_iterator);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(element, children)
+{
+	const Element *pElement = Object_element::GetObject(valueThis)->GetElement();
+	const ElementOwner *pChildren = pElement->GetChildren();
+	if (pChildren == nullptr) return Value::Nil;
+	Iterator *pIterator = new Iterator_element(pChildren->Reference());
+	return Value(new Object_iterator(env, pIterator));
+}
+
+// xml.element#comment
+Gura_DeclareProperty_R(element, comment)
+{
+	SetPropAttr(VTYPE_string, FLAG_Nil);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(element, comment)
+{
+	const Element *pElement = Object_element::GetObject(valueThis)->GetElement();
+	if (!pElement->IsComment()) return Value::Nil;
+	return Value(pElement->GetComment());
+}
+
+// xml.element#tagname
+Gura_DeclareProperty_R(element, tagname)
+{
+	SetPropAttr(VTYPE_string, FLAG_Nil);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(element, tagname)
+{
+	const Element *pElement = Object_element::GetObject(valueThis)->GetElement();
+	if (!pElement->IsTag()) return Value::Nil;
+	return Value(pElement->GetTagName());
+}
+
+// xml.element#text
+Gura_DeclareProperty_R(element, text)
+{
+	SetPropAttr(VTYPE_string, FLAG_Nil);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(element, text)
+{
+	const Element *pElement = Object_element::GetObject(valueThis)->GetElement();
+	if (!pElement->IsText()) return Value::Nil;
+	return Value(pElement->GetText());
+}
+
 //-----------------------------------------------------------------------------
 // ElementList
 //-----------------------------------------------------------------------------
@@ -481,7 +573,7 @@ Document::Document() : _cntRef(1), _version("1.0"), _encoding("utf-8"), _standal
 {
 }
 
-bool Document::Write(Signal sig, SimpleStream &stream,
+bool Document::Write(Signal &sig, SimpleStream &stream,
 								bool fancyFlag, const char *indentUnit) const
 {
 	stream.Print(sig, "<?xml version=\"");
@@ -627,21 +719,22 @@ int Document::OnNotStandalone()
 // Object_parser
 //-----------------------------------------------------------------------------
 Object_parser::Object_parser(Class *pClass) :
-						Object(pClass), _parser(this), _pSig(NULL)
+						Object(pClass), _parser(this), _pSig(nullptr)
 {
 }
 
-void Object_parser::Parse(Environment &env, Signal &sig, Stream &stream)
+void Object_parser::Parse(Environment &env, Stream &stream)
 {
+	Signal &sig = env.GetSignal();
 	_pSig = &sig;
 	_parser.Parse(sig, stream);
-	_pSig = NULL;
+	_pSig = nullptr;
 }
 
 void Object_parser::CallHandler(const Symbol *pSymbol, const ValueList argList)
 {
 	bool evaluatedFlag;
-	Value rtn = EvalMethod(*this, *_pSig, pSymbol, argList, evaluatedFlag);
+	Value rtn = EvalMethod(*this, pSymbol, argList, evaluatedFlag);
 	if (_pSig->IsSignalled()) {
 		_parser.StopParser();
 	}
@@ -855,15 +948,16 @@ Gura_DeclareMethod(parser, parse)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Read);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(parser, parse)
 {
-	Object_parser *pObj = Object_parser::GetThisObj(args);
-	pObj->Parse(env, sig, args.GetStream(0));
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_parser *pObj = Object_parser::GetObjectThis(arg);
+	pObj->Parse(env, arg.GetStream(0));
+	return Value::Nil;
 }
 
 // implementation of class Parser
@@ -874,7 +968,7 @@ Gura_ImplementUserInheritableClass(parser)
 
 Gura_ImplementDescendantCreator(parser)
 {
-	return new Object_parser((pClass == NULL)? this : pClass);
+	return new Object_parser((pClass == nullptr)? this : pClass);
 }
 
 //-----------------------------------------------------------------------------
@@ -885,27 +979,6 @@ Object_attribute::Object_attribute(Attribute *pAttribute) :
 {
 }
 
-bool Object_attribute::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_UserSymbol(name));
-	symbols.insert(Gura_UserSymbol(value));
-	return true;
-}
-
-Value Object_attribute::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(name))) {
-		return Value(_pAttribute->GetName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(value))) {
-		return Value(_pAttribute->GetValue());
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_attribute::ToString(bool exprFlag)
 {
 	String str;
@@ -917,12 +990,51 @@ String Object_attribute::ToString(bool exprFlag)
 	return str;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// xml.attribute#name
+Gura_DeclareProperty_R(attribute, name)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(attribute, name)
+{
+	const Attribute *pAttribute = Object_attribute::GetObject(valueThis)->GetAttribute();
+	return Value(pAttribute->GetName());
+}
+
+// xml.attribute#value
+Gura_DeclareProperty_R(attribute, value)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(attribute, value)
+{
+	const Attribute *pAttribute = Object_attribute::GetObject(valueThis)->GetAttribute();
+	return Value(pAttribute->GetValue());
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for Object_attribute
 //-----------------------------------------------------------------------------
 // implementation of class attribute
 Gura_ImplementUserClass(attribute)
 {
+	// Assignment of properties
+	Gura_AssignProperty(attribute, name);
+	Gura_AssignProperty(attribute, value);
+	// Assignment of value
 	Gura_AssignValue(attribute, Value(Reference()));
 }
 
@@ -934,61 +1046,23 @@ Object_element::Object_element(Element *pElement) :
 {
 }
 
-Value Object_element::IndexGet(Environment &env, Signal sig, const Value &valueIdx)
+Value Object_element::IndexGet(Environment &env, const Value &valueIdx)
 {
+	Signal &sig = GetSignal();
 	if (!valueIdx.Is_string()) {
 		sig.SetError(ERR_ValueError, "index must be a string");
-		return Value::Null;
+		return Value::Nil;
 	}
 	const AttributeOwner *pAttributes = _pElement->GetAttributes();
-	const Attribute *pAttribute = (pAttributes == NULL)?
-					NULL : pAttributes->FindByName(valueIdx.GetString());
-	if (pAttribute == NULL) {
+	const Attribute *pAttribute = (pAttributes == nullptr)?
+					nullptr : pAttributes->FindByName(valueIdx.GetString());
+	if (pAttribute == nullptr) {
 		sig.SetError(ERR_IndexError, "specified attribute doesn't exist");
-		return Value::Null;
+		return Value::Nil;
 	}
 	return Value(pAttribute->GetValue());
 }
 
-bool Object_element::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_UserSymbol(tagname));
-	symbols.insert(Gura_UserSymbol(text));
-	symbols.insert(Gura_UserSymbol(comment));
-	symbols.insert(Gura_UserSymbol(children));
-	symbols.insert(Gura_UserSymbol(attrs));
-	return true;
-}
-
-Value Object_element::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(tagname))) {
-		if (!_pElement->IsTag()) return Value::Null;
-		return Value(_pElement->GetTagName());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(text))) {
-		if (!_pElement->IsText()) return Value::Null;
-		return Value(_pElement->GetText());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(comment))) {
-		if (!_pElement->IsComment()) return Value::Null;
-		return Value(_pElement->GetComment());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(children))) {
-		const ElementOwner *pChildren = _pElement->GetChildren();
-		if (pChildren == NULL) return Value::Null;
-		Iterator *pIterator = new Iterator_element(pChildren->Reference());
-		return Value(new Object_iterator(env, pIterator));
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(attrs))) {
-		const AttributeOwner *pAttrs = _pElement->GetAttributes();
-		if (pAttrs == NULL) return Value::Null;
-		Iterator *pIterator = new Iterator_attribute(pAttrs->Reference());
-		return Value(new Object_iterator(env, pIterator));
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_element::ToString(bool exprFlag)
 {
 	String str;
@@ -1013,15 +1087,16 @@ Gura_DeclareMethod(element, addchild)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "value", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(element, addchild)
 {
-	Object_element *pObj = Object_element::GetThisObj(args);
-	pObj->GetElement()->AddChild(env, sig, args.GetValue(0));
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_element *pObj = Object_element::GetObjectThis(arg);
+	pObj->GetElement()->AddChild(env, sig, arg.GetValue(0));
+	return Value::Nil;
 }
 
 // xml.element#gettext()
@@ -1029,15 +1104,16 @@ Gura_DeclareMethod(element, gettext)
 {
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(element, gettext)
 {
-	Object_element *pObj = Object_element::GetThisObj(args);
+	Signal &sig = env.GetSignal();
+	Object_element *pObj = Object_element::GetObjectThis(arg);
 	String str = pObj->GetElement()->GatherText();
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	return Value(str);
 }
 
@@ -1049,16 +1125,17 @@ Gura_DeclareMethod(element, textize)
 	DeclareArg(env, "indentLevel", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "tabs", VTYPE_number, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(element, textize)
 {
-	Object_element *pObj = Object_element::GetThisObj(args);
-	bool fancyFlag = args.IsValid(0)? args.GetBoolean(0) : false;
-	int indentLevel = args.Is_number(1)? args.GetInt(1) : 0;
-	int cntSpace = args.Is_number(2)? args.GetInt(2) : 2;
+	Signal &sig = env.GetSignal();
+	Object_element *pObj = Object_element::GetObjectThis(arg);
+	bool fancyFlag = arg.IsValid(0)? arg.GetBoolean(0) : false;
+	int indentLevel = arg.Is_number(1)? arg.GetInt(1) : 0;
+	int cntSpace = arg.Is_number(2)? arg.GetInt(2) : 2;
 	String strDst;
 	SimpleStream_StringWriter streamDst(strDst);
 	pObj->GetElement()->Write(sig, streamDst, fancyFlag,
@@ -1075,32 +1152,41 @@ Gura_DeclareMethod(element, write)
 	DeclareArg(env, "indentLevel", VTYPE_number, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "tabs", VTYPE_number, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(element, write)
 {
-	Object_element *pObj = Object_element::GetThisObj(args);
-	bool fancyFlag = args.IsValid(1)? args.GetBoolean(1) : false;
-	int indentLevel = args.Is_number(2)? args.GetInt(2) : 0;
-	int cntSpace = args.Is_number(3)? args.GetInt(3) : 2;
-	pObj->GetElement()->Write(sig, args.GetStream(0),
+	Signal &sig = env.GetSignal();
+	Object_element *pObj = Object_element::GetObjectThis(arg);
+	bool fancyFlag = arg.IsValid(1)? arg.GetBoolean(1) : false;
+	int indentLevel = arg.Is_number(2)? arg.GetInt(2) : 0;
+	int cntSpace = arg.Is_number(3)? arg.GetInt(3) : 2;
+	pObj->GetElement()->Write(sig, arg.GetStream(0),
 				fancyFlag, indentLevel, MakeIndentUnit(cntSpace).c_str());
-	return Value::Null;
+	return Value::Nil;
 }
 
 // operator <<
 Gura_ImplementBinaryOperator(Shl, element, any)
 {
+	Signal &sig = env.GetSignal();
 	Object_element *pObj = Object_element::GetObject(valueLeft);
-	if (!pObj->GetElement()->AddChild(env, sig, valueRight)) return Value::Null;
+	if (!pObj->GetElement()->AddChild(env, sig, valueRight)) return Value::Nil;
 	return valueLeft;
 }
 
 // implementation of class Element
 Gura_ImplementUserClass(element)
 {
+	// Assignment of properties
+	Gura_AssignProperty(element, attrs);
+	Gura_AssignProperty(element, children);
+	Gura_AssignProperty(element, comment);
+	Gura_AssignProperty(element, tagname);
+	Gura_AssignProperty(element, text);
+	// Assignment of methods
 	Gura_AssignMethod(element, addchild);
 	Gura_AssignMethod(element, gettext);
 	Gura_AssignMethod(element, textize);
@@ -1117,47 +1203,6 @@ Object_document::Object_document(Document *pDocument) :
 {
 }
 
-bool Object_document::DoDirProp(Environment &env, Signal sig, SymbolSet &symbols)
-{
-	if (!Object::DoDirProp(env, sig, symbols)) return false;
-	symbols.insert(Gura_UserSymbol(version));
-	symbols.insert(Gura_UserSymbol(encoding));
-	symbols.insert(Gura_UserSymbol(root));
-	return true;
-}
-
-Value Object_document::DoGetProp(Environment &env, Signal sig, const Symbol *pSymbol,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(version))) {
-		return Value(_pDocument->GetVersion());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(encoding))) {
-		return Value(_pDocument->GetEncoding());
-	} else if (pSymbol->IsIdentical(Gura_UserSymbol(root))) {
-		if (_pDocument->GetRoot() == NULL) return Value::Null;
-		return Value(new Object_element(_pDocument->GetRoot()->Reference()));
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
-Value Object_document::DoSetProp(Environment &env, Signal sig, const Symbol *pSymbol, const Value &value,
-							const SymbolSet &attrs, bool &evaluatedFlag)
-{
-	evaluatedFlag = true;
-	if (pSymbol->IsIdentical(Gura_UserSymbol(root))) {
-		if (!value.IsInstanceOf(VTYPE_element)) {
-			sig.SetError(ERR_TypeError, "must specify an instance of xml.element");
-			return Value::Null;
-		}
-		_pDocument->SetRoot(Object_element::GetObject(value)->GetElement()->Reference());
-		return value;
-	}
-	evaluatedFlag = false;
-	return Value::Null;
-}
-
 String Object_document::ToString(bool exprFlag)
 {
 	String str;
@@ -1166,6 +1211,65 @@ String Object_document::ToString(bool exprFlag)
 	return str;
 }
 
+//-----------------------------------------------------------------------------
+// Implementation of properties
+//-----------------------------------------------------------------------------
+// xml.document#encoding
+Gura_DeclareProperty_R(document, encoding)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(document, encoding)
+{
+	const Document *pDocument = Object_document::GetObject(valueThis)->GetDocument();
+	return Value(pDocument->GetEncoding());
+}
+
+// xml.document#root
+Gura_DeclareProperty_RW(document, root)
+{
+	SetPropAttr(VTYPE_element);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(document, root)
+{
+	const Document *pDocument = Object_document::GetObject(valueThis)->GetDocument();
+	if (pDocument->GetRoot() == nullptr) return Value::Nil;
+	return Value(new Object_element(pDocument->GetRoot()->Reference()));
+}
+
+Gura_ImplementPropertySetter(document, root)
+{
+	Document *pDocument = Object_document::GetObject(valueThis)->GetDocument();
+	pDocument->SetRoot(Object_element::GetObject(value)->GetElement()->Reference());
+	return value;
+}
+
+// xml.document#version
+Gura_DeclareProperty_R(document, version)
+{
+	SetPropAttr(VTYPE_string);
+	AddHelp(
+		Gura_Symbol(en),
+		""
+		);
+}
+
+Gura_ImplementPropertyGetter(document, version)
+{
+	const Document *pDocument = Object_document::GetObject(valueThis)->GetDocument();
+	return Value(pDocument->GetVersion());
+}
+
 //-----------------------------------------------------------------------------
 // Gura interfaces for Object_document
 //-----------------------------------------------------------------------------
@@ -1175,16 +1279,17 @@ Gura_DeclareMethod(document, parse)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "str", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(document, parse)
 {
-	Object_document *pObj = Object_document::GetThisObj(args);
-	SimpleStream_CStringReader streamSrc(args.GetString(0));
+	Signal &sig = env.GetSignal();
+	Object_document *pObj = Object_document::GetObjectThis(arg);
+	SimpleStream_CStringReader streamSrc(arg.GetString(0));
 	pObj->GetDocument()->Parse(sig, streamSrc);
-	return Value::Null;
+	return Value::Nil;
 }
 
 // xml.document#read(stream:stream:r):void
@@ -1193,15 +1298,16 @@ Gura_DeclareMethod(document, read)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Void, FLAG_None);
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Read);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(document, read)
 {
-	Object_document *pObj = Object_document::GetThisObj(args);
-	pObj->GetDocument()->Parse(sig, args.GetStream(0));
-	return Value::Null;
+	Signal &sig = env.GetSignal();
+	Object_document *pObj = Object_document::GetObjectThis(arg);
+	pObj->GetDocument()->Parse(sig, arg.GetStream(0));
+	return Value::Nil;
 }
 
 // xml.document#textize(fancy?:boolean, tabs?:number)
@@ -1211,15 +1317,16 @@ Gura_DeclareMethod(document, textize)
 	DeclareArg(env, "fancy", VTYPE_boolean, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "tabs", VTYPE_number, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(document, textize)
 {
-	Object_document *pObj = Object_document::GetThisObj(args);
-	bool fancyFlag = args.IsValid(0)? args.GetBoolean(0) : false;
-	int cntSpace = args.Is_number(1)? args.GetInt(1) : 2;
+	Signal &sig = env.GetSignal();
+	Object_document *pObj = Object_document::GetObjectThis(arg);
+	bool fancyFlag = arg.IsValid(0)? arg.GetBoolean(0) : false;
+	int cntSpace = arg.Is_number(1)? arg.GetInt(1) : 2;
 	String strDst;
 	SimpleStream_StringWriter streamDst(strDst);
 	pObj->GetDocument()->Write(sig, streamDst,
@@ -1235,23 +1342,29 @@ Gura_DeclareMethod(document, write)
 	DeclareArg(env, "fancy", VTYPE_boolean, OCCUR_ZeroOrOnce);
 	DeclareArg(env, "tabs", VTYPE_number, OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementMethod(document, write)
 {
-	Object_document *pObj = Object_document::GetThisObj(args);
-	bool fancyFlag = args.IsValid(1)? args.GetBoolean(1) : false;
-	int cntSpace = args.Is_number(2)? args.GetInt(2) : 2;
-	pObj->GetDocument()->Write(sig, args.GetStream(0),
+	Signal &sig = env.GetSignal();
+	Object_document *pObj = Object_document::GetObjectThis(arg);
+	bool fancyFlag = arg.IsValid(1)? arg.GetBoolean(1) : false;
+	int cntSpace = arg.Is_number(2)? arg.GetInt(2) : 2;
+	pObj->GetDocument()->Write(sig, arg.GetStream(0),
 						fancyFlag, MakeIndentUnit(cntSpace).c_str());
-	return Value::Null;
+	return Value::Nil;
 }
 
 // implementation of class document
 Gura_ImplementUserClass(document)
 {
+	// Assignment of properties
+	Gura_AssignProperty(document, encoding);
+	Gura_AssignProperty(document, root);
+	Gura_AssignProperty(document, version);
+	// Assignment of methods
 	Gura_AssignMethod(document, parse);
 	Gura_AssignMethod(document, read);
 	Gura_AssignMethod(document, textize);
@@ -1262,16 +1375,16 @@ Gura_ImplementUserClass(document)
 // Iterator_attribute
 //-----------------------------------------------------------------------------
 Iterator_attribute::Iterator_attribute(AttributeOwner *pAttributeOwner) :
-						Iterator(false), _idx(0), _pAttributeOwner(pAttributeOwner)
+						Iterator(Finite), _idx(0), _pAttributeOwner(pAttributeOwner)
 {
 }
 
 Iterator *Iterator_attribute::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_attribute::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_attribute::DoNext(Environment &env, Value &value)
 {
 	if (_idx < _pAttributeOwner->size()) {
 		Attribute *pAttribute = (*_pAttributeOwner)[_idx++];
@@ -1297,16 +1410,16 @@ void Iterator_attribute::GatherFollower(Environment::Frame *pFrame, EnvironmentS
 // Iterator_element
 //-----------------------------------------------------------------------------
 Iterator_element::Iterator_element(ElementOwner *pElementOwner) :
-						Iterator(false), _idx(0), _pElementOwner(pElementOwner)
+						Iterator(Finite), _idx(0), _pElementOwner(pElementOwner)
 {
 }
 
 Iterator *Iterator_element::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_element::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_element::DoNext(Environment &env, Value &value)
 {
 	if (_idx < _pElementOwner->size()) {
 		Element *pElement = (*_pElementOwner)[_idx++];
@@ -1338,18 +1451,18 @@ Gura_DeclareFunction(parser)
 	SetClassToConstruct(Gura_UserClass(parser));
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementFunction(parser)
 {
-	Object_parser *pObj = Object_parser::GetThisObj(args);
-	if (pObj == NULL) {
+	Object_parser *pObj = Object_parser::GetObjectThis(arg);
+	if (pObj == nullptr) {
 		pObj = new Object_parser(Gura_UserClass(parser));
-		return ReturnValue(env, sig, args, Value(pObj));
+		return ReturnValue(env, arg, Value(pObj));
 	}
-	return ReturnValue(env, sig, args, args.GetThis());
+	return ReturnValue(env, arg, arg.GetValueThis());
 }
 
 // xml.element(_tagname_:string, attrs%):map {block?}
@@ -1361,41 +1474,41 @@ Gura_DeclareFunction(element)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(element));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementFunction(element)
 {
-	Element *pElement = new Element(Element::TYPE_Tag, args.GetStringSTL(0));
-	foreach_const (ValueDict, iter, args.GetValueDictArg()) {
+	Signal &sig = env.GetSignal();
+	Element *pElement = new Element(Element::TYPE_Tag, arg.GetStringSTL(0));
+	foreach_const (ValueDict, iter, arg.GetValueDictArg()) {
 		String key = iter->first.ToString(false);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		String value = iter->second.ToString(false);
-		if (sig.IsSignalled()) return Value::Null;
+		if (sig.IsSignalled()) return Value::Nil;
 		pElement->GetAttributes()->push_back(new Attribute(key, value));
 	}
-	const Expr_Block *pExprBlock = args.GetBlock(env, sig);
-	if (sig.IsSignalled()) return Value::Null;
-	if (pExprBlock != NULL) {
+	const Expr_Block *pExprBlock = arg.GetBlockCooked(env);
+	if (sig.IsSignalled()) return Value::Nil;
+	if (pExprBlock != nullptr) {
 		foreach_const (ExprList, ppExpr, pExprBlock->GetExprOwner()) {
-			SeqPostHandler *pSeqPostHandler = NULL;
-			for (const Expr *pExpr = *ppExpr; pExpr != NULL; ) {
-				Value value = pExpr->Exec2(env, sig, pSeqPostHandler);
-				if (sig.IsSignalled()) return Value::Null;
+			for (const Expr *pExpr = *ppExpr; pExpr != nullptr; ) {
+				Value value = pExpr->Exec(env);
+				if (sig.IsSignalled()) return Value::Nil;
 				if (!pElement->AddChild(env, sig, value)) {
 					sig.AddExprCause(pExpr);
-					return Value::Null;
+					return Value::Nil;
 				}
 				if (pExpr->IsCaller()) {
 					pExpr = dynamic_cast<const Expr_Caller *>(pExpr)->GetTrailer();
 				} else {
-					pExpr = NULL;
+					pExpr = nullptr;
 				}
 			}
 		}
 	}
-	args.QuitTrailer();
+	arg.QuitTrailer();
 	return Value(new Object_element(pElement));
 }
 
@@ -1405,14 +1518,14 @@ Gura_DeclareFunction(comment)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "comment", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementFunction(comment)
 {
-	Element *pElement = new Element(Element::TYPE_Comment, args.GetStringSTL(0));
-	args.QuitTrailer();
+	Element *pElement = new Element(Element::TYPE_Comment, arg.GetStringSTL(0));
+	arg.QuitTrailer();
 	return Value(new Object_element(pElement));
 }
 
@@ -1424,23 +1537,28 @@ Gura_DeclareFunction(document)
 	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetClassToConstruct(Gura_UserClass(document));
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
+		Gura_Symbol(en),
 		"");
 }
 
 Gura_ImplementFunction(document)
 {
+	Signal &sig = env.GetSignal();
 	AutoPtr<Document> pDocument(new Document());
-	if (args.Is_stream(0)) {
-		if (!pDocument->Parse(sig, args.GetStream(0))) return Value::Null;
+	if (arg.Is_stream(0)) {
+		if (!pDocument->Parse(sig, arg.GetStream(0))) return Value::Nil;
 	}
-	return ReturnValue(env, sig, args, Value(new Object_document(pDocument.release())));
+	return ReturnValue(env, arg, Value(new Object_document(pDocument.release())));
 }
 
 //-----------------------------------------------------------------------------
-// Gura interfaces for Object_stream
+// Module Entries
 //-----------------------------------------------------------------------------
-// Module entry
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
+}
+
 Gura_ModuleEntry()
 {
 	// symbol realization
