@@ -14,14 +14,16 @@ Gura_DeclareFunction(compose)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "obj", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"");
+		Gura_Symbol(en),
+		"Composes YAML text to represent the content of `obj` that consists of\n"
+		"`list`, `dict` and `string` instances.");
 }
 
 Gura_ImplementFunction(compose)
 {
+	Signal &sig = env.GetSignal();
 	String str;
-	WriterToString::Write(env, sig, str, args.GetValue(0));
+	WriterToString::Write(env, str, arg.GetValue(0));
 	return Value(str);
 }
 
@@ -31,18 +33,20 @@ Gura_DeclareFunction(parse)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "str", VTYPE_string);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"");
+		Gura_Symbol(en),
+		"Parses YAML text in `str` and returns a composition of\n"
+		"`list`, `dict` and `string` instances.");
 }
 
 Gura_ImplementFunction(parse)
 {
-	Iterator_FromString *pIterator = new Iterator_FromString(args.GetString(0));
-	if (args.IsRsltMulti()) {
-		return ReturnIterator(env, sig, args, pIterator);
+	Signal &sig = env.GetSignal();
+	Iterator_FromString *pIterator = new Iterator_FromString(arg.GetString(0));
+	if (arg.IsResultMulti()) {
+		return ReturnIterator(env, arg, pIterator);
 	}
 	Value value;
-	pIterator->Next(env, sig, value);
+	pIterator->Next(env, value);
 	Iterator::Delete(pIterator);
 	return value;
 }
@@ -53,19 +57,21 @@ Gura_DeclareFunction(read)
 	SetFuncAttr(VTYPE_any, RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Read);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"");
+		Gura_Symbol(en),
+		"Parses YAML text from `stream` and returns a composition of\n"
+		"`list`, `dict` and `string` instances.");
 }
 
 Gura_ImplementFunction(read)
 {
-	Stream &stream = args.GetStream(0);
+	Signal &sig = env.GetSignal();
+	Stream &stream = arg.GetStream(0);
 	Iterator_FromStream *pIterator = new Iterator_FromStream(sig, stream.Reference());
-	if (args.IsRsltMulti()) {
-		return ReturnIterator(env, sig, args, pIterator);
+	if (arg.IsResultMulti()) {
+		return ReturnIterator(env, arg, pIterator);
 	}
 	Value value;
-	pIterator->Next(env, sig, value);
+	pIterator->Next(env, value);
 	Iterator::Delete(pIterator);
 	return value;
 }
@@ -77,19 +83,28 @@ Gura_DeclareFunction(write)
 	DeclareArg(env, "stream", VTYPE_stream, OCCUR_Once, FLAG_Write);
 	DeclareArg(env, "obj", VTYPE_any);
 	AddHelp(
-		Gura_Symbol(en), Help::FMT_markdown,
-		"");
+		Gura_Symbol(en),
+		"Composes YAML text to represent the content of `obj` that consists of\n"
+		"`list`, `dict` and `string` instances and writes the result to `stream`.");
 }
 
 Gura_ImplementFunction(write)
 {
-	if (!WriterToStream::Write(env, sig, args.GetStream(0), args.GetValue(1))) {
-		return Value::Null;
+	Signal &sig = env.GetSignal();
+	if (!WriterToStream::Write(env, arg.GetStream(0), arg.GetValue(1))) {
+		return Value::Nil;
 	}
-	return args.GetThis();
+	return arg.GetValueThis();
+}
+
+//-----------------------------------------------------------------------------
+// Module Entries
+//-----------------------------------------------------------------------------
+Gura_ModuleValidate()
+{
+	return Version::CheckCoreVersion(GURA_VERSION, nullptr);
 }
 
-// Module entry
 Gura_ModuleEntry()
 {
 	// function assignment
@@ -118,8 +133,9 @@ int WriterToStream::WriteHandlerStub(void *ext, unsigned char *buffer, size_t si
 	return reinterpret_cast<WriterToStream *>(ext)->WriteHandler(buffer, size);
 }
 
-bool WriterToStream::Write(Environment &env, Signal sig, Stream &stream, const Value &value)
+bool WriterToStream::Write(Environment &env, Stream &stream, const Value &value)
 {
+	Signal &sig = env.GetSignal();
 	WriterToStream writer(sig, stream);
 	yaml_emitter_t emitter;
 	::yaml_emitter_initialize(&emitter);
@@ -145,8 +161,9 @@ int WriterToString::WriteHandlerStub(void *ext, unsigned char *buffer, size_t si
 	return reinterpret_cast<WriterToString *>(ext)->WriteHandler(buffer, size);
 }
 
-bool WriterToString::Write(Environment &env, Signal sig, String &str, const Value &value)
+bool WriterToString::Write(Environment &env, String &str, const Value &value)
 {
+	Signal &sig = env.GetSignal();
 	WriterToString writer(str);
 	yaml_emitter_t emitter;
 	::yaml_emitter_initialize(&emitter);
@@ -179,7 +196,7 @@ Value Stocker_Mapping::GetValue()
 //-----------------------------------------------------------------------------
 void Stocker_Sequence::Stock(const Value &value)
 {
-	_pObjList->GetList().push_back(value);
+	_pObjList->Add(value);
 }
 
 Value Stocker_Sequence::GetValue()
@@ -190,8 +207,8 @@ Value Stocker_Sequence::GetValue()
 //-----------------------------------------------------------------------------
 // Iterator_FromStream
 //-----------------------------------------------------------------------------
-Iterator_FromStream::Iterator_FromStream(Signal sig, Stream *pStream) :
-			Iterator(false), _sig(sig), _pStream(pStream), _doneFlag(false)
+Iterator_FromStream::Iterator_FromStream(Signal &sig, Stream *pStream) :
+			Iterator(Finite), _sig(sig), _pStream(pStream), _doneFlag(false)
 {
 	::yaml_parser_initialize(&_parser);
 	::yaml_parser_set_input(&_parser, ReadHandler, this);
@@ -205,11 +222,12 @@ Iterator_FromStream::~Iterator_FromStream()
 
 Iterator *Iterator_FromStream::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_FromStream::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_FromStream::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	if (_doneFlag) return false;
 	value = ExecParser(env, sig, _parser, _anchorMap);
 	_doneFlag = value.IsInvalid();
@@ -241,7 +259,7 @@ int Iterator_FromStream::ReadHandler(void *ext,
 // Iterator_FromString
 //-----------------------------------------------------------------------------
 Iterator_FromString::Iterator_FromString(const char *str) :
-									Iterator(false), _doneFlag(false)
+									Iterator(Finite), _doneFlag(false)
 {
 	::yaml_parser_initialize(&_parser);
 	::yaml_parser_set_input_string(&_parser,
@@ -255,11 +273,12 @@ Iterator_FromString::~Iterator_FromString()
 
 Iterator *Iterator_FromString::GetSource()
 {
-	return NULL;
+	return nullptr;
 }
 
-bool Iterator_FromString::DoNext(Environment &env, Signal sig, Value &value)
+bool Iterator_FromString::DoNext(Environment &env, Value &value)
 {
+	Signal &sig = env.GetSignal();
 	if (_doneFlag) return false;
 	value = ExecParser(env, sig, _parser, _anchorMap);
 	_doneFlag = value.IsInvalid();
@@ -278,7 +297,7 @@ void Iterator_FromString::GatherFollower(Environment::Frame *pFrame, Environment
 //-----------------------------------------------------------------------------
 // Parser body
 //-----------------------------------------------------------------------------
-Value ExecParser(Environment &env, Signal sig,
+Value ExecParser(Environment &env, Signal &sig,
 							yaml_parser_t &parser, AnchorMap &anchorMap)
 {
 	Value result;
@@ -310,11 +329,11 @@ Value ExecParser(Environment &env, Signal sig,
 		} else if (event.type == YAML_SCALAR_EVENT ||
 					event.type == YAML_SEQUENCE_START_EVENT ||
 					event.type == YAML_MAPPING_START_EVENT) {
-			yaml_char_t *anchor = NULL;
-			yaml_char_t *tag = NULL;
+			yaml_char_t *anchor = nullptr;
+			yaml_char_t *tag = nullptr;
 			Value value;
 			Stocker *pStockerTop =
-						stockerList.empty()? NULL : stockerList.back();
+						stockerList.empty()? nullptr : stockerList.back();
 			if (event.type == YAML_SCALAR_EVENT) {
 				anchor = event.data.scalar.anchor;
 				tag = event.data.scalar.tag;
@@ -345,12 +364,12 @@ Value ExecParser(Environment &env, Signal sig,
 				stockerList.push_back(pStocker);
 				value = pStocker->GetValue();
 			}
-			if (pStockerTop == NULL) {
+			if (pStockerTop == nullptr) {
 				result = value;
 			} else {
 				pStockerTop->Stock(value);
 			}
-			if (anchor != NULL) {
+			if (anchor != nullptr) {
 				anchorMap[reinterpret_cast<char *>(anchor)] = value;
 			}
 		} else if (event.type == YAML_ALIAS_EVENT) {
@@ -385,17 +404,17 @@ Value ExecParser(Environment &env, Signal sig,
 		}
 		::yaml_event_delete(&event);
 	}
-	if (sig.IsSignalled()) return Value::Null;
+	if (sig.IsSignalled()) return Value::Nil;
 	return result;
 }
 
 //-----------------------------------------------------------------------------
 // Emitter body
 //-----------------------------------------------------------------------------
-bool ExecEmitterSub(Environment &env, Signal sig,
+bool ExecEmitterSub(Environment &env, Signal &sig,
 								yaml_emitter_t &emitter, const Value &value);
 
-bool ExecEmitter(Environment &env, Signal sig, yaml_emitter_t &emitter,
+bool ExecEmitter(Environment &env, Signal &sig, yaml_emitter_t &emitter,
 								yaml_encoding_t encoding, const Value &value)
 {
 	do {
@@ -407,9 +426,9 @@ bool ExecEmitter(Environment &env, Signal sig, yaml_emitter_t &emitter,
 		}
 	} while (0);
 	do {
-		yaml_version_directive_t *version_directive = NULL;
-		yaml_tag_directive_t *tag_start = NULL;
-		yaml_tag_directive_t *tag_end = NULL;
+		yaml_version_directive_t *version_directive = nullptr;
+		yaml_tag_directive_t *tag_start = nullptr;
+		yaml_tag_directive_t *tag_end = nullptr;
 		int implicit = 1;
 		yaml_event_t event;
 		::yaml_document_start_event_initialize(&event,
@@ -440,13 +459,13 @@ bool ExecEmitter(Environment &env, Signal sig, yaml_emitter_t &emitter,
 	return true;
 }
 
-bool ExecEmitterSub(Environment &env, Signal sig,
+bool ExecEmitterSub(Environment &env, Signal &sig,
 								yaml_emitter_t &emitter, const Value &value)
 {
 	if (value.Is_list()) {
 		do {
-			yaml_char_t *anchor = NULL;
-			yaml_char_t *tag = NULL;
+			yaml_char_t *anchor = nullptr;
+			yaml_char_t *tag = nullptr;
 			int implicit = 0;
 			yaml_sequence_style_t style = YAML_ANY_SEQUENCE_STYLE;
 			yaml_event_t event;
@@ -469,8 +488,8 @@ bool ExecEmitterSub(Environment &env, Signal sig,
 		} while (0);
 	} else if (value.Is_dict()) {
 		do {
-			yaml_char_t *anchor = NULL;
-			yaml_char_t *tag = NULL;
+			yaml_char_t *anchor = nullptr;
+			yaml_char_t *tag = nullptr;
 			int implicit = 0;
 			yaml_mapping_style_t style = YAML_ANY_MAPPING_STYLE;
 			yaml_event_t event;
@@ -494,8 +513,8 @@ bool ExecEmitterSub(Environment &env, Signal sig,
 	} else {
 		String str = value.ToString(false);
 		if (sig.IsSignalled()) return false;
-		yaml_char_t *anchor = NULL;
-		yaml_char_t *tag = NULL;
+		yaml_char_t *anchor = nullptr;
+		yaml_char_t *tag = nullptr;
 		yaml_char_t *valueRaw =
 			reinterpret_cast<unsigned char *>(const_cast<char *>(str.c_str()));
 		size_t length = str.size();
